#========================================================================================
# package      DE_EPAGES::Product::t::LastUpdateProfile
#----------------------------------------------------------------------------------------
# description  Test LastUpdate profiles for products
#========================================================================================
package DE_EPAGES::Product::t::LastUpdateProfile;
use base DE_EPAGES::Shop::API::Test;

use strict;
use Test::More tests => 10;

use DE_EPAGES::Core::API::PerlTools qw (AddDuration);
use DE_EPAGES::Object::API::Factory qw (LoadClassByAlias);
use DE_EPAGES::Object::API::XML::ObjectImportHandler qw (ImportObjects);

use constant COUNTRYID_BERMUDA => '060';
use constant GENDER_FEMALE => 2;

sub testAddress {
    my $self = shift;

    my $Now = $self->dbi->currentDateTime;
    my $Profile = LoadClassByAlias('Customer')->lastUpdateProfile('Address');
    my $Shop = $self->shop;
    my $Customer = $Shop->child('C1');

    my $TestAddressAttrubute = sub {
        my ($Address, $AttributeName, $Value) = @_;

        $Shop->clearUpdatedObjects( $Profile, AddDuration($Now, 'seconds', 2) );
        my $Iterator = $Shop->getUpdatedObjects($Profile, $Now);
        is $Iterator->count, 0, 'pofile reset';

        $Address->set({ $AttributeName, $Value });

        $Iterator = $Shop->getUpdatedObjects($Profile, $Now);
        is $Iterator->count, 1, "Update of address attribute $AttributeName recorded";
    };

    my $BillingAddress = $Customer->get('BillingAddress');
    $TestAddressAttrubute->($BillingAddress, 'Street', 'Magdelstieg 25');
    $TestAddressAttrubute->($BillingAddress, 'CountryID', COUNTRYID_BERMUDA);
    $TestAddressAttrubute->($BillingAddress, 'Birthday', DateTime->new( year => 1988, day => 1, month => 4) );
    $TestAddressAttrubute->($BillingAddress, 'Gender', GENDER_FEMALE);
    $TestAddressAttrubute->($BillingAddress, 'BankCode', 'DE123456789');
}

sub init {
    my $self = shift;

    $self->SUPER::init;
    die 'Shop alias is not TestShop' unless $self->shop->alias eq 'TestShop';

    note 'importing import.xml';
    ImportObjects('import.xml', $self->shop->parent->pathString);
}

sub test {
    my $self = shift;

    $self->testAddress;
}

__PACKAGE__->runScript;
