package DE_EPAGES::Object::t::LastUpdate;
use base DE_EPAGES::Database::API::Test;

use strict;
use Test::More tests => 7;
use DE_EPAGES::Core::API::PerlTools qw (AddDuration);
use DE_EPAGES::Object::API::Factory qw( LoadObjectByPath LoadRootObject ExistsObjectByPath Transaction );

use constant TEST_ALIAS => 'Test';
use constant TEST_PATH => '/'.TEST_ALIAS;

## no critic qw(ProhibitMagicNumbers)

sub init {
    LoadRootObject()->insertChild('Object', { Alias => TEST_ALIAS });
}

sub cleanup {
    LoadObjectByPath(TEST_PATH)->delete if ExistsObjectByPath(TEST_PATH);
}

sub test {
    my $self = shift;
    my $dbi = $self->dbi;

    my $TestRoot = LoadObjectByPath(TEST_PATH);
    my $Site = $TestRoot->insertChild('Site', { Alias => 'TestSite' });
    my $Unit1 = $Site->insertChild('UnitOfMeasurement', {
        Alias => 'Elle',
        Type => 'length',
        Factor => '0.34',
    });

    my $Iterator = $Site->getDeletedObjects('UnitOfMeasurement', $dbi->currentDateTime);
    is $Iterator->count, 0, 'before setDeleted';

    my $GUID1 = $Unit1->guid; # remember the GUID of the deleted object
    my $Now = $dbi->currentDateTime; # remember the time before deletion

    Transaction( sub {
        $Unit1->setDeleted('UnitOfMeasurement');
        $Unit1->delete;
    });

    $Iterator = $Site->getDeletedObjects('UnitOfMeasurement', $Now);
    is $Iterator->count, 1, 'setDeleted/getDeletedObjects';
    my $hDeleted = $Iterator->next;
    is $hDeleted->{'GUID'}, $GUID1, 'GUID';
    is $hDeleted->{'PathFromSite'}, 'Elle', 'PathFromSite';
    ok abs($Now->epoch - $hDeleted->{DeletedOn}->epoch) < 2, 'DeletedOn';

    $Site->clearDeletedObjects('UnitOfMeasurement', AddDuration($Now, 'seconds', -2));
    $Iterator = $Site->getDeletedObjects('UnitOfMeasurement', $Now);
    is $Iterator->count, 1, 'clearDeletedObjects 1';

    $Site->clearDeletedObjects('UnitOfMeasurement', AddDuration($Now, 'seconds', 2));
    $Iterator = $Site->getDeletedObjects('UnitOfMeasurement', $Now);
    is $Iterator->count, 0, 'clearDeletedObjects 2';
}

__PACKAGE__->runScript;
