#========================================================================================
# package      DE_EPAGES::Order::t::LastUpdateProfile
#----------------------------------------------------------------------------------------
# description  Test LastUpdate profiles for orders
#========================================================================================
package DE_EPAGES::Order::t::LastUpdateProfile;
use base DE_EPAGES::Shop::API::Test;

use strict;
use Test::More tests => 6;

use DE_EPAGES::Core::API::PerlTools qw (AddDuration);
use DE_EPAGES::Object::API::Factory qw (LoadClassByAlias);
use DE_EPAGES::Object::API::XML::ObjectImportHandler qw (ImportObjects);

sub _initProfile {
    my $self = shift;
    my ($ProfileName) = @_;

    my $Profile = LoadClassByAlias('CustomerOrder')->lastUpdateProfile($ProfileName);
    my $Shop = $self->shop;
    my $Now = $self->dbi->currentDateTime;

    $Shop->clearUpdatedObjects( $Profile, AddDuration($Now, 'seconds', 2) );
    my $Iterator = $Shop->getUpdatedObjects($Profile, $Now);
    is $Iterator->count, 0, "no $ProfileName updates yet";

    return $Profile;
}

sub testStatus {
    my $self = shift;

    my $Shop = $self->shop;
    my $Now = $self->dbi->currentDateTime;
    # verify routine
    my $cAssertItemCount = sub {
        my ($Count, $Profile) = @_;
        my $Iterator = $Shop->getUpdatedObjects($Profile, $Now);
        is $Iterator->count, $Count, 'content updates recorded' or do {
            while (my $hUpdate = $Iterator->next) {
               note 'Updated: (' . $hUpdate->{'Object'}->id . ') ' . $hUpdate->{'Object'}->get('RelativePath');
            }
        };
    };

    # test set
    my $Profile = $self->_initProfile('Status');
    $Shop->path('TestCustomer/Orders/1234-5678')->set({'ShippedOn' => $Now });
    $cAssertItemCount->(1, $Profile);

    # test if status is set to same value.
    $Profile = $self->_initProfile('Status');
    $Shop->path('TestCustomer/Orders/1234-5678')->set({'ShippedOn' => $Now });
    $cAssertItemCount->(0, $Profile);

    # test unset
    $Profile = $self->_initProfile('Status');
    $Shop->path('TestCustomer/Orders/1234-5678')->set({'ShippedOn' => undef });
    $cAssertItemCount->(1, $Profile);
}

sub init {
    my $self = shift;

    $self->SUPER::init;
    die 'Shop alias is not TestShop' unless $self->shop->alias eq 'TestShop';

    note 'importing import.xml';
    ImportObjects('import.xml', $self->shop->parent->pathString);
}

sub test {
    my $self = shift;
    $self->testStatus;
}

__PACKAGE__->runScript;
