/*global define,window*/
define([
    'testsuite/qunit',
    'jquery',
    'ep',
    'testsuite/qunit-fixture!./packagepickup-test',
    'de_epages/usps/ui/packagepickup'
], function (QUnit, $, ep, fixture, packagepickup) {

    'use strict';
    ep.ajax = function (o) {
        var result = $.Deferred();

        if (o.data && o.data.ChangeAction === 'JSONUSPSPickUpAvailabilityRequest') {
            result.resolve({
                "CarrierRoute": "C",
                "ReturnedDate": "2014-11-09 00:00:00",
                "ReturnCode": 0,
                "DayOftheWeek": "Tuesday"
            });
        } else if (o.data && o.data.ChangeAction === 'JSONUSPSPickUpRequest') {
            result.resolve({
            	"ScheduledDay" : "07/22/2014",
                "ReturnMessage": "WTC57843902",
                "ReturnCode": 0
            });
        } else if (o.data && o.data.ChangeAction === 'JSONUSPSPickUpCancelRequest') {
            result.resolve({
                "ReturnMessage": "Your pickup request was canceled.",
                "ReturnCode": 0
            });
        }
        return result;
    };

    QUnit.module('de_epages/usps/ui/packagepickup', {
        setup: function () {
            var FakeShippingLabelId = 12345;
            fixture.init();

            packagepickup(
                $('#PickUpFields'),
                FakeShippingLabelId,
                $('#PickupDateDiv'),
                $('#PackageLocationElement'),
                $('#SpecialInstructionsElement'),
                $('#PickUpInfo'),
                $('#ConfirmationNumberDiv'),
                $('#PickUpRequestButton'),
                $('#PickUpCancelButton'),
                $('#PickUpAvailabilityButton')
            );
        },
        teardown: fixture.destroy
    });

    QUnit.test('Check if the behaviour of Availability button is as expected', 5, function () {
        var PickUpDateDiv = $('#PickupDateDiv'),
            PackageLocationElement = $('#PackageLocationElement'),
            SpecialInstructionsElement = $('#SpecialInstructionsElement'),
            PickUpRequestButton = $('#PickUpRequestButton'),
            PickUpInfo = $('#PickUpInfo'),
            PickUpCancelButton = $('#PickUpCancelButton'),
            PickUpAvailabilityButton = $('#PickUpAvailabilityButton');

        QUnit.strictEqual(
            PickUpInfo.html(),
            " ",
            'PickUpInfo should be empty before something happens. We expect the PickUpInfo element to contain a single white space'
        );

        PackageLocationElement.val('19078');
        SpecialInstructionsElement.val('test');
        PickUpAvailabilityButton.trigger('click');

        QUnit.strictEqual(
            PickUpInfo.html(),
            'Day:Tuesday Date:2014-11-09 00:00:00 Carrier Route:C',
            'The message with the Pickup Availability data is shown at Pickupinfo element. We expect display day,date and carrier route of the available service'
        );

        QUnit.strictEqual(
            PickUpRequestButton.is(':disabled'),
            false,
            'Check RequestButton element after cancel a PickUp. PickUpRequestButton is is available to change'
        );

        QUnit.strictEqual(
            PickUpAvailabilityButton.is(':disabled'),
            false,
            'Check PickUpAvailabilityButton element after cancel a PickUp. PickUpAvailabilityButton is available to change'
        );

        QUnit.strictEqual(
            PickUpCancelButton.is(':disabled'),
            true,
            'Check PickUpCancelButton element after cancel a PickUp. PickUpCancelButton is disabled and not available to use'
        );
    });

    QUnit.test('Check if the behaviour of request button is as expected', 9, function () {
        var PickUpDateDiv = $('#PickupDateDiv'),
            PackageLocationElement = $('#PackageLocationElement'),
            SpecialInstructionsElement = $('#SpecialInstructionsElement'),
            PickUpRequestButton = $('#PickUpRequestButton'),
            PickUpInfo = $('#PickUpInfo'),
            PickUpCancelButton = $('#PickUpCancelButton'),
            PickUpAvailabilityButton = $('#PickUpAvailabilityButton'),
            ConfirmationNumberDiv = $('#ConfirmationNumberDiv');

        QUnit.strictEqual(
            PickUpInfo.html(),
            " ",
            'PickUpInfo should be empty before something happens. We expect the PickUpInfo element to contain a single white space'
        );

        PackageLocationElement.val('19078');
        SpecialInstructionsElement.val('test');
        PickUpRequestButton.trigger('click');

        QUnit.strictEqual(
            PickUpInfo.html(),
            'Confirmation Number: WTC57843902',
            'Check confirmation message. The message with the Pickup Confirmation Number data is shown at Pickupinfo element.'
        );

        QUnit.strictEqual(
            ConfirmationNumberDiv.html(),
            'WTC57843902',
            'Check confirmation number. The ConfirmationNumberDiv contains the number of the petition returned by the service'
        );

        QUnit.strictEqual(
            PickUpDateDiv.html(),
            '07/22/2014',
            'Check PickupDateDiv element after schedule a PickUp. PickupDateDiv element contains the scheduled pick up date'
        );

        QUnit.strictEqual(
            PackageLocationElement.is(':disabled'),
            true,
            'Check PackageLocation element after schedule a PickUp. PackageLocation field is disable and not available to change'
        );

        QUnit.strictEqual(
            SpecialInstructionsElement.is(':disabled'),
            true,
            'Check SpecialInstructions element after schedule a PickUp. SpecialInstructions field is disable and not available to change'
        );

        QUnit.strictEqual(
            PickUpRequestButton.is(':disabled'),
            true,
            'Check RequestButton element after schedule a PickUp. PickUpRequestButton is disable and is not available to use'
        );

        QUnit.strictEqual(
            PickUpAvailabilityButton.is(':disabled'),
            true,
            'Check PickUpAvailabilityButton element after schedule a PickUp. PickUpAvailabilityButton is disable and is not available to use'
        );

        QUnit.strictEqual(
            PickUpCancelButton.is(':disabled'),
            false,
            'Check PickUpCancelButton element after schedule a PickUp. PickUpCancelButton is available to use'
        );
    });

    QUnit.test('Check if the behaviour of cancel button is as expected', 9, function () {
        var PickUpDateDiv = $('#PickupDateDiv'),
            PackageLocationElement = $('#PackageLocationElement'),
            SpecialInstructionsElement = $('#SpecialInstructionsElement'),
            PickUpRequestButton = $('#PickUpRequestButton'),
            PickUpInfo = $('#PickUpInfo'),
            PickUpCancelButton = $('#PickUpCancelButton'),
            PickUpAvailabilityButton = $('#PickUpAvailabilityButton'),
            ConfirmationNumberDiv = $('#ConfirmationNumberDiv');

        QUnit.strictEqual(
            PickUpInfo.html(),
            " ",
            'PickUpInfo should be empty before something happens. We expect the PickUpInfo element to contain a single white space'
        );

        PackageLocationElement.val('19078');
        SpecialInstructionsElement.val('test');
        PickUpCancelButton.trigger('click');

        QUnit.strictEqual(
            PickUpInfo.html(),
            'Your pickup request was canceled.',
            'Check cancelation message. The message with the Cancel Confirmation is shown at Pickupinfo element'
        );

        QUnit.strictEqual(
            ConfirmationNumberDiv.html(),
            'Canceled',
            'Check cancelation number. The ConfirmationNumberDiv contains the number of the petition returned by the service'
        );

        QUnit.strictEqual(
            PickUpDateDiv.html(),
            '-',
            'Check PickupDateDiv element after cancel a PickUp. PickupDateDiv field contains a dash'
        );

        QUnit.strictEqual(
            PackageLocationElement.is(':disabled'),
            false,
            'Check PackageLocation element after cancel a PickUp. PackageLocation field field is available to change'
        );

        QUnit.strictEqual(
            SpecialInstructionsElement.is(':disabled'),
            false,
            'Check SpecialInstructions element after cancel a PickUp. SpecialInstructions field is available to change'
        );

        QUnit.strictEqual(
            PickUpRequestButton.is(':disabled'),
            false,
            'Check RequestButton element after cancel a PickUp. PickUpRequestButton is is available to change'
        );

        QUnit.strictEqual(
            PickUpAvailabilityButton.is(':disabled'),
            false,
            'Check PickUpAvailabilityButton element after cancel a PickUp. PickUpAvailabilityButton is available to change'
        );

        QUnit.strictEqual(
            PickUpCancelButton.is(':disabled'),
            true,
            'Check PickUpCancelButton element after cancel a PickUp. PickUpCancelButton is disabled and not available to use'
        );
    });

});