#!/bin/env perl

use strict;
use DE_EPAGES::Core::API::File                        qw( GetFileContent );
use DE_EPAGES::Core::API::Log                         qw( GetLog );
use DE_EPAGES::Core::API::Script                      qw( RunScript );
use DE_EPAGES::Database::API::Config                  qw( StoreType GetBusinessUnits StoreTypesWithCartridge );
use DE_EPAGES::Database::API::Connection              qw( GetCurrentDBHandle RunOnStore);
use DE_EPAGES::Database::API::DBInterface             qw( ProcessSqlGo );


RunScript(
    'Sub' => \&Main
);

sub Main {
    local $| = 1;

    my $BU;
    push @{$BU->{StoreType($_)}}, $_ foreach @{GetBusinessUnits({conf => 1})};

    my $CartridgeVendor = 'DE_EPAGES';
    my $Cartridge       = 'Object';
    my $Package = join '::',$CartridgeVendor ,$Cartridge;
    foreach my $Store (@{_StoresWithCartridge($Package, $BU)}) {
        RunOnStore(
            Store => $Store,
            Sub => sub  {
               my $dbi = GetCurrentDBHandle();
               if($dbi->driverName() eq 'mysql'){
                  print "patch DBStructure for Cartridge $Cartridge in $Store\n";                 
                  foreach my $table (qw (lastupdateprofile lastupdate objectdelete) ){
                    #insert Object/Database/mysql/Tables/(lastupdateprofile|lastupdate|objectdelete).sql
                    unless ($dbi->existsTable($table)) {
                        print "insert table $table\n";                 
                        my $FileName = join ('/', $ENV{'EPAGES_CARTRIDGES'},$CartridgeVendor, $Cartridge, 'Database/mysql/Tables' , $table . '.sql');
                        ImportSQL($FileName);
                     }
                  }
               }
            }, );
    }
}


sub ImportSQL {
    my ($FileName) = @_;
    my $rContent = GetFileContent( $FileName );

    my $IgnoreErrors = 0;
    $IgnoreErrors = $2 if $$rContent =~ /^\s*(#|--)\s+ignore_error\s*=\s*(\S)/m;

    ProcessSqlGo( $$rContent, { ignore_error => $IgnoreErrors } );
}



sub _StoresWithCartridge ($$) {
    my ($Cartridge, $BU) = @_;

    my @Stores;
    foreach my $StoreType (@{StoreTypesWithCartridge("$Cartridge")}) {
        push @Stores, $_ foreach @{$BU->{$StoreType}};
    }
    return \@Stores;
}

1;

