

/* ---- Module:require ---- */

/** vim: et:ts=4:sw=4:sts=4
 * @license RequireJS 2.1.4 Copyright (c) 2010-2012, The Dojo Foundation All Rights Reserved.
 * Available via the MIT or new BSD license.
 * see: http://github.com/jrburke/requirejs for details
 */
//Not using strict: uneven strict support in browsers, #392, and causes
//problems with requirejs.exec()/transpiler plugins that may not be strict.
/*jslint regexp: true, nomen: true, sloppy: true */
/*global window, navigator, document, importScripts, setTimeout, opera */

var requirejs, require, define;
(function (global) {
    var req, s, head, baseElement, dataMain, src,
        interactiveScript, currentlyAddingScript, mainScript, subPath,
        version = '2.1.4',
        commentRegExp = /(\/\*([\s\S]*?)\*\/|([^:]|^)\/\/(.*)$)/mg,
        cjsRequireRegExp = /[^.]\s*require\s*\(\s*["']([^'"\s]+)["']\s*\)/g,
        jsSuffixRegExp = /\.js$/,
        currDirRegExp = /^\.\//,
        op = Object.prototype,
        ostring = op.toString,
        hasOwn = op.hasOwnProperty,
        ap = Array.prototype,
        apsp = ap.splice,
        isBrowser = !!(typeof window !== 'undefined' && navigator && document),
        isWebWorker = !isBrowser && typeof importScripts !== 'undefined',
        //PS3 indicates loaded and complete, but need to wait for complete
        //specifically. Sequence is 'loading', 'loaded', execution,
        // then 'complete'. The UA check is unfortunate, but not sure how
        //to feature test w/o causing perf issues.
        readyRegExp = isBrowser && navigator.platform === 'PLAYSTATION 3' ?
                      /^complete$/ : /^(complete|loaded)$/,
        defContextName = '_',
        //Oh the tragedy, detecting opera. See the usage of isOpera for reason.
        isOpera = typeof opera !== 'undefined' && opera.toString() === '[object Opera]',
        contexts = {},
        cfg = {},
        globalDefQueue = [],
        useInteractive = false;

    function isFunction(it) {
        return ostring.call(it) === '[object Function]';
    }

    function isArray(it) {
        return ostring.call(it) === '[object Array]';
    }

    /**
     * Helper function for iterating over an array. If the func returns
     * a true value, it will break out of the loop.
     */
    function each(ary, func) {
        if (ary) {
            var i;
            for (i = 0; i < ary.length; i += 1) {
                if (ary[i] && func(ary[i], i, ary)) {
                    break;
                }
            }
        }
    }

    /**
     * Helper function for iterating over an array backwards. If the func
     * returns a true value, it will break out of the loop.
     */
    function eachReverse(ary, func) {
        if (ary) {
            var i;
            for (i = ary.length - 1; i > -1; i -= 1) {
                if (ary[i] && func(ary[i], i, ary)) {
                    break;
                }
            }
        }
    }

    function hasProp(obj, prop) {
        return hasOwn.call(obj, prop);
    }

    function getOwn(obj, prop) {
        return hasProp(obj, prop) && obj[prop];
    }

    /**
     * Cycles over properties in an object and calls a function for each
     * property value. If the function returns a truthy value, then the
     * iteration is stopped.
     */
    function eachProp(obj, func) {
        var prop;
        for (prop in obj) {
            if (hasProp(obj, prop)) {
                if (func(obj[prop], prop)) {
                    break;
                }
            }
        }
    }

    /**
     * Simple function to mix in properties from source into target,
     * but only if target does not already have a property of the same name.
     */
    function mixin(target, source, force, deepStringMixin) {
        if (source) {
            eachProp(source, function (value, prop) {
                if (force || !hasProp(target, prop)) {
                    if (deepStringMixin && typeof value !== 'string') {
                        if (!target[prop]) {
                            target[prop] = {};
                        }
                        mixin(target[prop], value, force, deepStringMixin);
                    } else {
                        target[prop] = value;
                    }
                }
            });
        }
        return target;
    }

    //Similar to Function.prototype.bind, but the 'this' object is specified
    //first, since it is easier to read/figure out what 'this' will be.
    function bind(obj, fn) {
        return function () {
            return fn.apply(obj, arguments);
        };
    }

    function scripts() {
        return document.getElementsByTagName('script');
    }

    //Allow getting a global that expressed in
    //dot notation, like 'a.b.c'.
    function getGlobal(value) {
        if (!value) {
            return value;
        }
        var g = global;
        each(value.split('.'), function (part) {
            g = g[part];
        });
        return g;
    }

    /**
     * Constructs an error with a pointer to an URL with more information.
     * @param {String} id the error ID that maps to an ID on a web page.
     * @param {String} message human readable error.
     * @param {Error} [err] the original error, if there is one.
     *
     * @returns {Error}
     */
    function makeError(id, msg, err, requireModules) {
        var e = new Error(msg + '\nhttp://requirejs.org/docs/errors.html#' + id);
        e.requireType = id;
        e.requireModules = requireModules;
        if (err) {
            e.originalError = err;
        }
        return e;
    }

    if (typeof define !== 'undefined') {
        //If a define is already in play via another AMD loader,
        //do not overwrite.
        return;
    }

    if (typeof requirejs !== 'undefined') {
        if (isFunction(requirejs)) {
            //Do not overwrite and existing requirejs instance.
            return;
        }
        cfg = requirejs;
        requirejs = undefined;
    }

    //Allow for a require config object
    if (typeof require !== 'undefined' && !isFunction(require)) {
        //assume it is a config object.
        cfg = require;
        require = undefined;
    }

    function newContext(contextName) {
        var inCheckLoaded, Module, context, handlers,
            checkLoadedTimeoutId,
            config = {
                waitSeconds: 7,
                baseUrl: './',
                paths: {},
                pkgs: {},
                shim: {},
                map: {},
                config: {}
            },
            registry = {},
            undefEvents = {},
            defQueue = [],
            defined = {},
            urlFetched = {},
            requireCounter = 1,
            unnormalizedCounter = 1;

        /**
         * Trims the . and .. from an array of path segments.
         * It will keep a leading path segment if a .. will become
         * the first path segment, to help with module name lookups,
         * which act like paths, but can be remapped. But the end result,
         * all paths that use this function should look normalized.
         * NOTE: this method MODIFIES the input array.
         * @param {Array} ary the array of path segments.
         */
        function trimDots(ary) {
            var i, part;
            for (i = 0; ary[i]; i += 1) {
                part = ary[i];
                if (part === '.') {
                    ary.splice(i, 1);
                    i -= 1;
                } else if (part === '..') {
                    if (i === 1 && (ary[2] === '..' || ary[0] === '..')) {
                        //End of the line. Keep at least one non-dot
                        //path segment at the front so it can be mapped
                        //correctly to disk. Otherwise, there is likely
                        //no path mapping for a path starting with '..'.
                        //This can still fail, but catches the most reasonable
                        //uses of ..
                        break;
                    } else if (i > 0) {
                        ary.splice(i - 1, 2);
                        i -= 2;
                    }
                }
            }
        }

        /**
         * Given a relative module name, like ./something, normalize it to
         * a real name that can be mapped to a path.
         * @param {String} name the relative name
         * @param {String} baseName a real name that the name arg is relative
         * to.
         * @param {Boolean} applyMap apply the map config to the value. Should
         * only be done if this normalization is for a dependency ID.
         * @returns {String} normalized name
         */
        function normalize(name, baseName, applyMap) {
            var pkgName, pkgConfig, mapValue, nameParts, i, j, nameSegment,
                foundMap, foundI, foundStarMap, starI,
                baseParts = baseName && baseName.split('/'),
                normalizedBaseParts = baseParts,
                map = config.map,
                starMap = map && map['*'];

            //Adjust any relative paths.
            if (name && name.charAt(0) === '.') {
                //If have a base name, try to normalize against it,
                //otherwise, assume it is a top-level require that will
                //be relative to baseUrl in the end.
                if (baseName) {
                    if (getOwn(config.pkgs, baseName)) {
                        //If the baseName is a package name, then just treat it as one
                        //name to concat the name with.
                        normalizedBaseParts = baseParts = [baseName];
                    } else {
                        //Convert baseName to array, and lop off the last part,
                        //so that . matches that 'directory' and not name of the baseName's
                        //module. For instance, baseName of 'one/two/three', maps to
                        //'one/two/three.js', but we want the directory, 'one/two' for
                        //this normalization.
                        normalizedBaseParts = baseParts.slice(0, baseParts.length - 1);
                    }

                    name = normalizedBaseParts.concat(name.split('/'));
                    trimDots(name);

                    //Some use of packages may use a . path to reference the
                    //'main' module name, so normalize for that.
                    pkgConfig = getOwn(config.pkgs, (pkgName = name[0]));
                    name = name.join('/');
                    if (pkgConfig && name === pkgName + '/' + pkgConfig.main) {
                        name = pkgName;
                    }
                } else if (name.indexOf('./') === 0) {
                    // No baseName, so this is ID is resolved relative
                    // to baseUrl, pull off the leading dot.
                    name = name.substring(2);
                }
            }

            //Apply map config if available.
            if (applyMap && (baseParts || starMap) && map) {
                nameParts = name.split('/');

                for (i = nameParts.length; i > 0; i -= 1) {
                    nameSegment = nameParts.slice(0, i).join('/');

                    if (baseParts) {
                        //Find the longest baseName segment match in the config.
                        //So, do joins on the biggest to smallest lengths of baseParts.
                        for (j = baseParts.length; j > 0; j -= 1) {
                            mapValue = getOwn(map, baseParts.slice(0, j).join('/'));

                            //baseName segment has config, find if it has one for
                            //this name.
                            if (mapValue) {
                                mapValue = getOwn(mapValue, nameSegment);
                                if (mapValue) {
                                    //Match, update name to the new value.
                                    foundMap = mapValue;
                                    foundI = i;
                                    break;
                                }
                            }
                        }
                    }

                    if (foundMap) {
                        break;
                    }

                    //Check for a star map match, but just hold on to it,
                    //if there is a shorter segment match later in a matching
                    //config, then favor over this star map.
                    if (!foundStarMap && starMap && getOwn(starMap, nameSegment)) {
                        foundStarMap = getOwn(starMap, nameSegment);
                        starI = i;
                    }
                }

                if (!foundMap && foundStarMap) {
                    foundMap = foundStarMap;
                    foundI = starI;
                }

                if (foundMap) {
                    nameParts.splice(0, foundI, foundMap);
                    name = nameParts.join('/');
                }
            }

            return name;
        }

        function removeScript(name) {
            if (isBrowser) {
                each(scripts(), function (scriptNode) {
                    if (scriptNode.getAttribute('data-requiremodule') === name &&
                            scriptNode.getAttribute('data-requirecontext') === context.contextName) {
                        scriptNode.parentNode.removeChild(scriptNode);
                        return true;
                    }
                });
            }
        }

        function hasPathFallback(id) {
            var pathConfig = getOwn(config.paths, id);
            if (pathConfig && isArray(pathConfig) && pathConfig.length > 1) {
                removeScript(id);
                //Pop off the first array value, since it failed, and
                //retry
                pathConfig.shift();
                context.require.undef(id);
                context.require([id]);
                return true;
            }
        }

        //Turns a plugin!resource to [plugin, resource]
        //with the plugin being undefined if the name
        //did not have a plugin prefix.
        function splitPrefix(name) {
            var prefix,
                index = name ? name.indexOf('!') : -1;
            if (index > -1) {
                prefix = name.substring(0, index);
                name = name.substring(index + 1, name.length);
            }
            return [prefix, name];
        }

        /**
         * Creates a module mapping that includes plugin prefix, module
         * name, and path. If parentModuleMap is provided it will
         * also normalize the name via require.normalize()
         *
         * @param {String} name the module name
         * @param {String} [parentModuleMap] parent module map
         * for the module name, used to resolve relative names.
         * @param {Boolean} isNormalized: is the ID already normalized.
         * This is true if this call is done for a define() module ID.
         * @param {Boolean} applyMap: apply the map config to the ID.
         * Should only be true if this map is for a dependency.
         *
         * @returns {Object}
         */
        function makeModuleMap(name, parentModuleMap, isNormalized, applyMap) {
            var url, pluginModule, suffix, nameParts,
                prefix = null,
                parentName = parentModuleMap ? parentModuleMap.name : null,
                originalName = name,
                isDefine = true,
                normalizedName = '';

            //If no name, then it means it is a require call, generate an
            //internal name.
            if (!name) {
                isDefine = false;
                name = '_@r' + (requireCounter += 1);
            }

            nameParts = splitPrefix(name);
            prefix = nameParts[0];
            name = nameParts[1];

            if (prefix) {
                prefix = normalize(prefix, parentName, applyMap);
                pluginModule = getOwn(defined, prefix);
            }

            //Account for relative paths if there is a base name.
            if (name) {
                if (prefix) {
                    if (pluginModule && pluginModule.normalize) {
                        //Plugin is loaded, use its normalize method.
                        normalizedName = pluginModule.normalize(name, function (name) {
                            return normalize(name, parentName, applyMap);
                        });
                    } else {
                        normalizedName = normalize(name, parentName, applyMap);
                    }
                } else {
                    //A regular module.
                    normalizedName = normalize(name, parentName, applyMap);

                    //Normalized name may be a plugin ID due to map config
                    //application in normalize. The map config values must
                    //already be normalized, so do not need to redo that part.
                    nameParts = splitPrefix(normalizedName);
                    prefix = nameParts[0];
                    normalizedName = nameParts[1];
                    isNormalized = true;

                    url = context.nameToUrl(normalizedName);
                }
            }

            //If the id is a plugin id that cannot be determined if it needs
            //normalization, stamp it with a unique ID so two matching relative
            //ids that may conflict can be separate.
            suffix = prefix && !pluginModule && !isNormalized ?
                     '_unnormalized' + (unnormalizedCounter += 1) :
                     '';

            return {
                prefix: prefix,
                name: normalizedName,
                parentMap: parentModuleMap,
                unnormalized: !!suffix,
                url: url,
                originalName: originalName,
                isDefine: isDefine,
                id: (prefix ?
                        prefix + '!' + normalizedName :
                        normalizedName) + suffix
            };
        }

        function getModule(depMap) {
            var id = depMap.id,
                mod = getOwn(registry, id);

            if (!mod) {
                mod = registry[id] = new context.Module(depMap);
            }

            return mod;
        }

        function on(depMap, name, fn) {
            var id = depMap.id,
                mod = getOwn(registry, id);

            if (hasProp(defined, id) &&
                    (!mod || mod.defineEmitComplete)) {
                if (name === 'defined') {
                    fn(defined[id]);
                }
            } else {
                getModule(depMap).on(name, fn);
            }
        }

        function onError(err, errback) {
            var ids = err.requireModules,
                notified = false;

            if (errback) {
                errback(err);
            } else {
                each(ids, function (id) {
                    var mod = getOwn(registry, id);
                    if (mod) {
                        //Set error on module, so it skips timeout checks.
                        mod.error = err;
                        if (mod.events.error) {
                            notified = true;
                            mod.emit('error', err);
                        }
                    }
                });

                if (!notified) {
                    req.onError(err);
                }
            }
        }

        /**
         * Internal method to transfer globalQueue items to this context's
         * defQueue.
         */
        function takeGlobalQueue() {
            //Push all the globalDefQueue items into the context's defQueue
            if (globalDefQueue.length) {
                //Array splice in the values since the context code has a
                //local var ref to defQueue, so cannot just reassign the one
                //on context.
                apsp.apply(defQueue,
                           [defQueue.length - 1, 0].concat(globalDefQueue));
                globalDefQueue = [];
            }
        }

        handlers = {
            'require': function (mod) {
                if (mod.require) {
                    return mod.require;
                } else {
                    return (mod.require = context.makeRequire(mod.map));
                }
            },
            'exports': function (mod) {
                mod.usingExports = true;
                if (mod.map.isDefine) {
                    if (mod.exports) {
                        return mod.exports;
                    } else {
                        return (mod.exports = defined[mod.map.id] = {});
                    }
                }
            },
            'module': function (mod) {
                if (mod.module) {
                    return mod.module;
                } else {
                    return (mod.module = {
                        id: mod.map.id,
                        uri: mod.map.url,
                        config: function () {
                            return (config.config && getOwn(config.config, mod.map.id)) || {};
                        },
                        exports: defined[mod.map.id]
                    });
                }
            }
        };

        function cleanRegistry(id) {
            //Clean up machinery used for waiting modules.
            delete registry[id];
        }

        function breakCycle(mod, traced, processed) {
            var id = mod.map.id;

            if (mod.error) {
                mod.emit('error', mod.error);
            } else {
                traced[id] = true;
                each(mod.depMaps, function (depMap, i) {
                    var depId = depMap.id,
                        dep = getOwn(registry, depId);

                    //Only force things that have not completed
                    //being defined, so still in the registry,
                    //and only if it has not been matched up
                    //in the module already.
                    if (dep && !mod.depMatched[i] && !processed[depId]) {
                        if (getOwn(traced, depId)) {
                            mod.defineDep(i, defined[depId]);
                            mod.check(); //pass false?
                        } else {
                            breakCycle(dep, traced, processed);
                        }
                    }
                });
                processed[id] = true;
            }
        }

        function checkLoaded() {
            var map, modId, err, usingPathFallback,
                waitInterval = config.waitSeconds * 1000,
                //It is possible to disable the wait interval by using waitSeconds of 0.
                expired = waitInterval && (context.startTime + waitInterval) < new Date().getTime(),
                noLoads = [],
                reqCalls = [],
                stillLoading = false,
                needCycleCheck = true;

            //Do not bother if this call was a result of a cycle break.
            if (inCheckLoaded) {
                return;
            }

            inCheckLoaded = true;

            //Figure out the state of all the modules.
            eachProp(registry, function (mod) {
                map = mod.map;
                modId = map.id;

                //Skip things that are not enabled or in error state.
                if (!mod.enabled) {
                    return;
                }

                if (!map.isDefine) {
                    reqCalls.push(mod);
                }

                if (!mod.error) {
                    //If the module should be executed, and it has not
                    //been inited and time is up, remember it.
                    if (!mod.inited && expired) {
                        if (hasPathFallback(modId)) {
                            usingPathFallback = true;
                            stillLoading = true;
                        } else {
                            noLoads.push(modId);
                            removeScript(modId);
                        }
                    } else if (!mod.inited && mod.fetched && map.isDefine) {
                        stillLoading = true;
                        if (!map.prefix) {
                            //No reason to keep looking for unfinished
                            //loading. If the only stillLoading is a
                            //plugin resource though, keep going,
                            //because it may be that a plugin resource
                            //is waiting on a non-plugin cycle.
                            return (needCycleCheck = false);
                        }
                    }
                }
            });

            if (expired && noLoads.length) {
                //If wait time expired, throw error of unloaded modules.
                err = makeError('timeout', 'Load timeout for modules: ' + noLoads, null, noLoads);
                err.contextName = context.contextName;
                return onError(err);
            }

            //Not expired, check for a cycle.
            if (needCycleCheck) {
                each(reqCalls, function (mod) {
                    breakCycle(mod, {}, {});
                });
            }

            //If still waiting on loads, and the waiting load is something
            //other than a plugin resource, or there are still outstanding
            //scripts, then just try back later.
            if ((!expired || usingPathFallback) && stillLoading) {
                //Something is still waiting to load. Wait for it, but only
                //if a timeout is not already in effect.
                if ((isBrowser || isWebWorker) && !checkLoadedTimeoutId) {
                    checkLoadedTimeoutId = setTimeout(function () {
                        checkLoadedTimeoutId = 0;
                        checkLoaded();
                    }, 50);
                }
            }

            inCheckLoaded = false;
        }

        Module = function (map) {
            this.events = getOwn(undefEvents, map.id) || {};
            this.map = map;
            this.shim = getOwn(config.shim, map.id);
            this.depExports = [];
            this.depMaps = [];
            this.depMatched = [];
            this.pluginMaps = {};
            this.depCount = 0;

            /* this.exports this.factory
               this.depMaps = [],
               this.enabled, this.fetched
            */
        };

        Module.prototype = {
            init: function (depMaps, factory, errback, options) {
                options = options || {};

                //Do not do more inits if already done. Can happen if there
                //are multiple define calls for the same module. That is not
                //a normal, common case, but it is also not unexpected.
                if (this.inited) {
                    return;
                }

                this.factory = factory;

                if (errback) {
                    //Register for errors on this module.
                    this.on('error', errback);
                } else if (this.events.error) {
                    //If no errback already, but there are error listeners
                    //on this module, set up an errback to pass to the deps.
                    errback = bind(this, function (err) {
                        this.emit('error', err);
                    });
                }

                //Do a copy of the dependency array, so that
                //source inputs are not modified. For example
                //"shim" deps are passed in here directly, and
                //doing a direct modification of the depMaps array
                //would affect that config.
                this.depMaps = depMaps && depMaps.slice(0);

                this.errback = errback;

                //Indicate this module has be initialized
                this.inited = true;

                this.ignore = options.ignore;

                //Could have option to init this module in enabled mode,
                //or could have been previously marked as enabled. However,
                //the dependencies are not known until init is called. So
                //if enabled previously, now trigger dependencies as enabled.
                if (options.enabled || this.enabled) {
                    //Enable this module and dependencies.
                    //Will call this.check()
                    this.enable();
                } else {
                    this.check();
                }
            },

            defineDep: function (i, depExports) {
                //Because of cycles, defined callback for a given
                //export can be called more than once.
                if (!this.depMatched[i]) {
                    this.depMatched[i] = true;
                    this.depCount -= 1;
                    this.depExports[i] = depExports;
                }
            },

            fetch: function () {
                if (this.fetched) {
                    return;
                }
                this.fetched = true;

                context.startTime = (new Date()).getTime();

                var map = this.map;

                //If the manager is for a plugin managed resource,
                //ask the plugin to load it now.
                if (this.shim) {
                    context.makeRequire(this.map, {
                        enableBuildCallback: true
                    })(this.shim.deps || [], bind(this, function () {
                        return map.prefix ? this.callPlugin() : this.load();
                    }));
                } else {
                    //Regular dependency.
                    return map.prefix ? this.callPlugin() : this.load();
                }
            },

            load: function () {
                var url = this.map.url;

                //Regular dependency.
                if (!urlFetched[url]) {
                    urlFetched[url] = true;
                    context.load(this.map.id, url);
                }
            },

            /**
             * Checks is the module is ready to define itself, and if so,
             * define it.
             */
            check: function () {
                if (!this.enabled || this.enabling) {
                    return;
                }

                var err, cjsModule,
                    id = this.map.id,
                    depExports = this.depExports,
                    exports = this.exports,
                    factory = this.factory;

                if (!this.inited) {
                    this.fetch();
                } else if (this.error) {
                    this.emit('error', this.error);
                } else if (!this.defining) {
                    //The factory could trigger another require call
                    //that would result in checking this module to
                    //define itself again. If already in the process
                    //of doing that, skip this work.
                    this.defining = true;

                    if (this.depCount < 1 && !this.defined) {
                        if (isFunction(factory)) {
                            //If there is an error listener, favor passing
                            //to that instead of throwing an error.
                            if (this.events.error) {
                                try {
                                    exports = context.execCb(id, factory, depExports, exports);
                                } catch (e) {
                                    err = e;
                                }
                            } else {
                                exports = context.execCb(id, factory, depExports, exports);
                            }

                            if (this.map.isDefine) {
                                //If setting exports via 'module' is in play,
                                //favor that over return value and exports. After that,
                                //favor a non-undefined return value over exports use.
                                cjsModule = this.module;
                                if (cjsModule &&
                                        cjsModule.exports !== undefined &&
                                        //Make sure it is not already the exports value
                                        cjsModule.exports !== this.exports) {
                                    exports = cjsModule.exports;
                                } else if (exports === undefined && this.usingExports) {
                                    //exports already set the defined value.
                                    exports = this.exports;
                                }
                            }

                            if (err) {
                                err.requireMap = this.map;
                                err.requireModules = [this.map.id];
                                err.requireType = 'define';
                                return onError((this.error = err));
                            }

                        } else {
                            //Just a literal value
                            exports = factory;
                        }

                        this.exports = exports;

                        if (this.map.isDefine && !this.ignore) {
                            defined[id] = exports;

                            if (req.onResourceLoad) {
                                req.onResourceLoad(context, this.map, this.depMaps);
                            }
                        }

                        //Clean up
                        delete registry[id];

                        this.defined = true;
                    }

                    //Finished the define stage. Allow calling check again
                    //to allow define notifications below in the case of a
                    //cycle.
                    this.defining = false;

                    if (this.defined && !this.defineEmitted) {
                        this.defineEmitted = true;
                        this.emit('defined', this.exports);
                        this.defineEmitComplete = true;
                    }

                }
            },

            callPlugin: function () {
                var map = this.map,
                    id = map.id,
                    //Map already normalized the prefix.
                    pluginMap = makeModuleMap(map.prefix);

                //Mark this as a dependency for this plugin, so it
                //can be traced for cycles.
                this.depMaps.push(pluginMap);

                on(pluginMap, 'defined', bind(this, function (plugin) {
                    var load, normalizedMap, normalizedMod,
                        name = this.map.name,
                        parentName = this.map.parentMap ? this.map.parentMap.name : null,
                        localRequire = context.makeRequire(map.parentMap, {
                            enableBuildCallback: true
                        });

                    //If current map is not normalized, wait for that
                    //normalized name to load instead of continuing.
                    if (this.map.unnormalized) {
                        //Normalize the ID if the plugin allows it.
                        if (plugin.normalize) {
                            name = plugin.normalize(name, function (name) {
                                return normalize(name, parentName, true);
                            }) || '';
                        }

                        //prefix and name should already be normalized, no need
                        //for applying map config again either.
                        normalizedMap = makeModuleMap(map.prefix + '!' + name,
                                                      this.map.parentMap);
                        on(normalizedMap,
                            'defined', bind(this, function (value) {
                                this.init([], function () { return value; }, null, {
                                    enabled: true,
                                    ignore: true
                                });
                            }));

                        normalizedMod = getOwn(registry, normalizedMap.id);
                        if (normalizedMod) {
                            //Mark this as a dependency for this plugin, so it
                            //can be traced for cycles.
                            this.depMaps.push(normalizedMap);

                            if (this.events.error) {
                                normalizedMod.on('error', bind(this, function (err) {
                                    this.emit('error', err);
                                }));
                            }
                            normalizedMod.enable();
                        }

                        return;
                    }

                    load = bind(this, function (value) {
                        this.init([], function () { return value; }, null, {
                            enabled: true
                        });
                    });

                    load.error = bind(this, function (err) {
                        this.inited = true;
                        this.error = err;
                        err.requireModules = [id];

                        //Remove temp unnormalized modules for this module,
                        //since they will never be resolved otherwise now.
                        eachProp(registry, function (mod) {
                            if (mod.map.id.indexOf(id + '_unnormalized') === 0) {
                                cleanRegistry(mod.map.id);
                            }
                        });

                        onError(err);
                    });

                    //Allow plugins to load other code without having to know the
                    //context or how to 'complete' the load.
                    load.fromText = bind(this, function (text, textAlt) {
                        /*jslint evil: true */
                        var moduleName = map.name,
                            moduleMap = makeModuleMap(moduleName),
                            hasInteractive = useInteractive;

                        //As of 2.1.0, support just passing the text, to reinforce
                        //fromText only being called once per resource. Still
                        //support old style of passing moduleName but discard
                        //that moduleName in favor of the internal ref.
                        if (textAlt) {
                            text = textAlt;
                        }

                        //Turn off interactive script matching for IE for any define
                        //calls in the text, then turn it back on at the end.
                        if (hasInteractive) {
                            useInteractive = false;
                        }

                        //Prime the system by creating a module instance for
                        //it.
                        getModule(moduleMap);

                        //Transfer any config to this other module.
                        if (hasProp(config.config, id)) {
                            config.config[moduleName] = config.config[id];
                        }

                        try {
                            req.exec(text);
                        } catch (e) {
                            return onError(makeError('fromtexteval',
                                             'fromText eval for ' + id +
                                            ' failed: ' + e,
                                             e,
                                             [id]));
                        }

                        if (hasInteractive) {
                            useInteractive = true;
                        }

                        //Mark this as a dependency for the plugin
                        //resource
                        this.depMaps.push(moduleMap);

                        //Support anonymous modules.
                        context.completeLoad(moduleName);

                        //Bind the value of that module to the value for this
                        //resource ID.
                        localRequire([moduleName], load);
                    });

                    //Use parentName here since the plugin's name is not reliable,
                    //could be some weird string with no path that actually wants to
                    //reference the parentName's path.
                    plugin.load(map.name, localRequire, load, config);
                }));

                context.enable(pluginMap, this);
                this.pluginMaps[pluginMap.id] = pluginMap;
            },

            enable: function () {
                this.enabled = true;

                //Set flag mentioning that the module is enabling,
                //so that immediate calls to the defined callbacks
                //for dependencies do not trigger inadvertent load
                //with the depCount still being zero.
                this.enabling = true;

                //Enable each dependency
                each(this.depMaps, bind(this, function (depMap, i) {
                    var id, mod, handler;

                    if (typeof depMap === 'string') {
                        //Dependency needs to be converted to a depMap
                        //and wired up to this module.
                        depMap = makeModuleMap(depMap,
                                               (this.map.isDefine ? this.map : this.map.parentMap),
                                               false,
                                               !this.skipMap);
                        this.depMaps[i] = depMap;

                        handler = getOwn(handlers, depMap.id);

                        if (handler) {
                            this.depExports[i] = handler(this);
                            return;
                        }

                        this.depCount += 1;

                        on(depMap, 'defined', bind(this, function (depExports) {
                            this.defineDep(i, depExports);
                            this.check();
                        }));

                        if (this.errback) {
                            on(depMap, 'error', this.errback);
                        }
                    }

                    id = depMap.id;
                    mod = registry[id];

                    //Skip special modules like 'require', 'exports', 'module'
                    //Also, don't call enable if it is already enabled,
                    //important in circular dependency cases.
                    if (!hasProp(handlers, id) && mod && !mod.enabled) {
                        context.enable(depMap, this);
                    }
                }));

                //Enable each plugin that is used in
                //a dependency
                eachProp(this.pluginMaps, bind(this, function (pluginMap) {
                    var mod = getOwn(registry, pluginMap.id);
                    if (mod && !mod.enabled) {
                        context.enable(pluginMap, this);
                    }
                }));

                this.enabling = false;

                this.check();
            },

            on: function (name, cb) {
                var cbs = this.events[name];
                if (!cbs) {
                    cbs = this.events[name] = [];
                }
                cbs.push(cb);
            },

            emit: function (name, evt) {
                each(this.events[name], function (cb) {
                    cb(evt);
                });
                if (name === 'error') {
                    //Now that the error handler was triggered, remove
                    //the listeners, since this broken Module instance
                    //can stay around for a while in the registry.
                    delete this.events[name];
                }
            }
        };

        function callGetModule(args) {
            //Skip modules already defined.
            if (!hasProp(defined, args[0])) {
                getModule(makeModuleMap(args[0], null, true)).init(args[1], args[2]);
            }
        }

        function removeListener(node, func, name, ieName) {
            //Favor detachEvent because of IE9
            //issue, see attachEvent/addEventListener comment elsewhere
            //in this file.
            if (node.detachEvent && !isOpera) {
                //Probably IE. If not it will throw an error, which will be
                //useful to know.
                if (ieName) {
                    node.detachEvent(ieName, func);
                }
            } else {
                node.removeEventListener(name, func, false);
            }
        }

        /**
         * Given an event from a script node, get the requirejs info from it,
         * and then removes the event listeners on the node.
         * @param {Event} evt
         * @returns {Object}
         */
        function getScriptData(evt) {
            //Using currentTarget instead of target for Firefox 2.0's sake. Not
            //all old browsers will be supported, but this one was easy enough
            //to support and still makes sense.
            var node = evt.currentTarget || evt.srcElement;

            //Remove the listeners once here.
            removeListener(node, context.onScriptLoad, 'load', 'onreadystatechange');
            removeListener(node, context.onScriptError, 'error');

            return {
                node: node,
                id: node && node.getAttribute('data-requiremodule')
            };
        }

        function intakeDefines() {
            var args;

            //Any defined modules in the global queue, intake them now.
            takeGlobalQueue();

            //Make sure any remaining defQueue items get properly processed.
            while (defQueue.length) {
                args = defQueue.shift();
                if (args[0] === null) {
                    return onError(makeError('mismatch', 'Mismatched anonymous define() module: ' + args[args.length - 1]));
                } else {
                    //args are id, deps, factory. Should be normalized by the
                    //define() function.
                    callGetModule(args);
                }
            }
        }

        context = {
            config: config,
            contextName: contextName,
            registry: registry,
            defined: defined,
            urlFetched: urlFetched,
            defQueue: defQueue,
            Module: Module,
            makeModuleMap: makeModuleMap,
            nextTick: req.nextTick,

            /**
             * Set a configuration for the context.
             * @param {Object} cfg config object to integrate.
             */
            configure: function (cfg) {
                //Make sure the baseUrl ends in a slash.
                if (cfg.baseUrl) {
                    if (cfg.baseUrl.charAt(cfg.baseUrl.length - 1) !== '/') {
                        cfg.baseUrl += '/';
                    }
                }

                //Save off the paths and packages since they require special processing,
                //they are additive.
                var pkgs = config.pkgs,
                    shim = config.shim,
                    objs = {
                        paths: true,
                        config: true,
                        map: true
                    };

                eachProp(cfg, function (value, prop) {
                    if (objs[prop]) {
                        if (prop === 'map') {
                            mixin(config[prop], value, true, true);
                        } else {
                            mixin(config[prop], value, true);
                        }
                    } else {
                        config[prop] = value;
                    }
                });

                //Merge shim
                if (cfg.shim) {
                    eachProp(cfg.shim, function (value, id) {
                        //Normalize the structure
                        if (isArray(value)) {
                            value = {
                                deps: value
                            };
                        }
                        if ((value.exports || value.init) && !value.exportsFn) {
                            value.exportsFn = context.makeShimExports(value);
                        }
                        shim[id] = value;
                    });
                    config.shim = shim;
                }

                //Adjust packages if necessary.
                if (cfg.packages) {
                    each(cfg.packages, function (pkgObj) {
                        var location;

                        pkgObj = typeof pkgObj === 'string' ? { name: pkgObj } : pkgObj;
                        location = pkgObj.location;

                        //Create a brand new object on pkgs, since currentPackages can
                        //be passed in again, and config.pkgs is the internal transformed
                        //state for all package configs.
                        pkgs[pkgObj.name] = {
                            name: pkgObj.name,
                            location: location || pkgObj.name,
                            //Remove leading dot in main, so main paths are normalized,
                            //and remove any trailing .js, since different package
                            //envs have different conventions: some use a module name,
                            //some use a file name.
                            main: (pkgObj.main || 'main')
                                  .replace(currDirRegExp, '')
                                  .replace(jsSuffixRegExp, '')
                        };
                    });

                    //Done with modifications, assing packages back to context config
                    config.pkgs = pkgs;
                }

                //If there are any "waiting to execute" modules in the registry,
                //update the maps for them, since their info, like URLs to load,
                //may have changed.
                eachProp(registry, function (mod, id) {
                    //If module already has init called, since it is too
                    //late to modify them, and ignore unnormalized ones
                    //since they are transient.
                    if (!mod.inited && !mod.map.unnormalized) {
                        mod.map = makeModuleMap(id);
                    }
                });

                //If a deps array or a config callback is specified, then call
                //require with those args. This is useful when require is defined as a
                //config object before require.js is loaded.
                if (cfg.deps || cfg.callback) {
                    context.require(cfg.deps || [], cfg.callback);
                }
            },

            makeShimExports: function (value) {
                function fn() {
                    var ret;
                    if (value.init) {
                        ret = value.init.apply(global, arguments);
                    }
                    return ret || (value.exports && getGlobal(value.exports));
                }
                return fn;
            },

            makeRequire: function (relMap, options) {
                options = options || {};

                function localRequire(deps, callback, errback) {
                    var id, map, requireMod;

                    if (options.enableBuildCallback && callback && isFunction(callback)) {
                        callback.__requireJsBuild = true;
                    }

                    if (typeof deps === 'string') {
                        if (isFunction(callback)) {
                            //Invalid call
                            return onError(makeError('requireargs', 'Invalid require call'), errback);
                        }

                        //If require|exports|module are requested, get the
                        //value for them from the special handlers. Caveat:
                        //this only works while module is being defined.
                        if (relMap && hasProp(handlers, deps)) {
                            return handlers[deps](registry[relMap.id]);
                        }

                        //Synchronous access to one module. If require.get is
                        //available (as in the Node adapter), prefer that.
                        if (req.get) {
                            return req.get(context, deps, relMap);
                        }

                        //Normalize module name, if it contains . or ..
                        map = makeModuleMap(deps, relMap, false, true);
                        id = map.id;

                        if (!hasProp(defined, id)) {
                            return onError(makeError('notloaded', 'Module name "' +
                                        id +
                                        '" has not been loaded yet for context: ' +
                                        contextName +
                                        (relMap ? '' : '. Use require([])')));
                        }
                        return defined[id];
                    }

                    //Grab defines waiting in the global queue.
                    intakeDefines();

                    //Mark all the dependencies as needing to be loaded.
                    context.nextTick(function () {
                        //Some defines could have been added since the
                        //require call, collect them.
                        intakeDefines();

                        requireMod = getModule(makeModuleMap(null, relMap));

                        //Store if map config should be applied to this require
                        //call for dependencies.
                        requireMod.skipMap = options.skipMap;

                        requireMod.init(deps, callback, errback, {
                            enabled: true
                        });

                        checkLoaded();
                    });

                    return localRequire;
                }

                mixin(localRequire, {
                    isBrowser: isBrowser,

                    /**
                     * Converts a module name + .extension into an URL path.
                     * *Requires* the use of a module name. It does not support using
                     * plain URLs like nameToUrl.
                     */
                    toUrl: function (moduleNamePlusExt) {
                        var ext, url,
                            index = moduleNamePlusExt.lastIndexOf('.'),
                            segment = moduleNamePlusExt.split('/')[0],
                            isRelative = segment === '.' || segment === '..';

                        //Have a file extension alias, and it is not the
                        //dots from a relative path.
                        if (index !== -1 && (!isRelative || index > 1)) {
                            ext = moduleNamePlusExt.substring(index, moduleNamePlusExt.length);
                            moduleNamePlusExt = moduleNamePlusExt.substring(0, index);
                        }

                        url = context.nameToUrl(normalize(moduleNamePlusExt,
                                                relMap && relMap.id, true), ext || '.fake');
                        return ext ? url : url.substring(0, url.length - 5);
                    },

                    defined: function (id) {
                        return hasProp(defined, makeModuleMap(id, relMap, false, true).id);
                    },

                    specified: function (id) {
                        id = makeModuleMap(id, relMap, false, true).id;
                        return hasProp(defined, id) || hasProp(registry, id);
                    }
                });

                //Only allow undef on top level require calls
                if (!relMap) {
                    localRequire.undef = function (id) {
                        //Bind any waiting define() calls to this context,
                        //fix for #408
                        takeGlobalQueue();

                        var map = makeModuleMap(id, relMap, true),
                            mod = getOwn(registry, id);

                        delete defined[id];
                        delete urlFetched[map.url];
                        delete undefEvents[id];

                        if (mod) {
                            //Hold on to listeners in case the
                            //module will be attempted to be reloaded
                            //using a different config.
                            if (mod.events.defined) {
                                undefEvents[id] = mod.events;
                            }

                            cleanRegistry(id);
                        }
                    };
                }

                return localRequire;
            },

            /**
             * Called to enable a module if it is still in the registry
             * awaiting enablement. A second arg, parent, the parent module,
             * is passed in for context, when this method is overriden by
             * the optimizer. Not shown here to keep code compact.
             */
            enable: function (depMap) {
                var mod = getOwn(registry, depMap.id);
                if (mod) {
                    getModule(depMap).enable();
                }
            },

            /**
             * Internal method used by environment adapters to complete a load event.
             * A load event could be a script load or just a load pass from a synchronous
             * load call.
             * @param {String} moduleName the name of the module to potentially complete.
             */
            completeLoad: function (moduleName) {
                var found, args, mod,
                    shim = getOwn(config.shim, moduleName) || {},
                    shExports = shim.exports;

                takeGlobalQueue();

                while (defQueue.length) {
                    args = defQueue.shift();
                    if (args[0] === null) {
                        args[0] = moduleName;
                        //If already found an anonymous module and bound it
                        //to this name, then this is some other anon module
                        //waiting for its completeLoad to fire.
                        if (found) {
                            break;
                        }
                        found = true;
                    } else if (args[0] === moduleName) {
                        //Found matching define call for this script!
                        found = true;
                    }

                    callGetModule(args);
                }

                //Do this after the cycle of callGetModule in case the result
                //of those calls/init calls changes the registry.
                mod = getOwn(registry, moduleName);

                if (!found && !hasProp(defined, moduleName) && mod && !mod.inited) {
                    if (config.enforceDefine && (!shExports || !getGlobal(shExports))) {
                        if (hasPathFallback(moduleName)) {
                            return;
                        } else {
                            return onError(makeError('nodefine',
                                             'No define call for ' + moduleName,
                                             null,
                                             [moduleName]));
                        }
                    } else {
                        //A script that does not call define(), so just simulate
                        //the call for it.
                        callGetModule([moduleName, (shim.deps || []), shim.exportsFn]);
                    }
                }

                checkLoaded();
            },

            /**
             * Converts a module name to a file path. Supports cases where
             * moduleName may actually be just an URL.
             * Note that it **does not** call normalize on the moduleName,
             * it is assumed to have already been normalized. This is an
             * internal API, not a public one. Use toUrl for the public API.
             */
            nameToUrl: function (moduleName, ext) {
                var paths, pkgs, pkg, pkgPath, syms, i, parentModule, url,
                    parentPath;

                //If a colon is in the URL, it indicates a protocol is used and it is just
                //an URL to a file, or if it starts with a slash, contains a query arg (i.e. ?)
                //or ends with .js, then assume the user meant to use an url and not a module id.
                //The slash is important for protocol-less URLs as well as full paths.
                if (req.jsExtRegExp.test(moduleName)) {
                    //Just a plain path, not module name lookup, so just return it.
                    //Add extension if it is included. This is a bit wonky, only non-.js things pass
                    //an extension, this method probably needs to be reworked.
                    url = moduleName + (ext || '');
                } else {
                    //A module that needs to be converted to a path.
                    paths = config.paths;
                    pkgs = config.pkgs;

                    syms = moduleName.split('/');
                    //For each module name segment, see if there is a path
                    //registered for it. Start with most specific name
                    //and work up from it.
                    for (i = syms.length; i > 0; i -= 1) {
                        parentModule = syms.slice(0, i).join('/');
                        pkg = getOwn(pkgs, parentModule);
                        parentPath = getOwn(paths, parentModule);
                        if (parentPath) {
                            //If an array, it means there are a few choices,
                            //Choose the one that is desired
                            if (isArray(parentPath)) {
                                parentPath = parentPath[0];
                            }
                            syms.splice(0, i, parentPath);
                            break;
                        } else if (pkg) {
                            //If module name is just the package name, then looking
                            //for the main module.
                            if (moduleName === pkg.name) {
                                pkgPath = pkg.location + '/' + pkg.main;
                            } else {
                                pkgPath = pkg.location;
                            }
                            syms.splice(0, i, pkgPath);
                            break;
                        }
                    }

                    //Join the path parts together, then figure out if baseUrl is needed.
                    url = syms.join('/');
                    url += (ext || (/\?/.test(url) ? '' : '.js'));
                    url = (url.charAt(0) === '/' || url.match(/^[\w\+\.\-]+:/) ? '' : config.baseUrl) + url;
                }

                return config.urlArgs ? url +
                                        ((url.indexOf('?') === -1 ? '?' : '&') +
                                         config.urlArgs) : url;
            },

            //Delegates to req.load. Broken out as a separate function to
            //allow overriding in the optimizer.
            load: function (id, url) {
                req.load(context, id, url);
            },

            /**
             * Executes a module callack function. Broken out as a separate function
             * solely to allow the build system to sequence the files in the built
             * layer in the right sequence.
             *
             * @private
             */
            execCb: function (name, callback, args, exports) {
                return callback.apply(exports, args);
            },

            /**
             * callback for script loads, used to check status of loading.
             *
             * @param {Event} evt the event from the browser for the script
             * that was loaded.
             */
            onScriptLoad: function (evt) {
                //Using currentTarget instead of target for Firefox 2.0's sake. Not
                //all old browsers will be supported, but this one was easy enough
                //to support and still makes sense.
                if (evt.type === 'load' ||
                        (readyRegExp.test((evt.currentTarget || evt.srcElement).readyState))) {
                    //Reset interactive script so a script node is not held onto for
                    //to long.
                    interactiveScript = null;

                    //Pull out the name of the module and the context.
                    var data = getScriptData(evt);
                    context.completeLoad(data.id);
                }
            },

            /**
             * Callback for script errors.
             */
            onScriptError: function (evt) {
                var data = getScriptData(evt);
                if (!hasPathFallback(data.id)) {
                    return onError(makeError('scripterror', 'Script error', evt, [data.id]));
                }
            }
        };

        context.require = context.makeRequire();
        return context;
    }

    /**
     * Main entry point.
     *
     * If the only argument to require is a string, then the module that
     * is represented by that string is fetched for the appropriate context.
     *
     * If the first argument is an array, then it will be treated as an array
     * of dependency string names to fetch. An optional function callback can
     * be specified to execute when all of those dependencies are available.
     *
     * Make a local req variable to help Caja compliance (it assumes things
     * on a require that are not standardized), and to give a short
     * name for minification/local scope use.
     */
    req = requirejs = function (deps, callback, errback, optional) {

        //Find the right context, use default
        var context, config,
            contextName = defContextName;

        // Determine if have config object in the call.
        if (!isArray(deps) && typeof deps !== 'string') {
            // deps is a config object
            config = deps;
            if (isArray(callback)) {
                // Adjust args if there are dependencies
                deps = callback;
                callback = errback;
                errback = optional;
            } else {
                deps = [];
            }
        }

        if (config && config.context) {
            contextName = config.context;
        }

        context = getOwn(contexts, contextName);
        if (!context) {
            context = contexts[contextName] = req.s.newContext(contextName);
        }

        if (config) {
            context.configure(config);
        }

        return context.require(deps, callback, errback);
    };

    /**
     * Support require.config() to make it easier to cooperate with other
     * AMD loaders on globally agreed names.
     */
    req.config = function (config) {
        return req(config);
    };

    /**
     * Execute something after the current tick
     * of the event loop. Override for other envs
     * that have a better solution than setTimeout.
     * @param  {Function} fn function to execute later.
     */
    req.nextTick = typeof setTimeout !== 'undefined' ? function (fn) {
        setTimeout(fn, 4);
    } : function (fn) { fn(); };

    /**
     * Export require as a global, but only if it does not already exist.
     */
    if (!require) {
        require = req;
    }

    req.version = version;

    //Used to filter out dependencies that are already paths.
    req.jsExtRegExp = /^\/|:|\?|\.js$/;
    req.isBrowser = isBrowser;
    s = req.s = {
        contexts: contexts,
        newContext: newContext
    };

    //Create default context.
    req({});

    //Exports some context-sensitive methods on global require.
    each([
        'toUrl',
        'undef',
        'defined',
        'specified'
    ], function (prop) {
        //Reference from contexts instead of early binding to default context,
        //so that during builds, the latest instance of the default context
        //with its config gets used.
        req[prop] = function () {
            var ctx = contexts[defContextName];
            return ctx.require[prop].apply(ctx, arguments);
        };
    });

    if (isBrowser) {
        head = s.head = document.getElementsByTagName('head')[0];
        //If BASE tag is in play, using appendChild is a problem for IE6.
        //When that browser dies, this can be removed. Details in this jQuery bug:
        //http://dev.jquery.com/ticket/2709
        baseElement = document.getElementsByTagName('base')[0];
        if (baseElement) {
            head = s.head = baseElement.parentNode;
        }
    }

    /**
     * Any errors that require explicitly generates will be passed to this
     * function. Intercept/override it if you want custom error handling.
     * @param {Error} err the error object.
     */
    req.onError = function (err) {
        throw err;
    };

    /**
     * Does the request to load a module for the browser case.
     * Make this a separate function to allow other environments
     * to override it.
     *
     * @param {Object} context the require context to find state.
     * @param {String} moduleName the name of the module.
     * @param {Object} url the URL to the module.
     */
    req.load = function (context, moduleName, url) {
        var config = (context && context.config) || {},
            node;
        if (isBrowser) {
            //In the browser so use a script tag
            node = config.xhtml ?
                    document.createElementNS('http://www.w3.org/1999/xhtml', 'html:script') :
                    document.createElement('script');
            node.type = config.scriptType || 'text/javascript';
            node.charset = 'utf-8';
            node.async = true;

            node.setAttribute('data-requirecontext', context.contextName);
            node.setAttribute('data-requiremodule', moduleName);

            //Set up load listener. Test attachEvent first because IE9 has
            //a subtle issue in its addEventListener and script onload firings
            //that do not match the behavior of all other browsers with
            //addEventListener support, which fire the onload event for a
            //script right after the script execution. See:
            //https://connect.microsoft.com/IE/feedback/details/648057/script-onload-event-is-not-fired-immediately-after-script-execution
            //UNFORTUNATELY Opera implements attachEvent but does not follow the script
            //script execution mode.
            if (node.attachEvent &&
                    //Check if node.attachEvent is artificially added by custom script or
                    //natively supported by browser
                    //read https://github.com/jrburke/requirejs/issues/187
                    //if we can NOT find [native code] then it must NOT natively supported.
                    //in IE8, node.attachEvent does not have toString()
                    //Note the test for "[native code" with no closing brace, see:
                    //https://github.com/jrburke/requirejs/issues/273
                    !(node.attachEvent.toString && node.attachEvent.toString().indexOf('[native code') < 0) &&
                    !isOpera) {
                //Probably IE. IE (at least 6-8) do not fire
                //script onload right after executing the script, so
                //we cannot tie the anonymous define call to a name.
                //However, IE reports the script as being in 'interactive'
                //readyState at the time of the define call.
                useInteractive = true;

                node.attachEvent('onreadystatechange', context.onScriptLoad);
                //It would be great to add an error handler here to catch
                //404s in IE9+. However, onreadystatechange will fire before
                //the error handler, so that does not help. If addEvenListener
                //is used, then IE will fire error before load, but we cannot
                //use that pathway given the connect.microsoft.com issue
                //mentioned above about not doing the 'script execute,
                //then fire the script load event listener before execute
                //next script' that other browsers do.
                //Best hope: IE10 fixes the issues,
                //and then destroys all installs of IE 6-9.
                //node.attachEvent('onerror', context.onScriptError);
            } else {
                node.addEventListener('load', context.onScriptLoad, false);
                node.addEventListener('error', context.onScriptError, false);
            }
            node.src = url;

            //For some cache cases in IE 6-8, the script executes before the end
            //of the appendChild execution, so to tie an anonymous define
            //call to the module name (which is stored on the node), hold on
            //to a reference to this node, but clear after the DOM insertion.
            currentlyAddingScript = node;
            if (baseElement) {
                head.insertBefore(node, baseElement);
            } else {
                head.appendChild(node);
            }
            currentlyAddingScript = null;

            return node;
        } else if (isWebWorker) {
            //In a web worker, use importScripts. This is not a very
            //efficient use of importScripts, importScripts will block until
            //its script is downloaded and evaluated. However, if web workers
            //are in play, the expectation that a build has been done so that
            //only one script needs to be loaded anyway. This may need to be
            //reevaluated if other use cases become common.
            importScripts(url);

            //Account for anonymous modules
            context.completeLoad(moduleName);
        }
    };

    function getInteractiveScript() {
        if (interactiveScript && interactiveScript.readyState === 'interactive') {
            return interactiveScript;
        }

        eachReverse(scripts(), function (script) {
            if (script.readyState === 'interactive') {
                return (interactiveScript = script);
            }
        });
        return interactiveScript;
    }

    //Look for a data-main script attribute, which could also adjust the baseUrl.
    if (isBrowser) {
        //Figure out baseUrl. Get it from the script tag with require.js in it.
        eachReverse(scripts(), function (script) {
            //Set the 'head' where we can append children by
            //using the script's parent.
            if (!head) {
                head = script.parentNode;
            }

            //Look for a data-main attribute to set main script for the page
            //to load. If it is there, the path to data main becomes the
            //baseUrl, if it is not already set.
            dataMain = script.getAttribute('data-main');
            if (dataMain) {
                //Set final baseUrl if there is not already an explicit one.
                if (!cfg.baseUrl) {
                    //Pull off the directory of data-main for use as the
                    //baseUrl.
                    src = dataMain.split('/');
                    mainScript = src.pop();
                    subPath = src.length ? src.join('/')  + '/' : './';

                    cfg.baseUrl = subPath;
                    dataMain = mainScript;
                }

                //Strip off any trailing .js since dataMain is now
                //like a module name.
                dataMain = dataMain.replace(jsSuffixRegExp, '');

                //Put the data-main script in the files to load.
                cfg.deps = cfg.deps ? cfg.deps.concat(dataMain) : [dataMain];

                return true;
            }
        });
    }

    /**
     * The function that handles definitions of modules. Differs from
     * require() in that a string for the module should be the first argument,
     * and the function to execute after dependencies are loaded should
     * return a value to define the module corresponding to the first argument's
     * name.
     */
    define = function (name, deps, callback) {
        var node, context;

        //Allow for anonymous modules
        if (typeof name !== 'string') {
            //Adjust args appropriately
            callback = deps;
            deps = name;
            name = null;
        }

        //This module may not have dependencies
        if (!isArray(deps)) {
            callback = deps;
            deps = [];
        }

        //If no name, and callback is a function, then figure out if it a
        //CommonJS thing with dependencies.
        if (!deps.length && isFunction(callback)) {
            //Remove comments from the callback string,
            //look for require calls, and pull them into the dependencies,
            //but only if there are function args.
            if (callback.length) {
                callback
                    .toString()
                    .replace(commentRegExp, '')
                    .replace(cjsRequireRegExp, function (match, dep) {
                        deps.push(dep);
                    });

                //May be a CommonJS thing even without require calls, but still
                //could use exports, and module. Avoid doing exports and module
                //work though if it just needs require.
                //REQUIRES the function to expect the CommonJS variables in the
                //order listed below.
                deps = (callback.length === 1 ? ['require'] : ['require', 'exports', 'module']).concat(deps);
            }
        }

        //If in IE 6-8 and hit an anonymous define() call, do the interactive
        //work.
        if (useInteractive) {
            node = currentlyAddingScript || getInteractiveScript();
            if (node) {
                if (!name) {
                    name = node.getAttribute('data-requiremodule');
                }
                context = contexts[node.getAttribute('data-requirecontext')];
            }
        }

        //Always save off evaluating the def call until the script onload handler.
        //This allows multiple modules to be in a file without prematurely
        //tracing dependencies, and allows for anonymous module support,
        //where the module name is not known until the script onload event
        //occurs. If no context, use the global queue, and get it processed
        //in the onscript load callback.
        (context ? context.defQueue : globalDefQueue).push([name, deps, callback]);
    };

    define.amd = {
        jQuery: true
    };


    /**
     * Executes the text. Normally just uses eval, but can be modified
     * to use a better, environment-specific call. Only used for transpiling
     * loader plugins, not for plain JS modules.
     * @param {String} text the text to execute/evaluate.
     */
    req.exec = function (text) {
        /*jslint evil: true */
        return eval(text);
    };

    //Set up with config info.
    req(cfg);
}(this));


require({
	paths: {
		"$dict": "require/$dict",
		"$i18n": "require/$i18n",
		"$pub": "require/$pub",
		"$ready": "require/$ready",
		"$tmpl": "require/$tmpl"
	}
});

/* ---- Module:jquery-migrate-sdk ---- */

/*!
 * jQuery JavaScript Library v1.9.1
 * http://jquery.com/
 *
 * Includes Sizzle.js
 * http://sizzlejs.com/
 *
 * Copyright 2005, 2012 jQuery Foundation, Inc. and other contributors
 * Released under the MIT license
 * http://jquery.org/license
 *
 * Date: 2013-2-4
 */
(function( window, undefined ) {

// Can't do this because several apps including ASP.NET trace
// the stack via arguments.caller.callee and Firefox dies if
// you try to trace through "use strict" call chains. (#13335)
// Support: Firefox 18+
//"use strict";
var
	// The deferred used on DOM ready
	readyList,

	// A central reference to the root jQuery(document)
	rootjQuery,

	// Support: IE<9
	// For `typeof node.method` instead of `node.method !== undefined`
	core_strundefined = typeof undefined,

	// Use the correct document accordingly with window argument (sandbox)
	document = window.document,
	location = window.location,

	// Map over jQuery in case of overwrite
	_jQuery = window.jQuery,

	// Map over the $ in case of overwrite
	_$ = window.$,

	// [[Class]] -> type pairs
	class2type = {},

	// List of deleted data cache ids, so we can reuse them
	core_deletedIds = [],

	core_version = "1.9.1",

	// Save a reference to some core methods
	core_concat = core_deletedIds.concat,
	core_push = core_deletedIds.push,
	core_slice = core_deletedIds.slice,
	core_indexOf = core_deletedIds.indexOf,
	core_toString = class2type.toString,
	core_hasOwn = class2type.hasOwnProperty,
	core_trim = core_version.trim,

	// Define a local copy of jQuery
	jQuery = function( selector, context ) {
		// The jQuery object is actually just the init constructor 'enhanced'
		return new jQuery.fn.init( selector, context, rootjQuery );
	},

	// Used for matching numbers
	core_pnum = /[+-]?(?:\d*\.|)\d+(?:[eE][+-]?\d+|)/.source,

	// Used for splitting on whitespace
	core_rnotwhite = /\S+/g,

	// Make sure we trim BOM and NBSP (here's looking at you, Safari 5.0 and IE)
	rtrim = /^[\s\uFEFF\xA0]+|[\s\uFEFF\xA0]+$/g,

	// A simple way to check for HTML strings
	// Prioritize #id over <tag> to avoid XSS via location.hash (#9521)
	// Strict HTML recognition (#11290: must start with <)
	rquickExpr = /^(?:(<[\w\W]+>)[^>]*|#([\w-]*))$/,

	// Match a standalone tag
	rsingleTag = /^<(\w+)\s*\/?>(?:<\/\1>|)$/,

	// JSON RegExp
	rvalidchars = /^[\],:{}\s]*$/,
	rvalidbraces = /(?:^|:|,)(?:\s*\[)+/g,
	rvalidescape = /\\(?:["\\\/bfnrt]|u[\da-fA-F]{4})/g,
	rvalidtokens = /"[^"\\\r\n]*"|true|false|null|-?(?:\d+\.|)\d+(?:[eE][+-]?\d+|)/g,

	// Matches dashed string for camelizing
	rmsPrefix = /^-ms-/,
	rdashAlpha = /-([\da-z])/gi,

	// Used by jQuery.camelCase as callback to replace()
	fcamelCase = function( all, letter ) {
		return letter.toUpperCase();
	},

	// The ready event handler
	completed = function( event ) {

		// readyState === "complete" is good enough for us to call the dom ready in oldIE
		if ( document.addEventListener || event.type === "load" || document.readyState === "complete" ) {
			detach();
			jQuery.ready();
		}
	},
	// Clean-up method for dom ready events
	detach = function() {
		if ( document.addEventListener ) {
			document.removeEventListener( "DOMContentLoaded", completed, false );
			window.removeEventListener( "load", completed, false );

		} else {
			document.detachEvent( "onreadystatechange", completed );
			window.detachEvent( "onload", completed );
		}
	};

jQuery.fn = jQuery.prototype = {
	// The current version of jQuery being used
	jquery: core_version,

	constructor: jQuery,
	init: function( selector, context, rootjQuery ) {
		var match, elem;

		// HANDLE: $(""), $(null), $(undefined), $(false)
		if ( !selector ) {
			return this;
		}

		// Handle HTML strings
		if ( typeof selector === "string" ) {
			if ( selector.charAt(0) === "<" && selector.charAt( selector.length - 1 ) === ">" && selector.length >= 3 ) {
				// Assume that strings that start and end with <> are HTML and skip the regex check
				match = [ null, selector, null ];

			} else {
				match = rquickExpr.exec( selector );
			}

			// Match html or make sure no context is specified for #id
			if ( match && (match[1] || !context) ) {

				// HANDLE: $(html) -> $(array)
				if ( match[1] ) {
					context = context instanceof jQuery ? context[0] : context;

					// scripts is true for back-compat
					jQuery.merge( this, jQuery.parseHTML(
						match[1],
						context && context.nodeType ? context.ownerDocument || context : document,
						true
					) );

					// HANDLE: $(html, props)
					if ( rsingleTag.test( match[1] ) && jQuery.isPlainObject( context ) ) {
						for ( match in context ) {
							// Properties of context are called as methods if possible
							if ( jQuery.isFunction( this[ match ] ) ) {
								this[ match ]( context[ match ] );

							// ...and otherwise set as attributes
							} else {
								this.attr( match, context[ match ] );
							}
						}
					}

					return this;

				// HANDLE: $(#id)
				} else {
					elem = document.getElementById( match[2] );

					// Check parentNode to catch when Blackberry 4.6 returns
					// nodes that are no longer in the document #6963
					if ( elem && elem.parentNode ) {
						// Handle the case where IE and Opera return items
						// by name instead of ID
						if ( elem.id !== match[2] ) {
							return rootjQuery.find( selector );
						}

						// Otherwise, we inject the element directly into the jQuery object
						this.length = 1;
						this[0] = elem;
					}

					this.context = document;
					this.selector = selector;
					return this;
				}

			// HANDLE: $(expr, $(...))
			} else if ( !context || context.jquery ) {
				return ( context || rootjQuery ).find( selector );

			// HANDLE: $(expr, context)
			// (which is just equivalent to: $(context).find(expr)
			} else {
				return this.constructor( context ).find( selector );
			}

		// HANDLE: $(DOMElement)
		} else if ( selector.nodeType ) {
			this.context = this[0] = selector;
			this.length = 1;
			return this;

		// HANDLE: $(function)
		// Shortcut for document ready
		} else if ( jQuery.isFunction( selector ) ) {
			return rootjQuery.ready( selector );
		}

		if ( selector.selector !== undefined ) {
			this.selector = selector.selector;
			this.context = selector.context;
		}

		return jQuery.makeArray( selector, this );
	},

	// Start with an empty selector
	selector: "",

	// The default length of a jQuery object is 0
	length: 0,

	// The number of elements contained in the matched element set
	size: function() {
		return this.length;
	},

	toArray: function() {
		return core_slice.call( this );
	},

	// Get the Nth element in the matched element set OR
	// Get the whole matched element set as a clean array
	get: function( num ) {
		return num == null ?

			// Return a 'clean' array
			this.toArray() :

			// Return just the object
			( num < 0 ? this[ this.length + num ] : this[ num ] );
	},

	// Take an array of elements and push it onto the stack
	// (returning the new matched element set)
	pushStack: function( elems ) {

		// Build a new jQuery matched element set
		var ret = jQuery.merge( this.constructor(), elems );

		// Add the old object onto the stack (as a reference)
		ret.prevObject = this;
		ret.context = this.context;

		// Return the newly-formed element set
		return ret;
	},

	// Execute a callback for every element in the matched set.
	// (You can seed the arguments with an array of args, but this is
	// only used internally.)
	each: function( callback, args ) {
		return jQuery.each( this, callback, args );
	},

	ready: function( fn ) {
		// Add the callback
		jQuery.ready.promise().done( fn );

		return this;
	},

	slice: function() {
		return this.pushStack( core_slice.apply( this, arguments ) );
	},

	first: function() {
		return this.eq( 0 );
	},

	last: function() {
		return this.eq( -1 );
	},

	eq: function( i ) {
		var len = this.length,
			j = +i + ( i < 0 ? len : 0 );
		return this.pushStack( j >= 0 && j < len ? [ this[j] ] : [] );
	},

	map: function( callback ) {
		return this.pushStack( jQuery.map(this, function( elem, i ) {
			return callback.call( elem, i, elem );
		}));
	},

	end: function() {
		return this.prevObject || this.constructor(null);
	},

	// For internal use only.
	// Behaves like an Array's method, not like a jQuery method.
	push: core_push,
	sort: [].sort,
	splice: [].splice
};

// Give the init function the jQuery prototype for later instantiation
jQuery.fn.init.prototype = jQuery.fn;

jQuery.extend = jQuery.fn.extend = function() {
	var src, copyIsArray, copy, name, options, clone,
		target = arguments[0] || {},
		i = 1,
		length = arguments.length,
		deep = false;

	// Handle a deep copy situation
	if ( typeof target === "boolean" ) {
		deep = target;
		target = arguments[1] || {};
		// skip the boolean and the target
		i = 2;
	}

	// Handle case when target is a string or something (possible in deep copy)
	if ( typeof target !== "object" && !jQuery.isFunction(target) ) {
		target = {};
	}

	// extend jQuery itself if only one argument is passed
	if ( length === i ) {
		target = this;
		--i;
	}

	for ( ; i < length; i++ ) {
		// Only deal with non-null/undefined values
		if ( (options = arguments[ i ]) != null ) {
			// Extend the base object
			for ( name in options ) {
				src = target[ name ];
				copy = options[ name ];

				// Prevent never-ending loop
				if ( target === copy ) {
					continue;
				}

				// Recurse if we're merging plain objects or arrays
				if ( deep && copy && ( jQuery.isPlainObject(copy) || (copyIsArray = jQuery.isArray(copy)) ) ) {
					if ( copyIsArray ) {
						copyIsArray = false;
						clone = src && jQuery.isArray(src) ? src : [];

					} else {
						clone = src && jQuery.isPlainObject(src) ? src : {};
					}

					// Never move original objects, clone them
					target[ name ] = jQuery.extend( deep, clone, copy );

				// Don't bring in undefined values
				} else if ( copy !== undefined ) {
					target[ name ] = copy;
				}
			}
		}
	}

	// Return the modified object
	return target;
};

jQuery.extend({
	noConflict: function( deep ) {
		if ( window.$ === jQuery ) {
			window.$ = _$;
		}

		if ( deep && window.jQuery === jQuery ) {
			window.jQuery = _jQuery;
		}

		return jQuery;
	},

	// Is the DOM ready to be used? Set to true once it occurs.
	isReady: false,

	// A counter to track how many items to wait for before
	// the ready event fires. See #6781
	readyWait: 1,

	// Hold (or release) the ready event
	holdReady: function( hold ) {
		if ( hold ) {
			jQuery.readyWait++;
		} else {
			jQuery.ready( true );
		}
	},

	// Handle when the DOM is ready
	ready: function( wait ) {

		// Abort if there are pending holds or we're already ready
		if ( wait === true ? --jQuery.readyWait : jQuery.isReady ) {
			return;
		}

		// Make sure body exists, at least, in case IE gets a little overzealous (ticket #5443).
		if ( !document.body ) {
			return setTimeout( jQuery.ready );
		}

		// Remember that the DOM is ready
		jQuery.isReady = true;

		// If a normal DOM Ready event fired, decrement, and wait if need be
		if ( wait !== true && --jQuery.readyWait > 0 ) {
			return;
		}

		// If there are functions bound, to execute
		readyList.resolveWith( document, [ jQuery ] );

		// Trigger any bound ready events
		if ( jQuery.fn.trigger ) {
			jQuery( document ).trigger("ready").off("ready");
		}
	},

	// See test/unit/core.js for details concerning isFunction.
	// Since version 1.3, DOM methods and functions like alert
	// aren't supported. They return false on IE (#2968).
	isFunction: function( obj ) {
		return jQuery.type(obj) === "function";
	},

	isArray: Array.isArray || function( obj ) {
		return jQuery.type(obj) === "array";
	},

	isWindow: function( obj ) {
		return obj != null && obj == obj.window;
	},

	isNumeric: function( obj ) {
		return !isNaN( parseFloat(obj) ) && isFinite( obj );
	},

	type: function( obj ) {
		if ( obj == null ) {
			return String( obj );
		}
		return typeof obj === "object" || typeof obj === "function" ?
			class2type[ core_toString.call(obj) ] || "object" :
			typeof obj;
	},

	isPlainObject: function( obj ) {
		// Must be an Object.
		// Because of IE, we also have to check the presence of the constructor property.
		// Make sure that DOM nodes and window objects don't pass through, as well
		if ( !obj || jQuery.type(obj) !== "object" || obj.nodeType || jQuery.isWindow( obj ) ) {
			return false;
		}

		try {
			// Not own constructor property must be Object
			if ( obj.constructor &&
				!core_hasOwn.call(obj, "constructor") &&
				!core_hasOwn.call(obj.constructor.prototype, "isPrototypeOf") ) {
				return false;
			}
		} catch ( e ) {
			// IE8,9 Will throw exceptions on certain host objects #9897
			return false;
		}

		// Own properties are enumerated firstly, so to speed up,
		// if last one is own, then all properties are own.

		var key;
		for ( key in obj ) {}

		return key === undefined || core_hasOwn.call( obj, key );
	},

	isEmptyObject: function( obj ) {
		var name;
		for ( name in obj ) {
			return false;
		}
		return true;
	},

	error: function( msg ) {
		throw new Error( msg );
	},

	// data: string of html
	// context (optional): If specified, the fragment will be created in this context, defaults to document
	// keepScripts (optional): If true, will include scripts passed in the html string
	parseHTML: function( data, context, keepScripts ) {
		if ( !data || typeof data !== "string" ) {
			return null;
		}
		if ( typeof context === "boolean" ) {
			keepScripts = context;
			context = false;
		}
		context = context || document;

		var parsed = rsingleTag.exec( data ),
			scripts = !keepScripts && [];

		// Single tag
		if ( parsed ) {
			return [ context.createElement( parsed[1] ) ];
		}

		parsed = jQuery.buildFragment( [ data ], context, scripts );
		if ( scripts ) {
			jQuery( scripts ).remove();
		}
		return jQuery.merge( [], parsed.childNodes );
	},

	parseJSON: function( data ) {
		// Attempt to parse using the native JSON parser first
		if ( window.JSON && window.JSON.parse ) {
			return window.JSON.parse( data );
		}

		if ( data === null ) {
			return data;
		}

		if ( typeof data === "string" ) {

			// Make sure leading/trailing whitespace is removed (IE can't handle it)
			data = jQuery.trim( data );

			if ( data ) {
				// Make sure the incoming data is actual JSON
				// Logic borrowed from http://json.org/json2.js
				if ( rvalidchars.test( data.replace( rvalidescape, "@" )
					.replace( rvalidtokens, "]" )
					.replace( rvalidbraces, "")) ) {

					return ( new Function( "return " + data ) )();
				}
			}
		}

		jQuery.error( "Invalid JSON: " + data );
	},

	// Cross-browser xml parsing
	parseXML: function( data ) {
		var xml, tmp;
		if ( !data || typeof data !== "string" ) {
			return null;
		}
		try {
			if ( window.DOMParser ) { // Standard
				tmp = new DOMParser();
				xml = tmp.parseFromString( data , "text/xml" );
			} else { // IE
				xml = new ActiveXObject( "Microsoft.XMLDOM" );
				xml.async = "false";
				xml.loadXML( data );
			}
		} catch( e ) {
			xml = undefined;
		}
		if ( !xml || !xml.documentElement || xml.getElementsByTagName( "parsererror" ).length ) {
			jQuery.error( "Invalid XML: " + data );
		}
		return xml;
	},

	noop: function() {},

	// Evaluates a script in a global context
	// Workarounds based on findings by Jim Driscoll
	// http://weblogs.java.net/blog/driscoll/archive/2009/09/08/eval-javascript-global-context
	globalEval: function( data ) {
		if ( data && jQuery.trim( data ) ) {
			// We use execScript on Internet Explorer
			// We use an anonymous function so that context is window
			// rather than jQuery in Firefox
			( window.execScript || function( data ) {
				window[ "eval" ].call( window, data );
			} )( data );
		}
	},

	// Convert dashed to camelCase; used by the css and data modules
	// Microsoft forgot to hump their vendor prefix (#9572)
	camelCase: function( string ) {
		return string.replace( rmsPrefix, "ms-" ).replace( rdashAlpha, fcamelCase );
	},

	nodeName: function( elem, name ) {
		return elem.nodeName && elem.nodeName.toLowerCase() === name.toLowerCase();
	},

	// args is for internal usage only
	each: function( obj, callback, args ) {
		var value,
			i = 0,
			length = obj.length,
			isArray = isArraylike( obj );

		if ( args ) {
			if ( isArray ) {
				for ( ; i < length; i++ ) {
					value = callback.apply( obj[ i ], args );

					if ( value === false ) {
						break;
					}
				}
			} else {
				for ( i in obj ) {
					value = callback.apply( obj[ i ], args );

					if ( value === false ) {
						break;
					}
				}
			}

		// A special, fast, case for the most common use of each
		} else {
			if ( isArray ) {
				for ( ; i < length; i++ ) {
					value = callback.call( obj[ i ], i, obj[ i ] );

					if ( value === false ) {
						break;
					}
				}
			} else {
				for ( i in obj ) {
					value = callback.call( obj[ i ], i, obj[ i ] );

					if ( value === false ) {
						break;
					}
				}
			}
		}

		return obj;
	},

	// Use native String.trim function wherever possible
	trim: core_trim && !core_trim.call("\uFEFF\xA0") ?
		function( text ) {
			return text == null ?
				"" :
				core_trim.call( text );
		} :

		// Otherwise use our own trimming functionality
		function( text ) {
			return text == null ?
				"" :
				( text + "" ).replace( rtrim, "" );
		},

	// results is for internal usage only
	makeArray: function( arr, results ) {
		var ret = results || [];

		if ( arr != null ) {
			if ( isArraylike( Object(arr) ) ) {
				jQuery.merge( ret,
					typeof arr === "string" ?
					[ arr ] : arr
				);
			} else {
				core_push.call( ret, arr );
			}
		}

		return ret;
	},

	inArray: function( elem, arr, i ) {
		var len;

		if ( arr ) {
			if ( core_indexOf ) {
				return core_indexOf.call( arr, elem, i );
			}

			len = arr.length;
			i = i ? i < 0 ? Math.max( 0, len + i ) : i : 0;

			for ( ; i < len; i++ ) {
				// Skip accessing in sparse arrays
				if ( i in arr && arr[ i ] === elem ) {
					return i;
				}
			}
		}

		return -1;
	},

	merge: function( first, second ) {
		var l = second.length,
			i = first.length,
			j = 0;

		if ( typeof l === "number" ) {
			for ( ; j < l; j++ ) {
				first[ i++ ] = second[ j ];
			}
		} else {
			while ( second[j] !== undefined ) {
				first[ i++ ] = second[ j++ ];
			}
		}

		first.length = i;

		return first;
	},

	grep: function( elems, callback, inv ) {
		var retVal,
			ret = [],
			i = 0,
			length = elems.length;
		inv = !!inv;

		// Go through the array, only saving the items
		// that pass the validator function
		for ( ; i < length; i++ ) {
			retVal = !!callback( elems[ i ], i );
			if ( inv !== retVal ) {
				ret.push( elems[ i ] );
			}
		}

		return ret;
	},

	// arg is for internal usage only
	map: function( elems, callback, arg ) {
		var value,
			i = 0,
			length = elems.length,
			isArray = isArraylike( elems ),
			ret = [];

		// Go through the array, translating each of the items to their
		if ( isArray ) {
			for ( ; i < length; i++ ) {
				value = callback( elems[ i ], i, arg );

				if ( value != null ) {
					ret[ ret.length ] = value;
				}
			}

		// Go through every key on the object,
		} else {
			for ( i in elems ) {
				value = callback( elems[ i ], i, arg );

				if ( value != null ) {
					ret[ ret.length ] = value;
				}
			}
		}

		// Flatten any nested arrays
		return core_concat.apply( [], ret );
	},

	// A global GUID counter for objects
	guid: 1,

	// Bind a function to a context, optionally partially applying any
	// arguments.
	proxy: function( fn, context ) {
		var args, proxy, tmp;

		if ( typeof context === "string" ) {
			tmp = fn[ context ];
			context = fn;
			fn = tmp;
		}

		// Quick check to determine if target is callable, in the spec
		// this throws a TypeError, but we will just return undefined.
		if ( !jQuery.isFunction( fn ) ) {
			return undefined;
		}

		// Simulated bind
		args = core_slice.call( arguments, 2 );
		proxy = function() {
			return fn.apply( context || this, args.concat( core_slice.call( arguments ) ) );
		};

		// Set the guid of unique handler to the same of original handler, so it can be removed
		proxy.guid = fn.guid = fn.guid || jQuery.guid++;

		return proxy;
	},

	// Multifunctional method to get and set values of a collection
	// The value/s can optionally be executed if it's a function
	access: function( elems, fn, key, value, chainable, emptyGet, raw ) {
		var i = 0,
			length = elems.length,
			bulk = key == null;

		// Sets many values
		if ( jQuery.type( key ) === "object" ) {
			chainable = true;
			for ( i in key ) {
				jQuery.access( elems, fn, i, key[i], true, emptyGet, raw );
			}

		// Sets one value
		} else if ( value !== undefined ) {
			chainable = true;

			if ( !jQuery.isFunction( value ) ) {
				raw = true;
			}

			if ( bulk ) {
				// Bulk operations run against the entire set
				if ( raw ) {
					fn.call( elems, value );
					fn = null;

				// ...except when executing function values
				} else {
					bulk = fn;
					fn = function( elem, key, value ) {
						return bulk.call( jQuery( elem ), value );
					};
				}
			}

			if ( fn ) {
				for ( ; i < length; i++ ) {
					fn( elems[i], key, raw ? value : value.call( elems[i], i, fn( elems[i], key ) ) );
				}
			}
		}

		return chainable ?
			elems :

			// Gets
			bulk ?
				fn.call( elems ) :
				length ? fn( elems[0], key ) : emptyGet;
	},

	now: function() {
		return ( new Date() ).getTime();
	}
});

jQuery.ready.promise = function( obj ) {
	if ( !readyList ) {

		readyList = jQuery.Deferred();

		// Catch cases where $(document).ready() is called after the browser event has already occurred.
		// we once tried to use readyState "interactive" here, but it caused issues like the one
		// discovered by ChrisS here: http://bugs.jquery.com/ticket/12282#comment:15
		if ( document.readyState === "complete" ) {
			// Handle it asynchronously to allow scripts the opportunity to delay ready
			setTimeout( jQuery.ready );

		// Standards-based browsers support DOMContentLoaded
		} else if ( document.addEventListener ) {
			// Use the handy event callback
			document.addEventListener( "DOMContentLoaded", completed, false );

			// A fallback to window.onload, that will always work
			window.addEventListener( "load", completed, false );

		// If IE event model is used
		} else {
			// Ensure firing before onload, maybe late but safe also for iframes
			document.attachEvent( "onreadystatechange", completed );

			// A fallback to window.onload, that will always work
			window.attachEvent( "onload", completed );

			// If IE and not a frame
			// continually check to see if the document is ready
			var top = false;

			try {
				top = window.frameElement == null && document.documentElement;
			} catch(e) {}

			if ( top && top.doScroll ) {
				(function doScrollCheck() {
					if ( !jQuery.isReady ) {

						try {
							// Use the trick by Diego Perini
							// http://javascript.nwbox.com/IEContentLoaded/
							top.doScroll("left");
						} catch(e) {
							return setTimeout( doScrollCheck, 50 );
						}

						// detach all dom ready events
						detach();

						// and execute any waiting functions
						jQuery.ready();
					}
				})();
			}
		}
	}
	return readyList.promise( obj );
};

// Populate the class2type map
jQuery.each("Boolean Number String Function Array Date RegExp Object Error".split(" "), function(i, name) {
	class2type[ "[object " + name + "]" ] = name.toLowerCase();
});

function isArraylike( obj ) {
	var length = obj.length,
		type = jQuery.type( obj );

	if ( jQuery.isWindow( obj ) ) {
		return false;
	}

	if ( obj.nodeType === 1 && length ) {
		return true;
	}

	return type === "array" || type !== "function" &&
		( length === 0 ||
		typeof length === "number" && length > 0 && ( length - 1 ) in obj );
}

// All jQuery objects should point back to these
rootjQuery = jQuery(document);
// String to Object options format cache
var optionsCache = {};

// Convert String-formatted options into Object-formatted ones and store in cache
function createOptions( options ) {
	var object = optionsCache[ options ] = {};
	jQuery.each( options.match( core_rnotwhite ) || [], function( _, flag ) {
		object[ flag ] = true;
	});
	return object;
}

/*
 * Create a callback list using the following parameters:
 *
 *	options: an optional list of space-separated options that will change how
 *			the callback list behaves or a more traditional option object
 *
 * By default a callback list will act like an event callback list and can be
 * "fired" multiple times.
 *
 * Possible options:
 *
 *	once:			will ensure the callback list can only be fired once (like a Deferred)
 *
 *	memory:			will keep track of previous values and will call any callback added
 *					after the list has been fired right away with the latest "memorized"
 *					values (like a Deferred)
 *
 *	unique:			will ensure a callback can only be added once (no duplicate in the list)
 *
 *	stopOnFalse:	interrupt callings when a callback returns false
 *
 */
jQuery.Callbacks = function( options ) {

	// Convert options from String-formatted to Object-formatted if needed
	// (we check in cache first)
	options = typeof options === "string" ?
		( optionsCache[ options ] || createOptions( options ) ) :
		jQuery.extend( {}, options );

	var // Flag to know if list is currently firing
		firing,
		// Last fire value (for non-forgettable lists)
		memory,
		// Flag to know if list was already fired
		fired,
		// End of the loop when firing
		firingLength,
		// Index of currently firing callback (modified by remove if needed)
		firingIndex,
		// First callback to fire (used internally by add and fireWith)
		firingStart,
		// Actual callback list
		list = [],
		// Stack of fire calls for repeatable lists
		stack = !options.once && [],
		// Fire callbacks
		fire = function( data ) {
			memory = options.memory && data;
			fired = true;
			firingIndex = firingStart || 0;
			firingStart = 0;
			firingLength = list.length;
			firing = true;
			for ( ; list && firingIndex < firingLength; firingIndex++ ) {
				if ( list[ firingIndex ].apply( data[ 0 ], data[ 1 ] ) === false && options.stopOnFalse ) {
					memory = false; // To prevent further calls using add
					break;
				}
			}
			firing = false;
			if ( list ) {
				if ( stack ) {
					if ( stack.length ) {
						fire( stack.shift() );
					}
				} else if ( memory ) {
					list = [];
				} else {
					self.disable();
				}
			}
		},
		// Actual Callbacks object
		self = {
			// Add a callback or a collection of callbacks to the list
			add: function() {
				if ( list ) {
					// First, we save the current length
					var start = list.length;
					(function add( args ) {
						jQuery.each( args, function( _, arg ) {
							var type = jQuery.type( arg );
							if ( type === "function" ) {
								if ( !options.unique || !self.has( arg ) ) {
									list.push( arg );
								}
							} else if ( arg && arg.length && type !== "string" ) {
								// Inspect recursively
								add( arg );
							}
						});
					})( arguments );
					// Do we need to add the callbacks to the
					// current firing batch?
					if ( firing ) {
						firingLength = list.length;
					// With memory, if we're not firing then
					// we should call right away
					} else if ( memory ) {
						firingStart = start;
						fire( memory );
					}
				}
				return this;
			},
			// Remove a callback from the list
			remove: function() {
				if ( list ) {
					jQuery.each( arguments, function( _, arg ) {
						var index;
						while( ( index = jQuery.inArray( arg, list, index ) ) > -1 ) {
							list.splice( index, 1 );
							// Handle firing indexes
							if ( firing ) {
								if ( index <= firingLength ) {
									firingLength--;
								}
								if ( index <= firingIndex ) {
									firingIndex--;
								}
							}
						}
					});
				}
				return this;
			},
			// Check if a given callback is in the list.
			// If no argument is given, return whether or not list has callbacks attached.
			has: function( fn ) {
				return fn ? jQuery.inArray( fn, list ) > -1 : !!( list && list.length );
			},
			// Remove all callbacks from the list
			empty: function() {
				list = [];
				return this;
			},
			// Have the list do nothing anymore
			disable: function() {
				list = stack = memory = undefined;
				return this;
			},
			// Is it disabled?
			disabled: function() {
				return !list;
			},
			// Lock the list in its current state
			lock: function() {
				stack = undefined;
				if ( !memory ) {
					self.disable();
				}
				return this;
			},
			// Is it locked?
			locked: function() {
				return !stack;
			},
			// Call all callbacks with the given context and arguments
			fireWith: function( context, args ) {
				args = args || [];
				args = [ context, args.slice ? args.slice() : args ];
				if ( list && ( !fired || stack ) ) {
					if ( firing ) {
						stack.push( args );
					} else {
						fire( args );
					}
				}
				return this;
			},
			// Call all the callbacks with the given arguments
			fire: function() {
				self.fireWith( this, arguments );
				return this;
			},
			// To know if the callbacks have already been called at least once
			fired: function() {
				return !!fired;
			}
		};

	return self;
};
jQuery.extend({

	Deferred: function( func ) {
		var tuples = [
				// action, add listener, listener list, final state
				[ "resolve", "done", jQuery.Callbacks("once memory"), "resolved" ],
				[ "reject", "fail", jQuery.Callbacks("once memory"), "rejected" ],
				[ "notify", "progress", jQuery.Callbacks("memory") ]
			],
			state = "pending",
			promise = {
				state: function() {
					return state;
				},
				always: function() {
					deferred.done( arguments ).fail( arguments );
					return this;
				},
				then: function( /* fnDone, fnFail, fnProgress */ ) {
					var fns = arguments;
					return jQuery.Deferred(function( newDefer ) {
						jQuery.each( tuples, function( i, tuple ) {
							var action = tuple[ 0 ],
								fn = jQuery.isFunction( fns[ i ] ) && fns[ i ];
							// deferred[ done | fail | progress ] for forwarding actions to newDefer
							deferred[ tuple[1] ](function() {
								var returned = fn && fn.apply( this, arguments );
								if ( returned && jQuery.isFunction( returned.promise ) ) {
									returned.promise()
										.done( newDefer.resolve )
										.fail( newDefer.reject )
										.progress( newDefer.notify );
								} else {
									newDefer[ action + "With" ]( this === promise ? newDefer.promise() : this, fn ? [ returned ] : arguments );
								}
							});
						});
						fns = null;
					}).promise();
				},
				// Get a promise for this deferred
				// If obj is provided, the promise aspect is added to the object
				promise: function( obj ) {
					return obj != null ? jQuery.extend( obj, promise ) : promise;
				}
			},
			deferred = {};

		// Keep pipe for back-compat
		promise.pipe = promise.then;

		// Add list-specific methods
		jQuery.each( tuples, function( i, tuple ) {
			var list = tuple[ 2 ],
				stateString = tuple[ 3 ];

			// promise[ done | fail | progress ] = list.add
			promise[ tuple[1] ] = list.add;

			// Handle state
			if ( stateString ) {
				list.add(function() {
					// state = [ resolved | rejected ]
					state = stateString;

				// [ reject_list | resolve_list ].disable; progress_list.lock
				}, tuples[ i ^ 1 ][ 2 ].disable, tuples[ 2 ][ 2 ].lock );
			}

			// deferred[ resolve | reject | notify ]
			deferred[ tuple[0] ] = function() {
				deferred[ tuple[0] + "With" ]( this === deferred ? promise : this, arguments );
				return this;
			};
			deferred[ tuple[0] + "With" ] = list.fireWith;
		});

		// Make the deferred a promise
		promise.promise( deferred );

		// Call given func if any
		if ( func ) {
			func.call( deferred, deferred );
		}

		// All done!
		return deferred;
	},

	// Deferred helper
	when: function( subordinate /* , ..., subordinateN */ ) {
		var i = 0,
			resolveValues = core_slice.call( arguments ),
			length = resolveValues.length,

			// the count of uncompleted subordinates
			remaining = length !== 1 || ( subordinate && jQuery.isFunction( subordinate.promise ) ) ? length : 0,

			// the master Deferred. If resolveValues consist of only a single Deferred, just use that.
			deferred = remaining === 1 ? subordinate : jQuery.Deferred(),

			// Update function for both resolve and progress values
			updateFunc = function( i, contexts, values ) {
				return function( value ) {
					contexts[ i ] = this;
					values[ i ] = arguments.length > 1 ? core_slice.call( arguments ) : value;
					if( values === progressValues ) {
						deferred.notifyWith( contexts, values );
					} else if ( !( --remaining ) ) {
						deferred.resolveWith( contexts, values );
					}
				};
			},

			progressValues, progressContexts, resolveContexts;

		// add listeners to Deferred subordinates; treat others as resolved
		if ( length > 1 ) {
			progressValues = new Array( length );
			progressContexts = new Array( length );
			resolveContexts = new Array( length );
			for ( ; i < length; i++ ) {
				if ( resolveValues[ i ] && jQuery.isFunction( resolveValues[ i ].promise ) ) {
					resolveValues[ i ].promise()
						.done( updateFunc( i, resolveContexts, resolveValues ) )
						.fail( deferred.reject )
						.progress( updateFunc( i, progressContexts, progressValues ) );
				} else {
					--remaining;
				}
			}
		}

		// if we're not waiting on anything, resolve the master
		if ( !remaining ) {
			deferred.resolveWith( resolveContexts, resolveValues );
		}

		return deferred.promise();
	}
});
jQuery.support = (function() {

	var support, all, a,
		input, select, fragment,
		opt, eventName, isSupported, i,
		div = document.createElement("div");

	// Setup
	div.setAttribute( "className", "t" );
	div.innerHTML = "  <link/><table></table><a href='/a'>a</a><input type='checkbox'/>";

	// Support tests won't run in some limited or non-browser environments
	all = div.getElementsByTagName("*");
	a = div.getElementsByTagName("a")[ 0 ];
	if ( !all || !a || !all.length ) {
		return {};
	}

	// First batch of tests
	select = document.createElement("select");
	opt = select.appendChild( document.createElement("option") );
	input = div.getElementsByTagName("input")[ 0 ];

	a.style.cssText = "top:1px;float:left;opacity:.5";
	support = {
		// Test setAttribute on camelCase class. If it works, we need attrFixes when doing get/setAttribute (ie6/7)
		getSetAttribute: div.className !== "t",

		// IE strips leading whitespace when .innerHTML is used
		leadingWhitespace: div.firstChild.nodeType === 3,

		// Make sure that tbody elements aren't automatically inserted
		// IE will insert them into empty tables
		tbody: !div.getElementsByTagName("tbody").length,

		// Make sure that link elements get serialized correctly by innerHTML
		// This requires a wrapper element in IE
		htmlSerialize: !!div.getElementsByTagName("link").length,

		// Get the style information from getAttribute
		// (IE uses .cssText instead)
		style: /top/.test( a.getAttribute("style") ),

		// Make sure that URLs aren't manipulated
		// (IE normalizes it by default)
		hrefNormalized: a.getAttribute("href") === "/a",

		// Make sure that element opacity exists
		// (IE uses filter instead)
		// Use a regex to work around a WebKit issue. See #5145
		opacity: /^0.5/.test( a.style.opacity ),

		// Verify style float existence
		// (IE uses styleFloat instead of cssFloat)
		cssFloat: !!a.style.cssFloat,

		// Check the default checkbox/radio value ("" on WebKit; "on" elsewhere)
		checkOn: !!input.value,

		// Make sure that a selected-by-default option has a working selected property.
		// (WebKit defaults to false instead of true, IE too, if it's in an optgroup)
		optSelected: opt.selected,

		// Tests for enctype support on a form (#6743)
		enctype: !!document.createElement("form").enctype,

		// Makes sure cloning an html5 element does not cause problems
		// Where outerHTML is undefined, this still works
		html5Clone: document.createElement("nav").cloneNode( true ).outerHTML !== "<:nav></:nav>",

		// jQuery.support.boxModel DEPRECATED in 1.8 since we don't support Quirks Mode
		boxModel: document.compatMode === "CSS1Compat",

		// Will be defined later
		deleteExpando: true,
		noCloneEvent: true,
		inlineBlockNeedsLayout: false,
		shrinkWrapBlocks: false,
		reliableMarginRight: true,
		boxSizingReliable: true,
		pixelPosition: false
	};

	// Make sure checked status is properly cloned
	input.checked = true;
	support.noCloneChecked = input.cloneNode( true ).checked;

	// Make sure that the options inside disabled selects aren't marked as disabled
	// (WebKit marks them as disabled)
	select.disabled = true;
	support.optDisabled = !opt.disabled;

	// Support: IE<9
	try {
		delete div.test;
	} catch( e ) {
		support.deleteExpando = false;
	}

	// Check if we can trust getAttribute("value")
	input = document.createElement("input");
	input.setAttribute( "value", "" );
	support.input = input.getAttribute( "value" ) === "";

	// Check if an input maintains its value after becoming a radio
	input.value = "t";
	input.setAttribute( "type", "radio" );
	support.radioValue = input.value === "t";

	// #11217 - WebKit loses check when the name is after the checked attribute
	input.setAttribute( "checked", "t" );
	input.setAttribute( "name", "t" );

	fragment = document.createDocumentFragment();
	fragment.appendChild( input );

	// Check if a disconnected checkbox will retain its checked
	// value of true after appended to the DOM (IE6/7)
	support.appendChecked = input.checked;

	// WebKit doesn't clone checked state correctly in fragments
	support.checkClone = fragment.cloneNode( true ).cloneNode( true ).lastChild.checked;

	// Support: IE<9
	// Opera does not clone events (and typeof div.attachEvent === undefined).
	// IE9-10 clones events bound via attachEvent, but they don't trigger with .click()
	if ( div.attachEvent ) {
		div.attachEvent( "onclick", function() {
			support.noCloneEvent = false;
		});

		div.cloneNode( true ).click();
	}

	// Support: IE<9 (lack submit/change bubble), Firefox 17+ (lack focusin event)
	// Beware of CSP restrictions (https://developer.mozilla.org/en/Security/CSP), test/csp.php
	for ( i in { submit: true, change: true, focusin: true }) {
		div.setAttribute( eventName = "on" + i, "t" );

		support[ i + "Bubbles" ] = eventName in window || div.attributes[ eventName ].expando === false;
	}

	div.style.backgroundClip = "content-box";
	div.cloneNode( true ).style.backgroundClip = "";
	support.clearCloneStyle = div.style.backgroundClip === "content-box";

	// Run tests that need a body at doc ready
	jQuery(function() {
		var container, marginDiv, tds,
			divReset = "padding:0;margin:0;border:0;display:block;box-sizing:content-box;-moz-box-sizing:content-box;-webkit-box-sizing:content-box;",
			body = document.getElementsByTagName("body")[0];

		if ( !body ) {
			// Return for frameset docs that don't have a body
			return;
		}

		container = document.createElement("div");
		container.style.cssText = "border:0;width:0;height:0;position:absolute;top:0;left:-9999px;margin-top:1px";

		body.appendChild( container ).appendChild( div );

		// Support: IE8
		// Check if table cells still have offsetWidth/Height when they are set
		// to display:none and there are still other visible table cells in a
		// table row; if so, offsetWidth/Height are not reliable for use when
		// determining if an element has been hidden directly using
		// display:none (it is still safe to use offsets if a parent element is
		// hidden; don safety goggles and see bug #4512 for more information).
		div.innerHTML = "<table><tr><td></td><td>t</td></tr></table>";
		tds = div.getElementsByTagName("td");
		tds[ 0 ].style.cssText = "padding:0;margin:0;border:0;display:none";
		isSupported = ( tds[ 0 ].offsetHeight === 0 );

		tds[ 0 ].style.display = "";
		tds[ 1 ].style.display = "none";

		// Support: IE8
		// Check if empty table cells still have offsetWidth/Height
		support.reliableHiddenOffsets = isSupported && ( tds[ 0 ].offsetHeight === 0 );

		// Check box-sizing and margin behavior
		div.innerHTML = "";
		div.style.cssText = "box-sizing:border-box;-moz-box-sizing:border-box;-webkit-box-sizing:border-box;padding:1px;border:1px;display:block;width:4px;margin-top:1%;position:absolute;top:1%;";
		support.boxSizing = ( div.offsetWidth === 4 );
		support.doesNotIncludeMarginInBodyOffset = ( body.offsetTop !== 1 );

		// Use window.getComputedStyle because jsdom on node.js will break without it.
		if ( window.getComputedStyle ) {
			support.pixelPosition = ( window.getComputedStyle( div, null ) || {} ).top !== "1%";
			support.boxSizingReliable = ( window.getComputedStyle( div, null ) || { width: "4px" } ).width === "4px";

			// Check if div with explicit width and no margin-right incorrectly
			// gets computed margin-right based on width of container. (#3333)
			// Fails in WebKit before Feb 2011 nightlies
			// WebKit Bug 13343 - getComputedStyle returns wrong value for margin-right
			marginDiv = div.appendChild( document.createElement("div") );
			marginDiv.style.cssText = div.style.cssText = divReset;
			marginDiv.style.marginRight = marginDiv.style.width = "0";
			div.style.width = "1px";

			support.reliableMarginRight =
				!parseFloat( ( window.getComputedStyle( marginDiv, null ) || {} ).marginRight );
		}

		if ( typeof div.style.zoom !== core_strundefined ) {
			// Support: IE<8
			// Check if natively block-level elements act like inline-block
			// elements when setting their display to 'inline' and giving
			// them layout
			div.innerHTML = "";
			div.style.cssText = divReset + "width:1px;padding:1px;display:inline;zoom:1";
			support.inlineBlockNeedsLayout = ( div.offsetWidth === 3 );

			// Support: IE6
			// Check if elements with layout shrink-wrap their children
			div.style.display = "block";
			div.innerHTML = "<div></div>";
			div.firstChild.style.width = "5px";
			support.shrinkWrapBlocks = ( div.offsetWidth !== 3 );

			if ( support.inlineBlockNeedsLayout ) {
				// Prevent IE 6 from affecting layout for positioned elements #11048
				// Prevent IE from shrinking the body in IE 7 mode #12869
				// Support: IE<8
				body.style.zoom = 1;
			}
		}

		body.removeChild( container );

		// Null elements to avoid leaks in IE
		container = div = tds = marginDiv = null;
	});

	// Null elements to avoid leaks in IE
	all = select = fragment = opt = a = input = null;

	return support;
})();

var rbrace = /(?:\{[\s\S]*\}|\[[\s\S]*\])$/,
	rmultiDash = /([A-Z])/g;

function internalData( elem, name, data, pvt /* Internal Use Only */ ){
	if ( !jQuery.acceptData( elem ) ) {
		return;
	}

	var thisCache, ret,
		internalKey = jQuery.expando,
		getByName = typeof name === "string",

		// We have to handle DOM nodes and JS objects differently because IE6-7
		// can't GC object references properly across the DOM-JS boundary
		isNode = elem.nodeType,

		// Only DOM nodes need the global jQuery cache; JS object data is
		// attached directly to the object so GC can occur automatically
		cache = isNode ? jQuery.cache : elem,

		// Only defining an ID for JS objects if its cache already exists allows
		// the code to shortcut on the same path as a DOM node with no cache
		id = isNode ? elem[ internalKey ] : elem[ internalKey ] && internalKey;

	// Avoid doing any more work than we need to when trying to get data on an
	// object that has no data at all
	if ( (!id || !cache[id] || (!pvt && !cache[id].data)) && getByName && data === undefined ) {
		return;
	}

	if ( !id ) {
		// Only DOM nodes need a new unique ID for each element since their data
		// ends up in the global cache
		if ( isNode ) {
			elem[ internalKey ] = id = core_deletedIds.pop() || jQuery.guid++;
		} else {
			id = internalKey;
		}
	}

	if ( !cache[ id ] ) {
		cache[ id ] = {};

		// Avoids exposing jQuery metadata on plain JS objects when the object
		// is serialized using JSON.stringify
		if ( !isNode ) {
			cache[ id ].toJSON = jQuery.noop;
		}
	}

	// An object can be passed to jQuery.data instead of a key/value pair; this gets
	// shallow copied over onto the existing cache
	if ( typeof name === "object" || typeof name === "function" ) {
		if ( pvt ) {
			cache[ id ] = jQuery.extend( cache[ id ], name );
		} else {
			cache[ id ].data = jQuery.extend( cache[ id ].data, name );
		}
	}

	thisCache = cache[ id ];

	// jQuery data() is stored in a separate object inside the object's internal data
	// cache in order to avoid key collisions between internal data and user-defined
	// data.
	if ( !pvt ) {
		if ( !thisCache.data ) {
			thisCache.data = {};
		}

		thisCache = thisCache.data;
	}

	if ( data !== undefined ) {
		thisCache[ jQuery.camelCase( name ) ] = data;
	}

	// Check for both converted-to-camel and non-converted data property names
	// If a data property was specified
	if ( getByName ) {

		// First Try to find as-is property data
		ret = thisCache[ name ];

		// Test for null|undefined property data
		if ( ret == null ) {

			// Try to find the camelCased property
			ret = thisCache[ jQuery.camelCase( name ) ];
		}
	} else {
		ret = thisCache;
	}

	return ret;
}

function internalRemoveData( elem, name, pvt ) {
	if ( !jQuery.acceptData( elem ) ) {
		return;
	}

	var i, l, thisCache,
		isNode = elem.nodeType,

		// See jQuery.data for more information
		cache = isNode ? jQuery.cache : elem,
		id = isNode ? elem[ jQuery.expando ] : jQuery.expando;

	// If there is already no cache entry for this object, there is no
	// purpose in continuing
	if ( !cache[ id ] ) {
		return;
	}

	if ( name ) {

		thisCache = pvt ? cache[ id ] : cache[ id ].data;

		if ( thisCache ) {

			// Support array or space separated string names for data keys
			if ( !jQuery.isArray( name ) ) {

				// try the string as a key before any manipulation
				if ( name in thisCache ) {
					name = [ name ];
				} else {

					// split the camel cased version by spaces unless a key with the spaces exists
					name = jQuery.camelCase( name );
					if ( name in thisCache ) {
						name = [ name ];
					} else {
						name = name.split(" ");
					}
				}
			} else {
				// If "name" is an array of keys...
				// When data is initially created, via ("key", "val") signature,
				// keys will be converted to camelCase.
				// Since there is no way to tell _how_ a key was added, remove
				// both plain key and camelCase key. #12786
				// This will only penalize the array argument path.
				name = name.concat( jQuery.map( name, jQuery.camelCase ) );
			}

			for ( i = 0, l = name.length; i < l; i++ ) {
				delete thisCache[ name[i] ];
			}

			// If there is no data left in the cache, we want to continue
			// and let the cache object itself get destroyed
			if ( !( pvt ? isEmptyDataObject : jQuery.isEmptyObject )( thisCache ) ) {
				return;
			}
		}
	}

	// See jQuery.data for more information
	if ( !pvt ) {
		delete cache[ id ].data;

		// Don't destroy the parent cache unless the internal data object
		// had been the only thing left in it
		if ( !isEmptyDataObject( cache[ id ] ) ) {
			return;
		}
	}

	// Destroy the cache
	if ( isNode ) {
		jQuery.cleanData( [ elem ], true );

	// Use delete when supported for expandos or `cache` is not a window per isWindow (#10080)
	} else if ( jQuery.support.deleteExpando || cache != cache.window ) {
		delete cache[ id ];

	// When all else fails, null
	} else {
		cache[ id ] = null;
	}
}

jQuery.extend({
	cache: {},

	// Unique for each copy of jQuery on the page
	// Non-digits removed to match rinlinejQuery
	expando: "jQuery" + ( core_version + Math.random() ).replace( /\D/g, "" ),

	// The following elements throw uncatchable exceptions if you
	// attempt to add expando properties to them.
	noData: {
		"embed": true,
		// Ban all objects except for Flash (which handle expandos)
		"object": "clsid:D27CDB6E-AE6D-11cf-96B8-444553540000",
		"applet": true
	},

	hasData: function( elem ) {
		elem = elem.nodeType ? jQuery.cache[ elem[jQuery.expando] ] : elem[ jQuery.expando ];
		return !!elem && !isEmptyDataObject( elem );
	},

	data: function( elem, name, data ) {
		return internalData( elem, name, data );
	},

	removeData: function( elem, name ) {
		return internalRemoveData( elem, name );
	},

	// For internal use only.
	_data: function( elem, name, data ) {
		return internalData( elem, name, data, true );
	},

	_removeData: function( elem, name ) {
		return internalRemoveData( elem, name, true );
	},

	// A method for determining if a DOM node can handle the data expando
	acceptData: function( elem ) {
		// Do not set data on non-element because it will not be cleared (#8335).
		if ( elem.nodeType && elem.nodeType !== 1 && elem.nodeType !== 9 ) {
			return false;
		}

		var noData = elem.nodeName && jQuery.noData[ elem.nodeName.toLowerCase() ];

		// nodes accept data unless otherwise specified; rejection can be conditional
		return !noData || noData !== true && elem.getAttribute("classid") === noData;
	}
});

jQuery.fn.extend({
	data: function( key, value ) {
		var attrs, name,
			elem = this[0],
			i = 0,
			data = null;

		// Gets all values
		if ( key === undefined ) {
			if ( this.length ) {
				data = jQuery.data( elem );

				if ( elem.nodeType === 1 && !jQuery._data( elem, "parsedAttrs" ) ) {
					attrs = elem.attributes;
					for ( ; i < attrs.length; i++ ) {
						name = attrs[i].name;

						if ( !name.indexOf( "data-" ) ) {
							name = jQuery.camelCase( name.slice(5) );

							dataAttr( elem, name, data[ name ] );
						}
					}
					jQuery._data( elem, "parsedAttrs", true );
				}
			}

			return data;
		}

		// Sets multiple values
		if ( typeof key === "object" ) {
			return this.each(function() {
				jQuery.data( this, key );
			});
		}

		return jQuery.access( this, function( value ) {

			if ( value === undefined ) {
				// Try to fetch any internally stored data first
				return elem ? dataAttr( elem, key, jQuery.data( elem, key ) ) : null;
			}

			this.each(function() {
				jQuery.data( this, key, value );
			});
		}, null, value, arguments.length > 1, null, true );
	},

	removeData: function( key ) {
		return this.each(function() {
			jQuery.removeData( this, key );
		});
	}
});

function dataAttr( elem, key, data ) {
	// If nothing was found internally, try to fetch any
	// data from the HTML5 data-* attribute
	if ( data === undefined && elem.nodeType === 1 ) {

		var name = "data-" + key.replace( rmultiDash, "-$1" ).toLowerCase();

		data = elem.getAttribute( name );

		if ( typeof data === "string" ) {
			try {
				data = data === "true" ? true :
					data === "false" ? false :
					data === "null" ? null :
					// Only convert to a number if it doesn't change the string
					+data + "" === data ? +data :
					rbrace.test( data ) ? jQuery.parseJSON( data ) :
						data;
			} catch( e ) {}

			// Make sure we set the data so it isn't changed later
			jQuery.data( elem, key, data );

		} else {
			data = undefined;
		}
	}

	return data;
}

// checks a cache object for emptiness
function isEmptyDataObject( obj ) {
	var name;
	for ( name in obj ) {

		// if the public data object is empty, the private is still empty
		if ( name === "data" && jQuery.isEmptyObject( obj[name] ) ) {
			continue;
		}
		if ( name !== "toJSON" ) {
			return false;
		}
	}

	return true;
}
jQuery.extend({
	queue: function( elem, type, data ) {
		var queue;

		if ( elem ) {
			type = ( type || "fx" ) + "queue";
			queue = jQuery._data( elem, type );

			// Speed up dequeue by getting out quickly if this is just a lookup
			if ( data ) {
				if ( !queue || jQuery.isArray(data) ) {
					queue = jQuery._data( elem, type, jQuery.makeArray(data) );
				} else {
					queue.push( data );
				}
			}
			return queue || [];
		}
	},

	dequeue: function( elem, type ) {
		type = type || "fx";

		var queue = jQuery.queue( elem, type ),
			startLength = queue.length,
			fn = queue.shift(),
			hooks = jQuery._queueHooks( elem, type ),
			next = function() {
				jQuery.dequeue( elem, type );
			};

		// If the fx queue is dequeued, always remove the progress sentinel
		if ( fn === "inprogress" ) {
			fn = queue.shift();
			startLength--;
		}

		hooks.cur = fn;
		if ( fn ) {

			// Add a progress sentinel to prevent the fx queue from being
			// automatically dequeued
			if ( type === "fx" ) {
				queue.unshift( "inprogress" );
			}

			// clear up the last queue stop function
			delete hooks.stop;
			fn.call( elem, next, hooks );
		}

		if ( !startLength && hooks ) {
			hooks.empty.fire();
		}
	},

	// not intended for public consumption - generates a queueHooks object, or returns the current one
	_queueHooks: function( elem, type ) {
		var key = type + "queueHooks";
		return jQuery._data( elem, key ) || jQuery._data( elem, key, {
			empty: jQuery.Callbacks("once memory").add(function() {
				jQuery._removeData( elem, type + "queue" );
				jQuery._removeData( elem, key );
			})
		});
	}
});

jQuery.fn.extend({
	queue: function( type, data ) {
		var setter = 2;

		if ( typeof type !== "string" ) {
			data = type;
			type = "fx";
			setter--;
		}

		if ( arguments.length < setter ) {
			return jQuery.queue( this[0], type );
		}

		return data === undefined ?
			this :
			this.each(function() {
				var queue = jQuery.queue( this, type, data );

				// ensure a hooks for this queue
				jQuery._queueHooks( this, type );

				if ( type === "fx" && queue[0] !== "inprogress" ) {
					jQuery.dequeue( this, type );
				}
			});
	},
	dequeue: function( type ) {
		return this.each(function() {
			jQuery.dequeue( this, type );
		});
	},
	// Based off of the plugin by Clint Helfers, with permission.
	// http://blindsignals.com/index.php/2009/07/jquery-delay/
	delay: function( time, type ) {
		time = jQuery.fx ? jQuery.fx.speeds[ time ] || time : time;
		type = type || "fx";

		return this.queue( type, function( next, hooks ) {
			var timeout = setTimeout( next, time );
			hooks.stop = function() {
				clearTimeout( timeout );
			};
		});
	},
	clearQueue: function( type ) {
		return this.queue( type || "fx", [] );
	},
	// Get a promise resolved when queues of a certain type
	// are emptied (fx is the type by default)
	promise: function( type, obj ) {
		var tmp,
			count = 1,
			defer = jQuery.Deferred(),
			elements = this,
			i = this.length,
			resolve = function() {
				if ( !( --count ) ) {
					defer.resolveWith( elements, [ elements ] );
				}
			};

		if ( typeof type !== "string" ) {
			obj = type;
			type = undefined;
		}
		type = type || "fx";

		while( i-- ) {
			tmp = jQuery._data( elements[ i ], type + "queueHooks" );
			if ( tmp && tmp.empty ) {
				count++;
				tmp.empty.add( resolve );
			}
		}
		resolve();
		return defer.promise( obj );
	}
});
var nodeHook, boolHook,
	rclass = /[\t\r\n]/g,
	rreturn = /\r/g,
	rfocusable = /^(?:input|select|textarea|button|object)$/i,
	rclickable = /^(?:a|area)$/i,
	rboolean = /^(?:checked|selected|autofocus|autoplay|async|controls|defer|disabled|hidden|loop|multiple|open|readonly|required|scoped)$/i,
	ruseDefault = /^(?:checked|selected)$/i,
	getSetAttribute = jQuery.support.getSetAttribute,
	getSetInput = jQuery.support.input;

jQuery.fn.extend({
	attr: function( name, value ) {
		return jQuery.access( this, jQuery.attr, name, value, arguments.length > 1 );
	},

	removeAttr: function( name ) {
		return this.each(function() {
			jQuery.removeAttr( this, name );
		});
	},

	prop: function( name, value ) {
		return jQuery.access( this, jQuery.prop, name, value, arguments.length > 1 );
	},

	removeProp: function( name ) {
		name = jQuery.propFix[ name ] || name;
		return this.each(function() {
			// try/catch handles cases where IE balks (such as removing a property on window)
			try {
				this[ name ] = undefined;
				delete this[ name ];
			} catch( e ) {}
		});
	},

	addClass: function( value ) {
		var classes, elem, cur, clazz, j,
			i = 0,
			len = this.length,
			proceed = typeof value === "string" && value;

		if ( jQuery.isFunction( value ) ) {
			return this.each(function( j ) {
				jQuery( this ).addClass( value.call( this, j, this.className ) );
			});
		}

		if ( proceed ) {
			// The disjunction here is for better compressibility (see removeClass)
			classes = ( value || "" ).match( core_rnotwhite ) || [];

			for ( ; i < len; i++ ) {
				elem = this[ i ];
				cur = elem.nodeType === 1 && ( elem.className ?
					( " " + elem.className + " " ).replace( rclass, " " ) :
					" "
				);

				if ( cur ) {
					j = 0;
					while ( (clazz = classes[j++]) ) {
						if ( cur.indexOf( " " + clazz + " " ) < 0 ) {
							cur += clazz + " ";
						}
					}
					elem.className = jQuery.trim( cur );

				}
			}
		}

		return this;
	},

	removeClass: function( value ) {
		var classes, elem, cur, clazz, j,
			i = 0,
			len = this.length,
			proceed = arguments.length === 0 || typeof value === "string" && value;

		if ( jQuery.isFunction( value ) ) {
			return this.each(function( j ) {
				jQuery( this ).removeClass( value.call( this, j, this.className ) );
			});
		}
		if ( proceed ) {
			classes = ( value || "" ).match( core_rnotwhite ) || [];

			for ( ; i < len; i++ ) {
				elem = this[ i ];
				// This expression is here for better compressibility (see addClass)
				cur = elem.nodeType === 1 && ( elem.className ?
					( " " + elem.className + " " ).replace( rclass, " " ) :
					""
				);

				if ( cur ) {
					j = 0;
					while ( (clazz = classes[j++]) ) {
						// Remove *all* instances
						while ( cur.indexOf( " " + clazz + " " ) >= 0 ) {
							cur = cur.replace( " " + clazz + " ", " " );
						}
					}
					elem.className = value ? jQuery.trim( cur ) : "";
				}
			}
		}

		return this;
	},

	toggleClass: function( value, stateVal ) {
		var type = typeof value,
			isBool = typeof stateVal === "boolean";

		if ( jQuery.isFunction( value ) ) {
			return this.each(function( i ) {
				jQuery( this ).toggleClass( value.call(this, i, this.className, stateVal), stateVal );
			});
		}

		return this.each(function() {
			if ( type === "string" ) {
				// toggle individual class names
				var className,
					i = 0,
					self = jQuery( this ),
					state = stateVal,
					classNames = value.match( core_rnotwhite ) || [];

				while ( (className = classNames[ i++ ]) ) {
					// check each className given, space separated list
					state = isBool ? state : !self.hasClass( className );
					self[ state ? "addClass" : "removeClass" ]( className );
				}

			// Toggle whole class name
			} else if ( type === core_strundefined || type === "boolean" ) {
				if ( this.className ) {
					// store className if set
					jQuery._data( this, "__className__", this.className );
				}

				// If the element has a class name or if we're passed "false",
				// then remove the whole classname (if there was one, the above saved it).
				// Otherwise bring back whatever was previously saved (if anything),
				// falling back to the empty string if nothing was stored.
				this.className = this.className || value === false ? "" : jQuery._data( this, "__className__" ) || "";
			}
		});
	},

	hasClass: function( selector ) {
		var className = " " + selector + " ",
			i = 0,
			l = this.length;
		for ( ; i < l; i++ ) {
			if ( this[i].nodeType === 1 && (" " + this[i].className + " ").replace(rclass, " ").indexOf( className ) >= 0 ) {
				return true;
			}
		}

		return false;
	},

	val: function( value ) {
		var ret, hooks, isFunction,
			elem = this[0];

		if ( !arguments.length ) {
			if ( elem ) {
				hooks = jQuery.valHooks[ elem.type ] || jQuery.valHooks[ elem.nodeName.toLowerCase() ];

				if ( hooks && "get" in hooks && (ret = hooks.get( elem, "value" )) !== undefined ) {
					return ret;
				}

				ret = elem.value;

				return typeof ret === "string" ?
					// handle most common string cases
					ret.replace(rreturn, "") :
					// handle cases where value is null/undef or number
					ret == null ? "" : ret;
			}

			return;
		}

		isFunction = jQuery.isFunction( value );

		return this.each(function( i ) {
			var val,
				self = jQuery(this);

			if ( this.nodeType !== 1 ) {
				return;
			}

			if ( isFunction ) {
				val = value.call( this, i, self.val() );
			} else {
				val = value;
			}

			// Treat null/undefined as ""; convert numbers to string
			if ( val == null ) {
				val = "";
			} else if ( typeof val === "number" ) {
				val += "";
			} else if ( jQuery.isArray( val ) ) {
				val = jQuery.map(val, function ( value ) {
					return value == null ? "" : value + "";
				});
			}

			hooks = jQuery.valHooks[ this.type ] || jQuery.valHooks[ this.nodeName.toLowerCase() ];

			// If set returns undefined, fall back to normal setting
			if ( !hooks || !("set" in hooks) || hooks.set( this, val, "value" ) === undefined ) {
				this.value = val;
			}
		});
	}
});

jQuery.extend({
	valHooks: {
		option: {
			get: function( elem ) {
				// attributes.value is undefined in Blackberry 4.7 but
				// uses .value. See #6932
				var val = elem.attributes.value;
				return !val || val.specified ? elem.value : elem.text;
			}
		},
		select: {
			get: function( elem ) {
				var value, option,
					options = elem.options,
					index = elem.selectedIndex,
					one = elem.type === "select-one" || index < 0,
					values = one ? null : [],
					max = one ? index + 1 : options.length,
					i = index < 0 ?
						max :
						one ? index : 0;

				// Loop through all the selected options
				for ( ; i < max; i++ ) {
					option = options[ i ];

					// oldIE doesn't update selected after form reset (#2551)
					if ( ( option.selected || i === index ) &&
							// Don't return options that are disabled or in a disabled optgroup
							( jQuery.support.optDisabled ? !option.disabled : option.getAttribute("disabled") === null ) &&
							( !option.parentNode.disabled || !jQuery.nodeName( option.parentNode, "optgroup" ) ) ) {

						// Get the specific value for the option
						value = jQuery( option ).val();

						// We don't need an array for one selects
						if ( one ) {
							return value;
						}

						// Multi-Selects return an array
						values.push( value );
					}
				}

				return values;
			},

			set: function( elem, value ) {
				var values = jQuery.makeArray( value );

				jQuery(elem).find("option").each(function() {
					this.selected = jQuery.inArray( jQuery(this).val(), values ) >= 0;
				});

				if ( !values.length ) {
					elem.selectedIndex = -1;
				}
				return values;
			}
		}
	},

	attr: function( elem, name, value ) {
		var hooks, notxml, ret,
			nType = elem.nodeType;

		// don't get/set attributes on text, comment and attribute nodes
		if ( !elem || nType === 3 || nType === 8 || nType === 2 ) {
			return;
		}

		// Fallback to prop when attributes are not supported
		if ( typeof elem.getAttribute === core_strundefined ) {
			return jQuery.prop( elem, name, value );
		}

		notxml = nType !== 1 || !jQuery.isXMLDoc( elem );

		// All attributes are lowercase
		// Grab necessary hook if one is defined
		if ( notxml ) {
			name = name.toLowerCase();
			hooks = jQuery.attrHooks[ name ] || ( rboolean.test( name ) ? boolHook : nodeHook );
		}

		if ( value !== undefined ) {

			if ( value === null ) {
				jQuery.removeAttr( elem, name );

			} else if ( hooks && notxml && "set" in hooks && (ret = hooks.set( elem, value, name )) !== undefined ) {
				return ret;

			} else {
				elem.setAttribute( name, value + "" );
				return value;
			}

		} else if ( hooks && notxml && "get" in hooks && (ret = hooks.get( elem, name )) !== null ) {
			return ret;

		} else {

			// In IE9+, Flash objects don't have .getAttribute (#12945)
			// Support: IE9+
			if ( typeof elem.getAttribute !== core_strundefined ) {
				ret =  elem.getAttribute( name );
			}

			// Non-existent attributes return null, we normalize to undefined
			return ret == null ?
				undefined :
				ret;
		}
	},

	removeAttr: function( elem, value ) {
		var name, propName,
			i = 0,
			attrNames = value && value.match( core_rnotwhite );

		if ( attrNames && elem.nodeType === 1 ) {
			while ( (name = attrNames[i++]) ) {
				propName = jQuery.propFix[ name ] || name;

				// Boolean attributes get special treatment (#10870)
				if ( rboolean.test( name ) ) {
					// Set corresponding property to false for boolean attributes
					// Also clear defaultChecked/defaultSelected (if appropriate) for IE<8
					if ( !getSetAttribute && ruseDefault.test( name ) ) {
						elem[ jQuery.camelCase( "default-" + name ) ] =
							elem[ propName ] = false;
					} else {
						elem[ propName ] = false;
					}

				// See #9699 for explanation of this approach (setting first, then removal)
				} else {
					jQuery.attr( elem, name, "" );
				}

				elem.removeAttribute( getSetAttribute ? name : propName );
			}
		}
	},

	attrHooks: {
		type: {
			set: function( elem, value ) {
				if ( !jQuery.support.radioValue && value === "radio" && jQuery.nodeName(elem, "input") ) {
					// Setting the type on a radio button after the value resets the value in IE6-9
					// Reset value to default in case type is set after value during creation
					var val = elem.value;
					elem.setAttribute( "type", value );
					if ( val ) {
						elem.value = val;
					}
					return value;
				}
			}
		}
	},

	propFix: {
		tabindex: "tabIndex",
		readonly: "readOnly",
		"for": "htmlFor",
		"class": "className",
		maxlength: "maxLength",
		cellspacing: "cellSpacing",
		cellpadding: "cellPadding",
		rowspan: "rowSpan",
		colspan: "colSpan",
		usemap: "useMap",
		frameborder: "frameBorder",
		contenteditable: "contentEditable"
	},

	prop: function( elem, name, value ) {
		var ret, hooks, notxml,
			nType = elem.nodeType;

		// don't get/set properties on text, comment and attribute nodes
		if ( !elem || nType === 3 || nType === 8 || nType === 2 ) {
			return;
		}

		notxml = nType !== 1 || !jQuery.isXMLDoc( elem );

		if ( notxml ) {
			// Fix name and attach hooks
			name = jQuery.propFix[ name ] || name;
			hooks = jQuery.propHooks[ name ];
		}

		if ( value !== undefined ) {
			if ( hooks && "set" in hooks && (ret = hooks.set( elem, value, name )) !== undefined ) {
				return ret;

			} else {
				return ( elem[ name ] = value );
			}

		} else {
			if ( hooks && "get" in hooks && (ret = hooks.get( elem, name )) !== null ) {
				return ret;

			} else {
				return elem[ name ];
			}
		}
	},

	propHooks: {
		tabIndex: {
			get: function( elem ) {
				// elem.tabIndex doesn't always return the correct value when it hasn't been explicitly set
				// http://fluidproject.org/blog/2008/01/09/getting-setting-and-removing-tabindex-values-with-javascript/
				var attributeNode = elem.getAttributeNode("tabindex");

				return attributeNode && attributeNode.specified ?
					parseInt( attributeNode.value, 10 ) :
					rfocusable.test( elem.nodeName ) || rclickable.test( elem.nodeName ) && elem.href ?
						0 :
						undefined;
			}
		}
	}
});

// Hook for boolean attributes
boolHook = {
	get: function( elem, name ) {
		var
			// Use .prop to determine if this attribute is understood as boolean
			prop = jQuery.prop( elem, name ),

			// Fetch it accordingly
			attr = typeof prop === "boolean" && elem.getAttribute( name ),
			detail = typeof prop === "boolean" ?

				getSetInput && getSetAttribute ?
					attr != null :
					// oldIE fabricates an empty string for missing boolean attributes
					// and conflates checked/selected into attroperties
					ruseDefault.test( name ) ?
						elem[ jQuery.camelCase( "default-" + name ) ] :
						!!attr :

				// fetch an attribute node for properties not recognized as boolean
				elem.getAttributeNode( name );

		return detail && detail.value !== false ?
			name.toLowerCase() :
			undefined;
	},
	set: function( elem, value, name ) {
		if ( value === false ) {
			// Remove boolean attributes when set to false
			jQuery.removeAttr( elem, name );
		} else if ( getSetInput && getSetAttribute || !ruseDefault.test( name ) ) {
			// IE<8 needs the *property* name
			elem.setAttribute( !getSetAttribute && jQuery.propFix[ name ] || name, name );

		// Use defaultChecked and defaultSelected for oldIE
		} else {
			elem[ jQuery.camelCase( "default-" + name ) ] = elem[ name ] = true;
		}

		return name;
	}
};

// fix oldIE value attroperty
if ( !getSetInput || !getSetAttribute ) {
	jQuery.attrHooks.value = {
		get: function( elem, name ) {
			var ret = elem.getAttributeNode( name );
			return jQuery.nodeName( elem, "input" ) ?

				// Ignore the value *property* by using defaultValue
				elem.defaultValue :

				ret && ret.specified ? ret.value : undefined;
		},
		set: function( elem, value, name ) {
			if ( jQuery.nodeName( elem, "input" ) ) {
				// Does not return so that setAttribute is also used
				elem.defaultValue = value;
			} else {
				// Use nodeHook if defined (#1954); otherwise setAttribute is fine
				return nodeHook && nodeHook.set( elem, value, name );
			}
		}
	};
}

// IE6/7 do not support getting/setting some attributes with get/setAttribute
if ( !getSetAttribute ) {

	// Use this for any attribute in IE6/7
	// This fixes almost every IE6/7 issue
	nodeHook = jQuery.valHooks.button = {
		get: function( elem, name ) {
			var ret = elem.getAttributeNode( name );
			return ret && ( name === "id" || name === "name" || name === "coords" ? ret.value !== "" : ret.specified ) ?
				ret.value :
				undefined;
		},
		set: function( elem, value, name ) {
			// Set the existing or create a new attribute node
			var ret = elem.getAttributeNode( name );
			if ( !ret ) {
				elem.setAttributeNode(
					(ret = elem.ownerDocument.createAttribute( name ))
				);
			}

			ret.value = value += "";

			// Break association with cloned elements by also using setAttribute (#9646)
			return name === "value" || value === elem.getAttribute( name ) ?
				value :
				undefined;
		}
	};

	// Set contenteditable to false on removals(#10429)
	// Setting to empty string throws an error as an invalid value
	jQuery.attrHooks.contenteditable = {
		get: nodeHook.get,
		set: function( elem, value, name ) {
			nodeHook.set( elem, value === "" ? false : value, name );
		}
	};

	// Set width and height to auto instead of 0 on empty string( Bug #8150 )
	// This is for removals
	jQuery.each([ "width", "height" ], function( i, name ) {
		jQuery.attrHooks[ name ] = jQuery.extend( jQuery.attrHooks[ name ], {
			set: function( elem, value ) {
				if ( value === "" ) {
					elem.setAttribute( name, "auto" );
					return value;
				}
			}
		});
	});
}


// Some attributes require a special call on IE
// http://msdn.microsoft.com/en-us/library/ms536429%28VS.85%29.aspx
if ( !jQuery.support.hrefNormalized ) {
	jQuery.each([ "href", "src", "width", "height" ], function( i, name ) {
		jQuery.attrHooks[ name ] = jQuery.extend( jQuery.attrHooks[ name ], {
			get: function( elem ) {
				var ret = elem.getAttribute( name, 2 );
				return ret == null ? undefined : ret;
			}
		});
	});

	// href/src property should get the full normalized URL (#10299/#12915)
	jQuery.each([ "href", "src" ], function( i, name ) {
		jQuery.propHooks[ name ] = {
			get: function( elem ) {
				return elem.getAttribute( name, 4 );
			}
		};
	});
}

if ( !jQuery.support.style ) {
	jQuery.attrHooks.style = {
		get: function( elem ) {
			// Return undefined in the case of empty string
			// Note: IE uppercases css property names, but if we were to .toLowerCase()
			// .cssText, that would destroy case senstitivity in URL's, like in "background"
			return elem.style.cssText || undefined;
		},
		set: function( elem, value ) {
			return ( elem.style.cssText = value + "" );
		}
	};
}

// Safari mis-reports the default selected property of an option
// Accessing the parent's selectedIndex property fixes it
if ( !jQuery.support.optSelected ) {
	jQuery.propHooks.selected = jQuery.extend( jQuery.propHooks.selected, {
		get: function( elem ) {
			var parent = elem.parentNode;

			if ( parent ) {
				parent.selectedIndex;

				// Make sure that it also works with optgroups, see #5701
				if ( parent.parentNode ) {
					parent.parentNode.selectedIndex;
				}
			}
			return null;
		}
	});
}

// IE6/7 call enctype encoding
if ( !jQuery.support.enctype ) {
	jQuery.propFix.enctype = "encoding";
}

// Radios and checkboxes getter/setter
if ( !jQuery.support.checkOn ) {
	jQuery.each([ "radio", "checkbox" ], function() {
		jQuery.valHooks[ this ] = {
			get: function( elem ) {
				// Handle the case where in Webkit "" is returned instead of "on" if a value isn't specified
				return elem.getAttribute("value") === null ? "on" : elem.value;
			}
		};
	});
}
jQuery.each([ "radio", "checkbox" ], function() {
	jQuery.valHooks[ this ] = jQuery.extend( jQuery.valHooks[ this ], {
		set: function( elem, value ) {
			if ( jQuery.isArray( value ) ) {
				return ( elem.checked = jQuery.inArray( jQuery(elem).val(), value ) >= 0 );
			}
		}
	});
});
var rformElems = /^(?:input|select|textarea)$/i,
	rkeyEvent = /^key/,
	rmouseEvent = /^(?:mouse|contextmenu)|click/,
	rfocusMorph = /^(?:focusinfocus|focusoutblur)$/,
	rtypenamespace = /^([^.]*)(?:\.(.+)|)$/;

function returnTrue() {
	return true;
}

function returnFalse() {
	return false;
}

/*
 * Helper functions for managing events -- not part of the public interface.
 * Props to Dean Edwards' addEvent library for many of the ideas.
 */
jQuery.event = {

	global: {},

	add: function( elem, types, handler, data, selector ) {
		var tmp, events, t, handleObjIn,
			special, eventHandle, handleObj,
			handlers, type, namespaces, origType,
			elemData = jQuery._data( elem );

		// Don't attach events to noData or text/comment nodes (but allow plain objects)
		if ( !elemData ) {
			return;
		}

		// Caller can pass in an object of custom data in lieu of the handler
		if ( handler.handler ) {
			handleObjIn = handler;
			handler = handleObjIn.handler;
			selector = handleObjIn.selector;
		}

		// Make sure that the handler has a unique ID, used to find/remove it later
		if ( !handler.guid ) {
			handler.guid = jQuery.guid++;
		}

		// Init the element's event structure and main handler, if this is the first
		if ( !(events = elemData.events) ) {
			events = elemData.events = {};
		}
		if ( !(eventHandle = elemData.handle) ) {
			eventHandle = elemData.handle = function( e ) {
				// Discard the second event of a jQuery.event.trigger() and
				// when an event is called after a page has unloaded
				return typeof jQuery !== core_strundefined && (!e || jQuery.event.triggered !== e.type) ?
					jQuery.event.dispatch.apply( eventHandle.elem, arguments ) :
					undefined;
			};
			// Add elem as a property of the handle fn to prevent a memory leak with IE non-native events
			eventHandle.elem = elem;
		}

		// Handle multiple events separated by a space
		// jQuery(...).bind("mouseover mouseout", fn);
		types = ( types || "" ).match( core_rnotwhite ) || [""];
		t = types.length;
		while ( t-- ) {
			tmp = rtypenamespace.exec( types[t] ) || [];
			type = origType = tmp[1];
			namespaces = ( tmp[2] || "" ).split( "." ).sort();

			// If event changes its type, use the special event handlers for the changed type
			special = jQuery.event.special[ type ] || {};

			// If selector defined, determine special event api type, otherwise given type
			type = ( selector ? special.delegateType : special.bindType ) || type;

			// Update special based on newly reset type
			special = jQuery.event.special[ type ] || {};

			// handleObj is passed to all event handlers
			handleObj = jQuery.extend({
				type: type,
				origType: origType,
				data: data,
				handler: handler,
				guid: handler.guid,
				selector: selector,
				needsContext: selector && jQuery.expr.match.needsContext.test( selector ),
				namespace: namespaces.join(".")
			}, handleObjIn );

			// Init the event handler queue if we're the first
			if ( !(handlers = events[ type ]) ) {
				handlers = events[ type ] = [];
				handlers.delegateCount = 0;

				// Only use addEventListener/attachEvent if the special events handler returns false
				if ( !special.setup || special.setup.call( elem, data, namespaces, eventHandle ) === false ) {
					// Bind the global event handler to the element
					if ( elem.addEventListener ) {
						elem.addEventListener( type, eventHandle, false );

					} else if ( elem.attachEvent ) {
						elem.attachEvent( "on" + type, eventHandle );
					}
				}
			}

			if ( special.add ) {
				special.add.call( elem, handleObj );

				if ( !handleObj.handler.guid ) {
					handleObj.handler.guid = handler.guid;
				}
			}

			// Add to the element's handler list, delegates in front
			if ( selector ) {
				handlers.splice( handlers.delegateCount++, 0, handleObj );
			} else {
				handlers.push( handleObj );
			}

			// Keep track of which events have ever been used, for event optimization
			jQuery.event.global[ type ] = true;
		}

		// Nullify elem to prevent memory leaks in IE
		elem = null;
	},

	// Detach an event or set of events from an element
	remove: function( elem, types, handler, selector, mappedTypes ) {
		var j, handleObj, tmp,
			origCount, t, events,
			special, handlers, type,
			namespaces, origType,
			elemData = jQuery.hasData( elem ) && jQuery._data( elem );

		if ( !elemData || !(events = elemData.events) ) {
			return;
		}

		// Once for each type.namespace in types; type may be omitted
		types = ( types || "" ).match( core_rnotwhite ) || [""];
		t = types.length;
		while ( t-- ) {
			tmp = rtypenamespace.exec( types[t] ) || [];
			type = origType = tmp[1];
			namespaces = ( tmp[2] || "" ).split( "." ).sort();

			// Unbind all events (on this namespace, if provided) for the element
			if ( !type ) {
				for ( type in events ) {
					jQuery.event.remove( elem, type + types[ t ], handler, selector, true );
				}
				continue;
			}

			special = jQuery.event.special[ type ] || {};
			type = ( selector ? special.delegateType : special.bindType ) || type;
			handlers = events[ type ] || [];
			tmp = tmp[2] && new RegExp( "(^|\\.)" + namespaces.join("\\.(?:.*\\.|)") + "(\\.|$)" );

			// Remove matching events
			origCount = j = handlers.length;
			while ( j-- ) {
				handleObj = handlers[ j ];

				if ( ( mappedTypes || origType === handleObj.origType ) &&
					( !handler || handler.guid === handleObj.guid ) &&
					( !tmp || tmp.test( handleObj.namespace ) ) &&
					( !selector || selector === handleObj.selector || selector === "**" && handleObj.selector ) ) {
					handlers.splice( j, 1 );

					if ( handleObj.selector ) {
						handlers.delegateCount--;
					}
					if ( special.remove ) {
						special.remove.call( elem, handleObj );
					}
				}
			}

			// Remove generic event handler if we removed something and no more handlers exist
			// (avoids potential for endless recursion during removal of special event handlers)
			if ( origCount && !handlers.length ) {
				if ( !special.teardown || special.teardown.call( elem, namespaces, elemData.handle ) === false ) {
					jQuery.removeEvent( elem, type, elemData.handle );
				}

				delete events[ type ];
			}
		}

		// Remove the expando if it's no longer used
		if ( jQuery.isEmptyObject( events ) ) {
			delete elemData.handle;

			// removeData also checks for emptiness and clears the expando if empty
			// so use it instead of delete
			jQuery._removeData( elem, "events" );
		}
	},

	trigger: function( event, data, elem, onlyHandlers ) {
		var handle, ontype, cur,
			bubbleType, special, tmp, i,
			eventPath = [ elem || document ],
			type = core_hasOwn.call( event, "type" ) ? event.type : event,
			namespaces = core_hasOwn.call( event, "namespace" ) ? event.namespace.split(".") : [];

		cur = tmp = elem = elem || document;

		// Don't do events on text and comment nodes
		if ( elem.nodeType === 3 || elem.nodeType === 8 ) {
			return;
		}

		// focus/blur morphs to focusin/out; ensure we're not firing them right now
		if ( rfocusMorph.test( type + jQuery.event.triggered ) ) {
			return;
		}

		if ( type.indexOf(".") >= 0 ) {
			// Namespaced trigger; create a regexp to match event type in handle()
			namespaces = type.split(".");
			type = namespaces.shift();
			namespaces.sort();
		}
		ontype = type.indexOf(":") < 0 && "on" + type;

		// Caller can pass in a jQuery.Event object, Object, or just an event type string
		event = event[ jQuery.expando ] ?
			event :
			new jQuery.Event( type, typeof event === "object" && event );

		event.isTrigger = true;
		event.namespace = namespaces.join(".");
		event.namespace_re = event.namespace ?
			new RegExp( "(^|\\.)" + namespaces.join("\\.(?:.*\\.|)") + "(\\.|$)" ) :
			null;

		// Clean up the event in case it is being reused
		event.result = undefined;
		if ( !event.target ) {
			event.target = elem;
		}

		// Clone any incoming data and prepend the event, creating the handler arg list
		data = data == null ?
			[ event ] :
			jQuery.makeArray( data, [ event ] );

		// Allow special events to draw outside the lines
		special = jQuery.event.special[ type ] || {};
		if ( !onlyHandlers && special.trigger && special.trigger.apply( elem, data ) === false ) {
			return;
		}

		// Determine event propagation path in advance, per W3C events spec (#9951)
		// Bubble up to document, then to window; watch for a global ownerDocument var (#9724)
		if ( !onlyHandlers && !special.noBubble && !jQuery.isWindow( elem ) ) {

			bubbleType = special.delegateType || type;
			if ( !rfocusMorph.test( bubbleType + type ) ) {
				cur = cur.parentNode;
			}
			for ( ; cur; cur = cur.parentNode ) {
				eventPath.push( cur );
				tmp = cur;
			}

			// Only add window if we got to document (e.g., not plain obj or detached DOM)
			if ( tmp === (elem.ownerDocument || document) ) {
				eventPath.push( tmp.defaultView || tmp.parentWindow || window );
			}
		}

		// Fire handlers on the event path
		i = 0;
		while ( (cur = eventPath[i++]) && !event.isPropagationStopped() ) {

			event.type = i > 1 ?
				bubbleType :
				special.bindType || type;

			// jQuery handler
			handle = ( jQuery._data( cur, "events" ) || {} )[ event.type ] && jQuery._data( cur, "handle" );
			if ( handle ) {
				handle.apply( cur, data );
			}

			// Native handler
			handle = ontype && cur[ ontype ];
			if ( handle && jQuery.acceptData( cur ) && handle.apply && handle.apply( cur, data ) === false ) {
				event.preventDefault();
			}
		}
		event.type = type;

		// If nobody prevented the default action, do it now
		if ( !onlyHandlers && !event.isDefaultPrevented() ) {

			if ( (!special._default || special._default.apply( elem.ownerDocument, data ) === false) &&
				!(type === "click" && jQuery.nodeName( elem, "a" )) && jQuery.acceptData( elem ) ) {

				// Call a native DOM method on the target with the same name name as the event.
				// Can't use an .isFunction() check here because IE6/7 fails that test.
				// Don't do default actions on window, that's where global variables be (#6170)
				if ( ontype && elem[ type ] && !jQuery.isWindow( elem ) ) {

					// Don't re-trigger an onFOO event when we call its FOO() method
					tmp = elem[ ontype ];

					if ( tmp ) {
						elem[ ontype ] = null;
					}

					// Prevent re-triggering of the same event, since we already bubbled it above
					jQuery.event.triggered = type;
					try {
						elem[ type ]();
					} catch ( e ) {
						// IE<9 dies on focus/blur to hidden element (#1486,#12518)
						// only reproducible on winXP IE8 native, not IE9 in IE8 mode
					}
					jQuery.event.triggered = undefined;

					if ( tmp ) {
						elem[ ontype ] = tmp;
					}
				}
			}
		}

		return event.result;
	},

	dispatch: function( event ) {

		// Make a writable jQuery.Event from the native event object
		event = jQuery.event.fix( event );

		var i, ret, handleObj, matched, j,
			handlerQueue = [],
			args = core_slice.call( arguments ),
			handlers = ( jQuery._data( this, "events" ) || {} )[ event.type ] || [],
			special = jQuery.event.special[ event.type ] || {};

		// Use the fix-ed jQuery.Event rather than the (read-only) native event
		args[0] = event;
		event.delegateTarget = this;

		// Call the preDispatch hook for the mapped type, and let it bail if desired
		if ( special.preDispatch && special.preDispatch.call( this, event ) === false ) {
			return;
		}

		// Determine handlers
		handlerQueue = jQuery.event.handlers.call( this, event, handlers );

		// Run delegates first; they may want to stop propagation beneath us
		i = 0;
		while ( (matched = handlerQueue[ i++ ]) && !event.isPropagationStopped() ) {
			event.currentTarget = matched.elem;

			j = 0;
			while ( (handleObj = matched.handlers[ j++ ]) && !event.isImmediatePropagationStopped() ) {

				// Triggered event must either 1) have no namespace, or
				// 2) have namespace(s) a subset or equal to those in the bound event (both can have no namespace).
				if ( !event.namespace_re || event.namespace_re.test( handleObj.namespace ) ) {

					event.handleObj = handleObj;
					event.data = handleObj.data;

					ret = ( (jQuery.event.special[ handleObj.origType ] || {}).handle || handleObj.handler )
							.apply( matched.elem, args );

					if ( ret !== undefined ) {
						if ( (event.result = ret) === false ) {
							event.preventDefault();
							event.stopPropagation();
						}
					}
				}
			}
		}

		// Call the postDispatch hook for the mapped type
		if ( special.postDispatch ) {
			special.postDispatch.call( this, event );
		}

		return event.result;
	},

	handlers: function( event, handlers ) {
		var sel, handleObj, matches, i,
			handlerQueue = [],
			delegateCount = handlers.delegateCount,
			cur = event.target;

		// Find delegate handlers
		// Black-hole SVG <use> instance trees (#13180)
		// Avoid non-left-click bubbling in Firefox (#3861)
		if ( delegateCount && cur.nodeType && (!event.button || event.type !== "click") ) {

			for ( ; cur != this; cur = cur.parentNode || this ) {

				// Don't check non-elements (#13208)
				// Don't process clicks on disabled elements (#6911, #8165, #11382, #11764)
				if ( cur.nodeType === 1 && (cur.disabled !== true || event.type !== "click") ) {
					matches = [];
					for ( i = 0; i < delegateCount; i++ ) {
						handleObj = handlers[ i ];

						// Don't conflict with Object.prototype properties (#13203)
						sel = handleObj.selector + " ";

						if ( matches[ sel ] === undefined ) {
							matches[ sel ] = handleObj.needsContext ?
								jQuery( sel, this ).index( cur ) >= 0 :
								jQuery.find( sel, this, null, [ cur ] ).length;
						}
						if ( matches[ sel ] ) {
							matches.push( handleObj );
						}
					}
					if ( matches.length ) {
						handlerQueue.push({ elem: cur, handlers: matches });
					}
				}
			}
		}

		// Add the remaining (directly-bound) handlers
		if ( delegateCount < handlers.length ) {
			handlerQueue.push({ elem: this, handlers: handlers.slice( delegateCount ) });
		}

		return handlerQueue;
	},

	fix: function( event ) {
		if ( event[ jQuery.expando ] ) {
			return event;
		}

		// Create a writable copy of the event object and normalize some properties
		var i, prop, copy,
			type = event.type,
			originalEvent = event,
			fixHook = this.fixHooks[ type ];

		if ( !fixHook ) {
			this.fixHooks[ type ] = fixHook =
				rmouseEvent.test( type ) ? this.mouseHooks :
				rkeyEvent.test( type ) ? this.keyHooks :
				{};
		}
		copy = fixHook.props ? this.props.concat( fixHook.props ) : this.props;

		event = new jQuery.Event( originalEvent );

		i = copy.length;
		while ( i-- ) {
			prop = copy[ i ];
			event[ prop ] = originalEvent[ prop ];
		}

		// Support: IE<9
		// Fix target property (#1925)
		if ( !event.target ) {
			event.target = originalEvent.srcElement || document;
		}

		// Support: Chrome 23+, Safari?
		// Target should not be a text node (#504, #13143)
		if ( event.target.nodeType === 3 ) {
			event.target = event.target.parentNode;
		}

		// Support: IE<9
		// For mouse/key events, metaKey==false if it's undefined (#3368, #11328)
		event.metaKey = !!event.metaKey;

		return fixHook.filter ? fixHook.filter( event, originalEvent ) : event;
	},

	// Includes some event props shared by KeyEvent and MouseEvent
	props: "altKey bubbles cancelable ctrlKey currentTarget eventPhase metaKey relatedTarget shiftKey target timeStamp view which".split(" "),

	fixHooks: {},

	keyHooks: {
		props: "char charCode key keyCode".split(" "),
		filter: function( event, original ) {

			// Add which for key events
			if ( event.which == null ) {
				event.which = original.charCode != null ? original.charCode : original.keyCode;
			}

			return event;
		}
	},

	mouseHooks: {
		props: "button buttons clientX clientY fromElement offsetX offsetY pageX pageY screenX screenY toElement".split(" "),
		filter: function( event, original ) {
			var body, eventDoc, doc,
				button = original.button,
				fromElement = original.fromElement;

			// Calculate pageX/Y if missing and clientX/Y available
			if ( event.pageX == null && original.clientX != null ) {
				eventDoc = event.target.ownerDocument || document;
				doc = eventDoc.documentElement;
				body = eventDoc.body;

				event.pageX = original.clientX + ( doc && doc.scrollLeft || body && body.scrollLeft || 0 ) - ( doc && doc.clientLeft || body && body.clientLeft || 0 );
				event.pageY = original.clientY + ( doc && doc.scrollTop  || body && body.scrollTop  || 0 ) - ( doc && doc.clientTop  || body && body.clientTop  || 0 );
			}

			// Add relatedTarget, if necessary
			if ( !event.relatedTarget && fromElement ) {
				event.relatedTarget = fromElement === event.target ? original.toElement : fromElement;
			}

			// Add which for click: 1 === left; 2 === middle; 3 === right
			// Note: button is not normalized, so don't use it
			if ( !event.which && button !== undefined ) {
				event.which = ( button & 1 ? 1 : ( button & 2 ? 3 : ( button & 4 ? 2 : 0 ) ) );
			}

			return event;
		}
	},

	special: {
		load: {
			// Prevent triggered image.load events from bubbling to window.load
			noBubble: true
		},
		click: {
			// For checkbox, fire native event so checked state will be right
			trigger: function() {
				if ( jQuery.nodeName( this, "input" ) && this.type === "checkbox" && this.click ) {
					this.click();
					return false;
				}
			}
		},
		focus: {
			// Fire native event if possible so blur/focus sequence is correct
			trigger: function() {
				if ( this !== document.activeElement && this.focus ) {
					try {
						this.focus();
						return false;
					} catch ( e ) {
						// Support: IE<9
						// If we error on focus to hidden element (#1486, #12518),
						// let .trigger() run the handlers
					}
				}
			},
			delegateType: "focusin"
		},
		blur: {
			trigger: function() {
				if ( this === document.activeElement && this.blur ) {
					this.blur();
					return false;
				}
			},
			delegateType: "focusout"
		},

		beforeunload: {
			postDispatch: function( event ) {

				// Even when returnValue equals to undefined Firefox will still show alert
				if ( event.result !== undefined ) {
					event.originalEvent.returnValue = event.result;
				}
			}
		}
	},

	simulate: function( type, elem, event, bubble ) {
		// Piggyback on a donor event to simulate a different one.
		// Fake originalEvent to avoid donor's stopPropagation, but if the
		// simulated event prevents default then we do the same on the donor.
		var e = jQuery.extend(
			new jQuery.Event(),
			event,
			{ type: type,
				isSimulated: true,
				originalEvent: {}
			}
		);
		if ( bubble ) {
			jQuery.event.trigger( e, null, elem );
		} else {
			jQuery.event.dispatch.call( elem, e );
		}
		if ( e.isDefaultPrevented() ) {
			event.preventDefault();
		}
	}
};

jQuery.removeEvent = document.removeEventListener ?
	function( elem, type, handle ) {
		if ( elem.removeEventListener ) {
			elem.removeEventListener( type, handle, false );
		}
	} :
	function( elem, type, handle ) {
		var name = "on" + type;

		if ( elem.detachEvent ) {

			// #8545, #7054, preventing memory leaks for custom events in IE6-8
			// detachEvent needed property on element, by name of that event, to properly expose it to GC
			if ( typeof elem[ name ] === core_strundefined ) {
				elem[ name ] = null;
			}

			elem.detachEvent( name, handle );
		}
	};

jQuery.Event = function( src, props ) {
	// Allow instantiation without the 'new' keyword
	if ( !(this instanceof jQuery.Event) ) {
		return new jQuery.Event( src, props );
	}

	// Event object
	if ( src && src.type ) {
		this.originalEvent = src;
		this.type = src.type;

		// Events bubbling up the document may have been marked as prevented
		// by a handler lower down the tree; reflect the correct value.
		this.isDefaultPrevented = ( src.defaultPrevented || src.returnValue === false ||
			src.getPreventDefault && src.getPreventDefault() ) ? returnTrue : returnFalse;

	// Event type
	} else {
		this.type = src;
	}

	// Put explicitly provided properties onto the event object
	if ( props ) {
		jQuery.extend( this, props );
	}

	// Create a timestamp if incoming event doesn't have one
	this.timeStamp = src && src.timeStamp || jQuery.now();

	// Mark it as fixed
	this[ jQuery.expando ] = true;
};

// jQuery.Event is based on DOM3 Events as specified by the ECMAScript Language Binding
// http://www.w3.org/TR/2003/WD-DOM-Level-3-Events-20030331/ecma-script-binding.html
jQuery.Event.prototype = {
	isDefaultPrevented: returnFalse,
	isPropagationStopped: returnFalse,
	isImmediatePropagationStopped: returnFalse,

	preventDefault: function() {
		var e = this.originalEvent;

		this.isDefaultPrevented = returnTrue;
		if ( !e ) {
			return;
		}

		// If preventDefault exists, run it on the original event
		if ( e.preventDefault ) {
			e.preventDefault();

		// Support: IE
		// Otherwise set the returnValue property of the original event to false
		} else {
			e.returnValue = false;
		}
	},
	stopPropagation: function() {
		var e = this.originalEvent;

		this.isPropagationStopped = returnTrue;
		if ( !e ) {
			return;
		}
		// If stopPropagation exists, run it on the original event
		if ( e.stopPropagation ) {
			e.stopPropagation();
		}

		// Support: IE
		// Set the cancelBubble property of the original event to true
		e.cancelBubble = true;
	},
	stopImmediatePropagation: function() {
		this.isImmediatePropagationStopped = returnTrue;
		this.stopPropagation();
	}
};

// Create mouseenter/leave events using mouseover/out and event-time checks
jQuery.each({
	mouseenter: "mouseover",
	mouseleave: "mouseout"
}, function( orig, fix ) {
	jQuery.event.special[ orig ] = {
		delegateType: fix,
		bindType: fix,

		handle: function( event ) {
			var ret,
				target = this,
				related = event.relatedTarget,
				handleObj = event.handleObj;

			// For mousenter/leave call the handler if related is outside the target.
			// NB: No relatedTarget if the mouse left/entered the browser window
			if ( !related || (related !== target && !jQuery.contains( target, related )) ) {
				event.type = handleObj.origType;
				ret = handleObj.handler.apply( this, arguments );
				event.type = fix;
			}
			return ret;
		}
	};
});

// IE submit delegation
if ( !jQuery.support.submitBubbles ) {

	jQuery.event.special.submit = {
		setup: function() {
			// Only need this for delegated form submit events
			if ( jQuery.nodeName( this, "form" ) ) {
				return false;
			}

			// Lazy-add a submit handler when a descendant form may potentially be submitted
			jQuery.event.add( this, "click._submit keypress._submit", function( e ) {
				// Node name check avoids a VML-related crash in IE (#9807)
				var elem = e.target,
					form = jQuery.nodeName( elem, "input" ) || jQuery.nodeName( elem, "button" ) ? elem.form : undefined;
				if ( form && !jQuery._data( form, "submitBubbles" ) ) {
					jQuery.event.add( form, "submit._submit", function( event ) {
						event._submit_bubble = true;
					});
					jQuery._data( form, "submitBubbles", true );
				}
			});
			// return undefined since we don't need an event listener
		},

		postDispatch: function( event ) {
			// If form was submitted by the user, bubble the event up the tree
			if ( event._submit_bubble ) {
				delete event._submit_bubble;
				if ( this.parentNode && !event.isTrigger ) {
					jQuery.event.simulate( "submit", this.parentNode, event, true );
				}
			}
		},

		teardown: function() {
			// Only need this for delegated form submit events
			if ( jQuery.nodeName( this, "form" ) ) {
				return false;
			}

			// Remove delegated handlers; cleanData eventually reaps submit handlers attached above
			jQuery.event.remove( this, "._submit" );
		}
	};
}

// IE change delegation and checkbox/radio fix
if ( !jQuery.support.changeBubbles ) {

	jQuery.event.special.change = {

		setup: function() {

			if ( rformElems.test( this.nodeName ) ) {
				// IE doesn't fire change on a check/radio until blur; trigger it on click
				// after a propertychange. Eat the blur-change in special.change.handle.
				// This still fires onchange a second time for check/radio after blur.
				if ( this.type === "checkbox" || this.type === "radio" ) {
					jQuery.event.add( this, "propertychange._change", function( event ) {
						if ( event.originalEvent.propertyName === "checked" ) {
							this._just_changed = true;
						}
					});
					jQuery.event.add( this, "click._change", function( event ) {
						if ( this._just_changed && !event.isTrigger ) {
							this._just_changed = false;
						}
						// Allow triggered, simulated change events (#11500)
						jQuery.event.simulate( "change", this, event, true );
					});
				}
				return false;
			}
			// Delegated event; lazy-add a change handler on descendant inputs
			jQuery.event.add( this, "beforeactivate._change", function( e ) {
				var elem = e.target;

				if ( rformElems.test( elem.nodeName ) && !jQuery._data( elem, "changeBubbles" ) ) {
					jQuery.event.add( elem, "change._change", function( event ) {
						if ( this.parentNode && !event.isSimulated && !event.isTrigger ) {
							jQuery.event.simulate( "change", this.parentNode, event, true );
						}
					});
					jQuery._data( elem, "changeBubbles", true );
				}
			});
		},

		handle: function( event ) {
			var elem = event.target;

			// Swallow native change events from checkbox/radio, we already triggered them above
			if ( this !== elem || event.isSimulated || event.isTrigger || (elem.type !== "radio" && elem.type !== "checkbox") ) {
				return event.handleObj.handler.apply( this, arguments );
			}
		},

		teardown: function() {
			jQuery.event.remove( this, "._change" );

			return !rformElems.test( this.nodeName );
		}
	};
}

// Create "bubbling" focus and blur events
if ( !jQuery.support.focusinBubbles ) {
	jQuery.each({ focus: "focusin", blur: "focusout" }, function( orig, fix ) {

		// Attach a single capturing handler while someone wants focusin/focusout
		var attaches = 0,
			handler = function( event ) {
				jQuery.event.simulate( fix, event.target, jQuery.event.fix( event ), true );
			};

		jQuery.event.special[ fix ] = {
			setup: function() {
				if ( attaches++ === 0 ) {
					document.addEventListener( orig, handler, true );
				}
			},
			teardown: function() {
				if ( --attaches === 0 ) {
					document.removeEventListener( orig, handler, true );
				}
			}
		};
	});
}

jQuery.fn.extend({

	on: function( types, selector, data, fn, /*INTERNAL*/ one ) {
		var type, origFn;

		// Types can be a map of types/handlers
		if ( typeof types === "object" ) {
			// ( types-Object, selector, data )
			if ( typeof selector !== "string" ) {
				// ( types-Object, data )
				data = data || selector;
				selector = undefined;
			}
			for ( type in types ) {
				this.on( type, selector, data, types[ type ], one );
			}
			return this;
		}

		if ( data == null && fn == null ) {
			// ( types, fn )
			fn = selector;
			data = selector = undefined;
		} else if ( fn == null ) {
			if ( typeof selector === "string" ) {
				// ( types, selector, fn )
				fn = data;
				data = undefined;
			} else {
				// ( types, data, fn )
				fn = data;
				data = selector;
				selector = undefined;
			}
		}
		if ( fn === false ) {
			fn = returnFalse;
		} else if ( !fn ) {
			return this;
		}

		if ( one === 1 ) {
			origFn = fn;
			fn = function( event ) {
				// Can use an empty set, since event contains the info
				jQuery().off( event );
				return origFn.apply( this, arguments );
			};
			// Use same guid so caller can remove using origFn
			fn.guid = origFn.guid || ( origFn.guid = jQuery.guid++ );
		}
		return this.each( function() {
			jQuery.event.add( this, types, fn, data, selector );
		});
	},
	one: function( types, selector, data, fn ) {
		return this.on( types, selector, data, fn, 1 );
	},
	off: function( types, selector, fn ) {
		var handleObj, type;
		if ( types && types.preventDefault && types.handleObj ) {
			// ( event )  dispatched jQuery.Event
			handleObj = types.handleObj;
			jQuery( types.delegateTarget ).off(
				handleObj.namespace ? handleObj.origType + "." + handleObj.namespace : handleObj.origType,
				handleObj.selector,
				handleObj.handler
			);
			return this;
		}
		if ( typeof types === "object" ) {
			// ( types-object [, selector] )
			for ( type in types ) {
				this.off( type, selector, types[ type ] );
			}
			return this;
		}
		if ( selector === false || typeof selector === "function" ) {
			// ( types [, fn] )
			fn = selector;
			selector = undefined;
		}
		if ( fn === false ) {
			fn = returnFalse;
		}
		return this.each(function() {
			jQuery.event.remove( this, types, fn, selector );
		});
	},

	bind: function( types, data, fn ) {
		return this.on( types, null, data, fn );
	},
	unbind: function( types, fn ) {
		return this.off( types, null, fn );
	},

	delegate: function( selector, types, data, fn ) {
		return this.on( types, selector, data, fn );
	},
	undelegate: function( selector, types, fn ) {
		// ( namespace ) or ( selector, types [, fn] )
		return arguments.length === 1 ? this.off( selector, "**" ) : this.off( types, selector || "**", fn );
	},

	trigger: function( type, data ) {
		return this.each(function() {
			jQuery.event.trigger( type, data, this );
		});
	},
	triggerHandler: function( type, data ) {
		var elem = this[0];
		if ( elem ) {
			return jQuery.event.trigger( type, data, elem, true );
		}
	}
});
/*!
 * Sizzle CSS Selector Engine
 * Copyright 2012 jQuery Foundation and other contributors
 * Released under the MIT license
 * http://sizzlejs.com/
 */
(function( window, undefined ) {

var i,
	cachedruns,
	Expr,
	getText,
	isXML,
	compile,
	hasDuplicate,
	outermostContext,

	// Local document vars
	setDocument,
	document,
	docElem,
	documentIsXML,
	rbuggyQSA,
	rbuggyMatches,
	matches,
	contains,
	sortOrder,

	// Instance-specific data
	expando = "sizzle" + -(new Date()),
	preferredDoc = window.document,
	support = {},
	dirruns = 0,
	done = 0,
	classCache = createCache(),
	tokenCache = createCache(),
	compilerCache = createCache(),

	// General-purpose constants
	strundefined = typeof undefined,
	MAX_NEGATIVE = 1 << 31,

	// Array methods
	arr = [],
	pop = arr.pop,
	push = arr.push,
	slice = arr.slice,
	// Use a stripped-down indexOf if we can't use a native one
	indexOf = arr.indexOf || function( elem ) {
		var i = 0,
			len = this.length;
		for ( ; i < len; i++ ) {
			if ( this[i] === elem ) {
				return i;
			}
		}
		return -1;
	},


	// Regular expressions

	// Whitespace characters http://www.w3.org/TR/css3-selectors/#whitespace
	whitespace = "[\\x20\\t\\r\\n\\f]",
	// http://www.w3.org/TR/css3-syntax/#characters
	characterEncoding = "(?:\\\\.|[\\w-]|[^\\x00-\\xa0])+",

	// Loosely modeled on CSS identifier characters
	// An unquoted value should be a CSS identifier http://www.w3.org/TR/css3-selectors/#attribute-selectors
	// Proper syntax: http://www.w3.org/TR/CSS21/syndata.html#value-def-identifier
	identifier = characterEncoding.replace( "w", "w#" ),

	// Acceptable operators http://www.w3.org/TR/selectors/#attribute-selectors
	operators = "([*^$|!~]?=)",
	attributes = "\\[" + whitespace + "*(" + characterEncoding + ")" + whitespace +
		"*(?:" + operators + whitespace + "*(?:(['\"])((?:\\\\.|[^\\\\])*?)\\3|(" + identifier + ")|)|)" + whitespace + "*\\]",

	// Prefer arguments quoted,
	//   then not containing pseudos/brackets,
	//   then attribute selectors/non-parenthetical expressions,
	//   then anything else
	// These preferences are here to reduce the number of selectors
	//   needing tokenize in the PSEUDO preFilter
	pseudos = ":(" + characterEncoding + ")(?:\\(((['\"])((?:\\\\.|[^\\\\])*?)\\3|((?:\\\\.|[^\\\\()[\\]]|" + attributes.replace( 3, 8 ) + ")*)|.*)\\)|)",

	// Leading and non-escaped trailing whitespace, capturing some non-whitespace characters preceding the latter
	rtrim = new RegExp( "^" + whitespace + "+|((?:^|[^\\\\])(?:\\\\.)*)" + whitespace + "+$", "g" ),

	rcomma = new RegExp( "^" + whitespace + "*," + whitespace + "*" ),
	rcombinators = new RegExp( "^" + whitespace + "*([\\x20\\t\\r\\n\\f>+~])" + whitespace + "*" ),
	rpseudo = new RegExp( pseudos ),
	ridentifier = new RegExp( "^" + identifier + "$" ),

	matchExpr = {
		"ID": new RegExp( "^#(" + characterEncoding + ")" ),
		"CLASS": new RegExp( "^\\.(" + characterEncoding + ")" ),
		"NAME": new RegExp( "^\\[name=['\"]?(" + characterEncoding + ")['\"]?\\]" ),
		"TAG": new RegExp( "^(" + characterEncoding.replace( "w", "w*" ) + ")" ),
		"ATTR": new RegExp( "^" + attributes ),
		"PSEUDO": new RegExp( "^" + pseudos ),
		"CHILD": new RegExp( "^:(only|first|last|nth|nth-last)-(child|of-type)(?:\\(" + whitespace +
			"*(even|odd|(([+-]|)(\\d*)n|)" + whitespace + "*(?:([+-]|)" + whitespace +
			"*(\\d+)|))" + whitespace + "*\\)|)", "i" ),
		// For use in libraries implementing .is()
		// We use this for POS matching in `select`
		"needsContext": new RegExp( "^" + whitespace + "*[>+~]|:(even|odd|eq|gt|lt|nth|first|last)(?:\\(" +
			whitespace + "*((?:-\\d)?\\d*)" + whitespace + "*\\)|)(?=[^-]|$)", "i" )
	},

	rsibling = /[\x20\t\r\n\f]*[+~]/,

	rnative = /^[^{]+\{\s*\[native code/,

	// Easily-parseable/retrievable ID or TAG or CLASS selectors
	rquickExpr = /^(?:#([\w-]+)|(\w+)|\.([\w-]+))$/,

	rinputs = /^(?:input|select|textarea|button)$/i,
	rheader = /^h\d$/i,

	rescape = /'|\\/g,
	rattributeQuotes = /\=[\x20\t\r\n\f]*([^'"\]]*)[\x20\t\r\n\f]*\]/g,

	// CSS escapes http://www.w3.org/TR/CSS21/syndata.html#escaped-characters
	runescape = /\\([\da-fA-F]{1,6}[\x20\t\r\n\f]?|.)/g,
	funescape = function( _, escaped ) {
		var high = "0x" + escaped - 0x10000;
		// NaN means non-codepoint
		return high !== high ?
			escaped :
			// BMP codepoint
			high < 0 ?
				String.fromCharCode( high + 0x10000 ) :
				// Supplemental Plane codepoint (surrogate pair)
				String.fromCharCode( high >> 10 | 0xD800, high & 0x3FF | 0xDC00 );
	};

// Use a stripped-down slice if we can't use a native one
try {
	slice.call( preferredDoc.documentElement.childNodes, 0 )[0].nodeType;
} catch ( e ) {
	slice = function( i ) {
		var elem,
			results = [];
		while ( (elem = this[i++]) ) {
			results.push( elem );
		}
		return results;
	};
}

/**
 * For feature detection
 * @param {Function} fn The function to test for native support
 */
function isNative( fn ) {
	return rnative.test( fn + "" );
}

/**
 * Create key-value caches of limited size
 * @returns {Function(string, Object)} Returns the Object data after storing it on itself with
 *	property name the (space-suffixed) string and (if the cache is larger than Expr.cacheLength)
 *	deleting the oldest entry
 */
function createCache() {
	var cache,
		keys = [];

	return (cache = function( key, value ) {
		// Use (key + " ") to avoid collision with native prototype properties (see Issue #157)
		if ( keys.push( key += " " ) > Expr.cacheLength ) {
			// Only keep the most recent entries
			delete cache[ keys.shift() ];
		}
		return (cache[ key ] = value);
	});
}

/**
 * Mark a function for special use by Sizzle
 * @param {Function} fn The function to mark
 */
function markFunction( fn ) {
	fn[ expando ] = true;
	return fn;
}

/**
 * Support testing using an element
 * @param {Function} fn Passed the created div and expects a boolean result
 */
function assert( fn ) {
	var div = document.createElement("div");

	try {
		return fn( div );
	} catch (e) {
		return false;
	} finally {
		// release memory in IE
		div = null;
	}
}

function Sizzle( selector, context, results, seed ) {
	var match, elem, m, nodeType,
		// QSA vars
		i, groups, old, nid, newContext, newSelector;

	if ( ( context ? context.ownerDocument || context : preferredDoc ) !== document ) {
		setDocument( context );
	}

	context = context || document;
	results = results || [];

	if ( !selector || typeof selector !== "string" ) {
		return results;
	}

	if ( (nodeType = context.nodeType) !== 1 && nodeType !== 9 ) {
		return [];
	}

	if ( !documentIsXML && !seed ) {

		// Shortcuts
		if ( (match = rquickExpr.exec( selector )) ) {
			// Speed-up: Sizzle("#ID")
			if ( (m = match[1]) ) {
				if ( nodeType === 9 ) {
					elem = context.getElementById( m );
					// Check parentNode to catch when Blackberry 4.6 returns
					// nodes that are no longer in the document #6963
					if ( elem && elem.parentNode ) {
						// Handle the case where IE, Opera, and Webkit return items
						// by name instead of ID
						if ( elem.id === m ) {
							results.push( elem );
							return results;
						}
					} else {
						return results;
					}
				} else {
					// Context is not a document
					if ( context.ownerDocument && (elem = context.ownerDocument.getElementById( m )) &&
						contains( context, elem ) && elem.id === m ) {
						results.push( elem );
						return results;
					}
				}

			// Speed-up: Sizzle("TAG")
			} else if ( match[2] ) {
				push.apply( results, slice.call(context.getElementsByTagName( selector ), 0) );
				return results;

			// Speed-up: Sizzle(".CLASS")
			} else if ( (m = match[3]) && support.getByClassName && context.getElementsByClassName ) {
				push.apply( results, slice.call(context.getElementsByClassName( m ), 0) );
				return results;
			}
		}

		// QSA path
		if ( support.qsa && !rbuggyQSA.test(selector) ) {
			old = true;
			nid = expando;
			newContext = context;
			newSelector = nodeType === 9 && selector;

			// qSA works strangely on Element-rooted queries
			// We can work around this by specifying an extra ID on the root
			// and working up from there (Thanks to Andrew Dupont for the technique)
			// IE 8 doesn't work on object elements
			if ( nodeType === 1 && context.nodeName.toLowerCase() !== "object" ) {
				groups = tokenize( selector );

				if ( (old = context.getAttribute("id")) ) {
					nid = old.replace( rescape, "\\$&" );
				} else {
					context.setAttribute( "id", nid );
				}
				nid = "[id='" + nid + "'] ";

				i = groups.length;
				while ( i-- ) {
					groups[i] = nid + toSelector( groups[i] );
				}
				newContext = rsibling.test( selector ) && context.parentNode || context;
				newSelector = groups.join(",");
			}

			if ( newSelector ) {
				try {
					push.apply( results, slice.call( newContext.querySelectorAll(
						newSelector
					), 0 ) );
					return results;
				} catch(qsaError) {
				} finally {
					if ( !old ) {
						context.removeAttribute("id");
					}
				}
			}
		}
	}

	// All others
	return select( selector.replace( rtrim, "$1" ), context, results, seed );
}

/**
 * Detect xml
 * @param {Element|Object} elem An element or a document
 */
isXML = Sizzle.isXML = function( elem ) {
	// documentElement is verified for cases where it doesn't yet exist
	// (such as loading iframes in IE - #4833)
	var documentElement = elem && (elem.ownerDocument || elem).documentElement;
	return documentElement ? documentElement.nodeName !== "HTML" : false;
};

/**
 * Sets document-related variables once based on the current document
 * @param {Element|Object} [doc] An element or document object to use to set the document
 * @returns {Object} Returns the current document
 */
setDocument = Sizzle.setDocument = function( node ) {
	var doc = node ? node.ownerDocument || node : preferredDoc;

	// If no document and documentElement is available, return
	if ( doc === document || doc.nodeType !== 9 || !doc.documentElement ) {
		return document;
	}

	// Set our document
	document = doc;
	docElem = doc.documentElement;

	// Support tests
	documentIsXML = isXML( doc );

	// Check if getElementsByTagName("*") returns only elements
	support.tagNameNoComments = assert(function( div ) {
		div.appendChild( doc.createComment("") );
		return !div.getElementsByTagName("*").length;
	});

	// Check if attributes should be retrieved by attribute nodes
	support.attributes = assert(function( div ) {
		div.innerHTML = "<select></select>";
		var type = typeof div.lastChild.getAttribute("multiple");
		// IE8 returns a string for some attributes even when not present
		return type !== "boolean" && type !== "string";
	});

	// Check if getElementsByClassName can be trusted
	support.getByClassName = assert(function( div ) {
		// Opera can't find a second classname (in 9.6)
		div.innerHTML = "<div class='hidden e'></div><div class='hidden'></div>";
		if ( !div.getElementsByClassName || !div.getElementsByClassName("e").length ) {
			return false;
		}

		// Safari 3.2 caches class attributes and doesn't catch changes
		div.lastChild.className = "e";
		return div.getElementsByClassName("e").length === 2;
	});

	// Check if getElementById returns elements by name
	// Check if getElementsByName privileges form controls or returns elements by ID
	support.getByName = assert(function( div ) {
		// Inject content
		div.id = expando + 0;
		div.innerHTML = "<a name='" + expando + "'></a><div name='" + expando + "'></div>";
		docElem.insertBefore( div, docElem.firstChild );

		// Test
		var pass = doc.getElementsByName &&
			// buggy browsers will return fewer than the correct 2
			doc.getElementsByName( expando ).length === 2 +
			// buggy browsers will return more than the correct 0
			doc.getElementsByName( expando + 0 ).length;
		support.getIdNotName = !doc.getElementById( expando );

		// Cleanup
		docElem.removeChild( div );

		return pass;
	});

	// IE6/7 return modified attributes
	Expr.attrHandle = assert(function( div ) {
		div.innerHTML = "<a href='#'></a>";
		return div.firstChild && typeof div.firstChild.getAttribute !== strundefined &&
			div.firstChild.getAttribute("href") === "#";
	}) ?
		{} :
		{
			"href": function( elem ) {
				return elem.getAttribute( "href", 2 );
			},
			"type": function( elem ) {
				return elem.getAttribute("type");
			}
		};

	// ID find and filter
	if ( support.getIdNotName ) {
		Expr.find["ID"] = function( id, context ) {
			if ( typeof context.getElementById !== strundefined && !documentIsXML ) {
				var m = context.getElementById( id );
				// Check parentNode to catch when Blackberry 4.6 returns
				// nodes that are no longer in the document #6963
				return m && m.parentNode ? [m] : [];
			}
		};
		Expr.filter["ID"] = function( id ) {
			var attrId = id.replace( runescape, funescape );
			return function( elem ) {
				return elem.getAttribute("id") === attrId;
			};
		};
	} else {
		Expr.find["ID"] = function( id, context ) {
			if ( typeof context.getElementById !== strundefined && !documentIsXML ) {
				var m = context.getElementById( id );

				return m ?
					m.id === id || typeof m.getAttributeNode !== strundefined && m.getAttributeNode("id").value === id ?
						[m] :
						undefined :
					[];
			}
		};
		Expr.filter["ID"] =  function( id ) {
			var attrId = id.replace( runescape, funescape );
			return function( elem ) {
				var node = typeof elem.getAttributeNode !== strundefined && elem.getAttributeNode("id");
				return node && node.value === attrId;
			};
		};
	}

	// Tag
	Expr.find["TAG"] = support.tagNameNoComments ?
		function( tag, context ) {
			if ( typeof context.getElementsByTagName !== strundefined ) {
				return context.getElementsByTagName( tag );
			}
		} :
		function( tag, context ) {
			var elem,
				tmp = [],
				i = 0,
				results = context.getElementsByTagName( tag );

			// Filter out possible comments
			if ( tag === "*" ) {
				while ( (elem = results[i++]) ) {
					if ( elem.nodeType === 1 ) {
						tmp.push( elem );
					}
				}

				return tmp;
			}
			return results;
		};

	// Name
	Expr.find["NAME"] = support.getByName && function( tag, context ) {
		if ( typeof context.getElementsByName !== strundefined ) {
			return context.getElementsByName( name );
		}
	};

	// Class
	Expr.find["CLASS"] = support.getByClassName && function( className, context ) {
		if ( typeof context.getElementsByClassName !== strundefined && !documentIsXML ) {
			return context.getElementsByClassName( className );
		}
	};

	// QSA and matchesSelector support

	// matchesSelector(:active) reports false when true (IE9/Opera 11.5)
	rbuggyMatches = [];

	// qSa(:focus) reports false when true (Chrome 21),
	// no need to also add to buggyMatches since matches checks buggyQSA
	// A support test would require too much code (would include document ready)
	rbuggyQSA = [ ":focus" ];

	if ( (support.qsa = isNative(doc.querySelectorAll)) ) {
		// Build QSA regex
		// Regex strategy adopted from Diego Perini
		assert(function( div ) {
			// Select is set to empty string on purpose
			// This is to test IE's treatment of not explictly
			// setting a boolean content attribute,
			// since its presence should be enough
			// http://bugs.jquery.com/ticket/12359
			div.innerHTML = "<select><option selected=''></option></select>";

			// IE8 - Some boolean attributes are not treated correctly
			if ( !div.querySelectorAll("[selected]").length ) {
				rbuggyQSA.push( "\\[" + whitespace + "*(?:checked|disabled|ismap|multiple|readonly|selected|value)" );
			}

			// Webkit/Opera - :checked should return selected option elements
			// http://www.w3.org/TR/2011/REC-css3-selectors-20110929/#checked
			// IE8 throws error here and will not see later tests
			if ( !div.querySelectorAll(":checked").length ) {
				rbuggyQSA.push(":checked");
			}
		});

		assert(function( div ) {

			// Opera 10-12/IE8 - ^= $= *= and empty values
			// Should not select anything
			div.innerHTML = "<input type='hidden' i=''/>";
			if ( div.querySelectorAll("[i^='']").length ) {
				rbuggyQSA.push( "[*^$]=" + whitespace + "*(?:\"\"|'')" );
			}

			// FF 3.5 - :enabled/:disabled and hidden elements (hidden elements are still enabled)
			// IE8 throws error here and will not see later tests
			if ( !div.querySelectorAll(":enabled").length ) {
				rbuggyQSA.push( ":enabled", ":disabled" );
			}

			// Opera 10-11 does not throw on post-comma invalid pseudos
			div.querySelectorAll("*,:x");
			rbuggyQSA.push(",.*:");
		});
	}

	if ( (support.matchesSelector = isNative( (matches = docElem.matchesSelector ||
		docElem.mozMatchesSelector ||
		docElem.webkitMatchesSelector ||
		docElem.oMatchesSelector ||
		docElem.msMatchesSelector) )) ) {

		assert(function( div ) {
			// Check to see if it's possible to do matchesSelector
			// on a disconnected node (IE 9)
			support.disconnectedMatch = matches.call( div, "div" );

			// This should fail with an exception
			// Gecko does not error, returns false instead
			matches.call( div, "[s!='']:x" );
			rbuggyMatches.push( "!=", pseudos );
		});
	}

	rbuggyQSA = new RegExp( rbuggyQSA.join("|") );
	rbuggyMatches = new RegExp( rbuggyMatches.join("|") );

	// Element contains another
	// Purposefully does not implement inclusive descendent
	// As in, an element does not contain itself
	contains = isNative(docElem.contains) || docElem.compareDocumentPosition ?
		function( a, b ) {
			var adown = a.nodeType === 9 ? a.documentElement : a,
				bup = b && b.parentNode;
			return a === bup || !!( bup && bup.nodeType === 1 && (
				adown.contains ?
					adown.contains( bup ) :
					a.compareDocumentPosition && a.compareDocumentPosition( bup ) & 16
			));
		} :
		function( a, b ) {
			if ( b ) {
				while ( (b = b.parentNode) ) {
					if ( b === a ) {
						return true;
					}
				}
			}
			return false;
		};

	// Document order sorting
	sortOrder = docElem.compareDocumentPosition ?
	function( a, b ) {
		var compare;

		if ( a === b ) {
			hasDuplicate = true;
			return 0;
		}

		if ( (compare = b.compareDocumentPosition && a.compareDocumentPosition && a.compareDocumentPosition( b )) ) {
			if ( compare & 1 || a.parentNode && a.parentNode.nodeType === 11 ) {
				if ( a === doc || contains( preferredDoc, a ) ) {
					return -1;
				}
				if ( b === doc || contains( preferredDoc, b ) ) {
					return 1;
				}
				return 0;
			}
			return compare & 4 ? -1 : 1;
		}

		return a.compareDocumentPosition ? -1 : 1;
	} :
	function( a, b ) {
		var cur,
			i = 0,
			aup = a.parentNode,
			bup = b.parentNode,
			ap = [ a ],
			bp = [ b ];

		// Exit early if the nodes are identical
		if ( a === b ) {
			hasDuplicate = true;
			return 0;

		// Parentless nodes are either documents or disconnected
		} else if ( !aup || !bup ) {
			return a === doc ? -1 :
				b === doc ? 1 :
				aup ? -1 :
				bup ? 1 :
				0;

		// If the nodes are siblings, we can do a quick check
		} else if ( aup === bup ) {
			return siblingCheck( a, b );
		}

		// Otherwise we need full lists of their ancestors for comparison
		cur = a;
		while ( (cur = cur.parentNode) ) {
			ap.unshift( cur );
		}
		cur = b;
		while ( (cur = cur.parentNode) ) {
			bp.unshift( cur );
		}

		// Walk down the tree looking for a discrepancy
		while ( ap[i] === bp[i] ) {
			i++;
		}

		return i ?
			// Do a sibling check if the nodes have a common ancestor
			siblingCheck( ap[i], bp[i] ) :

			// Otherwise nodes in our document sort first
			ap[i] === preferredDoc ? -1 :
			bp[i] === preferredDoc ? 1 :
			0;
	};

	// Always assume the presence of duplicates if sort doesn't
	// pass them to our comparison function (as in Google Chrome).
	hasDuplicate = false;
	[0, 0].sort( sortOrder );
	support.detectDuplicates = hasDuplicate;

	return document;
};

Sizzle.matches = function( expr, elements ) {
	return Sizzle( expr, null, null, elements );
};

Sizzle.matchesSelector = function( elem, expr ) {
	// Set document vars if needed
	if ( ( elem.ownerDocument || elem ) !== document ) {
		setDocument( elem );
	}

	// Make sure that attribute selectors are quoted
	expr = expr.replace( rattributeQuotes, "='$1']" );

	// rbuggyQSA always contains :focus, so no need for an existence check
	if ( support.matchesSelector && !documentIsXML && (!rbuggyMatches || !rbuggyMatches.test(expr)) && !rbuggyQSA.test(expr) ) {
		try {
			var ret = matches.call( elem, expr );

			// IE 9's matchesSelector returns false on disconnected nodes
			if ( ret || support.disconnectedMatch ||
					// As well, disconnected nodes are said to be in a document
					// fragment in IE 9
					elem.document && elem.document.nodeType !== 11 ) {
				return ret;
			}
		} catch(e) {}
	}

	return Sizzle( expr, document, null, [elem] ).length > 0;
};

Sizzle.contains = function( context, elem ) {
	// Set document vars if needed
	if ( ( context.ownerDocument || context ) !== document ) {
		setDocument( context );
	}
	return contains( context, elem );
};

Sizzle.attr = function( elem, name ) {
	var val;

	// Set document vars if needed
	if ( ( elem.ownerDocument || elem ) !== document ) {
		setDocument( elem );
	}

	if ( !documentIsXML ) {
		name = name.toLowerCase();
	}
	if ( (val = Expr.attrHandle[ name ]) ) {
		return val( elem );
	}
	if ( documentIsXML || support.attributes ) {
		return elem.getAttribute( name );
	}
	return ( (val = elem.getAttributeNode( name )) || elem.getAttribute( name ) ) && elem[ name ] === true ?
		name :
		val && val.specified ? val.value : null;
};

Sizzle.error = function( msg ) {
	throw new Error( "Syntax error, unrecognized expression: " + msg );
};

// Document sorting and removing duplicates
Sizzle.uniqueSort = function( results ) {
	var elem,
		duplicates = [],
		i = 1,
		j = 0;

	// Unless we *know* we can detect duplicates, assume their presence
	hasDuplicate = !support.detectDuplicates;
	results.sort( sortOrder );

	if ( hasDuplicate ) {
		for ( ; (elem = results[i]); i++ ) {
			if ( elem === results[ i - 1 ] ) {
				j = duplicates.push( i );
			}
		}
		while ( j-- ) {
			results.splice( duplicates[ j ], 1 );
		}
	}

	return results;
};

function siblingCheck( a, b ) {
	var cur = b && a,
		diff = cur && ( ~b.sourceIndex || MAX_NEGATIVE ) - ( ~a.sourceIndex || MAX_NEGATIVE );

	// Use IE sourceIndex if available on both nodes
	if ( diff ) {
		return diff;
	}

	// Check if b follows a
	if ( cur ) {
		while ( (cur = cur.nextSibling) ) {
			if ( cur === b ) {
				return -1;
			}
		}
	}

	return a ? 1 : -1;
}

// Returns a function to use in pseudos for input types
function createInputPseudo( type ) {
	return function( elem ) {
		var name = elem.nodeName.toLowerCase();
		return name === "input" && elem.type === type;
	};
}

// Returns a function to use in pseudos for buttons
function createButtonPseudo( type ) {
	return function( elem ) {
		var name = elem.nodeName.toLowerCase();
		return (name === "input" || name === "button") && elem.type === type;
	};
}

// Returns a function to use in pseudos for positionals
function createPositionalPseudo( fn ) {
	return markFunction(function( argument ) {
		argument = +argument;
		return markFunction(function( seed, matches ) {
			var j,
				matchIndexes = fn( [], seed.length, argument ),
				i = matchIndexes.length;

			// Match elements found at the specified indexes
			while ( i-- ) {
				if ( seed[ (j = matchIndexes[i]) ] ) {
					seed[j] = !(matches[j] = seed[j]);
				}
			}
		});
	});
}

/**
 * Utility function for retrieving the text value of an array of DOM nodes
 * @param {Array|Element} elem
 */
getText = Sizzle.getText = function( elem ) {
	var node,
		ret = "",
		i = 0,
		nodeType = elem.nodeType;

	if ( !nodeType ) {
		// If no nodeType, this is expected to be an array
		for ( ; (node = elem[i]); i++ ) {
			// Do not traverse comment nodes
			ret += getText( node );
		}
	} else if ( nodeType === 1 || nodeType === 9 || nodeType === 11 ) {
		// Use textContent for elements
		// innerText usage removed for consistency of new lines (see #11153)
		if ( typeof elem.textContent === "string" ) {
			return elem.textContent;
		} else {
			// Traverse its children
			for ( elem = elem.firstChild; elem; elem = elem.nextSibling ) {
				ret += getText( elem );
			}
		}
	} else if ( nodeType === 3 || nodeType === 4 ) {
		return elem.nodeValue;
	}
	// Do not include comment or processing instruction nodes

	return ret;
};

Expr = Sizzle.selectors = {

	// Can be adjusted by the user
	cacheLength: 50,

	createPseudo: markFunction,

	match: matchExpr,

	find: {},

	relative: {
		">": { dir: "parentNode", first: true },
		" ": { dir: "parentNode" },
		"+": { dir: "previousSibling", first: true },
		"~": { dir: "previousSibling" }
	},

	preFilter: {
		"ATTR": function( match ) {
			match[1] = match[1].replace( runescape, funescape );

			// Move the given value to match[3] whether quoted or unquoted
			match[3] = ( match[4] || match[5] || "" ).replace( runescape, funescape );

			if ( match[2] === "~=" ) {
				match[3] = " " + match[3] + " ";
			}

			return match.slice( 0, 4 );
		},

		"CHILD": function( match ) {
			/* matches from matchExpr["CHILD"]
				1 type (only|nth|...)
				2 what (child|of-type)
				3 argument (even|odd|\d*|\d*n([+-]\d+)?|...)
				4 xn-component of xn+y argument ([+-]?\d*n|)
				5 sign of xn-component
				6 x of xn-component
				7 sign of y-component
				8 y of y-component
			*/
			match[1] = match[1].toLowerCase();

			if ( match[1].slice( 0, 3 ) === "nth" ) {
				// nth-* requires argument
				if ( !match[3] ) {
					Sizzle.error( match[0] );
				}

				// numeric x and y parameters for Expr.filter.CHILD
				// remember that false/true cast respectively to 0/1
				match[4] = +( match[4] ? match[5] + (match[6] || 1) : 2 * ( match[3] === "even" || match[3] === "odd" ) );
				match[5] = +( ( match[7] + match[8] ) || match[3] === "odd" );

			// other types prohibit arguments
			} else if ( match[3] ) {
				Sizzle.error( match[0] );
			}

			return match;
		},

		"PSEUDO": function( match ) {
			var excess,
				unquoted = !match[5] && match[2];

			if ( matchExpr["CHILD"].test( match[0] ) ) {
				return null;
			}

			// Accept quoted arguments as-is
			if ( match[4] ) {
				match[2] = match[4];

			// Strip excess characters from unquoted arguments
			} else if ( unquoted && rpseudo.test( unquoted ) &&
				// Get excess from tokenize (recursively)
				(excess = tokenize( unquoted, true )) &&
				// advance to the next closing parenthesis
				(excess = unquoted.indexOf( ")", unquoted.length - excess ) - unquoted.length) ) {

				// excess is a negative index
				match[0] = match[0].slice( 0, excess );
				match[2] = unquoted.slice( 0, excess );
			}

			// Return only captures needed by the pseudo filter method (type and argument)
			return match.slice( 0, 3 );
		}
	},

	filter: {

		"TAG": function( nodeName ) {
			if ( nodeName === "*" ) {
				return function() { return true; };
			}

			nodeName = nodeName.replace( runescape, funescape ).toLowerCase();
			return function( elem ) {
				return elem.nodeName && elem.nodeName.toLowerCase() === nodeName;
			};
		},

		"CLASS": function( className ) {
			var pattern = classCache[ className + " " ];

			return pattern ||
				(pattern = new RegExp( "(^|" + whitespace + ")" + className + "(" + whitespace + "|$)" )) &&
				classCache( className, function( elem ) {
					return pattern.test( elem.className || (typeof elem.getAttribute !== strundefined && elem.getAttribute("class")) || "" );
				});
		},

		"ATTR": function( name, operator, check ) {
			return function( elem ) {
				var result = Sizzle.attr( elem, name );

				if ( result == null ) {
					return operator === "!=";
				}
				if ( !operator ) {
					return true;
				}

				result += "";

				return operator === "=" ? result === check :
					operator === "!=" ? result !== check :
					operator === "^=" ? check && result.indexOf( check ) === 0 :
					operator === "*=" ? check && result.indexOf( check ) > -1 :
					operator === "$=" ? check && result.slice( -check.length ) === check :
					operator === "~=" ? ( " " + result + " " ).indexOf( check ) > -1 :
					operator === "|=" ? result === check || result.slice( 0, check.length + 1 ) === check + "-" :
					false;
			};
		},

		"CHILD": function( type, what, argument, first, last ) {
			var simple = type.slice( 0, 3 ) !== "nth",
				forward = type.slice( -4 ) !== "last",
				ofType = what === "of-type";

			return first === 1 && last === 0 ?

				// Shortcut for :nth-*(n)
				function( elem ) {
					return !!elem.parentNode;
				} :

				function( elem, context, xml ) {
					var cache, outerCache, node, diff, nodeIndex, start,
						dir = simple !== forward ? "nextSibling" : "previousSibling",
						parent = elem.parentNode,
						name = ofType && elem.nodeName.toLowerCase(),
						useCache = !xml && !ofType;

					if ( parent ) {

						// :(first|last|only)-(child|of-type)
						if ( simple ) {
							while ( dir ) {
								node = elem;
								while ( (node = node[ dir ]) ) {
									if ( ofType ? node.nodeName.toLowerCase() === name : node.nodeType === 1 ) {
										return false;
									}
								}
								// Reverse direction for :only-* (if we haven't yet done so)
								start = dir = type === "only" && !start && "nextSibling";
							}
							return true;
						}

						start = [ forward ? parent.firstChild : parent.lastChild ];

						// non-xml :nth-child(...) stores cache data on `parent`
						if ( forward && useCache ) {
							// Seek `elem` from a previously-cached index
							outerCache = parent[ expando ] || (parent[ expando ] = {});
							cache = outerCache[ type ] || [];
							nodeIndex = cache[0] === dirruns && cache[1];
							diff = cache[0] === dirruns && cache[2];
							node = nodeIndex && parent.childNodes[ nodeIndex ];

							while ( (node = ++nodeIndex && node && node[ dir ] ||

								// Fallback to seeking `elem` from the start
								(diff = nodeIndex = 0) || start.pop()) ) {

								// When found, cache indexes on `parent` and break
								if ( node.nodeType === 1 && ++diff && node === elem ) {
									outerCache[ type ] = [ dirruns, nodeIndex, diff ];
									break;
								}
							}

						// Use previously-cached element index if available
						} else if ( useCache && (cache = (elem[ expando ] || (elem[ expando ] = {}))[ type ]) && cache[0] === dirruns ) {
							diff = cache[1];

						// xml :nth-child(...) or :nth-last-child(...) or :nth(-last)?-of-type(...)
						} else {
							// Use the same loop as above to seek `elem` from the start
							while ( (node = ++nodeIndex && node && node[ dir ] ||
								(diff = nodeIndex = 0) || start.pop()) ) {

								if ( ( ofType ? node.nodeName.toLowerCase() === name : node.nodeType === 1 ) && ++diff ) {
									// Cache the index of each encountered element
									if ( useCache ) {
										(node[ expando ] || (node[ expando ] = {}))[ type ] = [ dirruns, diff ];
									}

									if ( node === elem ) {
										break;
									}
								}
							}
						}

						// Incorporate the offset, then check against cycle size
						diff -= last;
						return diff === first || ( diff % first === 0 && diff / first >= 0 );
					}
				};
		},

		"PSEUDO": function( pseudo, argument ) {
			// pseudo-class names are case-insensitive
			// http://www.w3.org/TR/selectors/#pseudo-classes
			// Prioritize by case sensitivity in case custom pseudos are added with uppercase letters
			// Remember that setFilters inherits from pseudos
			var args,
				fn = Expr.pseudos[ pseudo ] || Expr.setFilters[ pseudo.toLowerCase() ] ||
					Sizzle.error( "unsupported pseudo: " + pseudo );

			// The user may use createPseudo to indicate that
			// arguments are needed to create the filter function
			// just as Sizzle does
			if ( fn[ expando ] ) {
				return fn( argument );
			}

			// But maintain support for old signatures
			if ( fn.length > 1 ) {
				args = [ pseudo, pseudo, "", argument ];
				return Expr.setFilters.hasOwnProperty( pseudo.toLowerCase() ) ?
					markFunction(function( seed, matches ) {
						var idx,
							matched = fn( seed, argument ),
							i = matched.length;
						while ( i-- ) {
							idx = indexOf.call( seed, matched[i] );
							seed[ idx ] = !( matches[ idx ] = matched[i] );
						}
					}) :
					function( elem ) {
						return fn( elem, 0, args );
					};
			}

			return fn;
		}
	},

	pseudos: {
		// Potentially complex pseudos
		"not": markFunction(function( selector ) {
			// Trim the selector passed to compile
			// to avoid treating leading and trailing
			// spaces as combinators
			var input = [],
				results = [],
				matcher = compile( selector.replace( rtrim, "$1" ) );

			return matcher[ expando ] ?
				markFunction(function( seed, matches, context, xml ) {
					var elem,
						unmatched = matcher( seed, null, xml, [] ),
						i = seed.length;

					// Match elements unmatched by `matcher`
					while ( i-- ) {
						if ( (elem = unmatched[i]) ) {
							seed[i] = !(matches[i] = elem);
						}
					}
				}) :
				function( elem, context, xml ) {
					input[0] = elem;
					matcher( input, null, xml, results );
					return !results.pop();
				};
		}),

		"has": markFunction(function( selector ) {
			return function( elem ) {
				return Sizzle( selector, elem ).length > 0;
			};
		}),

		"contains": markFunction(function( text ) {
			return function( elem ) {
				return ( elem.textContent || elem.innerText || getText( elem ) ).indexOf( text ) > -1;
			};
		}),

		// "Whether an element is represented by a :lang() selector
		// is based solely on the element's language value
		// being equal to the identifier C,
		// or beginning with the identifier C immediately followed by "-".
		// The matching of C against the element's language value is performed case-insensitively.
		// The identifier C does not have to be a valid language name."
		// http://www.w3.org/TR/selectors/#lang-pseudo
		"lang": markFunction( function( lang ) {
			// lang value must be a valid identifider
			if ( !ridentifier.test(lang || "") ) {
				Sizzle.error( "unsupported lang: " + lang );
			}
			lang = lang.replace( runescape, funescape ).toLowerCase();
			return function( elem ) {
				var elemLang;
				do {
					if ( (elemLang = documentIsXML ?
						elem.getAttribute("xml:lang") || elem.getAttribute("lang") :
						elem.lang) ) {

						elemLang = elemLang.toLowerCase();
						return elemLang === lang || elemLang.indexOf( lang + "-" ) === 0;
					}
				} while ( (elem = elem.parentNode) && elem.nodeType === 1 );
				return false;
			};
		}),

		// Miscellaneous
		"target": function( elem ) {
			var hash = window.location && window.location.hash;
			return hash && hash.slice( 1 ) === elem.id;
		},

		"root": function( elem ) {
			return elem === docElem;
		},

		"focus": function( elem ) {
			return elem === document.activeElement && (!document.hasFocus || document.hasFocus()) && !!(elem.type || elem.href || ~elem.tabIndex);
		},

		// Boolean properties
		"enabled": function( elem ) {
			return elem.disabled === false;
		},

		"disabled": function( elem ) {
			return elem.disabled === true;
		},

		"checked": function( elem ) {
			// In CSS3, :checked should return both checked and selected elements
			// http://www.w3.org/TR/2011/REC-css3-selectors-20110929/#checked
			var nodeName = elem.nodeName.toLowerCase();
			return (nodeName === "input" && !!elem.checked) || (nodeName === "option" && !!elem.selected);
		},

		"selected": function( elem ) {
			// Accessing this property makes selected-by-default
			// options in Safari work properly
			if ( elem.parentNode ) {
				elem.parentNode.selectedIndex;
			}

			return elem.selected === true;
		},

		// Contents
		"empty": function( elem ) {
			// http://www.w3.org/TR/selectors/#empty-pseudo
			// :empty is only affected by element nodes and content nodes(including text(3), cdata(4)),
			//   not comment, processing instructions, or others
			// Thanks to Diego Perini for the nodeName shortcut
			//   Greater than "@" means alpha characters (specifically not starting with "#" or "?")
			for ( elem = elem.firstChild; elem; elem = elem.nextSibling ) {
				if ( elem.nodeName > "@" || elem.nodeType === 3 || elem.nodeType === 4 ) {
					return false;
				}
			}
			return true;
		},

		"parent": function( elem ) {
			return !Expr.pseudos["empty"]( elem );
		},

		// Element/input types
		"header": function( elem ) {
			return rheader.test( elem.nodeName );
		},

		"input": function( elem ) {
			return rinputs.test( elem.nodeName );
		},

		"button": function( elem ) {
			var name = elem.nodeName.toLowerCase();
			return name === "input" && elem.type === "button" || name === "button";
		},

		"text": function( elem ) {
			var attr;
			// IE6 and 7 will map elem.type to 'text' for new HTML5 types (search, etc)
			// use getAttribute instead to test this case
			return elem.nodeName.toLowerCase() === "input" &&
				elem.type === "text" &&
				( (attr = elem.getAttribute("type")) == null || attr.toLowerCase() === elem.type );
		},

		// Position-in-collection
		"first": createPositionalPseudo(function() {
			return [ 0 ];
		}),

		"last": createPositionalPseudo(function( matchIndexes, length ) {
			return [ length - 1 ];
		}),

		"eq": createPositionalPseudo(function( matchIndexes, length, argument ) {
			return [ argument < 0 ? argument + length : argument ];
		}),

		"even": createPositionalPseudo(function( matchIndexes, length ) {
			var i = 0;
			for ( ; i < length; i += 2 ) {
				matchIndexes.push( i );
			}
			return matchIndexes;
		}),

		"odd": createPositionalPseudo(function( matchIndexes, length ) {
			var i = 1;
			for ( ; i < length; i += 2 ) {
				matchIndexes.push( i );
			}
			return matchIndexes;
		}),

		"lt": createPositionalPseudo(function( matchIndexes, length, argument ) {
			var i = argument < 0 ? argument + length : argument;
			for ( ; --i >= 0; ) {
				matchIndexes.push( i );
			}
			return matchIndexes;
		}),

		"gt": createPositionalPseudo(function( matchIndexes, length, argument ) {
			var i = argument < 0 ? argument + length : argument;
			for ( ; ++i < length; ) {
				matchIndexes.push( i );
			}
			return matchIndexes;
		})
	}
};

// Add button/input type pseudos
for ( i in { radio: true, checkbox: true, file: true, password: true, image: true } ) {
	Expr.pseudos[ i ] = createInputPseudo( i );
}
for ( i in { submit: true, reset: true } ) {
	Expr.pseudos[ i ] = createButtonPseudo( i );
}

function tokenize( selector, parseOnly ) {
	var matched, match, tokens, type,
		soFar, groups, preFilters,
		cached = tokenCache[ selector + " " ];

	if ( cached ) {
		return parseOnly ? 0 : cached.slice( 0 );
	}

	soFar = selector;
	groups = [];
	preFilters = Expr.preFilter;

	while ( soFar ) {

		// Comma and first run
		if ( !matched || (match = rcomma.exec( soFar )) ) {
			if ( match ) {
				// Don't consume trailing commas as valid
				soFar = soFar.slice( match[0].length ) || soFar;
			}
			groups.push( tokens = [] );
		}

		matched = false;

		// Combinators
		if ( (match = rcombinators.exec( soFar )) ) {
			matched = match.shift();
			tokens.push( {
				value: matched,
				// Cast descendant combinators to space
				type: match[0].replace( rtrim, " " )
			} );
			soFar = soFar.slice( matched.length );
		}

		// Filters
		for ( type in Expr.filter ) {
			if ( (match = matchExpr[ type ].exec( soFar )) && (!preFilters[ type ] ||
				(match = preFilters[ type ]( match ))) ) {
				matched = match.shift();
				tokens.push( {
					value: matched,
					type: type,
					matches: match
				} );
				soFar = soFar.slice( matched.length );
			}
		}

		if ( !matched ) {
			break;
		}
	}

	// Return the length of the invalid excess
	// if we're just parsing
	// Otherwise, throw an error or return tokens
	return parseOnly ?
		soFar.length :
		soFar ?
			Sizzle.error( selector ) :
			// Cache the tokens
			tokenCache( selector, groups ).slice( 0 );
}

function toSelector( tokens ) {
	var i = 0,
		len = tokens.length,
		selector = "";
	for ( ; i < len; i++ ) {
		selector += tokens[i].value;
	}
	return selector;
}

function addCombinator( matcher, combinator, base ) {
	var dir = combinator.dir,
		checkNonElements = base && dir === "parentNode",
		doneName = done++;

	return combinator.first ?
		// Check against closest ancestor/preceding element
		function( elem, context, xml ) {
			while ( (elem = elem[ dir ]) ) {
				if ( elem.nodeType === 1 || checkNonElements ) {
					return matcher( elem, context, xml );
				}
			}
		} :

		// Check against all ancestor/preceding elements
		function( elem, context, xml ) {
			var data, cache, outerCache,
				dirkey = dirruns + " " + doneName;

			// We can't set arbitrary data on XML nodes, so they don't benefit from dir caching
			if ( xml ) {
				while ( (elem = elem[ dir ]) ) {
					if ( elem.nodeType === 1 || checkNonElements ) {
						if ( matcher( elem, context, xml ) ) {
							return true;
						}
					}
				}
			} else {
				while ( (elem = elem[ dir ]) ) {
					if ( elem.nodeType === 1 || checkNonElements ) {
						outerCache = elem[ expando ] || (elem[ expando ] = {});
						if ( (cache = outerCache[ dir ]) && cache[0] === dirkey ) {
							if ( (data = cache[1]) === true || data === cachedruns ) {
								return data === true;
							}
						} else {
							cache = outerCache[ dir ] = [ dirkey ];
							cache[1] = matcher( elem, context, xml ) || cachedruns;
							if ( cache[1] === true ) {
								return true;
							}
						}
					}
				}
			}
		};
}

function elementMatcher( matchers ) {
	return matchers.length > 1 ?
		function( elem, context, xml ) {
			var i = matchers.length;
			while ( i-- ) {
				if ( !matchers[i]( elem, context, xml ) ) {
					return false;
				}
			}
			return true;
		} :
		matchers[0];
}

function condense( unmatched, map, filter, context, xml ) {
	var elem,
		newUnmatched = [],
		i = 0,
		len = unmatched.length,
		mapped = map != null;

	for ( ; i < len; i++ ) {
		if ( (elem = unmatched[i]) ) {
			if ( !filter || filter( elem, context, xml ) ) {
				newUnmatched.push( elem );
				if ( mapped ) {
					map.push( i );
				}
			}
		}
	}

	return newUnmatched;
}

function setMatcher( preFilter, selector, matcher, postFilter, postFinder, postSelector ) {
	if ( postFilter && !postFilter[ expando ] ) {
		postFilter = setMatcher( postFilter );
	}
	if ( postFinder && !postFinder[ expando ] ) {
		postFinder = setMatcher( postFinder, postSelector );
	}
	return markFunction(function( seed, results, context, xml ) {
		var temp, i, elem,
			preMap = [],
			postMap = [],
			preexisting = results.length,

			// Get initial elements from seed or context
			elems = seed || multipleContexts( selector || "*", context.nodeType ? [ context ] : context, [] ),

			// Prefilter to get matcher input, preserving a map for seed-results synchronization
			matcherIn = preFilter && ( seed || !selector ) ?
				condense( elems, preMap, preFilter, context, xml ) :
				elems,

			matcherOut = matcher ?
				// If we have a postFinder, or filtered seed, or non-seed postFilter or preexisting results,
				postFinder || ( seed ? preFilter : preexisting || postFilter ) ?

					// ...intermediate processing is necessary
					[] :

					// ...otherwise use results directly
					results :
				matcherIn;

		// Find primary matches
		if ( matcher ) {
			matcher( matcherIn, matcherOut, context, xml );
		}

		// Apply postFilter
		if ( postFilter ) {
			temp = condense( matcherOut, postMap );
			postFilter( temp, [], context, xml );

			// Un-match failing elements by moving them back to matcherIn
			i = temp.length;
			while ( i-- ) {
				if ( (elem = temp[i]) ) {
					matcherOut[ postMap[i] ] = !(matcherIn[ postMap[i] ] = elem);
				}
			}
		}

		if ( seed ) {
			if ( postFinder || preFilter ) {
				if ( postFinder ) {
					// Get the final matcherOut by condensing this intermediate into postFinder contexts
					temp = [];
					i = matcherOut.length;
					while ( i-- ) {
						if ( (elem = matcherOut[i]) ) {
							// Restore matcherIn since elem is not yet a final match
							temp.push( (matcherIn[i] = elem) );
						}
					}
					postFinder( null, (matcherOut = []), temp, xml );
				}

				// Move matched elements from seed to results to keep them synchronized
				i = matcherOut.length;
				while ( i-- ) {
					if ( (elem = matcherOut[i]) &&
						(temp = postFinder ? indexOf.call( seed, elem ) : preMap[i]) > -1 ) {

						seed[temp] = !(results[temp] = elem);
					}
				}
			}

		// Add elements to results, through postFinder if defined
		} else {
			matcherOut = condense(
				matcherOut === results ?
					matcherOut.splice( preexisting, matcherOut.length ) :
					matcherOut
			);
			if ( postFinder ) {
				postFinder( null, results, matcherOut, xml );
			} else {
				push.apply( results, matcherOut );
			}
		}
	});
}

function matcherFromTokens( tokens ) {
	var checkContext, matcher, j,
		len = tokens.length,
		leadingRelative = Expr.relative[ tokens[0].type ],
		implicitRelative = leadingRelative || Expr.relative[" "],
		i = leadingRelative ? 1 : 0,

		// The foundational matcher ensures that elements are reachable from top-level context(s)
		matchContext = addCombinator( function( elem ) {
			return elem === checkContext;
		}, implicitRelative, true ),
		matchAnyContext = addCombinator( function( elem ) {
			return indexOf.call( checkContext, elem ) > -1;
		}, implicitRelative, true ),
		matchers = [ function( elem, context, xml ) {
			return ( !leadingRelative && ( xml || context !== outermostContext ) ) || (
				(checkContext = context).nodeType ?
					matchContext( elem, context, xml ) :
					matchAnyContext( elem, context, xml ) );
		} ];

	for ( ; i < len; i++ ) {
		if ( (matcher = Expr.relative[ tokens[i].type ]) ) {
			matchers = [ addCombinator(elementMatcher( matchers ), matcher) ];
		} else {
			matcher = Expr.filter[ tokens[i].type ].apply( null, tokens[i].matches );

			// Return special upon seeing a positional matcher
			if ( matcher[ expando ] ) {
				// Find the next relative operator (if any) for proper handling
				j = ++i;
				for ( ; j < len; j++ ) {
					if ( Expr.relative[ tokens[j].type ] ) {
						break;
					}
				}
				return setMatcher(
					i > 1 && elementMatcher( matchers ),
					i > 1 && toSelector( tokens.slice( 0, i - 1 ) ).replace( rtrim, "$1" ),
					matcher,
					i < j && matcherFromTokens( tokens.slice( i, j ) ),
					j < len && matcherFromTokens( (tokens = tokens.slice( j )) ),
					j < len && toSelector( tokens )
				);
			}
			matchers.push( matcher );
		}
	}

	return elementMatcher( matchers );
}

function matcherFromGroupMatchers( elementMatchers, setMatchers ) {
	// A counter to specify which element is currently being matched
	var matcherCachedRuns = 0,
		bySet = setMatchers.length > 0,
		byElement = elementMatchers.length > 0,
		superMatcher = function( seed, context, xml, results, expandContext ) {
			var elem, j, matcher,
				setMatched = [],
				matchedCount = 0,
				i = "0",
				unmatched = seed && [],
				outermost = expandContext != null,
				contextBackup = outermostContext,
				// We must always have either seed elements or context
				elems = seed || byElement && Expr.find["TAG"]( "*", expandContext && context.parentNode || context ),
				// Use integer dirruns iff this is the outermost matcher
				dirrunsUnique = (dirruns += contextBackup == null ? 1 : Math.random() || 0.1);

			if ( outermost ) {
				outermostContext = context !== document && context;
				cachedruns = matcherCachedRuns;
			}

			// Add elements passing elementMatchers directly to results
			// Keep `i` a string if there are no elements so `matchedCount` will be "00" below
			for ( ; (elem = elems[i]) != null; i++ ) {
				if ( byElement && elem ) {
					j = 0;
					while ( (matcher = elementMatchers[j++]) ) {
						if ( matcher( elem, context, xml ) ) {
							results.push( elem );
							break;
						}
					}
					if ( outermost ) {
						dirruns = dirrunsUnique;
						cachedruns = ++matcherCachedRuns;
					}
				}

				// Track unmatched elements for set filters
				if ( bySet ) {
					// They will have gone through all possible matchers
					if ( (elem = !matcher && elem) ) {
						matchedCount--;
					}

					// Lengthen the array for every element, matched or not
					if ( seed ) {
						unmatched.push( elem );
					}
				}
			}

			// Apply set filters to unmatched elements
			matchedCount += i;
			if ( bySet && i !== matchedCount ) {
				j = 0;
				while ( (matcher = setMatchers[j++]) ) {
					matcher( unmatched, setMatched, context, xml );
				}

				if ( seed ) {
					// Reintegrate element matches to eliminate the need for sorting
					if ( matchedCount > 0 ) {
						while ( i-- ) {
							if ( !(unmatched[i] || setMatched[i]) ) {
								setMatched[i] = pop.call( results );
							}
						}
					}

					// Discard index placeholder values to get only actual matches
					setMatched = condense( setMatched );
				}

				// Add matches to results
				push.apply( results, setMatched );

				// Seedless set matches succeeding multiple successful matchers stipulate sorting
				if ( outermost && !seed && setMatched.length > 0 &&
					( matchedCount + setMatchers.length ) > 1 ) {

					Sizzle.uniqueSort( results );
				}
			}

			// Override manipulation of globals by nested matchers
			if ( outermost ) {
				dirruns = dirrunsUnique;
				outermostContext = contextBackup;
			}

			return unmatched;
		};

	return bySet ?
		markFunction( superMatcher ) :
		superMatcher;
}

compile = Sizzle.compile = function( selector, group /* Internal Use Only */ ) {
	var i,
		setMatchers = [],
		elementMatchers = [],
		cached = compilerCache[ selector + " " ];

	if ( !cached ) {
		// Generate a function of recursive functions that can be used to check each element
		if ( !group ) {
			group = tokenize( selector );
		}
		i = group.length;
		while ( i-- ) {
			cached = matcherFromTokens( group[i] );
			if ( cached[ expando ] ) {
				setMatchers.push( cached );
			} else {
				elementMatchers.push( cached );
			}
		}

		// Cache the compiled function
		cached = compilerCache( selector, matcherFromGroupMatchers( elementMatchers, setMatchers ) );
	}
	return cached;
};

function multipleContexts( selector, contexts, results ) {
	var i = 0,
		len = contexts.length;
	for ( ; i < len; i++ ) {
		Sizzle( selector, contexts[i], results );
	}
	return results;
}

function select( selector, context, results, seed ) {
	var i, tokens, token, type, find,
		match = tokenize( selector );

	if ( !seed ) {
		// Try to minimize operations if there is only one group
		if ( match.length === 1 ) {

			// Take a shortcut and set the context if the root selector is an ID
			tokens = match[0] = match[0].slice( 0 );
			if ( tokens.length > 2 && (token = tokens[0]).type === "ID" &&
					context.nodeType === 9 && !documentIsXML &&
					Expr.relative[ tokens[1].type ] ) {

				context = Expr.find["ID"]( token.matches[0].replace( runescape, funescape ), context )[0];
				if ( !context ) {
					return results;
				}

				selector = selector.slice( tokens.shift().value.length );
			}

			// Fetch a seed set for right-to-left matching
			i = matchExpr["needsContext"].test( selector ) ? 0 : tokens.length;
			while ( i-- ) {
				token = tokens[i];

				// Abort if we hit a combinator
				if ( Expr.relative[ (type = token.type) ] ) {
					break;
				}
				if ( (find = Expr.find[ type ]) ) {
					// Search, expanding context for leading sibling combinators
					if ( (seed = find(
						token.matches[0].replace( runescape, funescape ),
						rsibling.test( tokens[0].type ) && context.parentNode || context
					)) ) {

						// If seed is empty or no tokens remain, we can return early
						tokens.splice( i, 1 );
						selector = seed.length && toSelector( tokens );
						if ( !selector ) {
							push.apply( results, slice.call( seed, 0 ) );
							return results;
						}

						break;
					}
				}
			}
		}
	}

	// Compile and execute a filtering function
	// Provide `match` to avoid retokenization if we modified the selector above
	compile( selector, match )(
		seed,
		context,
		documentIsXML,
		results,
		rsibling.test( selector )
	);
	return results;
}

// Deprecated
Expr.pseudos["nth"] = Expr.pseudos["eq"];

// Easy API for creating new setFilters
function setFilters() {}
Expr.filters = setFilters.prototype = Expr.pseudos;
Expr.setFilters = new setFilters();

// Initialize with the default document
setDocument();

// Override sizzle attribute retrieval
Sizzle.attr = jQuery.attr;
jQuery.find = Sizzle;
jQuery.expr = Sizzle.selectors;
jQuery.expr[":"] = jQuery.expr.pseudos;
jQuery.unique = Sizzle.uniqueSort;
jQuery.text = Sizzle.getText;
jQuery.isXMLDoc = Sizzle.isXML;
jQuery.contains = Sizzle.contains;


})( window );
var runtil = /Until$/,
	rparentsprev = /^(?:parents|prev(?:Until|All))/,
	isSimple = /^.[^:#\[\.,]*$/,
	rneedsContext = jQuery.expr.match.needsContext,
	// methods guaranteed to produce a unique set when starting from a unique set
	guaranteedUnique = {
		children: true,
		contents: true,
		next: true,
		prev: true
	};

jQuery.fn.extend({
	find: function( selector ) {
		var i, ret, self,
			len = this.length;

		if ( typeof selector !== "string" ) {
			self = this;
			return this.pushStack( jQuery( selector ).filter(function() {
				for ( i = 0; i < len; i++ ) {
					if ( jQuery.contains( self[ i ], this ) ) {
						return true;
					}
				}
			}) );
		}

		ret = [];
		for ( i = 0; i < len; i++ ) {
			jQuery.find( selector, this[ i ], ret );
		}

		// Needed because $( selector, context ) becomes $( context ).find( selector )
		ret = this.pushStack( len > 1 ? jQuery.unique( ret ) : ret );
		ret.selector = ( this.selector ? this.selector + " " : "" ) + selector;
		return ret;
	},

	has: function( target ) {
		var i,
			targets = jQuery( target, this ),
			len = targets.length;

		return this.filter(function() {
			for ( i = 0; i < len; i++ ) {
				if ( jQuery.contains( this, targets[i] ) ) {
					return true;
				}
			}
		});
	},

	not: function( selector ) {
		return this.pushStack( winnow(this, selector, false) );
	},

	filter: function( selector ) {
		return this.pushStack( winnow(this, selector, true) );
	},

	is: function( selector ) {
		return !!selector && (
			typeof selector === "string" ?
				// If this is a positional/relative selector, check membership in the returned set
				// so $("p:first").is("p:last") won't return true for a doc with two "p".
				rneedsContext.test( selector ) ?
					jQuery( selector, this.context ).index( this[0] ) >= 0 :
					jQuery.filter( selector, this ).length > 0 :
				this.filter( selector ).length > 0 );
	},

	closest: function( selectors, context ) {
		var cur,
			i = 0,
			l = this.length,
			ret = [],
			pos = rneedsContext.test( selectors ) || typeof selectors !== "string" ?
				jQuery( selectors, context || this.context ) :
				0;

		for ( ; i < l; i++ ) {
			cur = this[i];

			while ( cur && cur.ownerDocument && cur !== context && cur.nodeType !== 11 ) {
				if ( pos ? pos.index(cur) > -1 : jQuery.find.matchesSelector(cur, selectors) ) {
					ret.push( cur );
					break;
				}
				cur = cur.parentNode;
			}
		}

		return this.pushStack( ret.length > 1 ? jQuery.unique( ret ) : ret );
	},

	// Determine the position of an element within
	// the matched set of elements
	index: function( elem ) {

		// No argument, return index in parent
		if ( !elem ) {
			return ( this[0] && this[0].parentNode ) ? this.first().prevAll().length : -1;
		}

		// index in selector
		if ( typeof elem === "string" ) {
			return jQuery.inArray( this[0], jQuery( elem ) );
		}

		// Locate the position of the desired element
		return jQuery.inArray(
			// If it receives a jQuery object, the first element is used
			elem.jquery ? elem[0] : elem, this );
	},

	add: function( selector, context ) {
		var set = typeof selector === "string" ?
				jQuery( selector, context ) :
				jQuery.makeArray( selector && selector.nodeType ? [ selector ] : selector ),
			all = jQuery.merge( this.get(), set );

		return this.pushStack( jQuery.unique(all) );
	},

	addBack: function( selector ) {
		return this.add( selector == null ?
			this.prevObject : this.prevObject.filter(selector)
		);
	}
});

jQuery.fn.andSelf = jQuery.fn.addBack;

function sibling( cur, dir ) {
	do {
		cur = cur[ dir ];
	} while ( cur && cur.nodeType !== 1 );

	return cur;
}

jQuery.each({
	parent: function( elem ) {
		var parent = elem.parentNode;
		return parent && parent.nodeType !== 11 ? parent : null;
	},
	parents: function( elem ) {
		return jQuery.dir( elem, "parentNode" );
	},
	parentsUntil: function( elem, i, until ) {
		return jQuery.dir( elem, "parentNode", until );
	},
	next: function( elem ) {
		return sibling( elem, "nextSibling" );
	},
	prev: function( elem ) {
		return sibling( elem, "previousSibling" );
	},
	nextAll: function( elem ) {
		return jQuery.dir( elem, "nextSibling" );
	},
	prevAll: function( elem ) {
		return jQuery.dir( elem, "previousSibling" );
	},
	nextUntil: function( elem, i, until ) {
		return jQuery.dir( elem, "nextSibling", until );
	},
	prevUntil: function( elem, i, until ) {
		return jQuery.dir( elem, "previousSibling", until );
	},
	siblings: function( elem ) {
		return jQuery.sibling( ( elem.parentNode || {} ).firstChild, elem );
	},
	children: function( elem ) {
		return jQuery.sibling( elem.firstChild );
	},
	contents: function( elem ) {
		return jQuery.nodeName( elem, "iframe" ) ?
			elem.contentDocument || elem.contentWindow.document :
			jQuery.merge( [], elem.childNodes );
	}
}, function( name, fn ) {
	jQuery.fn[ name ] = function( until, selector ) {
		var ret = jQuery.map( this, fn, until );

		if ( !runtil.test( name ) ) {
			selector = until;
		}

		if ( selector && typeof selector === "string" ) {
			ret = jQuery.filter( selector, ret );
		}

		ret = this.length > 1 && !guaranteedUnique[ name ] ? jQuery.unique( ret ) : ret;

		if ( this.length > 1 && rparentsprev.test( name ) ) {
			ret = ret.reverse();
		}

		return this.pushStack( ret );
	};
});

jQuery.extend({
	filter: function( expr, elems, not ) {
		if ( not ) {
			expr = ":not(" + expr + ")";
		}

		return elems.length === 1 ?
			jQuery.find.matchesSelector(elems[0], expr) ? [ elems[0] ] : [] :
			jQuery.find.matches(expr, elems);
	},

	dir: function( elem, dir, until ) {
		var matched = [],
			cur = elem[ dir ];

		while ( cur && cur.nodeType !== 9 && (until === undefined || cur.nodeType !== 1 || !jQuery( cur ).is( until )) ) {
			if ( cur.nodeType === 1 ) {
				matched.push( cur );
			}
			cur = cur[dir];
		}
		return matched;
	},

	sibling: function( n, elem ) {
		var r = [];

		for ( ; n; n = n.nextSibling ) {
			if ( n.nodeType === 1 && n !== elem ) {
				r.push( n );
			}
		}

		return r;
	}
});

// Implement the identical functionality for filter and not
function winnow( elements, qualifier, keep ) {

	// Can't pass null or undefined to indexOf in Firefox 4
	// Set to 0 to skip string check
	qualifier = qualifier || 0;

	if ( jQuery.isFunction( qualifier ) ) {
		return jQuery.grep(elements, function( elem, i ) {
			var retVal = !!qualifier.call( elem, i, elem );
			return retVal === keep;
		});

	} else if ( qualifier.nodeType ) {
		return jQuery.grep(elements, function( elem ) {
			return ( elem === qualifier ) === keep;
		});

	} else if ( typeof qualifier === "string" ) {
		var filtered = jQuery.grep(elements, function( elem ) {
			return elem.nodeType === 1;
		});

		if ( isSimple.test( qualifier ) ) {
			return jQuery.filter(qualifier, filtered, !keep);
		} else {
			qualifier = jQuery.filter( qualifier, filtered );
		}
	}

	return jQuery.grep(elements, function( elem ) {
		return ( jQuery.inArray( elem, qualifier ) >= 0 ) === keep;
	});
}
function createSafeFragment( document ) {
	var list = nodeNames.split( "|" ),
		safeFrag = document.createDocumentFragment();

	if ( safeFrag.createElement ) {
		while ( list.length ) {
			safeFrag.createElement(
				list.pop()
			);
		}
	}
	return safeFrag;
}

var nodeNames = "abbr|article|aside|audio|bdi|canvas|data|datalist|details|figcaption|figure|footer|" +
		"header|hgroup|mark|meter|nav|output|progress|section|summary|time|video",
	rinlinejQuery = / jQuery\d+="(?:null|\d+)"/g,
	rnoshimcache = new RegExp("<(?:" + nodeNames + ")[\\s/>]", "i"),
	rleadingWhitespace = /^\s+/,
	rxhtmlTag = /<(?!area|br|col|embed|hr|img|input|link|meta|param)(([\w:]+)[^>]*)\/>/gi,
	rtagName = /<([\w:]+)/,
	rtbody = /<tbody/i,
	rhtml = /<|&#?\w+;/,
	rnoInnerhtml = /<(?:script|style|link)/i,
	manipulation_rcheckableType = /^(?:checkbox|radio)$/i,
	// checked="checked" or checked
	rchecked = /checked\s*(?:[^=]|=\s*.checked.)/i,
	rscriptType = /^$|\/(?:java|ecma)script/i,
	rscriptTypeMasked = /^true\/(.*)/,
	rcleanScript = /^\s*<!(?:\[CDATA\[|--)|(?:\]\]|--)>\s*$/g,

	// We have to close these tags to support XHTML (#13200)
	wrapMap = {
		option: [ 1, "<select multiple='multiple'>", "</select>" ],
		legend: [ 1, "<fieldset>", "</fieldset>" ],
		area: [ 1, "<map>", "</map>" ],
		param: [ 1, "<object>", "</object>" ],
		thead: [ 1, "<table>", "</table>" ],
		tr: [ 2, "<table><tbody>", "</tbody></table>" ],
		col: [ 2, "<table><tbody></tbody><colgroup>", "</colgroup></table>" ],
		td: [ 3, "<table><tbody><tr>", "</tr></tbody></table>" ],

		// IE6-8 can't serialize link, script, style, or any html5 (NoScope) tags,
		// unless wrapped in a div with non-breaking characters in front of it.
		_default: jQuery.support.htmlSerialize ? [ 0, "", "" ] : [ 1, "X<div>", "</div>"  ]
	},
	safeFragment = createSafeFragment( document ),
	fragmentDiv = safeFragment.appendChild( document.createElement("div") );

wrapMap.optgroup = wrapMap.option;
wrapMap.tbody = wrapMap.tfoot = wrapMap.colgroup = wrapMap.caption = wrapMap.thead;
wrapMap.th = wrapMap.td;

jQuery.fn.extend({
	text: function( value ) {
		return jQuery.access( this, function( value ) {
			return value === undefined ?
				jQuery.text( this ) :
				this.empty().append( ( this[0] && this[0].ownerDocument || document ).createTextNode( value ) );
		}, null, value, arguments.length );
	},

	wrapAll: function( html ) {
		if ( jQuery.isFunction( html ) ) {
			return this.each(function(i) {
				jQuery(this).wrapAll( html.call(this, i) );
			});
		}

		if ( this[0] ) {
			// The elements to wrap the target around
			var wrap = jQuery( html, this[0].ownerDocument ).eq(0).clone(true);

			if ( this[0].parentNode ) {
				wrap.insertBefore( this[0] );
			}

			wrap.map(function() {
				var elem = this;

				while ( elem.firstChild && elem.firstChild.nodeType === 1 ) {
					elem = elem.firstChild;
				}

				return elem;
			}).append( this );
		}

		return this;
	},

	wrapInner: function( html ) {
		if ( jQuery.isFunction( html ) ) {
			return this.each(function(i) {
				jQuery(this).wrapInner( html.call(this, i) );
			});
		}

		return this.each(function() {
			var self = jQuery( this ),
				contents = self.contents();

			if ( contents.length ) {
				contents.wrapAll( html );

			} else {
				self.append( html );
			}
		});
	},

	wrap: function( html ) {
		var isFunction = jQuery.isFunction( html );

		return this.each(function(i) {
			jQuery( this ).wrapAll( isFunction ? html.call(this, i) : html );
		});
	},

	unwrap: function() {
		return this.parent().each(function() {
			if ( !jQuery.nodeName( this, "body" ) ) {
				jQuery( this ).replaceWith( this.childNodes );
			}
		}).end();
	},

	append: function() {
		return this.domManip(arguments, true, function( elem ) {
			if ( this.nodeType === 1 || this.nodeType === 11 || this.nodeType === 9 ) {
				this.appendChild( elem );
			}
		});
	},

	prepend: function() {
		return this.domManip(arguments, true, function( elem ) {
			if ( this.nodeType === 1 || this.nodeType === 11 || this.nodeType === 9 ) {
				this.insertBefore( elem, this.firstChild );
			}
		});
	},

	before: function() {
		return this.domManip( arguments, false, function( elem ) {
			if ( this.parentNode ) {
				this.parentNode.insertBefore( elem, this );
			}
		});
	},

	after: function() {
		return this.domManip( arguments, false, function( elem ) {
			if ( this.parentNode ) {
				this.parentNode.insertBefore( elem, this.nextSibling );
			}
		});
	},

	// keepData is for internal use only--do not document
	remove: function( selector, keepData ) {
		var elem,
			i = 0;

		for ( ; (elem = this[i]) != null; i++ ) {
			if ( !selector || jQuery.filter( selector, [ elem ] ).length > 0 ) {
				if ( !keepData && elem.nodeType === 1 ) {
					jQuery.cleanData( getAll( elem ) );
				}

				if ( elem.parentNode ) {
					if ( keepData && jQuery.contains( elem.ownerDocument, elem ) ) {
						setGlobalEval( getAll( elem, "script" ) );
					}
					elem.parentNode.removeChild( elem );
				}
			}
		}

		return this;
	},

	empty: function() {
		var elem,
			i = 0;

		for ( ; (elem = this[i]) != null; i++ ) {
			// Remove element nodes and prevent memory leaks
			if ( elem.nodeType === 1 ) {
				jQuery.cleanData( getAll( elem, false ) );
			}

			// Remove any remaining nodes
			while ( elem.firstChild ) {
				elem.removeChild( elem.firstChild );
			}

			// If this is a select, ensure that it displays empty (#12336)
			// Support: IE<9
			if ( elem.options && jQuery.nodeName( elem, "select" ) ) {
				elem.options.length = 0;
			}
		}

		return this;
	},

	clone: function( dataAndEvents, deepDataAndEvents ) {
		dataAndEvents = dataAndEvents == null ? false : dataAndEvents;
		deepDataAndEvents = deepDataAndEvents == null ? dataAndEvents : deepDataAndEvents;

		return this.map( function () {
			return jQuery.clone( this, dataAndEvents, deepDataAndEvents );
		});
	},

	html: function( value ) {
		return jQuery.access( this, function( value ) {
			var elem = this[0] || {},
				i = 0,
				l = this.length;

			if ( value === undefined ) {
				return elem.nodeType === 1 ?
					elem.innerHTML.replace( rinlinejQuery, "" ) :
					undefined;
			}

			// See if we can take a shortcut and just use innerHTML
			if ( typeof value === "string" && !rnoInnerhtml.test( value ) &&
				( jQuery.support.htmlSerialize || !rnoshimcache.test( value )  ) &&
				( jQuery.support.leadingWhitespace || !rleadingWhitespace.test( value ) ) &&
				!wrapMap[ ( rtagName.exec( value ) || ["", ""] )[1].toLowerCase() ] ) {

				value = value.replace( rxhtmlTag, "<$1></$2>" );

				try {
					for (; i < l; i++ ) {
						// Remove element nodes and prevent memory leaks
						elem = this[i] || {};
						if ( elem.nodeType === 1 ) {
							jQuery.cleanData( getAll( elem, false ) );
							elem.innerHTML = value;
						}
					}

					elem = 0;

				// If using innerHTML throws an exception, use the fallback method
				} catch(e) {}
			}

			if ( elem ) {
				this.empty().append( value );
			}
		}, null, value, arguments.length );
	},

	replaceWith: function( value ) {
		var isFunc = jQuery.isFunction( value );

		// Make sure that the elements are removed from the DOM before they are inserted
		// this can help fix replacing a parent with child elements
		if ( !isFunc && typeof value !== "string" ) {
			value = jQuery( value ).not( this ).detach();
		}

		return this.domManip( [ value ], true, function( elem ) {
			var next = this.nextSibling,
				parent = this.parentNode;

			if ( parent ) {
				jQuery( this ).remove();
				parent.insertBefore( elem, next );
			}
		});
	},

	detach: function( selector ) {
		return this.remove( selector, true );
	},

	domManip: function( args, table, callback ) {

		// Flatten any nested arrays
		args = core_concat.apply( [], args );

		var first, node, hasScripts,
			scripts, doc, fragment,
			i = 0,
			l = this.length,
			set = this,
			iNoClone = l - 1,
			value = args[0],
			isFunction = jQuery.isFunction( value );

		// We can't cloneNode fragments that contain checked, in WebKit
		if ( isFunction || !( l <= 1 || typeof value !== "string" || jQuery.support.checkClone || !rchecked.test( value ) ) ) {
			return this.each(function( index ) {
				var self = set.eq( index );
				if ( isFunction ) {
					args[0] = value.call( this, index, table ? self.html() : undefined );
				}
				self.domManip( args, table, callback );
			});
		}

		if ( l ) {
			fragment = jQuery.buildFragment( args, this[ 0 ].ownerDocument, false, this );
			first = fragment.firstChild;

			if ( fragment.childNodes.length === 1 ) {
				fragment = first;
			}

			if ( first ) {
				table = table && jQuery.nodeName( first, "tr" );
				scripts = jQuery.map( getAll( fragment, "script" ), disableScript );
				hasScripts = scripts.length;

				// Use the original fragment for the last item instead of the first because it can end up
				// being emptied incorrectly in certain situations (#8070).
				for ( ; i < l; i++ ) {
					node = fragment;

					if ( i !== iNoClone ) {
						node = jQuery.clone( node, true, true );

						// Keep references to cloned scripts for later restoration
						if ( hasScripts ) {
							jQuery.merge( scripts, getAll( node, "script" ) );
						}
					}

					callback.call(
						table && jQuery.nodeName( this[i], "table" ) ?
							findOrAppend( this[i], "tbody" ) :
							this[i],
						node,
						i
					);
				}

				if ( hasScripts ) {
					doc = scripts[ scripts.length - 1 ].ownerDocument;

					// Reenable scripts
					jQuery.map( scripts, restoreScript );

					// Evaluate executable scripts on first document insertion
					for ( i = 0; i < hasScripts; i++ ) {
						node = scripts[ i ];
						if ( rscriptType.test( node.type || "" ) &&
							!jQuery._data( node, "globalEval" ) && jQuery.contains( doc, node ) ) {

							if ( node.src ) {
								// Hope ajax is available...
								jQuery.ajax({
									url: node.src,
									type: "GET",
									dataType: "script",
									async: false,
									global: false,
									"throws": true
								});
							} else {
								jQuery.globalEval( ( node.text || node.textContent || node.innerHTML || "" ).replace( rcleanScript, "" ) );
							}
						}
					}
				}

				// Fix #11809: Avoid leaking memory
				fragment = first = null;
			}
		}

		return this;
	}
});

function findOrAppend( elem, tag ) {
	return elem.getElementsByTagName( tag )[0] || elem.appendChild( elem.ownerDocument.createElement( tag ) );
}

// Replace/restore the type attribute of script elements for safe DOM manipulation
function disableScript( elem ) {
	var attr = elem.getAttributeNode("type");
	elem.type = ( attr && attr.specified ) + "/" + elem.type;
	return elem;
}
function restoreScript( elem ) {
	var match = rscriptTypeMasked.exec( elem.type );
	if ( match ) {
		elem.type = match[1];
	} else {
		elem.removeAttribute("type");
	}
	return elem;
}

// Mark scripts as having already been evaluated
function setGlobalEval( elems, refElements ) {
	var elem,
		i = 0;
	for ( ; (elem = elems[i]) != null; i++ ) {
		jQuery._data( elem, "globalEval", !refElements || jQuery._data( refElements[i], "globalEval" ) );
	}
}

function cloneCopyEvent( src, dest ) {

	if ( dest.nodeType !== 1 || !jQuery.hasData( src ) ) {
		return;
	}

	var type, i, l,
		oldData = jQuery._data( src ),
		curData = jQuery._data( dest, oldData ),
		events = oldData.events;

	if ( events ) {
		delete curData.handle;
		curData.events = {};

		for ( type in events ) {
			for ( i = 0, l = events[ type ].length; i < l; i++ ) {
				jQuery.event.add( dest, type, events[ type ][ i ] );
			}
		}
	}

	// make the cloned public data object a copy from the original
	if ( curData.data ) {
		curData.data = jQuery.extend( {}, curData.data );
	}
}

function fixCloneNodeIssues( src, dest ) {
	var nodeName, e, data;

	// We do not need to do anything for non-Elements
	if ( dest.nodeType !== 1 ) {
		return;
	}

	nodeName = dest.nodeName.toLowerCase();

	// IE6-8 copies events bound via attachEvent when using cloneNode.
	if ( !jQuery.support.noCloneEvent && dest[ jQuery.expando ] ) {
		data = jQuery._data( dest );

		for ( e in data.events ) {
			jQuery.removeEvent( dest, e, data.handle );
		}

		// Event data gets referenced instead of copied if the expando gets copied too
		dest.removeAttribute( jQuery.expando );
	}

	// IE blanks contents when cloning scripts, and tries to evaluate newly-set text
	if ( nodeName === "script" && dest.text !== src.text ) {
		disableScript( dest ).text = src.text;
		restoreScript( dest );

	// IE6-10 improperly clones children of object elements using classid.
	// IE10 throws NoModificationAllowedError if parent is null, #12132.
	} else if ( nodeName === "object" ) {
		if ( dest.parentNode ) {
			dest.outerHTML = src.outerHTML;
		}

		// This path appears unavoidable for IE9. When cloning an object
		// element in IE9, the outerHTML strategy above is not sufficient.
		// If the src has innerHTML and the destination does not,
		// copy the src.innerHTML into the dest.innerHTML. #10324
		if ( jQuery.support.html5Clone && ( src.innerHTML && !jQuery.trim(dest.innerHTML) ) ) {
			dest.innerHTML = src.innerHTML;
		}

	} else if ( nodeName === "input" && manipulation_rcheckableType.test( src.type ) ) {
		// IE6-8 fails to persist the checked state of a cloned checkbox
		// or radio button. Worse, IE6-7 fail to give the cloned element
		// a checked appearance if the defaultChecked value isn't also set

		dest.defaultChecked = dest.checked = src.checked;

		// IE6-7 get confused and end up setting the value of a cloned
		// checkbox/radio button to an empty string instead of "on"
		if ( dest.value !== src.value ) {
			dest.value = src.value;
		}

	// IE6-8 fails to return the selected option to the default selected
	// state when cloning options
	} else if ( nodeName === "option" ) {
		dest.defaultSelected = dest.selected = src.defaultSelected;

	// IE6-8 fails to set the defaultValue to the correct value when
	// cloning other types of input fields
	} else if ( nodeName === "input" || nodeName === "textarea" ) {
		dest.defaultValue = src.defaultValue;
	}
}

jQuery.each({
	appendTo: "append",
	prependTo: "prepend",
	insertBefore: "before",
	insertAfter: "after",
	replaceAll: "replaceWith"
}, function( name, original ) {
	jQuery.fn[ name ] = function( selector ) {
		var elems,
			i = 0,
			ret = [],
			insert = jQuery( selector ),
			last = insert.length - 1;

		for ( ; i <= last; i++ ) {
			elems = i === last ? this : this.clone(true);
			jQuery( insert[i] )[ original ]( elems );

			// Modern browsers can apply jQuery collections as arrays, but oldIE needs a .get()
			core_push.apply( ret, elems.get() );
		}

		return this.pushStack( ret );
	};
});

function getAll( context, tag ) {
	var elems, elem,
		i = 0,
		found = typeof context.getElementsByTagName !== core_strundefined ? context.getElementsByTagName( tag || "*" ) :
			typeof context.querySelectorAll !== core_strundefined ? context.querySelectorAll( tag || "*" ) :
			undefined;

	if ( !found ) {
		for ( found = [], elems = context.childNodes || context; (elem = elems[i]) != null; i++ ) {
			if ( !tag || jQuery.nodeName( elem, tag ) ) {
				found.push( elem );
			} else {
				jQuery.merge( found, getAll( elem, tag ) );
			}
		}
	}

	return tag === undefined || tag && jQuery.nodeName( context, tag ) ?
		jQuery.merge( [ context ], found ) :
		found;
}

// Used in buildFragment, fixes the defaultChecked property
function fixDefaultChecked( elem ) {
	if ( manipulation_rcheckableType.test( elem.type ) ) {
		elem.defaultChecked = elem.checked;
	}
}

jQuery.extend({
	clone: function( elem, dataAndEvents, deepDataAndEvents ) {
		var destElements, node, clone, i, srcElements,
			inPage = jQuery.contains( elem.ownerDocument, elem );

		if ( jQuery.support.html5Clone || jQuery.isXMLDoc(elem) || !rnoshimcache.test( "<" + elem.nodeName + ">" ) ) {
			clone = elem.cloneNode( true );

		// IE<=8 does not properly clone detached, unknown element nodes
		} else {
			fragmentDiv.innerHTML = elem.outerHTML;
			fragmentDiv.removeChild( clone = fragmentDiv.firstChild );
		}

		if ( (!jQuery.support.noCloneEvent || !jQuery.support.noCloneChecked) &&
				(elem.nodeType === 1 || elem.nodeType === 11) && !jQuery.isXMLDoc(elem) ) {

			// We eschew Sizzle here for performance reasons: http://jsperf.com/getall-vs-sizzle/2
			destElements = getAll( clone );
			srcElements = getAll( elem );

			// Fix all IE cloning issues
			for ( i = 0; (node = srcElements[i]) != null; ++i ) {
				// Ensure that the destination node is not null; Fixes #9587
				if ( destElements[i] ) {
					fixCloneNodeIssues( node, destElements[i] );
				}
			}
		}

		// Copy the events from the original to the clone
		if ( dataAndEvents ) {
			if ( deepDataAndEvents ) {
				srcElements = srcElements || getAll( elem );
				destElements = destElements || getAll( clone );

				for ( i = 0; (node = srcElements[i]) != null; i++ ) {
					cloneCopyEvent( node, destElements[i] );
				}
			} else {
				cloneCopyEvent( elem, clone );
			}
		}

		// Preserve script evaluation history
		destElements = getAll( clone, "script" );
		if ( destElements.length > 0 ) {
			setGlobalEval( destElements, !inPage && getAll( elem, "script" ) );
		}

		destElements = srcElements = node = null;

		// Return the cloned set
		return clone;
	},

	buildFragment: function( elems, context, scripts, selection ) {
		var j, elem, contains,
			tmp, tag, tbody, wrap,
			l = elems.length,

			// Ensure a safe fragment
			safe = createSafeFragment( context ),

			nodes = [],
			i = 0;

		for ( ; i < l; i++ ) {
			elem = elems[ i ];

			if ( elem || elem === 0 ) {

				// Add nodes directly
				if ( jQuery.type( elem ) === "object" ) {
					jQuery.merge( nodes, elem.nodeType ? [ elem ] : elem );

				// Convert non-html into a text node
				} else if ( !rhtml.test( elem ) ) {
					nodes.push( context.createTextNode( elem ) );

				// Convert html into DOM nodes
				} else {
					tmp = tmp || safe.appendChild( context.createElement("div") );

					// Deserialize a standard representation
					tag = ( rtagName.exec( elem ) || ["", ""] )[1].toLowerCase();
					wrap = wrapMap[ tag ] || wrapMap._default;

					tmp.innerHTML = wrap[1] + elem.replace( rxhtmlTag, "<$1></$2>" ) + wrap[2];

					// Descend through wrappers to the right content
					j = wrap[0];
					while ( j-- ) {
						tmp = tmp.lastChild;
					}

					// Manually add leading whitespace removed by IE
					if ( !jQuery.support.leadingWhitespace && rleadingWhitespace.test( elem ) ) {
						nodes.push( context.createTextNode( rleadingWhitespace.exec( elem )[0] ) );
					}

					// Remove IE's autoinserted <tbody> from table fragments
					if ( !jQuery.support.tbody ) {

						// String was a <table>, *may* have spurious <tbody>
						elem = tag === "table" && !rtbody.test( elem ) ?
							tmp.firstChild :

							// String was a bare <thead> or <tfoot>
							wrap[1] === "<table>" && !rtbody.test( elem ) ?
								tmp :
								0;

						j = elem && elem.childNodes.length;
						while ( j-- ) {
							if ( jQuery.nodeName( (tbody = elem.childNodes[j]), "tbody" ) && !tbody.childNodes.length ) {
								elem.removeChild( tbody );
							}
						}
					}

					jQuery.merge( nodes, tmp.childNodes );

					// Fix #12392 for WebKit and IE > 9
					tmp.textContent = "";

					// Fix #12392 for oldIE
					while ( tmp.firstChild ) {
						tmp.removeChild( tmp.firstChild );
					}

					// Remember the top-level container for proper cleanup
					tmp = safe.lastChild;
				}
			}
		}

		// Fix #11356: Clear elements from fragment
		if ( tmp ) {
			safe.removeChild( tmp );
		}

		// Reset defaultChecked for any radios and checkboxes
		// about to be appended to the DOM in IE 6/7 (#8060)
		if ( !jQuery.support.appendChecked ) {
			jQuery.grep( getAll( nodes, "input" ), fixDefaultChecked );
		}

		i = 0;
		while ( (elem = nodes[ i++ ]) ) {

			// #4087 - If origin and destination elements are the same, and this is
			// that element, do not do anything
			if ( selection && jQuery.inArray( elem, selection ) !== -1 ) {
				continue;
			}

			contains = jQuery.contains( elem.ownerDocument, elem );

			// Append to fragment
			tmp = getAll( safe.appendChild( elem ), "script" );

			// Preserve script evaluation history
			if ( contains ) {
				setGlobalEval( tmp );
			}

			// Capture executables
			if ( scripts ) {
				j = 0;
				while ( (elem = tmp[ j++ ]) ) {
					if ( rscriptType.test( elem.type || "" ) ) {
						scripts.push( elem );
					}
				}
			}
		}

		tmp = null;

		return safe;
	},

	cleanData: function( elems, /* internal */ acceptData ) {
		var elem, type, id, data,
			i = 0,
			internalKey = jQuery.expando,
			cache = jQuery.cache,
			deleteExpando = jQuery.support.deleteExpando,
			special = jQuery.event.special;

		for ( ; (elem = elems[i]) != null; i++ ) {

			if ( acceptData || jQuery.acceptData( elem ) ) {

				id = elem[ internalKey ];
				data = id && cache[ id ];

				if ( data ) {
					if ( data.events ) {
						for ( type in data.events ) {
							if ( special[ type ] ) {
								jQuery.event.remove( elem, type );

							// This is a shortcut to avoid jQuery.event.remove's overhead
							} else {
								jQuery.removeEvent( elem, type, data.handle );
							}
						}
					}

					// Remove cache only if it was not already removed by jQuery.event.remove
					if ( cache[ id ] ) {

						delete cache[ id ];

						// IE does not allow us to delete expando properties from nodes,
						// nor does it have a removeAttribute function on Document nodes;
						// we must handle all of these cases
						if ( deleteExpando ) {
							delete elem[ internalKey ];

						} else if ( typeof elem.removeAttribute !== core_strundefined ) {
							elem.removeAttribute( internalKey );

						} else {
							elem[ internalKey ] = null;
						}

						core_deletedIds.push( id );
					}
				}
			}
		}
	}
});
var iframe, getStyles, curCSS,
	ralpha = /alpha\([^)]*\)/i,
	ropacity = /opacity\s*=\s*([^)]*)/,
	rposition = /^(top|right|bottom|left)$/,
	// swappable if display is none or starts with table except "table", "table-cell", or "table-caption"
	// see here for display values: https://developer.mozilla.org/en-US/docs/CSS/display
	rdisplayswap = /^(none|table(?!-c[ea]).+)/,
	rmargin = /^margin/,
	rnumsplit = new RegExp( "^(" + core_pnum + ")(.*)$", "i" ),
	rnumnonpx = new RegExp( "^(" + core_pnum + ")(?!px)[a-z%]+$", "i" ),
	rrelNum = new RegExp( "^([+-])=(" + core_pnum + ")", "i" ),
	elemdisplay = { BODY: "block" },

	cssShow = { position: "absolute", visibility: "hidden", display: "block" },
	cssNormalTransform = {
		letterSpacing: 0,
		fontWeight: 400
	},

	cssExpand = [ "Top", "Right", "Bottom", "Left" ],
	cssPrefixes = [ "Webkit", "O", "Moz", "ms" ];

// return a css property mapped to a potentially vendor prefixed property
function vendorPropName( style, name ) {

	// shortcut for names that are not vendor prefixed
	if ( name in style ) {
		return name;
	}

	// check for vendor prefixed names
	var capName = name.charAt(0).toUpperCase() + name.slice(1),
		origName = name,
		i = cssPrefixes.length;

	while ( i-- ) {
		name = cssPrefixes[ i ] + capName;
		if ( name in style ) {
			return name;
		}
	}

	return origName;
}

function isHidden( elem, el ) {
	// isHidden might be called from jQuery#filter function;
	// in that case, element will be second argument
	elem = el || elem;
	return jQuery.css( elem, "display" ) === "none" || !jQuery.contains( elem.ownerDocument, elem );
}

function showHide( elements, show ) {
	var display, elem, hidden,
		values = [],
		index = 0,
		length = elements.length;

	for ( ; index < length; index++ ) {
		elem = elements[ index ];
		if ( !elem.style ) {
			continue;
		}

		values[ index ] = jQuery._data( elem, "olddisplay" );
		display = elem.style.display;
		if ( show ) {
			// Reset the inline display of this element to learn if it is
			// being hidden by cascaded rules or not
			if ( !values[ index ] && display === "none" ) {
				elem.style.display = "";
			}

			// Set elements which have been overridden with display: none
			// in a stylesheet to whatever the default browser style is
			// for such an element
			if ( elem.style.display === "" && isHidden( elem ) ) {
				values[ index ] = jQuery._data( elem, "olddisplay", css_defaultDisplay(elem.nodeName) );
			}
		} else {

			if ( !values[ index ] ) {
				hidden = isHidden( elem );

				if ( display && display !== "none" || !hidden ) {
					jQuery._data( elem, "olddisplay", hidden ? display : jQuery.css( elem, "display" ) );
				}
			}
		}
	}

	// Set the display of most of the elements in a second loop
	// to avoid the constant reflow
	for ( index = 0; index < length; index++ ) {
		elem = elements[ index ];
		if ( !elem.style ) {
			continue;
		}
		if ( !show || elem.style.display === "none" || elem.style.display === "" ) {
			elem.style.display = show ? values[ index ] || "" : "none";
		}
	}

	return elements;
}

jQuery.fn.extend({
	css: function( name, value ) {
		return jQuery.access( this, function( elem, name, value ) {
			var len, styles,
				map = {},
				i = 0;

			if ( jQuery.isArray( name ) ) {
				styles = getStyles( elem );
				len = name.length;

				for ( ; i < len; i++ ) {
					map[ name[ i ] ] = jQuery.css( elem, name[ i ], false, styles );
				}

				return map;
			}

			return value !== undefined ?
				jQuery.style( elem, name, value ) :
				jQuery.css( elem, name );
		}, name, value, arguments.length > 1 );
	},
	show: function() {
		return showHide( this, true );
	},
	hide: function() {
		return showHide( this );
	},
	toggle: function( state ) {
		var bool = typeof state === "boolean";

		return this.each(function() {
			if ( bool ? state : isHidden( this ) ) {
				jQuery( this ).show();
			} else {
				jQuery( this ).hide();
			}
		});
	}
});

jQuery.extend({
	// Add in style property hooks for overriding the default
	// behavior of getting and setting a style property
	cssHooks: {
		opacity: {
			get: function( elem, computed ) {
				if ( computed ) {
					// We should always get a number back from opacity
					var ret = curCSS( elem, "opacity" );
					return ret === "" ? "1" : ret;
				}
			}
		}
	},

	// Exclude the following css properties to add px
	cssNumber: {
		"columnCount": true,
		"fillOpacity": true,
		"fontWeight": true,
		"lineHeight": true,
		"opacity": true,
		"orphans": true,
		"widows": true,
		"zIndex": true,
		"zoom": true
	},

	// Add in properties whose names you wish to fix before
	// setting or getting the value
	cssProps: {
		// normalize float css property
		"float": jQuery.support.cssFloat ? "cssFloat" : "styleFloat"
	},

	// Get and set the style property on a DOM Node
	style: function( elem, name, value, extra ) {
		// Don't set styles on text and comment nodes
		if ( !elem || elem.nodeType === 3 || elem.nodeType === 8 || !elem.style ) {
			return;
		}

		// Make sure that we're working with the right name
		var ret, type, hooks,
			origName = jQuery.camelCase( name ),
			style = elem.style;

		name = jQuery.cssProps[ origName ] || ( jQuery.cssProps[ origName ] = vendorPropName( style, origName ) );

		// gets hook for the prefixed version
		// followed by the unprefixed version
		hooks = jQuery.cssHooks[ name ] || jQuery.cssHooks[ origName ];

		// Check if we're setting a value
		if ( value !== undefined ) {
			type = typeof value;

			// convert relative number strings (+= or -=) to relative numbers. #7345
			if ( type === "string" && (ret = rrelNum.exec( value )) ) {
				value = ( ret[1] + 1 ) * ret[2] + parseFloat( jQuery.css( elem, name ) );
				// Fixes bug #9237
				type = "number";
			}

			// Make sure that NaN and null values aren't set. See: #7116
			if ( value == null || type === "number" && isNaN( value ) ) {
				return;
			}

			// If a number was passed in, add 'px' to the (except for certain CSS properties)
			if ( type === "number" && !jQuery.cssNumber[ origName ] ) {
				value += "px";
			}

			// Fixes #8908, it can be done more correctly by specifing setters in cssHooks,
			// but it would mean to define eight (for every problematic property) identical functions
			if ( !jQuery.support.clearCloneStyle && value === "" && name.indexOf("background") === 0 ) {
				style[ name ] = "inherit";
			}

			// If a hook was provided, use that value, otherwise just set the specified value
			if ( !hooks || !("set" in hooks) || (value = hooks.set( elem, value, extra )) !== undefined ) {

				// Wrapped to prevent IE from throwing errors when 'invalid' values are provided
				// Fixes bug #5509
				try {
					style[ name ] = value;
				} catch(e) {}
			}

		} else {
			// If a hook was provided get the non-computed value from there
			if ( hooks && "get" in hooks && (ret = hooks.get( elem, false, extra )) !== undefined ) {
				return ret;
			}

			// Otherwise just get the value from the style object
			return style[ name ];
		}
	},

	css: function( elem, name, extra, styles ) {
		var num, val, hooks,
			origName = jQuery.camelCase( name );

		// Make sure that we're working with the right name
		name = jQuery.cssProps[ origName ] || ( jQuery.cssProps[ origName ] = vendorPropName( elem.style, origName ) );

		// gets hook for the prefixed version
		// followed by the unprefixed version
		hooks = jQuery.cssHooks[ name ] || jQuery.cssHooks[ origName ];

		// If a hook was provided get the computed value from there
		if ( hooks && "get" in hooks ) {
			val = hooks.get( elem, true, extra );
		}

		// Otherwise, if a way to get the computed value exists, use that
		if ( val === undefined ) {
			val = curCSS( elem, name, styles );
		}

		//convert "normal" to computed value
		if ( val === "normal" && name in cssNormalTransform ) {
			val = cssNormalTransform[ name ];
		}

		// Return, converting to number if forced or a qualifier was provided and val looks numeric
		if ( extra === "" || extra ) {
			num = parseFloat( val );
			return extra === true || jQuery.isNumeric( num ) ? num || 0 : val;
		}
		return val;
	},

	// A method for quickly swapping in/out CSS properties to get correct calculations
	swap: function( elem, options, callback, args ) {
		var ret, name,
			old = {};

		// Remember the old values, and insert the new ones
		for ( name in options ) {
			old[ name ] = elem.style[ name ];
			elem.style[ name ] = options[ name ];
		}

		ret = callback.apply( elem, args || [] );

		// Revert the old values
		for ( name in options ) {
			elem.style[ name ] = old[ name ];
		}

		return ret;
	}
});

// NOTE: we've included the "window" in window.getComputedStyle
// because jsdom on node.js will break without it.
if ( window.getComputedStyle ) {
	getStyles = function( elem ) {
		return window.getComputedStyle( elem, null );
	};

	curCSS = function( elem, name, _computed ) {
		var width, minWidth, maxWidth,
			computed = _computed || getStyles( elem ),

			// getPropertyValue is only needed for .css('filter') in IE9, see #12537
			ret = computed ? computed.getPropertyValue( name ) || computed[ name ] : undefined,
			style = elem.style;

		if ( computed ) {

			if ( ret === "" && !jQuery.contains( elem.ownerDocument, elem ) ) {
				ret = jQuery.style( elem, name );
			}

			// A tribute to the "awesome hack by Dean Edwards"
			// Chrome < 17 and Safari 5.0 uses "computed value" instead of "used value" for margin-right
			// Safari 5.1.7 (at least) returns percentage for a larger set of values, but width seems to be reliably pixels
			// this is against the CSSOM draft spec: http://dev.w3.org/csswg/cssom/#resolved-values
			if ( rnumnonpx.test( ret ) && rmargin.test( name ) ) {

				// Remember the original values
				width = style.width;
				minWidth = style.minWidth;
				maxWidth = style.maxWidth;

				// Put in the new values to get a computed value out
				style.minWidth = style.maxWidth = style.width = ret;
				ret = computed.width;

				// Revert the changed values
				style.width = width;
				style.minWidth = minWidth;
				style.maxWidth = maxWidth;
			}
		}

		return ret;
	};
} else if ( document.documentElement.currentStyle ) {
	getStyles = function( elem ) {
		return elem.currentStyle;
	};

	curCSS = function( elem, name, _computed ) {
		var left, rs, rsLeft,
			computed = _computed || getStyles( elem ),
			ret = computed ? computed[ name ] : undefined,
			style = elem.style;

		// Avoid setting ret to empty string here
		// so we don't default to auto
		if ( ret == null && style && style[ name ] ) {
			ret = style[ name ];
		}

		// From the awesome hack by Dean Edwards
		// http://erik.eae.net/archives/2007/07/27/18.54.15/#comment-102291

		// If we're not dealing with a regular pixel number
		// but a number that has a weird ending, we need to convert it to pixels
		// but not position css attributes, as those are proportional to the parent element instead
		// and we can't measure the parent instead because it might trigger a "stacking dolls" problem
		if ( rnumnonpx.test( ret ) && !rposition.test( name ) ) {

			// Remember the original values
			left = style.left;
			rs = elem.runtimeStyle;
			rsLeft = rs && rs.left;

			// Put in the new values to get a computed value out
			if ( rsLeft ) {
				rs.left = elem.currentStyle.left;
			}
			style.left = name === "fontSize" ? "1em" : ret;
			ret = style.pixelLeft + "px";

			// Revert the changed values
			style.left = left;
			if ( rsLeft ) {
				rs.left = rsLeft;
			}
		}

		return ret === "" ? "auto" : ret;
	};
}

function setPositiveNumber( elem, value, subtract ) {
	var matches = rnumsplit.exec( value );
	return matches ?
		// Guard against undefined "subtract", e.g., when used as in cssHooks
		Math.max( 0, matches[ 1 ] - ( subtract || 0 ) ) + ( matches[ 2 ] || "px" ) :
		value;
}

function augmentWidthOrHeight( elem, name, extra, isBorderBox, styles ) {
	var i = extra === ( isBorderBox ? "border" : "content" ) ?
		// If we already have the right measurement, avoid augmentation
		4 :
		// Otherwise initialize for horizontal or vertical properties
		name === "width" ? 1 : 0,

		val = 0;

	for ( ; i < 4; i += 2 ) {
		// both box models exclude margin, so add it if we want it
		if ( extra === "margin" ) {
			val += jQuery.css( elem, extra + cssExpand[ i ], true, styles );
		}

		if ( isBorderBox ) {
			// border-box includes padding, so remove it if we want content
			if ( extra === "content" ) {
				val -= jQuery.css( elem, "padding" + cssExpand[ i ], true, styles );
			}

			// at this point, extra isn't border nor margin, so remove border
			if ( extra !== "margin" ) {
				val -= jQuery.css( elem, "border" + cssExpand[ i ] + "Width", true, styles );
			}
		} else {
			// at this point, extra isn't content, so add padding
			val += jQuery.css( elem, "padding" + cssExpand[ i ], true, styles );

			// at this point, extra isn't content nor padding, so add border
			if ( extra !== "padding" ) {
				val += jQuery.css( elem, "border" + cssExpand[ i ] + "Width", true, styles );
			}
		}
	}

	return val;
}

function getWidthOrHeight( elem, name, extra ) {

	// Start with offset property, which is equivalent to the border-box value
	var valueIsBorderBox = true,
		val = name === "width" ? elem.offsetWidth : elem.offsetHeight,
		styles = getStyles( elem ),
		isBorderBox = jQuery.support.boxSizing && jQuery.css( elem, "boxSizing", false, styles ) === "border-box";

	// some non-html elements return undefined for offsetWidth, so check for null/undefined
	// svg - https://bugzilla.mozilla.org/show_bug.cgi?id=649285
	// MathML - https://bugzilla.mozilla.org/show_bug.cgi?id=491668
	if ( val <= 0 || val == null ) {
		// Fall back to computed then uncomputed css if necessary
		val = curCSS( elem, name, styles );
		if ( val < 0 || val == null ) {
			val = elem.style[ name ];
		}

		// Computed unit is not pixels. Stop here and return.
		if ( rnumnonpx.test(val) ) {
			return val;
		}

		// we need the check for style in case a browser which returns unreliable values
		// for getComputedStyle silently falls back to the reliable elem.style
		valueIsBorderBox = isBorderBox && ( jQuery.support.boxSizingReliable || val === elem.style[ name ] );

		// Normalize "", auto, and prepare for extra
		val = parseFloat( val ) || 0;
	}

	// use the active box-sizing model to add/subtract irrelevant styles
	return ( val +
		augmentWidthOrHeight(
			elem,
			name,
			extra || ( isBorderBox ? "border" : "content" ),
			valueIsBorderBox,
			styles
		)
	) + "px";
}

// Try to determine the default display value of an element
function css_defaultDisplay( nodeName ) {
	var doc = document,
		display = elemdisplay[ nodeName ];

	if ( !display ) {
		display = actualDisplay( nodeName, doc );

		// If the simple way fails, read from inside an iframe
		if ( display === "none" || !display ) {
			// Use the already-created iframe if possible
			iframe = ( iframe ||
				jQuery("<iframe frameborder='0' width='0' height='0'/>")
				.css( "cssText", "display:block !important" )
			).appendTo( doc.documentElement );

			// Always write a new HTML skeleton so Webkit and Firefox don't choke on reuse
			doc = ( iframe[0].contentWindow || iframe[0].contentDocument ).document;
			doc.write("<!doctype html><html><body>");
			doc.close();

			display = actualDisplay( nodeName, doc );
			iframe.detach();
		}

		// Store the correct default display
		elemdisplay[ nodeName ] = display;
	}

	return display;
}

// Called ONLY from within css_defaultDisplay
function actualDisplay( name, doc ) {
	var elem = jQuery( doc.createElement( name ) ).appendTo( doc.body ),
		display = jQuery.css( elem[0], "display" );
	elem.remove();
	return display;
}

jQuery.each([ "height", "width" ], function( i, name ) {
	jQuery.cssHooks[ name ] = {
		get: function( elem, computed, extra ) {
			if ( computed ) {
				// certain elements can have dimension info if we invisibly show them
				// however, it must have a current display style that would benefit from this
				return elem.offsetWidth === 0 && rdisplayswap.test( jQuery.css( elem, "display" ) ) ?
					jQuery.swap( elem, cssShow, function() {
						return getWidthOrHeight( elem, name, extra );
					}) :
					getWidthOrHeight( elem, name, extra );
			}
		},

		set: function( elem, value, extra ) {
			var styles = extra && getStyles( elem );
			return setPositiveNumber( elem, value, extra ?
				augmentWidthOrHeight(
					elem,
					name,
					extra,
					jQuery.support.boxSizing && jQuery.css( elem, "boxSizing", false, styles ) === "border-box",
					styles
				) : 0
			);
		}
	};
});

if ( !jQuery.support.opacity ) {
	jQuery.cssHooks.opacity = {
		get: function( elem, computed ) {
			// IE uses filters for opacity
			return ropacity.test( (computed && elem.currentStyle ? elem.currentStyle.filter : elem.style.filter) || "" ) ?
				( 0.01 * parseFloat( RegExp.$1 ) ) + "" :
				computed ? "1" : "";
		},

		set: function( elem, value ) {
			var style = elem.style,
				currentStyle = elem.currentStyle,
				opacity = jQuery.isNumeric( value ) ? "alpha(opacity=" + value * 100 + ")" : "",
				filter = currentStyle && currentStyle.filter || style.filter || "";

			// IE has trouble with opacity if it does not have layout
			// Force it by setting the zoom level
			style.zoom = 1;

			// if setting opacity to 1, and no other filters exist - attempt to remove filter attribute #6652
			// if value === "", then remove inline opacity #12685
			if ( ( value >= 1 || value === "" ) &&
					jQuery.trim( filter.replace( ralpha, "" ) ) === "" &&
					style.removeAttribute ) {

				// Setting style.filter to null, "" & " " still leave "filter:" in the cssText
				// if "filter:" is present at all, clearType is disabled, we want to avoid this
				// style.removeAttribute is IE Only, but so apparently is this code path...
				style.removeAttribute( "filter" );

				// if there is no filter style applied in a css rule or unset inline opacity, we are done
				if ( value === "" || currentStyle && !currentStyle.filter ) {
					return;
				}
			}

			// otherwise, set new filter values
			style.filter = ralpha.test( filter ) ?
				filter.replace( ralpha, opacity ) :
				filter + " " + opacity;
		}
	};
}

// These hooks cannot be added until DOM ready because the support test
// for it is not run until after DOM ready
jQuery(function() {
	if ( !jQuery.support.reliableMarginRight ) {
		jQuery.cssHooks.marginRight = {
			get: function( elem, computed ) {
				if ( computed ) {
					// WebKit Bug 13343 - getComputedStyle returns wrong value for margin-right
					// Work around by temporarily setting element display to inline-block
					return jQuery.swap( elem, { "display": "inline-block" },
						curCSS, [ elem, "marginRight" ] );
				}
			}
		};
	}

	// Webkit bug: https://bugs.webkit.org/show_bug.cgi?id=29084
	// getComputedStyle returns percent when specified for top/left/bottom/right
	// rather than make the css module depend on the offset module, we just check for it here
	if ( !jQuery.support.pixelPosition && jQuery.fn.position ) {
		jQuery.each( [ "top", "left" ], function( i, prop ) {
			jQuery.cssHooks[ prop ] = {
				get: function( elem, computed ) {
					if ( computed ) {
						computed = curCSS( elem, prop );
						// if curCSS returns percentage, fallback to offset
						return rnumnonpx.test( computed ) ?
							jQuery( elem ).position()[ prop ] + "px" :
							computed;
					}
				}
			};
		});
	}

});

if ( jQuery.expr && jQuery.expr.filters ) {
	jQuery.expr.filters.hidden = function( elem ) {
		// Support: Opera <= 12.12
		// Opera reports offsetWidths and offsetHeights less than zero on some elements
		return elem.offsetWidth <= 0 && elem.offsetHeight <= 0 ||
			(!jQuery.support.reliableHiddenOffsets && ((elem.style && elem.style.display) || jQuery.css( elem, "display" )) === "none");
	};

	jQuery.expr.filters.visible = function( elem ) {
		return !jQuery.expr.filters.hidden( elem );
	};
}

// These hooks are used by animate to expand properties
jQuery.each({
	margin: "",
	padding: "",
	border: "Width"
}, function( prefix, suffix ) {
	jQuery.cssHooks[ prefix + suffix ] = {
		expand: function( value ) {
			var i = 0,
				expanded = {},

				// assumes a single number if not a string
				parts = typeof value === "string" ? value.split(" ") : [ value ];

			for ( ; i < 4; i++ ) {
				expanded[ prefix + cssExpand[ i ] + suffix ] =
					parts[ i ] || parts[ i - 2 ] || parts[ 0 ];
			}

			return expanded;
		}
	};

	if ( !rmargin.test( prefix ) ) {
		jQuery.cssHooks[ prefix + suffix ].set = setPositiveNumber;
	}
});
var r20 = /%20/g,
	rbracket = /\[\]$/,
	rCRLF = /\r?\n/g,
	rsubmitterTypes = /^(?:submit|button|image|reset|file)$/i,
	rsubmittable = /^(?:input|select|textarea|keygen)/i;

jQuery.fn.extend({
	serialize: function() {
		return jQuery.param( this.serializeArray() );
	},
	serializeArray: function() {
		return this.map(function(){
			// Can add propHook for "elements" to filter or add form elements
			var elements = jQuery.prop( this, "elements" );
			return elements ? jQuery.makeArray( elements ) : this;
		})
		.filter(function(){
			var type = this.type;
			// Use .is(":disabled") so that fieldset[disabled] works
			return this.name && !jQuery( this ).is( ":disabled" ) &&
				rsubmittable.test( this.nodeName ) && !rsubmitterTypes.test( type ) &&
				( this.checked || !manipulation_rcheckableType.test( type ) );
		})
		.map(function( i, elem ){
			var val = jQuery( this ).val();

			return val == null ?
				null :
				jQuery.isArray( val ) ?
					jQuery.map( val, function( val ){
						return { name: elem.name, value: val.replace( rCRLF, "\r\n" ) };
					}) :
					{ name: elem.name, value: val.replace( rCRLF, "\r\n" ) };
		}).get();
	}
});

//Serialize an array of form elements or a set of
//key/values into a query string
jQuery.param = function( a, traditional ) {
	var prefix,
		s = [],
		add = function( key, value ) {
			// If value is a function, invoke it and return its value
			value = jQuery.isFunction( value ) ? value() : ( value == null ? "" : value );
			s[ s.length ] = encodeURIComponent( key ) + "=" + encodeURIComponent( value );
		};

	// Set traditional to true for jQuery <= 1.3.2 behavior.
	if ( traditional === undefined ) {
		traditional = jQuery.ajaxSettings && jQuery.ajaxSettings.traditional;
	}

	// If an array was passed in, assume that it is an array of form elements.
	if ( jQuery.isArray( a ) || ( a.jquery && !jQuery.isPlainObject( a ) ) ) {
		// Serialize the form elements
		jQuery.each( a, function() {
			add( this.name, this.value );
		});

	} else {
		// If traditional, encode the "old" way (the way 1.3.2 or older
		// did it), otherwise encode params recursively.
		for ( prefix in a ) {
			buildParams( prefix, a[ prefix ], traditional, add );
		}
	}

	// Return the resulting serialization
	return s.join( "&" ).replace( r20, "+" );
};

function buildParams( prefix, obj, traditional, add ) {
	var name;

	if ( jQuery.isArray( obj ) ) {
		// Serialize array item.
		jQuery.each( obj, function( i, v ) {
			if ( traditional || rbracket.test( prefix ) ) {
				// Treat each array item as a scalar.
				add( prefix, v );

			} else {
				// Item is non-scalar (array or object), encode its numeric index.
				buildParams( prefix + "[" + ( typeof v === "object" ? i : "" ) + "]", v, traditional, add );
			}
		});

	} else if ( !traditional && jQuery.type( obj ) === "object" ) {
		// Serialize object item.
		for ( name in obj ) {
			buildParams( prefix + "[" + name + "]", obj[ name ], traditional, add );
		}

	} else {
		// Serialize scalar item.
		add( prefix, obj );
	}
}
jQuery.each( ("blur focus focusin focusout load resize scroll unload click dblclick " +
	"mousedown mouseup mousemove mouseover mouseout mouseenter mouseleave " +
	"change select submit keydown keypress keyup error contextmenu").split(" "), function( i, name ) {

	// Handle event binding
	jQuery.fn[ name ] = function( data, fn ) {
		return arguments.length > 0 ?
			this.on( name, null, data, fn ) :
			this.trigger( name );
	};
});

jQuery.fn.hover = function( fnOver, fnOut ) {
	return this.mouseenter( fnOver ).mouseleave( fnOut || fnOver );
};
var
	// Document location
	ajaxLocParts,
	ajaxLocation,
	ajax_nonce = jQuery.now(),

	ajax_rquery = /\?/,
	rhash = /#.*$/,
	rts = /([?&])_=[^&]*/,
	rheaders = /^(.*?):[ \t]*([^\r\n]*)\r?$/mg, // IE leaves an \r character at EOL
	// #7653, #8125, #8152: local protocol detection
	rlocalProtocol = /^(?:about|app|app-storage|.+-extension|file|res|widget):$/,
	rnoContent = /^(?:GET|HEAD)$/,
	rprotocol = /^\/\//,
	rurl = /^([\w.+-]+:)(?:\/\/([^\/?#:]*)(?::(\d+)|)|)/,

	// Keep a copy of the old load method
	_load = jQuery.fn.load,

	/* Prefilters
	 * 1) They are useful to introduce custom dataTypes (see ajax/jsonp.js for an example)
	 * 2) These are called:
	 *    - BEFORE asking for a transport
	 *    - AFTER param serialization (s.data is a string if s.processData is true)
	 * 3) key is the dataType
	 * 4) the catchall symbol "*" can be used
	 * 5) execution will start with transport dataType and THEN continue down to "*" if needed
	 */
	prefilters = {},

	/* Transports bindings
	 * 1) key is the dataType
	 * 2) the catchall symbol "*" can be used
	 * 3) selection will start with transport dataType and THEN go to "*" if needed
	 */
	transports = {},

	// Avoid comment-prolog char sequence (#10098); must appease lint and evade compression
	allTypes = "*/".concat("*");

// #8138, IE may throw an exception when accessing
// a field from window.location if document.domain has been set
try {
	ajaxLocation = location.href;
} catch( e ) {
	// Use the href attribute of an A element
	// since IE will modify it given document.location
	ajaxLocation = document.createElement( "a" );
	ajaxLocation.href = "";
	ajaxLocation = ajaxLocation.href;
}

// Segment location into parts
ajaxLocParts = rurl.exec( ajaxLocation.toLowerCase() ) || [];

// Base "constructor" for jQuery.ajaxPrefilter and jQuery.ajaxTransport
function addToPrefiltersOrTransports( structure ) {

	// dataTypeExpression is optional and defaults to "*"
	return function( dataTypeExpression, func ) {

		if ( typeof dataTypeExpression !== "string" ) {
			func = dataTypeExpression;
			dataTypeExpression = "*";
		}

		var dataType,
			i = 0,
			dataTypes = dataTypeExpression.toLowerCase().match( core_rnotwhite ) || [];

		if ( jQuery.isFunction( func ) ) {
			// For each dataType in the dataTypeExpression
			while ( (dataType = dataTypes[i++]) ) {
				// Prepend if requested
				if ( dataType[0] === "+" ) {
					dataType = dataType.slice( 1 ) || "*";
					(structure[ dataType ] = structure[ dataType ] || []).unshift( func );

				// Otherwise append
				} else {
					(structure[ dataType ] = structure[ dataType ] || []).push( func );
				}
			}
		}
	};
}

// Base inspection function for prefilters and transports
function inspectPrefiltersOrTransports( structure, options, originalOptions, jqXHR ) {

	var inspected = {},
		seekingTransport = ( structure === transports );

	function inspect( dataType ) {
		var selected;
		inspected[ dataType ] = true;
		jQuery.each( structure[ dataType ] || [], function( _, prefilterOrFactory ) {
			var dataTypeOrTransport = prefilterOrFactory( options, originalOptions, jqXHR );
			if( typeof dataTypeOrTransport === "string" && !seekingTransport && !inspected[ dataTypeOrTransport ] ) {
				options.dataTypes.unshift( dataTypeOrTransport );
				inspect( dataTypeOrTransport );
				return false;
			} else if ( seekingTransport ) {
				return !( selected = dataTypeOrTransport );
			}
		});
		return selected;
	}

	return inspect( options.dataTypes[ 0 ] ) || !inspected[ "*" ] && inspect( "*" );
}

// A special extend for ajax options
// that takes "flat" options (not to be deep extended)
// Fixes #9887
function ajaxExtend( target, src ) {
	var deep, key,
		flatOptions = jQuery.ajaxSettings.flatOptions || {};

	for ( key in src ) {
		if ( src[ key ] !== undefined ) {
			( flatOptions[ key ] ? target : ( deep || (deep = {}) ) )[ key ] = src[ key ];
		}
	}
	if ( deep ) {
		jQuery.extend( true, target, deep );
	}

	return target;
}

jQuery.fn.load = function( url, params, callback ) {
	if ( typeof url !== "string" && _load ) {
		return _load.apply( this, arguments );
	}

	var selector, response, type,
		self = this,
		off = url.indexOf(" ");

	if ( off >= 0 ) {
		selector = url.slice( off, url.length );
		url = url.slice( 0, off );
	}

	// If it's a function
	if ( jQuery.isFunction( params ) ) {

		// We assume that it's the callback
		callback = params;
		params = undefined;

	// Otherwise, build a param string
	} else if ( params && typeof params === "object" ) {
		type = "POST";
	}

	// If we have elements to modify, make the request
	if ( self.length > 0 ) {
		jQuery.ajax({
			url: url,

			// if "type" variable is undefined, then "GET" method will be used
			type: type,
			dataType: "html",
			data: params
		}).done(function( responseText ) {

			// Save response for use in complete callback
			response = arguments;

			self.html( selector ?

				// If a selector was specified, locate the right elements in a dummy div
				// Exclude scripts to avoid IE 'Permission Denied' errors
				jQuery("<div>").append( jQuery.parseHTML( responseText ) ).find( selector ) :

				// Otherwise use the full result
				responseText );

		}).complete( callback && function( jqXHR, status ) {
			self.each( callback, response || [ jqXHR.responseText, status, jqXHR ] );
		});
	}

	return this;
};

// Attach a bunch of functions for handling common AJAX events
jQuery.each( [ "ajaxStart", "ajaxStop", "ajaxComplete", "ajaxError", "ajaxSuccess", "ajaxSend" ], function( i, type ){
	jQuery.fn[ type ] = function( fn ){
		return this.on( type, fn );
	};
});

jQuery.each( [ "get", "post" ], function( i, method ) {
	jQuery[ method ] = function( url, data, callback, type ) {
		// shift arguments if data argument was omitted
		if ( jQuery.isFunction( data ) ) {
			type = type || callback;
			callback = data;
			data = undefined;
		}

		return jQuery.ajax({
			url: url,
			type: method,
			dataType: type,
			data: data,
			success: callback
		});
	};
});

jQuery.extend({

	// Counter for holding the number of active queries
	active: 0,

	// Last-Modified header cache for next request
	lastModified: {},
	etag: {},

	ajaxSettings: {
		url: ajaxLocation,
		type: "GET",
		isLocal: rlocalProtocol.test( ajaxLocParts[ 1 ] ),
		global: true,
		processData: true,
		async: true,
		contentType: "application/x-www-form-urlencoded; charset=UTF-8",
		/*
		timeout: 0,
		data: null,
		dataType: null,
		username: null,
		password: null,
		cache: null,
		throws: false,
		traditional: false,
		headers: {},
		*/

		accepts: {
			"*": allTypes,
			text: "text/plain",
			html: "text/html",
			xml: "application/xml, text/xml",
			json: "application/json, text/javascript"
		},

		contents: {
			xml: /xml/,
			html: /html/,
			json: /json/
		},

		responseFields: {
			xml: "responseXML",
			text: "responseText"
		},

		// Data converters
		// Keys separate source (or catchall "*") and destination types with a single space
		converters: {

			// Convert anything to text
			"* text": window.String,

			// Text to html (true = no transformation)
			"text html": true,

			// Evaluate text as a json expression
			"text json": jQuery.parseJSON,

			// Parse text as xml
			"text xml": jQuery.parseXML
		},

		// For options that shouldn't be deep extended:
		// you can add your own custom options here if
		// and when you create one that shouldn't be
		// deep extended (see ajaxExtend)
		flatOptions: {
			url: true,
			context: true
		}
	},

	// Creates a full fledged settings object into target
	// with both ajaxSettings and settings fields.
	// If target is omitted, writes into ajaxSettings.
	ajaxSetup: function( target, settings ) {
		return settings ?

			// Building a settings object
			ajaxExtend( ajaxExtend( target, jQuery.ajaxSettings ), settings ) :

			// Extending ajaxSettings
			ajaxExtend( jQuery.ajaxSettings, target );
	},

	ajaxPrefilter: addToPrefiltersOrTransports( prefilters ),
	ajaxTransport: addToPrefiltersOrTransports( transports ),

	// Main method
	ajax: function( url, options ) {

		// If url is an object, simulate pre-1.5 signature
		if ( typeof url === "object" ) {
			options = url;
			url = undefined;
		}

		// Force options to be an object
		options = options || {};

		var // Cross-domain detection vars
			parts,
			// Loop variable
			i,
			// URL without anti-cache param
			cacheURL,
			// Response headers as string
			responseHeadersString,
			// timeout handle
			timeoutTimer,

			// To know if global events are to be dispatched
			fireGlobals,

			transport,
			// Response headers
			responseHeaders,
			// Create the final options object
			s = jQuery.ajaxSetup( {}, options ),
			// Callbacks context
			callbackContext = s.context || s,
			// Context for global events is callbackContext if it is a DOM node or jQuery collection
			globalEventContext = s.context && ( callbackContext.nodeType || callbackContext.jquery ) ?
				jQuery( callbackContext ) :
				jQuery.event,
			// Deferreds
			deferred = jQuery.Deferred(),
			completeDeferred = jQuery.Callbacks("once memory"),
			// Status-dependent callbacks
			statusCode = s.statusCode || {},
			// Headers (they are sent all at once)
			requestHeaders = {},
			requestHeadersNames = {},
			// The jqXHR state
			state = 0,
			// Default abort message
			strAbort = "canceled",
			// Fake xhr
			jqXHR = {
				readyState: 0,

				// Builds headers hashtable if needed
				getResponseHeader: function( key ) {
					var match;
					if ( state === 2 ) {
						if ( !responseHeaders ) {
							responseHeaders = {};
							while ( (match = rheaders.exec( responseHeadersString )) ) {
								responseHeaders[ match[1].toLowerCase() ] = match[ 2 ];
							}
						}
						match = responseHeaders[ key.toLowerCase() ];
					}
					return match == null ? null : match;
				},

				// Raw string
				getAllResponseHeaders: function() {
					return state === 2 ? responseHeadersString : null;
				},

				// Caches the header
				setRequestHeader: function( name, value ) {
					var lname = name.toLowerCase();
					if ( !state ) {
						name = requestHeadersNames[ lname ] = requestHeadersNames[ lname ] || name;
						requestHeaders[ name ] = value;
					}
					return this;
				},

				// Overrides response content-type header
				overrideMimeType: function( type ) {
					if ( !state ) {
						s.mimeType = type;
					}
					return this;
				},

				// Status-dependent callbacks
				statusCode: function( map ) {
					var code;
					if ( map ) {
						if ( state < 2 ) {
							for ( code in map ) {
								// Lazy-add the new callback in a way that preserves old ones
								statusCode[ code ] = [ statusCode[ code ], map[ code ] ];
							}
						} else {
							// Execute the appropriate callbacks
							jqXHR.always( map[ jqXHR.status ] );
						}
					}
					return this;
				},

				// Cancel the request
				abort: function( statusText ) {
					var finalText = statusText || strAbort;
					if ( transport ) {
						transport.abort( finalText );
					}
					done( 0, finalText );
					return this;
				}
			};

		// Attach deferreds
		deferred.promise( jqXHR ).complete = completeDeferred.add;
		jqXHR.success = jqXHR.done;
		jqXHR.error = jqXHR.fail;

		// Remove hash character (#7531: and string promotion)
		// Add protocol if not provided (#5866: IE7 issue with protocol-less urls)
		// Handle falsy url in the settings object (#10093: consistency with old signature)
		// We also use the url parameter if available
		s.url = ( ( url || s.url || ajaxLocation ) + "" ).replace( rhash, "" ).replace( rprotocol, ajaxLocParts[ 1 ] + "//" );

		// Alias method option to type as per ticket #12004
		s.type = options.method || options.type || s.method || s.type;

		// Extract dataTypes list
		s.dataTypes = jQuery.trim( s.dataType || "*" ).toLowerCase().match( core_rnotwhite ) || [""];

		// A cross-domain request is in order when we have a protocol:host:port mismatch
		if ( s.crossDomain == null ) {
			parts = rurl.exec( s.url.toLowerCase() );
			s.crossDomain = !!( parts &&
				( parts[ 1 ] !== ajaxLocParts[ 1 ] || parts[ 2 ] !== ajaxLocParts[ 2 ] ||
					( parts[ 3 ] || ( parts[ 1 ] === "http:" ? 80 : 443 ) ) !=
						( ajaxLocParts[ 3 ] || ( ajaxLocParts[ 1 ] === "http:" ? 80 : 443 ) ) )
			);
		}

		// Convert data if not already a string
		if ( s.data && s.processData && typeof s.data !== "string" ) {
			s.data = jQuery.param( s.data, s.traditional );
		}

		// Apply prefilters
		inspectPrefiltersOrTransports( prefilters, s, options, jqXHR );

		// If request was aborted inside a prefilter, stop there
		if ( state === 2 ) {
			return jqXHR;
		}

		// We can fire global events as of now if asked to
		fireGlobals = s.global;

		// Watch for a new set of requests
		if ( fireGlobals && jQuery.active++ === 0 ) {
			jQuery.event.trigger("ajaxStart");
		}

		// Uppercase the type
		s.type = s.type.toUpperCase();

		// Determine if request has content
		s.hasContent = !rnoContent.test( s.type );

		// Save the URL in case we're toying with the If-Modified-Since
		// and/or If-None-Match header later on
		cacheURL = s.url;

		// More options handling for requests with no content
		if ( !s.hasContent ) {

			// If data is available, append data to url
			if ( s.data ) {
				cacheURL = ( s.url += ( ajax_rquery.test( cacheURL ) ? "&" : "?" ) + s.data );
				// #9682: remove data so that it's not used in an eventual retry
				delete s.data;
			}

			// Add anti-cache in url if needed
			if ( s.cache === false ) {
				s.url = rts.test( cacheURL ) ?

					// If there is already a '_' parameter, set its value
					cacheURL.replace( rts, "$1_=" + ajax_nonce++ ) :

					// Otherwise add one to the end
					cacheURL + ( ajax_rquery.test( cacheURL ) ? "&" : "?" ) + "_=" + ajax_nonce++;
			}
		}

		// Set the If-Modified-Since and/or If-None-Match header, if in ifModified mode.
		if ( s.ifModified ) {
			if ( jQuery.lastModified[ cacheURL ] ) {
				jqXHR.setRequestHeader( "If-Modified-Since", jQuery.lastModified[ cacheURL ] );
			}
			if ( jQuery.etag[ cacheURL ] ) {
				jqXHR.setRequestHeader( "If-None-Match", jQuery.etag[ cacheURL ] );
			}
		}

		// Set the correct header, if data is being sent
		if ( s.data && s.hasContent && s.contentType !== false || options.contentType ) {
			jqXHR.setRequestHeader( "Content-Type", s.contentType );
		}

		// Set the Accepts header for the server, depending on the dataType
		jqXHR.setRequestHeader(
			"Accept",
			s.dataTypes[ 0 ] && s.accepts[ s.dataTypes[0] ] ?
				s.accepts[ s.dataTypes[0] ] + ( s.dataTypes[ 0 ] !== "*" ? ", " + allTypes + "; q=0.01" : "" ) :
				s.accepts[ "*" ]
		);

		// Check for headers option
		for ( i in s.headers ) {
			jqXHR.setRequestHeader( i, s.headers[ i ] );
		}

		// Allow custom headers/mimetypes and early abort
		if ( s.beforeSend && ( s.beforeSend.call( callbackContext, jqXHR, s ) === false || state === 2 ) ) {
			// Abort if not done already and return
			return jqXHR.abort();
		}

		// aborting is no longer a cancellation
		strAbort = "abort";

		// Install callbacks on deferreds
		for ( i in { success: 1, error: 1, complete: 1 } ) {
			jqXHR[ i ]( s[ i ] );
		}

		// Get transport
		transport = inspectPrefiltersOrTransports( transports, s, options, jqXHR );

		// If no transport, we auto-abort
		if ( !transport ) {
			done( -1, "No Transport" );
		} else {
			jqXHR.readyState = 1;

			// Send global event
			if ( fireGlobals ) {
				globalEventContext.trigger( "ajaxSend", [ jqXHR, s ] );
			}
			// Timeout
			if ( s.async && s.timeout > 0 ) {
				timeoutTimer = setTimeout(function() {
					jqXHR.abort("timeout");
				}, s.timeout );
			}

			try {
				state = 1;
				transport.send( requestHeaders, done );
			} catch ( e ) {
				// Propagate exception as error if not done
				if ( state < 2 ) {
					done( -1, e );
				// Simply rethrow otherwise
				} else {
					throw e;
				}
			}
		}

		// Callback for when everything is done
		function done( status, nativeStatusText, responses, headers ) {
			var isSuccess, success, error, response, modified,
				statusText = nativeStatusText;

			// Called once
			if ( state === 2 ) {
				return;
			}

			// State is "done" now
			state = 2;

			// Clear timeout if it exists
			if ( timeoutTimer ) {
				clearTimeout( timeoutTimer );
			}

			// Dereference transport for early garbage collection
			// (no matter how long the jqXHR object will be used)
			transport = undefined;

			// Cache response headers
			responseHeadersString = headers || "";

			// Set readyState
			jqXHR.readyState = status > 0 ? 4 : 0;

			// Get response data
			if ( responses ) {
				response = ajaxHandleResponses( s, jqXHR, responses );
			}

			// If successful, handle type chaining
			if ( status >= 200 && status < 300 || status === 304 ) {

				// Set the If-Modified-Since and/or If-None-Match header, if in ifModified mode.
				if ( s.ifModified ) {
					modified = jqXHR.getResponseHeader("Last-Modified");
					if ( modified ) {
						jQuery.lastModified[ cacheURL ] = modified;
					}
					modified = jqXHR.getResponseHeader("etag");
					if ( modified ) {
						jQuery.etag[ cacheURL ] = modified;
					}
				}

				// if no content
				if ( status === 204 ) {
					isSuccess = true;
					statusText = "nocontent";

				// if not modified
				} else if ( status === 304 ) {
					isSuccess = true;
					statusText = "notmodified";

				// If we have data, let's convert it
				} else {
					isSuccess = ajaxConvert( s, response );
					statusText = isSuccess.state;
					success = isSuccess.data;
					error = isSuccess.error;
					isSuccess = !error;
				}
			} else {
				// We extract error from statusText
				// then normalize statusText and status for non-aborts
				error = statusText;
				if ( status || !statusText ) {
					statusText = "error";
					if ( status < 0 ) {
						status = 0;
					}
				}
			}

			// Set data for the fake xhr object
			jqXHR.status = status;
			jqXHR.statusText = ( nativeStatusText || statusText ) + "";

			// Success/Error
			if ( isSuccess ) {
				deferred.resolveWith( callbackContext, [ success, statusText, jqXHR ] );
			} else {
				deferred.rejectWith( callbackContext, [ jqXHR, statusText, error ] );
			}

			// Status-dependent callbacks
			jqXHR.statusCode( statusCode );
			statusCode = undefined;

			if ( fireGlobals ) {
				globalEventContext.trigger( isSuccess ? "ajaxSuccess" : "ajaxError",
					[ jqXHR, s, isSuccess ? success : error ] );
			}

			// Complete
			completeDeferred.fireWith( callbackContext, [ jqXHR, statusText ] );

			if ( fireGlobals ) {
				globalEventContext.trigger( "ajaxComplete", [ jqXHR, s ] );
				// Handle the global AJAX counter
				if ( !( --jQuery.active ) ) {
					jQuery.event.trigger("ajaxStop");
				}
			}
		}

		return jqXHR;
	},

	getScript: function( url, callback ) {
		return jQuery.get( url, undefined, callback, "script" );
	},

	getJSON: function( url, data, callback ) {
		return jQuery.get( url, data, callback, "json" );
	}
});

/* Handles responses to an ajax request:
 * - sets all responseXXX fields accordingly
 * - finds the right dataType (mediates between content-type and expected dataType)
 * - returns the corresponding response
 */
function ajaxHandleResponses( s, jqXHR, responses ) {
	var firstDataType, ct, finalDataType, type,
		contents = s.contents,
		dataTypes = s.dataTypes,
		responseFields = s.responseFields;

	// Fill responseXXX fields
	for ( type in responseFields ) {
		if ( type in responses ) {
			jqXHR[ responseFields[type] ] = responses[ type ];
		}
	}

	// Remove auto dataType and get content-type in the process
	while( dataTypes[ 0 ] === "*" ) {
		dataTypes.shift();
		if ( ct === undefined ) {
			ct = s.mimeType || jqXHR.getResponseHeader("Content-Type");
		}
	}

	// Check if we're dealing with a known content-type
	if ( ct ) {
		for ( type in contents ) {
			if ( contents[ type ] && contents[ type ].test( ct ) ) {
				dataTypes.unshift( type );
				break;
			}
		}
	}

	// Check to see if we have a response for the expected dataType
	if ( dataTypes[ 0 ] in responses ) {
		finalDataType = dataTypes[ 0 ];
	} else {
		// Try convertible dataTypes
		for ( type in responses ) {
			if ( !dataTypes[ 0 ] || s.converters[ type + " " + dataTypes[0] ] ) {
				finalDataType = type;
				break;
			}
			if ( !firstDataType ) {
				firstDataType = type;
			}
		}
		// Or just use first one
		finalDataType = finalDataType || firstDataType;
	}

	// If we found a dataType
	// We add the dataType to the list if needed
	// and return the corresponding response
	if ( finalDataType ) {
		if ( finalDataType !== dataTypes[ 0 ] ) {
			dataTypes.unshift( finalDataType );
		}
		return responses[ finalDataType ];
	}
}

// Chain conversions given the request and the original response
function ajaxConvert( s, response ) {
	var conv2, current, conv, tmp,
		converters = {},
		i = 0,
		// Work with a copy of dataTypes in case we need to modify it for conversion
		dataTypes = s.dataTypes.slice(),
		prev = dataTypes[ 0 ];

	// Apply the dataFilter if provided
	if ( s.dataFilter ) {
		response = s.dataFilter( response, s.dataType );
	}

	// Create converters map with lowercased keys
	if ( dataTypes[ 1 ] ) {
		for ( conv in s.converters ) {
			converters[ conv.toLowerCase() ] = s.converters[ conv ];
		}
	}

	// Convert to each sequential dataType, tolerating list modification
	for ( ; (current = dataTypes[++i]); ) {

		// There's only work to do if current dataType is non-auto
		if ( current !== "*" ) {

			// Convert response if prev dataType is non-auto and differs from current
			if ( prev !== "*" && prev !== current ) {

				// Seek a direct converter
				conv = converters[ prev + " " + current ] || converters[ "* " + current ];

				// If none found, seek a pair
				if ( !conv ) {
					for ( conv2 in converters ) {

						// If conv2 outputs current
						tmp = conv2.split(" ");
						if ( tmp[ 1 ] === current ) {

							// If prev can be converted to accepted input
							conv = converters[ prev + " " + tmp[ 0 ] ] ||
								converters[ "* " + tmp[ 0 ] ];
							if ( conv ) {
								// Condense equivalence converters
								if ( conv === true ) {
									conv = converters[ conv2 ];

								// Otherwise, insert the intermediate dataType
								} else if ( converters[ conv2 ] !== true ) {
									current = tmp[ 0 ];
									dataTypes.splice( i--, 0, current );
								}

								break;
							}
						}
					}
				}

				// Apply converter (if not an equivalence)
				if ( conv !== true ) {

					// Unless errors are allowed to bubble, catch and return them
					if ( conv && s["throws"] ) {
						response = conv( response );
					} else {
						try {
							response = conv( response );
						} catch ( e ) {
							return { state: "parsererror", error: conv ? e : "No conversion from " + prev + " to " + current };
						}
					}
				}
			}

			// Update prev for next iteration
			prev = current;
		}
	}

	return { state: "success", data: response };
}
// Install script dataType
jQuery.ajaxSetup({
	accepts: {
		script: "text/javascript, application/javascript, application/ecmascript, application/x-ecmascript"
	},
	contents: {
		script: /(?:java|ecma)script/
	},
	converters: {
		"text script": function( text ) {
			jQuery.globalEval( text );
			return text;
		}
	}
});

// Handle cache's special case and global
jQuery.ajaxPrefilter( "script", function( s ) {
	if ( s.cache === undefined ) {
		s.cache = false;
	}
	if ( s.crossDomain ) {
		s.type = "GET";
		s.global = false;
	}
});

// Bind script tag hack transport
jQuery.ajaxTransport( "script", function(s) {

	// This transport only deals with cross domain requests
	if ( s.crossDomain ) {

		var script,
			head = document.head || jQuery("head")[0] || document.documentElement;

		return {

			send: function( _, callback ) {

				script = document.createElement("script");

				script.async = true;

				if ( s.scriptCharset ) {
					script.charset = s.scriptCharset;
				}

				script.src = s.url;

				// Attach handlers for all browsers
				script.onload = script.onreadystatechange = function( _, isAbort ) {

					if ( isAbort || !script.readyState || /loaded|complete/.test( script.readyState ) ) {

						// Handle memory leak in IE
						script.onload = script.onreadystatechange = null;

						// Remove the script
						if ( script.parentNode ) {
							script.parentNode.removeChild( script );
						}

						// Dereference the script
						script = null;

						// Callback if not abort
						if ( !isAbort ) {
							callback( 200, "success" );
						}
					}
				};

				// Circumvent IE6 bugs with base elements (#2709 and #4378) by prepending
				// Use native DOM manipulation to avoid our domManip AJAX trickery
				head.insertBefore( script, head.firstChild );
			},

			abort: function() {
				if ( script ) {
					script.onload( undefined, true );
				}
			}
		};
	}
});
var oldCallbacks = [],
	rjsonp = /(=)\?(?=&|$)|\?\?/;

// Default jsonp settings
jQuery.ajaxSetup({
	jsonp: "callback",
	jsonpCallback: function() {
		var callback = oldCallbacks.pop() || ( jQuery.expando + "_" + ( ajax_nonce++ ) );
		this[ callback ] = true;
		return callback;
	}
});

// Detect, normalize options and install callbacks for jsonp requests
jQuery.ajaxPrefilter( "json jsonp", function( s, originalSettings, jqXHR ) {

	var callbackName, overwritten, responseContainer,
		jsonProp = s.jsonp !== false && ( rjsonp.test( s.url ) ?
			"url" :
			typeof s.data === "string" && !( s.contentType || "" ).indexOf("application/x-www-form-urlencoded") && rjsonp.test( s.data ) && "data"
		);

	// Handle iff the expected data type is "jsonp" or we have a parameter to set
	if ( jsonProp || s.dataTypes[ 0 ] === "jsonp" ) {

		// Get callback name, remembering preexisting value associated with it
		callbackName = s.jsonpCallback = jQuery.isFunction( s.jsonpCallback ) ?
			s.jsonpCallback() :
			s.jsonpCallback;

		// Insert callback into url or form data
		if ( jsonProp ) {
			s[ jsonProp ] = s[ jsonProp ].replace( rjsonp, "$1" + callbackName );
		} else if ( s.jsonp !== false ) {
			s.url += ( ajax_rquery.test( s.url ) ? "&" : "?" ) + s.jsonp + "=" + callbackName;
		}

		// Use data converter to retrieve json after script execution
		s.converters["script json"] = function() {
			if ( !responseContainer ) {
				jQuery.error( callbackName + " was not called" );
			}
			return responseContainer[ 0 ];
		};

		// force json dataType
		s.dataTypes[ 0 ] = "json";

		// Install callback
		overwritten = window[ callbackName ];
		window[ callbackName ] = function() {
			responseContainer = arguments;
		};

		// Clean-up function (fires after converters)
		jqXHR.always(function() {
			// Restore preexisting value
			window[ callbackName ] = overwritten;

			// Save back as free
			if ( s[ callbackName ] ) {
				// make sure that re-using the options doesn't screw things around
				s.jsonpCallback = originalSettings.jsonpCallback;

				// save the callback name for future use
				oldCallbacks.push( callbackName );
			}

			// Call if it was a function and we have a response
			if ( responseContainer && jQuery.isFunction( overwritten ) ) {
				overwritten( responseContainer[ 0 ] );
			}

			responseContainer = overwritten = undefined;
		});

		// Delegate to script
		return "script";
	}
});
var xhrCallbacks, xhrSupported,
	xhrId = 0,
	// #5280: Internet Explorer will keep connections alive if we don't abort on unload
	xhrOnUnloadAbort = window.ActiveXObject && function() {
		// Abort all pending requests
		var key;
		for ( key in xhrCallbacks ) {
			xhrCallbacks[ key ]( undefined, true );
		}
	};

// Functions to create xhrs
function createStandardXHR() {
	try {
		return new window.XMLHttpRequest();
	} catch( e ) {}
}

function createActiveXHR() {
	try {
		return new window.ActiveXObject("Microsoft.XMLHTTP");
	} catch( e ) {}
}

// Create the request object
// (This is still attached to ajaxSettings for backward compatibility)
jQuery.ajaxSettings.xhr = window.ActiveXObject ?
	/* Microsoft failed to properly
	 * implement the XMLHttpRequest in IE7 (can't request local files),
	 * so we use the ActiveXObject when it is available
	 * Additionally XMLHttpRequest can be disabled in IE7/IE8 so
	 * we need a fallback.
	 */
	function() {
		return !this.isLocal && createStandardXHR() || createActiveXHR();
	} :
	// For all other browsers, use the standard XMLHttpRequest object
	createStandardXHR;

// Determine support properties
xhrSupported = jQuery.ajaxSettings.xhr();
jQuery.support.cors = !!xhrSupported && ( "withCredentials" in xhrSupported );
xhrSupported = jQuery.support.ajax = !!xhrSupported;

// Create transport if the browser can provide an xhr
if ( xhrSupported ) {

	jQuery.ajaxTransport(function( s ) {
		// Cross domain only allowed if supported through XMLHttpRequest
		if ( !s.crossDomain || jQuery.support.cors ) {

			var callback;

			return {
				send: function( headers, complete ) {

					// Get a new xhr
					var handle, i,
						xhr = s.xhr();

					// Open the socket
					// Passing null username, generates a login popup on Opera (#2865)
					if ( s.username ) {
						xhr.open( s.type, s.url, s.async, s.username, s.password );
					} else {
						xhr.open( s.type, s.url, s.async );
					}

					// Apply custom fields if provided
					if ( s.xhrFields ) {
						for ( i in s.xhrFields ) {
							xhr[ i ] = s.xhrFields[ i ];
						}
					}

					// Override mime type if needed
					if ( s.mimeType && xhr.overrideMimeType ) {
						xhr.overrideMimeType( s.mimeType );
					}

					// X-Requested-With header
					// For cross-domain requests, seeing as conditions for a preflight are
					// akin to a jigsaw puzzle, we simply never set it to be sure.
					// (it can always be set on a per-request basis or even using ajaxSetup)
					// For same-domain requests, won't change header if already provided.
					if ( !s.crossDomain && !headers["X-Requested-With"] ) {
						headers["X-Requested-With"] = "XMLHttpRequest";
					}

					// Need an extra try/catch for cross domain requests in Firefox 3
					try {
						for ( i in headers ) {
							xhr.setRequestHeader( i, headers[ i ] );
						}
					} catch( err ) {}

					// Do send the request
					// This may raise an exception which is actually
					// handled in jQuery.ajax (so no try/catch here)
					xhr.send( ( s.hasContent && s.data ) || null );

					// Listener
					callback = function( _, isAbort ) {
						var status, responseHeaders, statusText, responses;

						// Firefox throws exceptions when accessing properties
						// of an xhr when a network error occurred
						// http://helpful.knobs-dials.com/index.php/Component_returned_failure_code:_0x80040111_(NS_ERROR_NOT_AVAILABLE)
						try {

							// Was never called and is aborted or complete
							if ( callback && ( isAbort || xhr.readyState === 4 ) ) {

								// Only called once
								callback = undefined;

								// Do not keep as active anymore
								if ( handle ) {
									xhr.onreadystatechange = jQuery.noop;
									if ( xhrOnUnloadAbort ) {
										delete xhrCallbacks[ handle ];
									}
								}

								// If it's an abort
								if ( isAbort ) {
									// Abort it manually if needed
									if ( xhr.readyState !== 4 ) {
										xhr.abort();
									}
								} else {
									responses = {};
									status = xhr.status;
									responseHeaders = xhr.getAllResponseHeaders();

									// When requesting binary data, IE6-9 will throw an exception
									// on any attempt to access responseText (#11426)
									if ( typeof xhr.responseText === "string" ) {
										responses.text = xhr.responseText;
									}

									// Firefox throws an exception when accessing
									// statusText for faulty cross-domain requests
									try {
										statusText = xhr.statusText;
									} catch( e ) {
										// We normalize with Webkit giving an empty statusText
										statusText = "";
									}

									// Filter status for non standard behaviors

									// If the request is local and we have data: assume a success
									// (success with no data won't get notified, that's the best we
									// can do given current implementations)
									if ( !status && s.isLocal && !s.crossDomain ) {
										status = responses.text ? 200 : 404;
									// IE - #1450: sometimes returns 1223 when it should be 204
									} else if ( status === 1223 ) {
										status = 204;
									}
								}
							}
						} catch( firefoxAccessException ) {
							if ( !isAbort ) {
								complete( -1, firefoxAccessException );
							}
						}

						// Call complete if needed
						if ( responses ) {
							complete( status, statusText, responses, responseHeaders );
						}
					};

					if ( !s.async ) {
						// if we're in sync mode we fire the callback
						callback();
					} else if ( xhr.readyState === 4 ) {
						// (IE6 & IE7) if it's in cache and has been
						// retrieved directly we need to fire the callback
						setTimeout( callback );
					} else {
						handle = ++xhrId;
						if ( xhrOnUnloadAbort ) {
							// Create the active xhrs callbacks list if needed
							// and attach the unload handler
							if ( !xhrCallbacks ) {
								xhrCallbacks = {};
								jQuery( window ).unload( xhrOnUnloadAbort );
							}
							// Add to list of active xhrs callbacks
							xhrCallbacks[ handle ] = callback;
						}
						xhr.onreadystatechange = callback;
					}
				},

				abort: function() {
					if ( callback ) {
						callback( undefined, true );
					}
				}
			};
		}
	});
}
var fxNow, timerId,
	rfxtypes = /^(?:toggle|show|hide)$/,
	rfxnum = new RegExp( "^(?:([+-])=|)(" + core_pnum + ")([a-z%]*)$", "i" ),
	rrun = /queueHooks$/,
	animationPrefilters = [ defaultPrefilter ],
	tweeners = {
		"*": [function( prop, value ) {
			var end, unit,
				tween = this.createTween( prop, value ),
				parts = rfxnum.exec( value ),
				target = tween.cur(),
				start = +target || 0,
				scale = 1,
				maxIterations = 20;

			if ( parts ) {
				end = +parts[2];
				unit = parts[3] || ( jQuery.cssNumber[ prop ] ? "" : "px" );

				// We need to compute starting value
				if ( unit !== "px" && start ) {
					// Iteratively approximate from a nonzero starting point
					// Prefer the current property, because this process will be trivial if it uses the same units
					// Fallback to end or a simple constant
					start = jQuery.css( tween.elem, prop, true ) || end || 1;

					do {
						// If previous iteration zeroed out, double until we get *something*
						// Use a string for doubling factor so we don't accidentally see scale as unchanged below
						scale = scale || ".5";

						// Adjust and apply
						start = start / scale;
						jQuery.style( tween.elem, prop, start + unit );

					// Update scale, tolerating zero or NaN from tween.cur()
					// And breaking the loop if scale is unchanged or perfect, or if we've just had enough
					} while ( scale !== (scale = tween.cur() / target) && scale !== 1 && --maxIterations );
				}

				tween.unit = unit;
				tween.start = start;
				// If a +=/-= token was provided, we're doing a relative animation
				tween.end = parts[1] ? start + ( parts[1] + 1 ) * end : end;
			}
			return tween;
		}]
	};

// Animations created synchronously will run synchronously
function createFxNow() {
	setTimeout(function() {
		fxNow = undefined;
	});
	return ( fxNow = jQuery.now() );
}

function createTweens( animation, props ) {
	jQuery.each( props, function( prop, value ) {
		var collection = ( tweeners[ prop ] || [] ).concat( tweeners[ "*" ] ),
			index = 0,
			length = collection.length;
		for ( ; index < length; index++ ) {
			if ( collection[ index ].call( animation, prop, value ) ) {

				// we're done with this property
				return;
			}
		}
	});
}

function Animation( elem, properties, options ) {
	var result,
		stopped,
		index = 0,
		length = animationPrefilters.length,
		deferred = jQuery.Deferred().always( function() {
			// don't match elem in the :animated selector
			delete tick.elem;
		}),
		tick = function() {
			if ( stopped ) {
				return false;
			}
			var currentTime = fxNow || createFxNow(),
				remaining = Math.max( 0, animation.startTime + animation.duration - currentTime ),
				// archaic crash bug won't allow us to use 1 - ( 0.5 || 0 ) (#12497)
				temp = remaining / animation.duration || 0,
				percent = 1 - temp,
				index = 0,
				length = animation.tweens.length;

			for ( ; index < length ; index++ ) {
				animation.tweens[ index ].run( percent );
			}

			deferred.notifyWith( elem, [ animation, percent, remaining ]);

			if ( percent < 1 && length ) {
				return remaining;
			} else {
				deferred.resolveWith( elem, [ animation ] );
				return false;
			}
		},
		animation = deferred.promise({
			elem: elem,
			props: jQuery.extend( {}, properties ),
			opts: jQuery.extend( true, { specialEasing: {} }, options ),
			originalProperties: properties,
			originalOptions: options,
			startTime: fxNow || createFxNow(),
			duration: options.duration,
			tweens: [],
			createTween: function( prop, end ) {
				var tween = jQuery.Tween( elem, animation.opts, prop, end,
						animation.opts.specialEasing[ prop ] || animation.opts.easing );
				animation.tweens.push( tween );
				return tween;
			},
			stop: function( gotoEnd ) {
				var index = 0,
					// if we are going to the end, we want to run all the tweens
					// otherwise we skip this part
					length = gotoEnd ? animation.tweens.length : 0;
				if ( stopped ) {
					return this;
				}
				stopped = true;
				for ( ; index < length ; index++ ) {
					animation.tweens[ index ].run( 1 );
				}

				// resolve when we played the last frame
				// otherwise, reject
				if ( gotoEnd ) {
					deferred.resolveWith( elem, [ animation, gotoEnd ] );
				} else {
					deferred.rejectWith( elem, [ animation, gotoEnd ] );
				}
				return this;
			}
		}),
		props = animation.props;

	propFilter( props, animation.opts.specialEasing );

	for ( ; index < length ; index++ ) {
		result = animationPrefilters[ index ].call( animation, elem, props, animation.opts );
		if ( result ) {
			return result;
		}
	}

	createTweens( animation, props );

	if ( jQuery.isFunction( animation.opts.start ) ) {
		animation.opts.start.call( elem, animation );
	}

	jQuery.fx.timer(
		jQuery.extend( tick, {
			elem: elem,
			anim: animation,
			queue: animation.opts.queue
		})
	);

	// attach callbacks from options
	return animation.progress( animation.opts.progress )
		.done( animation.opts.done, animation.opts.complete )
		.fail( animation.opts.fail )
		.always( animation.opts.always );
}

function propFilter( props, specialEasing ) {
	var value, name, index, easing, hooks;

	// camelCase, specialEasing and expand cssHook pass
	for ( index in props ) {
		name = jQuery.camelCase( index );
		easing = specialEasing[ name ];
		value = props[ index ];
		if ( jQuery.isArray( value ) ) {
			easing = value[ 1 ];
			value = props[ index ] = value[ 0 ];
		}

		if ( index !== name ) {
			props[ name ] = value;
			delete props[ index ];
		}

		hooks = jQuery.cssHooks[ name ];
		if ( hooks && "expand" in hooks ) {
			value = hooks.expand( value );
			delete props[ name ];

			// not quite $.extend, this wont overwrite keys already present.
			// also - reusing 'index' from above because we have the correct "name"
			for ( index in value ) {
				if ( !( index in props ) ) {
					props[ index ] = value[ index ];
					specialEasing[ index ] = easing;
				}
			}
		} else {
			specialEasing[ name ] = easing;
		}
	}
}

jQuery.Animation = jQuery.extend( Animation, {

	tweener: function( props, callback ) {
		if ( jQuery.isFunction( props ) ) {
			callback = props;
			props = [ "*" ];
		} else {
			props = props.split(" ");
		}

		var prop,
			index = 0,
			length = props.length;

		for ( ; index < length ; index++ ) {
			prop = props[ index ];
			tweeners[ prop ] = tweeners[ prop ] || [];
			tweeners[ prop ].unshift( callback );
		}
	},

	prefilter: function( callback, prepend ) {
		if ( prepend ) {
			animationPrefilters.unshift( callback );
		} else {
			animationPrefilters.push( callback );
		}
	}
});

function defaultPrefilter( elem, props, opts ) {
	/*jshint validthis:true */
	var prop, index, length,
		value, dataShow, toggle,
		tween, hooks, oldfire,
		anim = this,
		style = elem.style,
		orig = {},
		handled = [],
		hidden = elem.nodeType && isHidden( elem );

	// handle queue: false promises
	if ( !opts.queue ) {
		hooks = jQuery._queueHooks( elem, "fx" );
		if ( hooks.unqueued == null ) {
			hooks.unqueued = 0;
			oldfire = hooks.empty.fire;
			hooks.empty.fire = function() {
				if ( !hooks.unqueued ) {
					oldfire();
				}
			};
		}
		hooks.unqueued++;

		anim.always(function() {
			// doing this makes sure that the complete handler will be called
			// before this completes
			anim.always(function() {
				hooks.unqueued--;
				if ( !jQuery.queue( elem, "fx" ).length ) {
					hooks.empty.fire();
				}
			});
		});
	}

	// height/width overflow pass
	if ( elem.nodeType === 1 && ( "height" in props || "width" in props ) ) {
		// Make sure that nothing sneaks out
		// Record all 3 overflow attributes because IE does not
		// change the overflow attribute when overflowX and
		// overflowY are set to the same value
		opts.overflow = [ style.overflow, style.overflowX, style.overflowY ];

		// Set display property to inline-block for height/width
		// animations on inline elements that are having width/height animated
		if ( jQuery.css( elem, "display" ) === "inline" &&
				jQuery.css( elem, "float" ) === "none" ) {

			// inline-level elements accept inline-block;
			// block-level elements need to be inline with layout
			if ( !jQuery.support.inlineBlockNeedsLayout || css_defaultDisplay( elem.nodeName ) === "inline" ) {
				style.display = "inline-block";

			} else {
				style.zoom = 1;
			}
		}
	}

	if ( opts.overflow ) {
		style.overflow = "hidden";
		if ( !jQuery.support.shrinkWrapBlocks ) {
			anim.always(function() {
				style.overflow = opts.overflow[ 0 ];
				style.overflowX = opts.overflow[ 1 ];
				style.overflowY = opts.overflow[ 2 ];
			});
		}
	}


	// show/hide pass
	for ( index in props ) {
		value = props[ index ];
		if ( rfxtypes.exec( value ) ) {
			delete props[ index ];
			toggle = toggle || value === "toggle";
			if ( value === ( hidden ? "hide" : "show" ) ) {
				continue;
			}
			handled.push( index );
		}
	}

	length = handled.length;
	if ( length ) {
		dataShow = jQuery._data( elem, "fxshow" ) || jQuery._data( elem, "fxshow", {} );
		if ( "hidden" in dataShow ) {
			hidden = dataShow.hidden;
		}

		// store state if its toggle - enables .stop().toggle() to "reverse"
		if ( toggle ) {
			dataShow.hidden = !hidden;
		}
		if ( hidden ) {
			jQuery( elem ).show();
		} else {
			anim.done(function() {
				jQuery( elem ).hide();
			});
		}
		anim.done(function() {
			var prop;
			jQuery._removeData( elem, "fxshow" );
			for ( prop in orig ) {
				jQuery.style( elem, prop, orig[ prop ] );
			}
		});
		for ( index = 0 ; index < length ; index++ ) {
			prop = handled[ index ];
			tween = anim.createTween( prop, hidden ? dataShow[ prop ] : 0 );
			orig[ prop ] = dataShow[ prop ] || jQuery.style( elem, prop );

			if ( !( prop in dataShow ) ) {
				dataShow[ prop ] = tween.start;
				if ( hidden ) {
					tween.end = tween.start;
					tween.start = prop === "width" || prop === "height" ? 1 : 0;
				}
			}
		}
	}
}

function Tween( elem, options, prop, end, easing ) {
	return new Tween.prototype.init( elem, options, prop, end, easing );
}
jQuery.Tween = Tween;

Tween.prototype = {
	constructor: Tween,
	init: function( elem, options, prop, end, easing, unit ) {
		this.elem = elem;
		this.prop = prop;
		this.easing = easing || "swing";
		this.options = options;
		this.start = this.now = this.cur();
		this.end = end;
		this.unit = unit || ( jQuery.cssNumber[ prop ] ? "" : "px" );
	},
	cur: function() {
		var hooks = Tween.propHooks[ this.prop ];

		return hooks && hooks.get ?
			hooks.get( this ) :
			Tween.propHooks._default.get( this );
	},
	run: function( percent ) {
		var eased,
			hooks = Tween.propHooks[ this.prop ];

		if ( this.options.duration ) {
			this.pos = eased = jQuery.easing[ this.easing ](
				percent, this.options.duration * percent, 0, 1, this.options.duration
			);
		} else {
			this.pos = eased = percent;
		}
		this.now = ( this.end - this.start ) * eased + this.start;

		if ( this.options.step ) {
			this.options.step.call( this.elem, this.now, this );
		}

		if ( hooks && hooks.set ) {
			hooks.set( this );
		} else {
			Tween.propHooks._default.set( this );
		}
		return this;
	}
};

Tween.prototype.init.prototype = Tween.prototype;

Tween.propHooks = {
	_default: {
		get: function( tween ) {
			var result;

			if ( tween.elem[ tween.prop ] != null &&
				(!tween.elem.style || tween.elem.style[ tween.prop ] == null) ) {
				return tween.elem[ tween.prop ];
			}

			// passing an empty string as a 3rd parameter to .css will automatically
			// attempt a parseFloat and fallback to a string if the parse fails
			// so, simple values such as "10px" are parsed to Float.
			// complex values such as "rotate(1rad)" are returned as is.
			result = jQuery.css( tween.elem, tween.prop, "" );
			// Empty strings, null, undefined and "auto" are converted to 0.
			return !result || result === "auto" ? 0 : result;
		},
		set: function( tween ) {
			// use step hook for back compat - use cssHook if its there - use .style if its
			// available and use plain properties where available
			if ( jQuery.fx.step[ tween.prop ] ) {
				jQuery.fx.step[ tween.prop ]( tween );
			} else if ( tween.elem.style && ( tween.elem.style[ jQuery.cssProps[ tween.prop ] ] != null || jQuery.cssHooks[ tween.prop ] ) ) {
				jQuery.style( tween.elem, tween.prop, tween.now + tween.unit );
			} else {
				tween.elem[ tween.prop ] = tween.now;
			}
		}
	}
};

// Remove in 2.0 - this supports IE8's panic based approach
// to setting things on disconnected nodes

Tween.propHooks.scrollTop = Tween.propHooks.scrollLeft = {
	set: function( tween ) {
		if ( tween.elem.nodeType && tween.elem.parentNode ) {
			tween.elem[ tween.prop ] = tween.now;
		}
	}
};

jQuery.each([ "toggle", "show", "hide" ], function( i, name ) {
	var cssFn = jQuery.fn[ name ];
	jQuery.fn[ name ] = function( speed, easing, callback ) {
		return speed == null || typeof speed === "boolean" ?
			cssFn.apply( this, arguments ) :
			this.animate( genFx( name, true ), speed, easing, callback );
	};
});

jQuery.fn.extend({
	fadeTo: function( speed, to, easing, callback ) {

		// show any hidden elements after setting opacity to 0
		return this.filter( isHidden ).css( "opacity", 0 ).show()

			// animate to the value specified
			.end().animate({ opacity: to }, speed, easing, callback );
	},
	animate: function( prop, speed, easing, callback ) {
		var empty = jQuery.isEmptyObject( prop ),
			optall = jQuery.speed( speed, easing, callback ),
			doAnimation = function() {
				// Operate on a copy of prop so per-property easing won't be lost
				var anim = Animation( this, jQuery.extend( {}, prop ), optall );
				doAnimation.finish = function() {
					anim.stop( true );
				};
				// Empty animations, or finishing resolves immediately
				if ( empty || jQuery._data( this, "finish" ) ) {
					anim.stop( true );
				}
			};
			doAnimation.finish = doAnimation;

		return empty || optall.queue === false ?
			this.each( doAnimation ) :
			this.queue( optall.queue, doAnimation );
	},
	stop: function( type, clearQueue, gotoEnd ) {
		var stopQueue = function( hooks ) {
			var stop = hooks.stop;
			delete hooks.stop;
			stop( gotoEnd );
		};

		if ( typeof type !== "string" ) {
			gotoEnd = clearQueue;
			clearQueue = type;
			type = undefined;
		}
		if ( clearQueue && type !== false ) {
			this.queue( type || "fx", [] );
		}

		return this.each(function() {
			var dequeue = true,
				index = type != null && type + "queueHooks",
				timers = jQuery.timers,
				data = jQuery._data( this );

			if ( index ) {
				if ( data[ index ] && data[ index ].stop ) {
					stopQueue( data[ index ] );
				}
			} else {
				for ( index in data ) {
					if ( data[ index ] && data[ index ].stop && rrun.test( index ) ) {
						stopQueue( data[ index ] );
					}
				}
			}

			for ( index = timers.length; index--; ) {
				if ( timers[ index ].elem === this && (type == null || timers[ index ].queue === type) ) {
					timers[ index ].anim.stop( gotoEnd );
					dequeue = false;
					timers.splice( index, 1 );
				}
			}

			// start the next in the queue if the last step wasn't forced
			// timers currently will call their complete callbacks, which will dequeue
			// but only if they were gotoEnd
			if ( dequeue || !gotoEnd ) {
				jQuery.dequeue( this, type );
			}
		});
	},
	finish: function( type ) {
		if ( type !== false ) {
			type = type || "fx";
		}
		return this.each(function() {
			var index,
				data = jQuery._data( this ),
				queue = data[ type + "queue" ],
				hooks = data[ type + "queueHooks" ],
				timers = jQuery.timers,
				length = queue ? queue.length : 0;

			// enable finishing flag on private data
			data.finish = true;

			// empty the queue first
			jQuery.queue( this, type, [] );

			if ( hooks && hooks.cur && hooks.cur.finish ) {
				hooks.cur.finish.call( this );
			}

			// look for any active animations, and finish them
			for ( index = timers.length; index--; ) {
				if ( timers[ index ].elem === this && timers[ index ].queue === type ) {
					timers[ index ].anim.stop( true );
					timers.splice( index, 1 );
				}
			}

			// look for any animations in the old queue and finish them
			for ( index = 0; index < length; index++ ) {
				if ( queue[ index ] && queue[ index ].finish ) {
					queue[ index ].finish.call( this );
				}
			}

			// turn off finishing flag
			delete data.finish;
		});
	}
});

// Generate parameters to create a standard animation
function genFx( type, includeWidth ) {
	var which,
		attrs = { height: type },
		i = 0;

	// if we include width, step value is 1 to do all cssExpand values,
	// if we don't include width, step value is 2 to skip over Left and Right
	includeWidth = includeWidth? 1 : 0;
	for( ; i < 4 ; i += 2 - includeWidth ) {
		which = cssExpand[ i ];
		attrs[ "margin" + which ] = attrs[ "padding" + which ] = type;
	}

	if ( includeWidth ) {
		attrs.opacity = attrs.width = type;
	}

	return attrs;
}

// Generate shortcuts for custom animations
jQuery.each({
	slideDown: genFx("show"),
	slideUp: genFx("hide"),
	slideToggle: genFx("toggle"),
	fadeIn: { opacity: "show" },
	fadeOut: { opacity: "hide" },
	fadeToggle: { opacity: "toggle" }
}, function( name, props ) {
	jQuery.fn[ name ] = function( speed, easing, callback ) {
		return this.animate( props, speed, easing, callback );
	};
});

jQuery.speed = function( speed, easing, fn ) {
	var opt = speed && typeof speed === "object" ? jQuery.extend( {}, speed ) : {
		complete: fn || !fn && easing ||
			jQuery.isFunction( speed ) && speed,
		duration: speed,
		easing: fn && easing || easing && !jQuery.isFunction( easing ) && easing
	};

	opt.duration = jQuery.fx.off ? 0 : typeof opt.duration === "number" ? opt.duration :
		opt.duration in jQuery.fx.speeds ? jQuery.fx.speeds[ opt.duration ] : jQuery.fx.speeds._default;

	// normalize opt.queue - true/undefined/null -> "fx"
	if ( opt.queue == null || opt.queue === true ) {
		opt.queue = "fx";
	}

	// Queueing
	opt.old = opt.complete;

	opt.complete = function() {
		if ( jQuery.isFunction( opt.old ) ) {
			opt.old.call( this );
		}

		if ( opt.queue ) {
			jQuery.dequeue( this, opt.queue );
		}
	};

	return opt;
};

jQuery.easing = {
	linear: function( p ) {
		return p;
	},
	swing: function( p ) {
		return 0.5 - Math.cos( p*Math.PI ) / 2;
	}
};

jQuery.timers = [];
jQuery.fx = Tween.prototype.init;
jQuery.fx.tick = function() {
	var timer,
		timers = jQuery.timers,
		i = 0;

	fxNow = jQuery.now();

	for ( ; i < timers.length; i++ ) {
		timer = timers[ i ];
		// Checks the timer has not already been removed
		if ( !timer() && timers[ i ] === timer ) {
			timers.splice( i--, 1 );
		}
	}

	if ( !timers.length ) {
		jQuery.fx.stop();
	}
	fxNow = undefined;
};

jQuery.fx.timer = function( timer ) {
	if ( timer() && jQuery.timers.push( timer ) ) {
		jQuery.fx.start();
	}
};

jQuery.fx.interval = 13;

jQuery.fx.start = function() {
	if ( !timerId ) {
		timerId = setInterval( jQuery.fx.tick, jQuery.fx.interval );
	}
};

jQuery.fx.stop = function() {
	clearInterval( timerId );
	timerId = null;
};

jQuery.fx.speeds = {
	slow: 600,
	fast: 200,
	// Default speed
	_default: 400
};

// Back Compat <1.8 extension point
jQuery.fx.step = {};

if ( jQuery.expr && jQuery.expr.filters ) {
	jQuery.expr.filters.animated = function( elem ) {
		return jQuery.grep(jQuery.timers, function( fn ) {
			return elem === fn.elem;
		}).length;
	};
}
jQuery.fn.offset = function( options ) {
	if ( arguments.length ) {
		return options === undefined ?
			this :
			this.each(function( i ) {
				jQuery.offset.setOffset( this, options, i );
			});
	}

	var docElem, win,
		box = { top: 0, left: 0 },
		elem = this[ 0 ],
		doc = elem && elem.ownerDocument;

	if ( !doc ) {
		return;
	}

	docElem = doc.documentElement;

	// Make sure it's not a disconnected DOM node
	if ( !jQuery.contains( docElem, elem ) ) {
		return box;
	}

	// If we don't have gBCR, just use 0,0 rather than error
	// BlackBerry 5, iOS 3 (original iPhone)
	if ( typeof elem.getBoundingClientRect !== core_strundefined ) {
		box = elem.getBoundingClientRect();
	}
	win = getWindow( doc );
	return {
		top: box.top  + ( win.pageYOffset || docElem.scrollTop )  - ( docElem.clientTop  || 0 ),
		left: box.left + ( win.pageXOffset || docElem.scrollLeft ) - ( docElem.clientLeft || 0 )
	};
};

jQuery.offset = {

	setOffset: function( elem, options, i ) {
		var position = jQuery.css( elem, "position" );

		// set position first, in-case top/left are set even on static elem
		if ( position === "static" ) {
			elem.style.position = "relative";
		}

		var curElem = jQuery( elem ),
			curOffset = curElem.offset(),
			curCSSTop = jQuery.css( elem, "top" ),
			curCSSLeft = jQuery.css( elem, "left" ),
			calculatePosition = ( position === "absolute" || position === "fixed" ) && jQuery.inArray("auto", [curCSSTop, curCSSLeft]) > -1,
			props = {}, curPosition = {}, curTop, curLeft;

		// need to be able to calculate position if either top or left is auto and position is either absolute or fixed
		if ( calculatePosition ) {
			curPosition = curElem.position();
			curTop = curPosition.top;
			curLeft = curPosition.left;
		} else {
			curTop = parseFloat( curCSSTop ) || 0;
			curLeft = parseFloat( curCSSLeft ) || 0;
		}

		if ( jQuery.isFunction( options ) ) {
			options = options.call( elem, i, curOffset );
		}

		if ( options.top != null ) {
			props.top = ( options.top - curOffset.top ) + curTop;
		}
		if ( options.left != null ) {
			props.left = ( options.left - curOffset.left ) + curLeft;
		}

		if ( "using" in options ) {
			options.using.call( elem, props );
		} else {
			curElem.css( props );
		}
	}
};


jQuery.fn.extend({

	position: function() {
		if ( !this[ 0 ] ) {
			return;
		}

		var offsetParent, offset,
			parentOffset = { top: 0, left: 0 },
			elem = this[ 0 ];

		// fixed elements are offset from window (parentOffset = {top:0, left: 0}, because it is it's only offset parent
		if ( jQuery.css( elem, "position" ) === "fixed" ) {
			// we assume that getBoundingClientRect is available when computed position is fixed
			offset = elem.getBoundingClientRect();
		} else {
			// Get *real* offsetParent
			offsetParent = this.offsetParent();

			// Get correct offsets
			offset = this.offset();
			if ( !jQuery.nodeName( offsetParent[ 0 ], "html" ) ) {
				parentOffset = offsetParent.offset();
			}

			// Add offsetParent borders
			parentOffset.top  += jQuery.css( offsetParent[ 0 ], "borderTopWidth", true );
			parentOffset.left += jQuery.css( offsetParent[ 0 ], "borderLeftWidth", true );
		}

		// Subtract parent offsets and element margins
		// note: when an element has margin: auto the offsetLeft and marginLeft
		// are the same in Safari causing offset.left to incorrectly be 0
		return {
			top:  offset.top  - parentOffset.top - jQuery.css( elem, "marginTop", true ),
			left: offset.left - parentOffset.left - jQuery.css( elem, "marginLeft", true)
		};
	},

	offsetParent: function() {
		return this.map(function() {
			var offsetParent = this.offsetParent || document.documentElement;
			while ( offsetParent && ( !jQuery.nodeName( offsetParent, "html" ) && jQuery.css( offsetParent, "position") === "static" ) ) {
				offsetParent = offsetParent.offsetParent;
			}
			return offsetParent || document.documentElement;
		});
	}
});


// Create scrollLeft and scrollTop methods
jQuery.each( {scrollLeft: "pageXOffset", scrollTop: "pageYOffset"}, function( method, prop ) {
	var top = /Y/.test( prop );

	jQuery.fn[ method ] = function( val ) {
		return jQuery.access( this, function( elem, method, val ) {
			var win = getWindow( elem );

			if ( val === undefined ) {
				return win ? (prop in win) ? win[ prop ] :
					win.document.documentElement[ method ] :
					elem[ method ];
			}

			if ( win ) {
				win.scrollTo(
					!top ? val : jQuery( win ).scrollLeft(),
					top ? val : jQuery( win ).scrollTop()
				);

			} else {
				elem[ method ] = val;
			}
		}, method, val, arguments.length, null );
	};
});

function getWindow( elem ) {
	return jQuery.isWindow( elem ) ?
		elem :
		elem.nodeType === 9 ?
			elem.defaultView || elem.parentWindow :
			false;
}
// Create innerHeight, innerWidth, height, width, outerHeight and outerWidth methods
jQuery.each( { Height: "height", Width: "width" }, function( name, type ) {
	jQuery.each( { padding: "inner" + name, content: type, "": "outer" + name }, function( defaultExtra, funcName ) {
		// margin is only for outerHeight, outerWidth
		jQuery.fn[ funcName ] = function( margin, value ) {
			var chainable = arguments.length && ( defaultExtra || typeof margin !== "boolean" ),
				extra = defaultExtra || ( margin === true || value === true ? "margin" : "border" );

			return jQuery.access( this, function( elem, type, value ) {
				var doc;

				if ( jQuery.isWindow( elem ) ) {
					// As of 5/8/2012 this will yield incorrect results for Mobile Safari, but there
					// isn't a whole lot we can do. See pull request at this URL for discussion:
					// https://github.com/jquery/jquery/pull/764
					return elem.document.documentElement[ "client" + name ];
				}

				// Get document width or height
				if ( elem.nodeType === 9 ) {
					doc = elem.documentElement;

					// Either scroll[Width/Height] or offset[Width/Height] or client[Width/Height], whichever is greatest
					// unfortunately, this causes bug #3838 in IE6/8 only, but there is currently no good, small way to fix it.
					return Math.max(
						elem.body[ "scroll" + name ], doc[ "scroll" + name ],
						elem.body[ "offset" + name ], doc[ "offset" + name ],
						doc[ "client" + name ]
					);
				}

				return value === undefined ?
					// Get width or height on the element, requesting but not forcing parseFloat
					jQuery.css( elem, type, extra ) :

					// Set width or height on the element
					jQuery.style( elem, type, value, extra );
			}, type, chainable ? margin : undefined, chainable, null );
		};
	});
});
// Limit scope pollution from any deprecated API
// (function() {

// })();
// Expose jQuery to the global object
window.jQuery = window.$ = jQuery;

// Expose jQuery as an AMD module, but only for AMD loaders that
// understand the issues with loading multiple versions of jQuery
// in a page that all might call define(). The loader will indicate
// they have special allowances for multiple jQuery versions by
// specifying define.amd.jQuery = true. Register as a named module,
// since jQuery can be concatenated with other files that may use define,
// but not use a proper concatenation script that understands anonymous
// AMD modules. A named AMD is safest and most robust way to register.
// Lowercase jquery is used because AMD module names are derived from
// file names, and jQuery is normally delivered in a lowercase file name.
// Do this after creating the global so that if an AMD module wants to call
// noConflict to hide this version of jQuery, it will work.
if ( typeof define === "function" && define.amd && define.amd.jQuery ) {
	define( "jquery", [], function () { return jQuery; } );
}

})( window );

/*!
 * jQuery Migrate - v1.1.1 - 2013-02-16
 * https://github.com/jquery/jquery-migrate
 * Copyright 2005, 2013 jQuery Foundation, Inc. and other contributors; Licensed MIT
 */
(function( jQuery, window, undefined ) {
// See http://bugs.jquery.com/ticket/13335
// "use strict";


var warnedAbout = {};

// List of warnings already given; public read only
jQuery.migrateWarnings = [];

// Set to true to prevent console output; migrateWarnings still maintained
// jQuery.migrateMute = false;

// Show a message on the console so devs know we're active
if ( !jQuery.migrateMute && window.console && console.log ) {
	console.log("JQMIGRATE: Logging is active");
}

// Set to false to disable traces that appear with warnings
if ( jQuery.migrateTrace === undefined ) {
	jQuery.migrateTrace = true;
}

// Forget any warnings we've already given; public
jQuery.migrateReset = function() {
	warnedAbout = {};
	jQuery.migrateWarnings.length = 0;
};

function migrateWarn( msg) {
	if ( !warnedAbout[ msg ] ) {
		warnedAbout[ msg ] = true;
		jQuery.migrateWarnings.push( msg );
		if ( window.console && console.warn && !jQuery.migrateMute ) {
			console.warn( "JQMIGRATE: " + msg );
			if ( jQuery.migrateTrace && console.trace ) {
				console.trace();
			}
		}
	}
}

function migrateWarnProp( obj, prop, value, msg ) {
	if ( Object.defineProperty ) {
		// On ES5 browsers (non-oldIE), warn if the code tries to get prop;
		// allow property to be overwritten in case some other plugin wants it
		try {
			Object.defineProperty( obj, prop, {
				configurable: true,
				enumerable: true,
				get: function() {
					migrateWarn( msg );
					return value;
				},
				set: function( newValue ) {
					migrateWarn( msg );
					value = newValue;
				}
			});
			return;
		} catch( err ) {
			// IE8 is a dope about Object.defineProperty, can't warn there
		}
	}

	// Non-ES5 (or broken) browser; just set the property
	jQuery._definePropertyBroken = true;
	obj[ prop ] = value;
}

if ( document.compatMode === "BackCompat" ) {
	// jQuery has never supported or tested Quirks Mode
	migrateWarn( "jQuery is not compatible with Quirks Mode" );
}


var attrFn = jQuery( "<input/>", { size: 1 } ).attr("size") && jQuery.attrFn,
	oldAttr = jQuery.attr,
	valueAttrGet = jQuery.attrHooks.value && jQuery.attrHooks.value.get ||
		function() { return null; },
	valueAttrSet = jQuery.attrHooks.value && jQuery.attrHooks.value.set ||
		function() { return undefined; },
	rnoType = /^(?:input|button)$/i,
	rnoAttrNodeType = /^[238]$/,
	rboolean = /^(?:autofocus|autoplay|async|checked|controls|defer|disabled|hidden|loop|multiple|open|readonly|required|scoped|selected)$/i,
	ruseDefault = /^(?:checked|selected)$/i;

// jQuery.attrFn
migrateWarnProp( jQuery, "attrFn", attrFn || {}, "jQuery.attrFn is deprecated" );

jQuery.attr = function( elem, name, value, pass ) {
	var lowerName = name.toLowerCase(),
		nType = elem && elem.nodeType;

	if ( pass ) {
		// Since pass is used internally, we only warn for new jQuery
		// versions where there isn't a pass arg in the formal params
		if ( oldAttr.length < 4 ) {
			migrateWarn("jQuery.fn.attr( props, pass ) is deprecated");
		}
		if ( elem && !rnoAttrNodeType.test( nType ) &&
			(attrFn ? name in attrFn : jQuery.isFunction(jQuery.fn[name])) ) {
			return jQuery( elem )[ name ]( value );
		}
	}

	// Warn if user tries to set `type`, since it breaks on IE 6/7/8; by checking
	// for disconnected elements we don't warn on $( "<button>", { type: "button" } ).
	if ( name === "type" && value !== undefined && rnoType.test( elem.nodeName ) && elem.parentNode ) {
		migrateWarn("Can't change the 'type' of an input or button in IE 6/7/8");
	}

	// Restore boolHook for boolean property/attribute synchronization
	if ( !jQuery.attrHooks[ lowerName ] && rboolean.test( lowerName ) ) {
		jQuery.attrHooks[ lowerName ] = {
			get: function( elem, name ) {
				// Align boolean attributes with corresponding properties
				// Fall back to attribute presence where some booleans are not supported
				var attrNode,
					property = jQuery.prop( elem, name );
				return property === true || typeof property !== "boolean" &&
					( attrNode = elem.getAttributeNode(name) ) && attrNode.nodeValue !== false ?

					name.toLowerCase() :
					undefined;
			},
			set: function( elem, value, name ) {
				var propName;
				if ( value === false ) {
					// Remove boolean attributes when set to false
					jQuery.removeAttr( elem, name );
				} else {
					// value is true since we know at this point it's type boolean and not false
					// Set boolean attributes to the same name and set the DOM property
					propName = jQuery.propFix[ name ] || name;
					if ( propName in elem ) {
						// Only set the IDL specifically if it already exists on the element
						elem[ propName ] = true;
					}

					elem.setAttribute( name, name.toLowerCase() );
				}
				return name;
			}
		};

		// Warn only for attributes that can remain distinct from their properties post-1.9
		if ( ruseDefault.test( lowerName ) ) {
			migrateWarn( "jQuery.fn.attr('" + lowerName + "') may use property instead of attribute" );
		}
	}

	return oldAttr.call( jQuery, elem, name, value );
};

// attrHooks: value
jQuery.attrHooks.value = {
	get: function( elem, name ) {
		var nodeName = ( elem.nodeName || "" ).toLowerCase();
		if ( nodeName === "button" ) {
			return valueAttrGet.apply( this, arguments );
		}
		if ( nodeName !== "input" && nodeName !== "option" ) {
			migrateWarn("jQuery.fn.attr('value') no longer gets properties");
		}
		return name in elem ?
			elem.value :
			null;
	},
	set: function( elem, value ) {
		var nodeName = ( elem.nodeName || "" ).toLowerCase();
		if ( nodeName === "button" ) {
			return valueAttrSet.apply( this, arguments );
		}
		if ( nodeName !== "input" && nodeName !== "option" ) {
			migrateWarn("jQuery.fn.attr('value', val) no longer sets properties");
		}
		// Does not return so that setAttribute is also used
		elem.value = value;
	}
};


var matched, browser,
	oldInit = jQuery.fn.init,
	oldParseJSON = jQuery.parseJSON,
	// Note this does NOT include the #9521 XSS fix from 1.7!
	rquickExpr = /^(?:[^<]*(<[\w\W]+>)[^>]*|#([\w\-]*))$/;

// $(html) "looks like html" rule change
jQuery.fn.init = function( selector, context, rootjQuery ) {
	var match;

	if ( selector && typeof selector === "string" && !jQuery.isPlainObject( context ) &&
			(match = rquickExpr.exec( selector )) && match[1] ) {
		// This is an HTML string according to the "old" rules; is it still?
		if ( selector.charAt( 0 ) !== "<" ) {
			migrateWarn("$(html) HTML strings must start with '<' character");
		}
		// Now process using loose rules; let pre-1.8 play too
		if ( context && context.context ) {
			// jQuery object as context; parseHTML expects a DOM object
			context = context.context;
		}
		if ( jQuery.parseHTML ) {
			return oldInit.call( this, jQuery.parseHTML( jQuery.trim(selector), context, true ),
					context, rootjQuery );
		}
	}
	return oldInit.apply( this, arguments );
};
jQuery.fn.init.prototype = jQuery.fn;

// Let $.parseJSON(falsy_value) return null
jQuery.parseJSON = function( json ) {
	if ( !json && json !== null ) {
		migrateWarn("jQuery.parseJSON requires a valid JSON string");
		return null;
	}
	return oldParseJSON.apply( this, arguments );
};

jQuery.uaMatch = function( ua ) {
	ua = ua.toLowerCase();

	var match = /(chrome)[ \/]([\w.]+)/.exec( ua ) ||
		/(webkit)[ \/]([\w.]+)/.exec( ua ) ||
		/(opera)(?:.*version|)[ \/]([\w.]+)/.exec( ua ) ||
		/(msie) ([\w.]+)/.exec( ua ) ||
		ua.indexOf("compatible") < 0 && /(mozilla)(?:.*? rv:([\w.]+)|)/.exec( ua ) ||
		[];

	return {
		browser: match[ 1 ] || "",
		version: match[ 2 ] || "0"
	};
};

// Don't clobber any existing jQuery.browser in case it's different
if ( !jQuery.browser ) {
	matched = jQuery.uaMatch( navigator.userAgent );
	browser = {};

	if ( matched.browser ) {
		browser[ matched.browser ] = true;
		browser.version = matched.version;
	}

	// Chrome is Webkit, but Webkit is also Safari.
	if ( browser.chrome ) {
		browser.webkit = true;
	} else if ( browser.webkit ) {
		browser.safari = true;
	}

	jQuery.browser = browser;
}

// Warn if the code tries to get jQuery.browser
migrateWarnProp( jQuery, "browser", jQuery.browser, "jQuery.browser is deprecated" );

jQuery.sub = function() {
	function jQuerySub( selector, context ) {
		return new jQuerySub.fn.init( selector, context );
	}
	jQuery.extend( true, jQuerySub, this );
	jQuerySub.superclass = this;
	jQuerySub.fn = jQuerySub.prototype = this();
	jQuerySub.fn.constructor = jQuerySub;
	jQuerySub.sub = this.sub;
	jQuerySub.fn.init = function init( selector, context ) {
		if ( context && context instanceof jQuery && !(context instanceof jQuerySub) ) {
			context = jQuerySub( context );
		}

		return jQuery.fn.init.call( this, selector, context, rootjQuerySub );
	};
	jQuerySub.fn.init.prototype = jQuerySub.fn;
	var rootjQuerySub = jQuerySub(document);
	migrateWarn( "jQuery.sub() is deprecated" );
	return jQuerySub;
};


// Ensure that $.ajax gets the new parseJSON defined in core.js
jQuery.ajaxSetup({
	converters: {
		"text json": jQuery.parseJSON
	}
});


var oldFnData = jQuery.fn.data;

jQuery.fn.data = function( name ) {
	var ret, evt,
		elem = this[0];

	// Handles 1.7 which has this behavior and 1.8 which doesn't
	if ( elem && name === "events" && arguments.length === 1 ) {
		ret = jQuery.data( elem, name );
		evt = jQuery._data( elem, name );
		if ( ( ret === undefined || ret === evt ) && evt !== undefined ) {
			migrateWarn("Use of jQuery.fn.data('events') is deprecated");
			return evt;
		}
	}
	return oldFnData.apply( this, arguments );
};


var rscriptType = /\/(java|ecma)script/i,
	oldSelf = jQuery.fn.andSelf || jQuery.fn.addBack;

jQuery.fn.andSelf = function() {
	migrateWarn("jQuery.fn.andSelf() replaced by jQuery.fn.addBack()");
	return oldSelf.apply( this, arguments );
};

// Since jQuery.clean is used internally on older versions, we only shim if it's missing
if ( !jQuery.clean ) {
	jQuery.clean = function( elems, context, fragment, scripts ) {
		// Set context per 1.8 logic
		context = context || document;
		context = !context.nodeType && context[0] || context;
		context = context.ownerDocument || context;

		migrateWarn("jQuery.clean() is deprecated");

		var i, elem, handleScript, jsTags,
			ret = [];

		jQuery.merge( ret, jQuery.buildFragment( elems, context ).childNodes );

		// Complex logic lifted directly from jQuery 1.8
		if ( fragment ) {
			// Special handling of each script element
			handleScript = function( elem ) {
				// Check if we consider it executable
				if ( !elem.type || rscriptType.test( elem.type ) ) {
					// Detach the script and store it in the scripts array (if provided) or the fragment
					// Return truthy to indicate that it has been handled
					return scripts ?
						scripts.push( elem.parentNode ? elem.parentNode.removeChild( elem ) : elem ) :
						fragment.appendChild( elem );
				}
			};

			for ( i = 0; (elem = ret[i]) != null; i++ ) {
				// Check if we're done after handling an executable script
				if ( !( jQuery.nodeName( elem, "script" ) && handleScript( elem ) ) ) {
					// Append to fragment and handle embedded scripts
					fragment.appendChild( elem );
					if ( typeof elem.getElementsByTagName !== "undefined" ) {
						// handleScript alters the DOM, so use jQuery.merge to ensure snapshot iteration
						jsTags = jQuery.grep( jQuery.merge( [], elem.getElementsByTagName("script") ), handleScript );

						// Splice the scripts into ret after their former ancestor and advance our index beyond them
						ret.splice.apply( ret, [i + 1, 0].concat( jsTags ) );
						i += jsTags.length;
					}
				}
			}
		}

		return ret;
	};
}

var eventAdd = jQuery.event.add,
	eventRemove = jQuery.event.remove,
	eventTrigger = jQuery.event.trigger,
	oldToggle = jQuery.fn.toggle,
	oldLive = jQuery.fn.live,
	oldDie = jQuery.fn.die,
	ajaxEvents = "ajaxStart|ajaxStop|ajaxSend|ajaxComplete|ajaxError|ajaxSuccess",
	rajaxEvent = new RegExp( "\\b(?:" + ajaxEvents + ")\\b" ),
	rhoverHack = /(?:^|\s)hover(\.\S+|)\b/,
	hoverHack = function( events ) {
		if ( typeof( events ) !== "string" || jQuery.event.special.hover ) {
			return events;
		}
		if ( rhoverHack.test( events ) ) {
			migrateWarn("'hover' pseudo-event is deprecated, use 'mouseenter mouseleave'");
		}
		return events && events.replace( rhoverHack, "mouseenter$1 mouseleave$1" );
	};

// Event props removed in 1.9, put them back if needed; no practical way to warn them
if ( jQuery.event.props && jQuery.event.props[ 0 ] !== "attrChange" ) {
	jQuery.event.props.unshift( "attrChange", "attrName", "relatedNode", "srcElement" );
}

// Undocumented jQuery.event.handle was "deprecated" in jQuery 1.7
if ( jQuery.event.dispatch ) {
	migrateWarnProp( jQuery.event, "handle", jQuery.event.dispatch, "jQuery.event.handle is undocumented and deprecated" );
}

// Support for 'hover' pseudo-event and ajax event warnings
jQuery.event.add = function( elem, types, handler, data, selector ){
	if ( elem !== document && rajaxEvent.test( types ) ) {
		migrateWarn( "AJAX events should be attached to document: " + types );
	}
	eventAdd.call( this, elem, hoverHack( types || "" ), handler, data, selector );
};
jQuery.event.remove = function( elem, types, handler, selector, mappedTypes ){
	eventRemove.call( this, elem, hoverHack( types ) || "", handler, selector, mappedTypes );
};

jQuery.fn.error = function() {
	var args = Array.prototype.slice.call( arguments, 0);
	migrateWarn("jQuery.fn.error() is deprecated");
	args.splice( 0, 0, "error" );
	if ( arguments.length ) {
		return this.bind.apply( this, args );
	}
	// error event should not bubble to window, although it does pre-1.7
	this.triggerHandler.apply( this, args );
	return this;
};

jQuery.fn.toggle = function( fn, fn2 ) {

	// Don't mess with animation or css toggles
	if ( !jQuery.isFunction( fn ) || !jQuery.isFunction( fn2 ) ) {
		return oldToggle.apply( this, arguments );
	}
	migrateWarn("jQuery.fn.toggle(handler, handler...) is deprecated");

	// Save reference to arguments for access in closure
	var args = arguments,
		guid = fn.guid || jQuery.guid++,
		i = 0,
		toggler = function( event ) {
			// Figure out which function to execute
			var lastToggle = ( jQuery._data( this, "lastToggle" + fn.guid ) || 0 ) % i;
			jQuery._data( this, "lastToggle" + fn.guid, lastToggle + 1 );

			// Make sure that clicks stop
			event.preventDefault();

			// and execute the function
			return args[ lastToggle ].apply( this, arguments ) || false;
		};

	// link all the functions, so any of them can unbind this click handler
	toggler.guid = guid;
	while ( i < args.length ) {
		args[ i++ ].guid = guid;
	}

	return this.click( toggler );
};

jQuery.fn.live = function( types, data, fn ) {
	migrateWarn("jQuery.fn.live() is deprecated");
	if ( oldLive ) {
		return oldLive.apply( this, arguments );
	}
	jQuery( this.context ).on( types, this.selector, data, fn );
	return this;
};

jQuery.fn.die = function( types, fn ) {
	migrateWarn("jQuery.fn.die() is deprecated");
	if ( oldDie ) {
		return oldDie.apply( this, arguments );
	}
	jQuery( this.context ).off( types, this.selector || "**", fn );
	return this;
};

// Turn global events into document-triggered events
jQuery.event.trigger = function( event, data, elem, onlyHandlers  ){
	if ( !elem && !rajaxEvent.test( event ) ) {
		migrateWarn( "Global events are undocumented and deprecated" );
	}
	return eventTrigger.call( this,  event, data, elem || document, onlyHandlers  );
};
jQuery.each( ajaxEvents.split("|"),
	function( _, name ) {
		jQuery.event.special[ name ] = {
			setup: function() {
				var elem = this;

				// The document needs no shimming; must be !== for oldIE
				if ( elem !== document ) {
					jQuery.event.add( document, name + "." + jQuery.guid, function() {
						jQuery.event.trigger( name, null, elem, true );
					});
					jQuery._data( this, name, jQuery.guid++ );
				}
				return false;
			},
			teardown: function() {
				if ( this !== document ) {
					jQuery.event.remove( document, name + "." + jQuery._data( this, name ) );
				}
				return false;
			}
		};
	}
);


})( jQuery, window );

/*
 * @author			Evan Vosberg
 * @copyright		© 2012 by Evan Vosberg
 * @info			http://github.com/evanvosberg
 *
 * @license			Licensed under the MIT (http://www.opensource.org/licenses/mit-license.php) license.
 *
 * @module			jquery-sdk
 */

/*global jQuery*/

(function ($, undefined) {

	//
	// Helper
	//

	var
		// Convert jQuery SDK plugin name to requirejs module id
		pluginToModule = function (pluginName) {
			return (pluginName + "")
			// Convert dots into slashes (directory paths)
			.replace(/\./g, "/")
			// Convert jQuery to lower case
			.replace(/^jQuery/, "jquery")
			// Remove boolean true / false statements
			.replace(/^(true|false)$/, "")
			// Move region of dictionaries to the end
			.replace(/^((?:[a-z]{2})(?:(?:(?:\-[A-Z][a-z]{1,3})?\-[A-Z]{2})?)):(.*?)$/, "$2.$1");
		},

		// Convert requirejs module id to jQuery SDK plugin name
		moduleToPlugin = function (moduleName) {
			return (moduleName + "")
				.replace(/^jquery/, "jQuery")
				.replace(/\//g, ".");
		};



	//
	// Backward compatibility API
	//

	var
		// Save original method
		ready = $.ready,

		// Save original method
		readyPromise = $.ready.promise,

		// Config from script
		scriptConfig = window.jQueryConfig && !window.jQueryConfig.nodeName ? window.jQueryConfig : undefined,

		// Config from meta tag
		metaConfig = $("meta[name=jQueryConfig]")
			.attr("content"),

		// Extend jQuery.config
		config = (function () {
			/*jshint evil:true*/
			return $.extend(true, {}, scriptConfig, (metaConfig ? eval("(" + metaConfig + ")") : undefined));
		}()),

		// Type of dependencies ready data
		typeExp = /^(string|object|array)$/,

		// Type of plugin dependencies
		pluginExp = /(string|array)/,

		dependMap = {
			"plugin": "",
			"script": "$pub!",
			"dict": "$dict!",
			"DOM": "$ready!",
			"i18n": "$i18n!",
			"tmpl": "$tmpl!"
		},

		// Convert dependencies for requirejs
		dependControl = function (depends, callback, type, name) {
			var deferred = $.Deferred(),
				promise = deferred.promise(),
				requireDepends = [],
				requireCallback = function () {
					var module;

					if (callback) {
						module = callback.call(promise, $);
					}

					deferred.resolve($);

					return module;
				};
				
			// NEW 6.15.1: Lower case structure
			if (type === "plugin" && name && name.toLowerCase) {
				name = name.toLowerCase();
			} 

			// May not have dependencies
			if (!callback) {
				callback = depends;
				depends = {};
			}

			// Normalize dependencies
			depends = pluginExp.test($.type(depends)) ? {
				plugin: depends
			} : depends;

			// Add dependencies to deferredStack
			$.each(depends, function (dependType, dependTypeDepends) {
				dependType = dependMap[dependType];

				$.each($.isArray(dependTypeDepends) ? dependTypeDepends : [dependTypeDepends], function (i, depend) {
					// NEW 6.15.1: Lower case structure
					if (dependType === "" && depend) {
						depend = depend.toLowerCase();
					}
				
					requireDepends.push(dependType + pluginToModule(depend));
				});
			});

			if (name) {
				var moduleId = dependMap[type] + pluginToModule(name);
				// Define module
				define(moduleId, requireDepends, requireCallback);
				// Trigger exec of callback
				require([moduleId]);
			}
			else {
				require(requireDepends, requireCallback);
			}

			return promise;
		},

		// Local alias of console
		_console = window.console;

	// Run config for ajax
	$.extend($.ajaxSettings, config.ajax);

	// Run config for noConflict mode
	if (config.noConflict) {
		var alias = $.noConflict();
		if (typeof config.noConflict === "string") {
			window[config.noConflict] = alias;
		}
	}

	$.extend({
		// jQuery.config
		config: config,

		// jQuery.debug
		debug: {
			// jQuery.debug.warn()
			warn: _console && $.isFunction(_console.warn) ? function () {
				_console.warn.apply(_console, arguments);
			} : $.noop
		},

		// jQuery.plugin()
		plugin: function (name, depends, callback) {
			return dependControl(depends, callback, "plugin", name);
		},

		// jQuery.provide()
		provide: function (name, depends, callback) {
			return dependControl(depends, callback, "script", name);
		},

		// jQuery.ready()
		ready: function (depends, callback) {
			var type = $.type(depends);

			if (typeExp.test(type)) {
				return dependControl(depends, callback || $.noop);
			}
			else {
				return type === "function" ? readyPromise()
					.done(depends) : ready(depends);
			}
		},

		// jQuery.scope()
		scope: function (scope, context) {
			var parts = scope ? scope.split(/\./) : [];

			context = context || window;

			for (var i = 0, l = parts.length; i < l; i++) {
				context = context[parts[i]] || (context[parts[i]] = {});
			}

			return context;
		}
	});

	$.fn.extend({
		// .jquerysdk --> Version
		jquerysdk: "1.4",

		// .sub() --> provide subclass switch as prototype method
		sub: function (jQuerySubclass) {
			return (typeof jQuerySubclass === "string" ? window[jQuerySubclass] : jQuerySubclass)(this);
		}
	});

	// Redefine original ready promise
	$.ready.promise = readyPromise;

	// Define module
	define("jquery-sdk", [], function () {
		return $;
	});

	//
	// Backward compatible plugins
	//

	var
		// Generate warn message for plugins which are replaced by an other module
		messageReplacedBy = function (moduleName, moduleDepend) {
			return "'" + moduleToPlugin(moduleName) + "' is replaced by module '" + moduleDepend + "'";
		},

		// Generate warn message for plugins which are already included in module jQuery
		messageSupportedBy = function (moduleName) {
			return "Now methods of '" + moduleToPlugin(moduleName) + "' supported by module 'jquery'";
		},

		// Configure redirect paths
		requireConfig = {
			paths: {
				"jQuery": "jquery",
				"jquery/fn/scrollTo": "jquery/fn/scrollto",
				"jquery/fn/equalSize": "jquery/fn/equalsize"
			},
			config: {

			}
		};

	// Setup backward compatible config
	$.each({
		"ajax": "jquery-sdk",
		"compareVersion": "util/version",
		"dict": "jquery/dict",
		"i18n": "jquery/i18n",
		"metaparse": "jquery/metaparse",
		"mime": "util/mime",
		"noConflict": "jquery-sdk",
		"shrink": "util/string.shrink",
		"storage": "util/storage"
	}, function (configName, moduleId) {
		var config = $.config[configName];

		if (config) {
			$.debug.warn("DEPRECATED: use 'module config of requirejs' instead of 'jQueryConfig." + configName + "'.");
			$.extend($.scope(moduleId, requireConfig.config), config);
		}
	});

	// Setup requirejs
	require(requireConfig);

	// Setup backward compatible modules
	$.each({
		"jquery/array": ["jQuery.array' was canceled entirely.", undefined, function ($) {
			var arrayProto = Array.prototype,

				splice = arrayProto.splice,

				push = arrayProto.push,

				add;

			$.unsplice = function (target, insert, i) {
				push.apply(add = [isNaN(i) ? target.length : i, 0], !$.isArray(insert) ? $.merge([], insert) : insert);
				splice.apply(target, add);

				return target;
			};
		}],

		"jquery/base64": [messageReplacedBy, "util/base64", function ($, base64) {
			$.toBASE64 = $.encodeBASE64 = base64.encode;
			$.fromBASE64 = $.decodeBASE64 = base64.decode;
		}],

		"jquery/base64/fix": [undefined, "jquery/base64"],

		"jquery/core": [undefined, undefined],

		"jquery/class": [messageReplacedBy, "class", function ($, Class) {
			$.Class = Class;
			$.isClass = Class.isClass;
		}],

		"jquery/compareVersion": [messageReplacedBy, "util/version", function ($, version) {
			$.compareVersionSettings = $.extend(version.config, $.config.compareVersion);
			$.compareVersion = version.compare;
		}],

		"jquery/css/borderradius": [messageSupportedBy],

		"jquery/debug/sortPlugins": ["jQuery.debug.sortPlugins' was canceled entirely.", undefined, function ($) {
			$.debug.sortPlugins = $.noop;
		}],

		"jquery/fn/size": [messageSupportedBy],

		"jquery/json": [messageReplacedBy, "util/json", function ($, json) {
			$.fromJSON = $.parseJSON;
			$.toJSON = json.encode;
		}],

		"jquery/json/fix": [undefined, "jquery/json"],

		"jquery/md5": [messageReplacedBy, "util/md5", function ($, md5) {
			$.md5 = md5;
		}],

		"jquery/mime": [messageReplacedBy, "util/mime", function ($, mime) {
			$.mime = mime.mime;
			$.mimeSettings = $.extend(true, mime.config, $.config.mime);
		}],

		"jquery/scope": [messageReplacedBy, "util/scope"],

		"jquery/storage": [messageReplacedBy, "util/storage", function ($, storage) {
			$.each(["local", "session"], function (i, type) {
				$[type + "Storage"] = storage[type + "Storage"];
				$[type + "StorageClear"] = storage[type + "Clear"];
				$[type + "StorageSettings"] = $.extend(storage.config, $.config.storage);
			});
		}],

		"jquery/string": [messageReplacedBy, "util/string", function ($, string) {
			$.reverse = string.reverse;
			$.escExpStr = string.escExpStr;
			$.stripTags = string.stripTags;
			$.htmlspecialchars = string.htmlspecialchars;
			$.shrinkSetting = $.extend(string.config.shrink, $.config.shrink);
			$.shrink = string.shrink;
		}],

		"jquery/support/cssprefix": [messageSupportedBy],

		"jquery/support/flash": [messageReplacedBy, "util/string", function ($, support) {
			$.support.flash = support.flash;
		}],

		"jquery/support/multipleUpload": [messageReplacedBy, "util/string", function ($, support) {
			$.support.multipleUpload = support.inputFileMultipleAttr;
		}],

		"jquery/support/placeholder": [messageReplacedBy, "util/string", function ($, support) {
			$.support.inputPlaceholderAttr = support.placeholder;
		}],

		"jquery/support/touch": [messageReplacedBy, "util/string", function ($, support) {
			$.support.touch = support.touchEvents;
		}],

		"jquery/utf8": [messageReplacedBy, "util/utf8", function ($, utf8) {
			$.toUTF8 = $.encodeUTF8 = utf8.encode;
			$.fromUTF8 = $.decodeUTF8 = utf8.decode;
		}]
	}, function (moduleId, moduleData) {
		var moduleMessage = moduleData[0],
			moduleDepend = moduleData[1],
			moduleCallback = moduleData[2];

		define(moduleId, ["jquery-sdk"].concat(moduleDepend ? [moduleDepend] : []), function ($) {

			if (moduleMessage) {
				$.debug.warn("JQSDK deprecated: " + ($.isFunction(moduleMessage) ? moduleMessage(moduleId, moduleDepend) : moduleMessage));
			}

			if (moduleCallback) {
				moduleCallback.apply(moduleCallback, arguments);
			}

			return $;
		});
		
		// NEW 6.15.1: Lower case structure
		if (moduleId !== moduleId.toLowerCase()) {
			define(moduleId.toLowerCase(), [moduleId], function ($) {
				return $
			});
		}
	});

}(jQuery));
(function (jQuery) {

	// Expose jQuery as an AMD module, but only for AMD loaders that
	// understand the issues with loading multiple versions of jQuery
	// in a page that all might call define(). The loader will indicate
	// they have special allowances for multiple jQuery versions by
	// specifying define.amd.jQuery = true. Register as a named module,
	// since jQuery can be concatenated with other files that may use define,
	// but not use a proper concatenation script that understands anonymous
	// AMD modules. A named AMD is safest and most robust way to register.
	// Lowercase jquery is used because AMD module names are derived from
	// file names, and jQuery is normally delivered in a lowercase file name.
	// Do this after creating the global so that if an AMD module wants to call
	// noConflict to hide this version of jQuery, it will work.

	if (typeof define === "function" && define.amd && define.amd.jQuery) {
		define("jquery-migrate-sdk", [], function () {
			return jQuery;
		});
		define("jquery", [], function () {
			return jQuery;
		});
	}

}(jQuery));

/* ---- Module:jquery.each ---- */

/*
 * @author			Evan Vosberg
 * @copyright		© 2012 by Evan Vosberg
 * @info			http://github.com/evanvosberg
 *
 * @license			Licensed under the MIT (http://www.opensource.org/licenses/mit-license.php) license.
 *
 * @module			jquery/each
 */

define("jquery/each", ["jquery"], function ($, undefined) {

	// enable overwrite "this" with the return value
	$.extend({
		// args is for internal usage only
		each: function (object, callback, args) {
			var overwrite;
			if (callback === true) {
				overwrite = callback;
				callback = args;
				args = arguments[3];
			}
			var name, i = 0,
				length = object.length,
				isObj = length === undefined || $.isFunction(object),
				ret;

			if (args) {
				if (isObj) {
					for (name in object) {
						ret = callback.apply(object[name], args);
						if (ret === false) {
							break;
						}
						else if (overwrite && ret !== undefined) {
							object[name] = ret;
						}
					}
				}
				else {
					for (; i < length;) {
						ret = callback.apply(object[i++], args);
						if (ret === false) {
							break;
						}
						else if (overwrite && ret !== undefined) {
							object[i] = ret;
						}
					}
				}

				// A special, fast, case for the most common use of each
			}
			else {
				if (isObj) {
					for (name in object) {
						ret = callback.call(object[name], name, object[name]);
						if (ret === false) {
							break;
						}
						else if (overwrite && ret !== undefined) {
							object[name] = ret;
						}
					}
				}
				else {
					ret = true;
					for (var value = object[0]; i < length && ret !== false; value = object[++i]) {
						ret = callback.call(value, i, value);

						if (overwrite && ret !== undefined) {
							object[i] = ret;
						}
					}
				}
			}

			return object;
		}
	});

	// enable overwrite "this" with the return value
	$.fn.extend({
		each: function (overwrite, callback, args) {
			return $.each(this, overwrite, callback, args);
		}
	});

	return $;
});

/* ---- Module:jquery.event.fix ---- */

/*
 * @author			Evan Vosberg
 * @copyright		© 2012 by Evan Vosberg
 * @info			http://github.com/evanvosberg
 *
 * @license			Licensed under the MIT (http://www.opensource.org/licenses/mit-license.php) license.
 *
 * @module			jquery/event/fix
 */

define("jquery/event/fix", ["jquery"], function ($) {

	var _fix = $.event.fix;

	$.extend($.event, {
		fix: function (event) {
			var originalEvent = event;

			// run  the original fix method
			event = _fix.call($.event, event);

			// Add originalTarget, if necessary
			if (!event.originalTarget) {
				event.originalTarget = originalEvent.srcElement || event.target;
			}

			// be sure touches isn't undefined
			// Calculate pageX/Y if missing and touches[0] available
			if ((event.touches = originalEvent.touches || {
				length: 0
			})
				.length) {
				event.pageX = event.touches[0].pageX;
				event.pageY = event.touches[0].pageY;
			}
			// Calculate pageX/Y and touches[0] if missing and touch available
			else if (originalEvent.touch) {
				event.touches = {
					0: originalEvent.touch,
					length: 1
				};
				event.pageX = originalEvent.touch.pageX;
				event.pageY = originalEvent.touch.pageY;
			}

			return event;
		}
	});

	return $;
});

/* ---- Module:jquery.fn.class ---- */

/*
 * @author			Evan Vosberg
 * @copyright		© 2012 by Evan Vosberg
 * @info			http://github.com/evanvosberg
 *
 * @license			Licensed under the MIT (http://www.opensource.org/licenses/mit-license.php) license.
 *
 * @module			jquery/fn/class
 */

define("jquery/fn/class", ["jquery"], function ($) {

	var _hasClass = $.fn.hasClass,
		_removeClass = $.fn.removeClass;

	$.fn.extend({
		hasClass: function (classes) {
			if ($.type(classes) === "regexp") {
				return classes.test($(this[0])
					.attr("class") || "");
			}
			else {
				return _hasClass.call(this, classes);
			}
		},
		removeClass: function (classes) {
			if ($.type(classes) === "regexp") {
				this.each(function () {
					var elem = $(this);

					$.each((elem.attr("class") || "")
						.split(/\s+/g), function (i, name) {
						if (classes.test(name)) {
								_removeClass.call(elem, name);
							}
					});

				});
			}
			else {
				_removeClass.call(this, classes);
			}

			return this;
		}
	});

	return $;
});

/* ---- Module:jquery.tmpl ---- */

define("jquery/tmpl", ["jquery"], function (jQuery) {

/*!
 * jQuery Templates Plugin 1.0.0pre
 * http://github.com/jquery/jquery-tmpl
 * Requires jQuery 1.4.2
 *
 * Copyright 2011, Software Freedom Conservancy, Inc.
 * Dual licensed under the MIT or GPL Version 2 licenses.
 * http://jquery.org/license
 */
(function(jQuery, undefined){

	var oldManip = jQuery.fn.domManip, tmplItmAtt = "_tmplitem", htmlExpr = /^[^<]*(<[\w\W]+>)[^>]*$|\{\{\! /,
		newTmplItems = {}, wrappedItems = {}, appendToTmplItems, topTmplItem = { key: 0, data: {} }, itemKey = 0, cloneIndex = 0, stack = [], unshift = Array.prototype.unshift;

	function newTmplItem( options, parentItem, fn, data ) {
		// Returns a template item data structure for a new rendered instance of a template (a 'template item').
		// The content field is a hierarchical array of strings and nested items (to be
		// removed and replaced by nodes field of dom elements, once inserted in DOM).
		var newItem = {
			data: data || (data === 0 || data === false) ? data : (parentItem ? parentItem.data : {}),
			_wrap: parentItem ? parentItem._wrap : null,
			tmpl: null,
			parent: parentItem || null,
			nodes: [],
			calls: tiCalls,
			nest: tiNest,
			wrap: tiWrap,
			html: tiHtml,
			update: tiUpdate
		};
		if ( options ) {
			jQuery.extend( newItem, options, { nodes: [], parent: parentItem });
		}
		if ( fn ) {
			// Build the hierarchical content to be used during insertion into DOM
			newItem.tmpl = fn;
			newItem._ctnt = newItem._ctnt || newItem.tmpl( jQuery, newItem );
			newItem.key = ++itemKey;
			// Keep track of new template item, until it is stored as jQuery Data on DOM element
			(stack.length ? wrappedItems : newTmplItems)[itemKey] = newItem;
		}
		return newItem;
	}

	// Override appendTo etc., in order to provide support for targeting multiple elements. (This code would disappear if integrated in jquery core).
	jQuery.each({
		appendTo: "append",
		prependTo: "prepend",
		insertBefore: "before",
		insertAfter: "after",
		replaceAll: "replaceWith"
	}, function( name, original ) {
		jQuery.fn[ name ] = function( selector ) {
			var ret = [], insert = jQuery( selector ), elems, i, l, tmplItems,
				parent = this.length === 1 && this[0].parentNode;

			appendToTmplItems = newTmplItems || {};
			if ( parent && parent.nodeType === 11 && parent.childNodes.length === 1 && insert.length === 1 ) {
				insert[ original ]( this[0] );
				ret = this;
			} else {
				for ( i = 0, l = insert.length; i < l; i++ ) {
					cloneIndex = i;
					elems = (i > 0 ? this.clone(true) : this).get();
					jQuery( insert[i] )[ original ]( elems );
					ret = ret.concat( elems );
				}
				cloneIndex = 0;
				ret = this.pushStack( ret, name, insert.selector );
			}
			tmplItems = appendToTmplItems;
			appendToTmplItems = null;
			jQuery.tmpl.complete( tmplItems );
			return ret;
		};
	});

	jQuery.fn.extend({
		// Use first wrapped element as template markup.
		// Return wrapped set of template items, obtained by rendering template against data.
		tmpl: function( data, options, parentItem ) {
			return jQuery.tmpl( this[0], data, options, parentItem );
		},

		// Find which rendered template item the first wrapped DOM element belongs to
		tmplItem: function(key) {
			return jQuery.tmplItem( this[0], key );
		},

		// Consider the first wrapped element as a template declaration, and get the compiled template or store it as a named template.
		template: function( name ) {
			return jQuery.template( name, this[0] );
		},

		domManip: function( args, table, callback, options ) {
			if ( args[0] && jQuery.isArray( args[0] )) {
				var dmArgs = jQuery.makeArray( arguments ), elems = args[0], elemsLength = elems.length, i = 0, tmplItem;
				while ( i < elemsLength && !(tmplItem = jQuery.data( elems[i++], "tmplItem" ))) {}
				if ( tmplItem && cloneIndex ) {
					dmArgs[2] = function( fragClone ) {
						// Handler called by oldManip when rendered template has been inserted into DOM.
						jQuery.tmpl.afterManip( this, fragClone, callback );
					};
				}
				oldManip.apply( this, dmArgs );
			} else {
				oldManip.apply( this, arguments );
			}
			cloneIndex = 0;
			if ( !appendToTmplItems ) {
				jQuery.tmpl.complete( newTmplItems );
			}
			return this;
		}
	});

	jQuery.extend({
		// Return wrapped set of template items, obtained by rendering template against data.
		tmpl: function( tmpl, data, options, parentItem ) {
			var ret, topLevel = !parentItem;
			if ( topLevel ) {
				// This is a top-level tmpl call (not from a nested template using {{tmpl}})
				parentItem = topTmplItem;
				tmpl = jQuery.template[tmpl] || jQuery.template( null, tmpl );
				wrappedItems = {}; // Any wrapped items will be rebuilt, since this is top level
			} else if ( !tmpl ) {
				// The template item is already associated with DOM - this is a refresh.
				// Re-evaluate rendered template for the parentItem
				tmpl = parentItem.tmpl;
				newTmplItems[parentItem.key] = parentItem;
				parentItem.nodes = [];
				if ( parentItem.wrapped ) {
					updateWrapped( parentItem, parentItem.wrapped );
				}
				// Rebuild, without creating a new template item
				return jQuery( build( parentItem, null, parentItem.tmpl( jQuery, parentItem ) ));
			}
			if ( !tmpl ) {
				return []; // Could throw...
			}
			if ( typeof data === "function" ) {
				data = data.call( parentItem || {} );
			}
			if ( options && options.wrapped ) {
				updateWrapped( options, options.wrapped );
			}
			ret = jQuery.isArray( data ) ?
				jQuery.map( data, function( dataItem ) {
					return dataItem ? newTmplItem( options, parentItem, tmpl, dataItem ) : null;
				}) :
				[ newTmplItem( options, parentItem, tmpl, data ) ];
			return topLevel ? jQuery( build( parentItem, null, ret ) ) : ret;
		},

		// Return rendered template item for an element.
		tmplItem: function( elem, key ) {
			var tmplItem;
			if ( elem instanceof jQuery ) {
				elem = elem[0];
			}
			while ( elem && elem.nodeType === 1 && !(tmplItem = jQuery.data( elem, "tmplItem" )) && (elem = elem.parentNode) ) {}
			return key ? (tmplItem || topTmplItem)[ key ] : tmplItem || topTmplItem;
		},

		// Set:
		// Use $.template( name, tmpl ) to cache a named template,
		// where tmpl is a template string, a script element or a jQuery instance wrapping a script element, etc.
		// Use $( "selector" ).template( name ) to provide access by name to a script block template declaration.

		// Get:
		// Use $.template( name ) to access a cached template.
		// Also $( selectorToScriptBlock ).template(), or $.template( null, templateString )
		// will return the compiled template, without adding a name reference.
		// If templateString includes at least one HTML tag, $.template( templateString ) is equivalent
		// to $.template( null, templateString )
		template: function( name, tmpl ) {
			if (tmpl) {
				// Compile template and associate with name
				if ( typeof tmpl === "string" ) {
					// This is an HTML string being passed directly in.
					tmpl = buildTmplFn( tmpl );
				} else if ( tmpl instanceof jQuery ) {
					tmpl = tmpl[0] || {};
				}
				if ( tmpl.nodeType ) {
					// If this is a template block, use cached copy, or generate tmpl function and cache.
					tmpl = jQuery.data( tmpl, "tmpl" ) || jQuery.data( tmpl, "tmpl", buildTmplFn( tmpl.innerHTML ));
					// Issue: In IE, if the container element is not a script block, the innerHTML will remove quotes from attribute values whenever the value does not include white space.
					// This means that foo="${x}" will not work if the value of x includes white space: foo="${x}" -> foo=value of x.
					// To correct this, include space in tag: foo="${ x }" -> foo="value of x"
				}
				return typeof name === "string" ? (jQuery.template[name] = tmpl) : tmpl;
			}
			// Return named compiled template
			return name ? (typeof name !== "string" ? jQuery.template( null, name ):
				(jQuery.template[name] ||
					// If not in map, and not containing at least on HTML tag, treat as a selector.
					// (If integrated with core, use quickExpr.exec)
					jQuery.template( null, htmlExpr.test( name ) ? name : jQuery( name )))) : null;
		},

		encode: function( text ) {
			// Do HTML encoding replacing < > & and ' and " by corresponding entities.
			return ("" + text).split("<").join("&lt;").split(">").join("&gt;").split('"').join("&#34;").split("'").join("&#39;");
		}
	});

	jQuery.extend( jQuery.tmpl, {
		tag: {
			"tmpl": {
				_default: { $2: "null" },
				open: "if($notnull_1){__=__.concat($item.nest($1,$2));}"
				// tmpl target parameter can be of type function, so use $1, not $1a (so not auto detection of functions)
				// This means that {{tmpl foo}} treats foo as a template (which IS a function).
				// Explicit parens can be used if foo is a function that returns a template: {{tmpl foo()}}.
			},
			"wrap": {
				_default: { $2: "null" },
				open: "$item.calls(__,$1,$2);__=[];",
				close: "call=$item.calls();__=call._.concat($item.wrap(call,__));"
			},
			"each": {
				_default: { $2: "$index, $value" },
				open: "if($notnull_1){$.each($1a,function($2){with(this){",
				close: "}});}"
			},
			"if": {
				open: "if(($notnull_1) && $1a){",
				close: "}"
			},
			"else": {
				_default: { $1: "true" },
				open: "}else if(($notnull_1) && $1a){"
			},
			"html": {
				// Unecoded expression evaluation.
				open: "if($notnull_1){__.push($1a);}"
			},
			"=": {
				// Encoded expression evaluation. Abbreviated form is ${}.
				_default: { $1: "$data" },
				open: "if($notnull_1){__.push($.encode($1a));}"
			},
			"!": {
				// Comment tag. Skipped by parser
				open: ""
			},
			"elem": {
				_default: { $2: "jQuery" },
				open: "if($notnull_1){__.push(' _tmplclass=\"$2\" _tmplelement=\"'+$.encode($1a)+'\"');}"
			}
		},

		// This stub can be overridden, e.g. in jquery.tmplPlus for providing rendered events
		complete: function( items ) {
			newTmplItems = {};
		},

		// Call this from code which overrides domManip, or equivalent
		// Manage cloning/storing template items etc.
		afterManip: function afterManip( elem, fragClone, callback ) {
			// Provides cloned fragment ready for fixup prior to and after insertion into DOM
			var content = fragClone.nodeType === 11 ?
				jQuery.makeArray(fragClone.childNodes) :
				fragClone.nodeType === 1 ? [fragClone] : [];

			// Return fragment to original caller (e.g. append) for DOM insertion
			callback.call( elem, fragClone );

			// Fragment has been inserted:- Add inserted nodes to tmplItem data structure. Replace inserted element annotations by jQuery.data.
			storeTmplItems( content );
			cloneIndex++;
		}
	});

	//========================== Private helper functions, used by code above ==========================

	function build( tmplItem, nested, content ) {
		// Convert hierarchical content into flat string array
		// and finally return array of fragments ready for DOM insertion
		var frag, ret = content ? jQuery.map( content, function( item ) {
			return (typeof item === "string") ?
				// Insert template item annotations, to be converted to jQuery.data( "tmplItem" ) when elems are inserted into DOM.
				(tmplItem.key ? item.replace( /(<\w+)(?=[\s>])(?![^>]*_tmplitem)([^>]*)/g, "$1 " + tmplItmAtt + "=\"" + tmplItem.key + "\" $2" ) : item) :
				// This is a child template item. Build nested template.
				build( item, tmplItem, item._ctnt );
		}) :
		// If content is not defined, insert tmplItem directly. Not a template item. May be a string, or a string array, e.g. from {{html $item.html()}}.
		tmplItem;
		if ( nested ) {
			return ret;
		}

		// top-level template
		ret = ret.join("");

		// Support templates which have initial or final text nodes, or consist only of text
		// Also support HTML entities within the HTML markup.
		ret.replace( /^\s*([^<\s][^<]*)?(<[\w\W]+>)([^>]*[^>\s])?\s*$/, function( all, before, middle, after) {
			frag = jQuery( middle ).get();

			storeTmplItems( frag );
			if ( before ) {
				frag = unencode( before ).concat(frag);
			}
			if ( after ) {
				frag = frag.concat(unencode( after ));
			}
		});
		return frag ? frag : unencode( ret );
	}

	function unencode( text ) {
		// Use createElement, since createTextNode will not render HTML entities correctly
		var el = document.createElement( "div" );
		el.innerHTML = text;
		return jQuery.makeArray(el.childNodes);
	}

	// Generate a reusable function that will serve to render a template against data
	function buildTmplFn( markup ) {
		return new Function("jQuery","$item",
			// Use the variable __ to hold a string array while building the compiled template. (See https://github.com/jquery/jquery-tmpl/issues#issue/10).
			"var $=jQuery,call,__=[],$data=$item.data;" +

			// Introduce the data as local variables using with(){}
			"with($data){__.push('" +

			// Convert the template into pure JavaScript
			jQuery.trim(markup)
				.replace( /([\\'])/g, "\\$1" )
				.replace( /[\r\t\n]/g, " " )
				.replace( /\$\{([^\}]*)\}/g, "{{= $1}}" )
				.replace( /\{\{(\/?)(\w+|.)(?:\(((?:[^\}]|\}(?!\}))*?)?\))?(?:\s+(.*?)?)?(\(((?:[^\}]|\}(?!\}))*?)\))?\s*\}\}/g,
				function( all, slash, type, fnargs, target, parens, args ) {
					var tag = jQuery.tmpl.tag[ type ], def, expr, exprAutoFnDetect;
					if ( !tag ) {
						throw "Unknown template tag: " + type;
					}
					def = tag._default || [];
					if ( parens && !/\w$/.test(target)) {
						target += parens;
						parens = "";
					}
					if ( target ) {
						target = unescape( target );
						args = args ? ("," + unescape( args ) + ")") : (parens ? ")" : "");
						// Support for target being things like a.toLowerCase();
						// In that case don't call with template item as 'this' pointer. Just evaluate...
						expr = parens ? (target.indexOf(".") > -1 ? target + unescape( parens ) : ("(" + target + ").call($item" + args)) : target;
						exprAutoFnDetect = parens ? expr : "(typeof(" + target + ")==='function'?(" + target + ").call($item):(" + target + "))";
					} else {
						exprAutoFnDetect = expr = def.$1 || "null";
					}
					fnargs = unescape( fnargs );
					return "');" +
						tag[ slash ? "close" : "open" ]
							.split( "$notnull_1" ).join( target ? "typeof(" + target + ")!=='undefined' && (" + target + ")!=null" : "true" )
							.split( "$1a" ).join( exprAutoFnDetect )
							.split( "$1" ).join( expr )
							.split( "$2" ).join( fnargs || def.$2 || "" ) +
						"__.push('";
				}) +
			"');}return __;"
		);
	}
	function updateWrapped( options, wrapped ) {
		// Build the wrapped content.
		options._wrap = build( options, true,
			// Suport imperative scenario in which options.wrapped can be set to a selector or an HTML string.
			jQuery.isArray( wrapped ) ? wrapped : [htmlExpr.test( wrapped ) ? wrapped : jQuery( wrapped ).html()]
		).join("");
	}

	function unescape( args ) {
		return args ? args.replace( /\\'/g, "'").replace(/\\\\/g, "\\" ) : null;
	}
	function outerHtml( elem ) {
		var div = document.createElement("div");
		div.appendChild( elem.cloneNode(true) );
		return div.innerHTML;
	}

	// Store template items in jQuery.data(), ensuring a unique tmplItem data data structure for each rendered template instance.
	function storeTmplItems( content ) {
		var keySuffix = "_" + cloneIndex, elem, elems, newClonedItems = {}, i, l, m, tmplElements;
		for ( i = 0, l = content.length; i < l; i++ ) {
			if ( (elem = content[i]).nodeType !== 1 ) {
				continue;
			}
			elems = elem.getElementsByTagName("*");
			tmplElements = {};
			for ( m = elems.length - 1; m >= 0; m-- ) {
				processItemKey( elems[m] );
			}
			processItemKey( elem );
		}
		function processItemKey( el ) {
			var pntKey, pntNode = el, pntItem, tmplItem, key;
			// Ensure that each rendered template inserted into the DOM has its own template item,
			if ( (key = el.getAttribute( tmplItmAtt ))) {
				while ( pntNode.parentNode && (pntNode = pntNode.parentNode).nodeType === 1 && !(pntKey = pntNode.getAttribute( tmplItmAtt ))) { }
				if ( pntKey !== key ) {
					// The next ancestor with a _tmplitem expando is on a different key than this one.
					// So this is a top-level element within this template item
					// Set pntNode to the key of the parentNode, or to 0 if pntNode.parentNode is null, or pntNode is a fragment.
					pntNode = pntNode.parentNode ? (pntNode.nodeType === 11 ? 0 : (pntNode.getAttribute( tmplItmAtt ) || 0)) : 0;
					if ( !(tmplItem = newTmplItems[key]) ) {
						// The item is for wrapped content, and was copied from the temporary parent wrappedItem.
						tmplItem = wrappedItems[key];
						tmplItem = newTmplItem( tmplItem, newTmplItems[pntNode]||wrappedItems[pntNode] );
						tmplItem.key = ++itemKey;
						newTmplItems[itemKey] = tmplItem;
					}
					if ( cloneIndex ) {
						cloneTmplItem( key );
					}
				}
				// push elements by identifier to elements stack of template item
				if( (key = el.getAttribute('_tmplelement')) ){
					if( tmplElements[ key ] ){
						unshift.call( tmplElements[ key ], el );
					}
					else{
						tmplElements[ key ] = (window[ el.getAttribute('_tmplclass') ] || $)(el);
					}
					el.removeAttribute('_tmplelement');
					el.removeAttribute('_tmplclass');
				}
				el.removeAttribute( tmplItmAtt );
			} else if ( cloneIndex && (tmplItem = jQuery.data( el, "tmplItem" )) ) {
				// This was a rendered element, cloned during append or appendTo etc.
				// TmplItem stored in jQuery data has already been cloned in cloneCopyEvent. We must replace it with a fresh cloned tmplItem.
				cloneTmplItem( tmplItem.key );
				newTmplItems[tmplItem.key] = tmplItem;
				pntNode = jQuery.data( el.parentNode, "tmplItem" );
				pntNode = pntNode ? pntNode.key : 0;
			}
			if ( tmplItem ) {
				pntItem = tmplItem;
				// add elements to template item data
				tmplItem.elements = tmplElements;
				// Find the template item of the parent element.
				// (Using !=, not !==, since pntItem.key is number, and pntNode may be a string)
				while ( pntItem && pntItem.key != pntNode ) {
					// Add this element as a top-level node for this rendered template item, as well as for any
					// ancestor items between this item and the item of its parent element
					pntItem.nodes.push( el );
					pntItem = pntItem.parent;
				}
				// Delete content built during rendering - reduce API surface area and memory use, and avoid exposing of stale data after rendering...
				delete tmplItem._ctnt;
				delete tmplItem._wrap;
				// Store template item as jQuery data on the element
				jQuery.data( el, "tmplItem", tmplItem );
			}
			function cloneTmplItem( key ) {
				key = key + keySuffix;
				tmplItem = newClonedItems[key] =
					(newClonedItems[key] || newTmplItem( tmplItem, newTmplItems[tmplItem.parent.key + keySuffix] || tmplItem.parent ));
			}
		}
	}

	//---- Helper functions for template item ----

	function tiCalls( content, tmpl, data, options ) {
		if ( !content ) {
			return stack.pop();
		}
		stack.push({ _: content, tmpl: tmpl, item:this, data: data, options: options });
	}

	function tiNest( tmpl, data, options ) {
		// nested template, using {{tmpl}} tag
		return jQuery.tmpl( jQuery.template( tmpl ), data, options, this );
	}

	function tiWrap( call, wrapped ) {
		// nested template, using {{wrap}} tag
		var options = call.options || {};
		options.wrapped = wrapped;
		// Apply the template, which may incorporate wrapped content,
		return jQuery.tmpl( jQuery.template( call.tmpl ), call.data, options, call.item );
	}

	function tiHtml( filter, textOnly ) {
		var wrapped = this._wrap;
		return jQuery.map(
			jQuery( jQuery.isArray( wrapped ) ? wrapped.join("") : wrapped ).filter( filter || "*" ),
			function(e) {
				return textOnly ?
					e.innerText || e.textContent :
					e.outerHTML || outerHtml(e);
			});
	}

	function tiUpdate() {
		var coll = this.nodes;
		jQuery.tmpl( null, null, null, this).insertBefore( coll[0] );
		jQuery( coll ).remove();
	}

})(jQuery);


	return jQuery;
});

/* ---- Module:ep.modify ---- */

/**
 * @event changeAttr Gets fired if an attribute(s) of an element changed.
 * @member jQuery
 * @since 6.11.0
 */

/*
 * @copyright		© Copyright 2006-2010, epages GmbH, All Rights Reserved.
 *
 * @module			ep.modify
 *
 * @revision		$Revision: 1.5.2.1 $
 */

define("ep/modify", [
	"jquery"
], function ($) {

// modify $.attr + $.removeAttr for event

		// save original methods
	var _attr = $.fn.attr,
		_removeAttr = $.fn.removeAttr
		_trigger = $.event.trigger,

		isVisible = $.expr.filters.visible,

		onEventExpr = /^on/,
		nativeEventExpr = /^(blur|change|click|dblclick|error|focus|keydown|keypress|keyup|load|mousedown|mousemove|mouseout|mouseover|mouseup|resize|select|unload)$/,
		mouseEventExpr = /^(click|dblclick|mousedown|mousemove|mouseout|mouseover|mouseup)$/;

	// handle for event trigger
	function attrEvent( elems, name, value ){
		var attr;

		if( typeof name === 'object' ){
			attr = name;
		}
		else if( value !== undefined ){
			(attr = {})[ name ] = value;
		}

		if( attr ){
			elems.trigger('changeAttr',attr);
		}
	}
//#JSCOVERAGE_IF false
	// overwrite trigger for dojo connect
	$.event.trigger = function( event, data, elem, onlyHandlers ){
		if( event.dojoconnect ){
			var type = event.type,
				eventObj;
			// break if no element given
			if( !elem ){
				return;
			}
			// remove exclusive option
			if ( type.indexOf("!") >= 0 ) {
				type = type.slice(0, -1);
			}
			// remove namespace
			if ( type.indexOf(".") >= 0 ) {
				type = type.split(".")[0];
			}
			// remove on prefix
			type = onEventExpr.test(type) ? type.slice(2) : type;

			if( nativeEventExpr.test(type) && !onlyHandlers ){
				if( elem.fireEvent ){
					try{
						elem.fireEvent( 'on' + type );
					}
					catch( error ){

					}
				}
				else{
					if( mouseEventExpr.test(type) ){ // create mouse events
						eventObj = document.createEvent('MouseEvents');
						eventObj.initMouseEvent(
							type,
							!!event.canBubble,
							!!event.cancelable,
							window,
							event.detail || 0,
							event.screenX || 0,
							event.screenY || 0,
							event || 0,
							event.clientY || 0,
							!!event.ctrlKey,
							!!event.altKey,
							!!event.shiftKey,
							!!event.metaKey,
							event.button || 0,
							event.relatedTarget || null
						);
					}
					else{										// create html events
						eventObj = document.createEvent('HTMLEvents');
						eventObj.initEvent(
							type,
							!!event.canBubble,
							!!event.cancelable
						);
					}
					elem.dispatchEvent(eventObj);
				}
				return;
			}
		}

		return _trigger.apply( this, arguments );
	};
//#JSCOVERAGE_ENDIF

	// overwrite methods
	$.fn.extend({
		/**
		 * Set one or more attributes for the set of matched elements.
		 * 
		 * The ep.modify plugin overwrites the `.attr()` method, is works like the original method but fire an
		 * event named changeAttr.
		 * 
		 * If only one parameter is given, the parameter is interpreted as a map, where the keys denote the `attributeName`s and the values denote the `value`s.
		 * 
		 * ### Examples
		 * Bind changeAttr event and change an attribute.
		 * 
		 * JavaScript:
		 * 
		 *     $(':checkbox').on( 'changeAttr', function( event ){
		 *         var elem = $(this);
		 *         if( elem.is(':selected') ){
		 *             elem.next().hide();
		 *         }
		 *         else{
		 *             elem.next().show();
		 *         }
		 *     });
		 *     
		 *     $(':checkbox').attr( 'selected', true );
		 * 
		 * HTML:
		 * 
		 *     <div>
		 *         <input type="checkbox" name="foo"/>
		 *         <span>This field is required.</span>
		 *     </span>
		 * 
		 * Results:
		 * 
		 *     <div>
		 *         <input type="checkbox" name="foo" selected="true"/>
		 *         <span style="display:none;">This field is required.</span>
		 *     </span>
		 * 
		 * 
		 * @param {String} attributeName The name of the attribute to set.
		 * @param {String} [value] A value to set for the attribute.
		 * 
		 * @fires changeAttr
		 * 
		 * @method attr
		 * @member jQuery
		 * 
		 * @since 6.11.0
		 */
		attr: function( name, value ){
			var elems = $(this),
				ret = _attr.apply(elems, arguments);

			attrEvent( elems, name, value );

			return ret;
		},
		/**
		 * Remove an attribute from each element in the set of matched elements.
		 * 
		 * The ep.modify plugin overwrites the `.removeAttr()` method, is works like the original method but fire an
		 * event named changeAttr.
		 * 
		 * ### Examples
		 * Bind changeAttr event and remove an attribute.
		 * 
		 * JavaScript:
		 * 
		 *     $(':checkbox').on( 'changeAttr', function( event ){
		 *         var elem = $(this);
		 *         if( elem.is(':selected') ){
		 *             elem.next().hide();
		 *         }
		 *         else{
		 *             elem.next().show();
		 *         }
		 *     });
		 *     
		 *     $(':checkbox').removeAttr( 'selected' );
		 * 
		 * HTML:
		 * 
		 *     <div>
		 *       <input type="checkbox" name="foo" selected="true"/>
		 *       <span style="display:none;">This field is required.</span>
		 *     </span>
		 * 
		 * Results:
		 * 
		 *     <div>
		 *       <input type="checkbox" name="foo"/>
		 *       <span>This field is required.</span>
		 *     </span>
		 * 
		 * 
		 * @param {String} attributeName The name of the attribute to set.
		 * 
		 * @fires changeAttr
		 * 
		 * @method removeAttr
		 * @member jQuery
		 * 
		 * @since 6.11.0
		 */
		removeAttr: function( name ){
			var elems = $(this),
				ret = _removeAttr.apply(elems, arguments);

			attrEvent( this, name, null );

			return ret;
		}
	});

	// special pseudo selector for input fields
	$.extend( $.expr[':'],{
		'invalid': function( elem ){
			return !!elem.formInvalid && !elem.disabled && (elem.type==='hidden' || isVisible(elem));
		}
	});

	return $;

});

/* ---- Module:jquery.expr ---- */

/*
 * @author			Evan Vosberg
 * @copyright		© 2012 by Evan Vosberg
 * @info			http://github.com/evanvosberg
 *
 * @license			Licensed under the MIT (http://www.opensource.org/licenses/mit-license.php) license.
 *
 * @module			jquery/expr
 */

define("jquery/expr", ["jquery"], function ($) {

	var inputTextareaExp = /^(input|textarea)$/i,
		selectExp = /^select$/i,
		checkedExp = /^(radio|checkbox)$/i,
		onExp = /^(|on)$/i;

	// special selector
	$.extend($.expr[":"], {
		"changed": function (elem) {
			return inputTextareaExp.test(elem.nodeName) ? checkedExp.test(elem.type) ? elem.defaultChecked !== elem.checked || (elem.defaultValue !== elem.value && !onExp.test(elem.defaultValue) && !onExp.test(elem.value)) : elem.defaultValue !== elem.value : selectExp.test(elem.nodeName) ? !(elem.options[elem.selectedIndex] || {})
				.defaultSelected : false;
		},
		"readonly": function (elem) {
			return !!elem[$.propFix.readonly];
		}
	});

	return $;
});

/* ---- Module:jquery.fn.form ---- */

/*
 * @author			Evan Vosberg
 * @copyright		© 2012 by Evan Vosberg
 * @info			http://github.com/evanvosberg
 *
 * @license			Licensed under the MIT (http://www.opensource.org/licenses/mit-license.php) license.
 *
 * @module			jquery/fn/form
 */

define("jquery/fn/form", ["jquery", "jquery/expr"], function ($) {

	var _form = document.createElement("form");

	$.fn.extend({
		// Find all associated inputs to the first matched (default selector ":radio")
		formGroup: function (selector) {
			var elem = this.filter((selector = selector || ":radio") + ":first")[0] || {},
				name = elem.name,
				form = elem.form,
				owner = elem.ownerDocument,
				elems = [];

			if (name && (form || owner)) {
				$.each(selector = selector.split(","), function (i, sel) {
					selector[i] = $.trim(sel) + "[name='" + name + "']";
				});
				selector = selector.join(",");

				elems = (
				form ? $(form)
					.formInput()
					.filter(selector) : $(":input", owner)
					.filter(selector)
					.filter(function () {
						return !this.form;
					}))
					.get();
			}

			return this.pushStack(elems);
		},

		// Find all inputs of the the first matched form
		formInput: function () {
			return this.pushStack((this.filter("form:first")[0] || {})
				.elements || []);
		},

		// Reset all selected forms or formInputs
		formReset: function () {
			var stack = [],
				form = this.filter("form:first");

			this.filter(":input")
				.each(function () {
					var elem = $(this),
						spacer = elem.clone()
							.insertAfter(elem);

					_form.appendChild(this);
					stack.push([elem, spacer]);
				});

			// First match form
			if (form.length) {
				form[0].reset();
				form.triggerHandler("reset");
			}

			// Matched elements
			_form.reset();

			$.each(stack, function (i, data) {
				var elem = data[0],
					spacer = data[1];

				elem.insertBefore(spacer)
					.triggerHandler("reset");
				spacer.remove();
			});

			return this;
		},

		// Clear all selected forms or formInputs
		formClear: function () {
			var inputs = $(this);

			inputs.push.apply(inputs, inputs.formInput()
				.get());

			inputs.filter(":file")
				.formReset();
			inputs.filter(":checked")
				.removeProp("checked");
			inputs.not("select,:radio,:checkbox")
				.val("");
			inputs.find("select")
				.prop("selectedIndex", - 1);
			inputs.find("option:selected")
				.removeProp("selected");

			return this;
		}
	});

	return $;
});

/* ---- Module:jquery.fn.scrollto ---- */

define("jquery/fn/scrollto", ["jquery"], function (jQuery) {

/*!
 * jQuery.ScrollTo
 * Copyright (c) 2007-2012 Ariel Flesler - aflesler(at)gmail(dot)com | http://flesler.blogspot.com
 * Dual licensed under MIT and GPL.
 * Date: 4/09/2012
 *
 * @projectDescription Easy element scrolling using jQuery.
 * http://flesler.blogspot.com/2007/10/jqueryscrollto.html
 * @author Ariel Flesler
 * @version 1.4.4
 *
 * @id jQuery.scrollTo
 * @id jQuery.fn.scrollTo
 * @param {String, Number, DOMElement, jQuery, Object} target Where to scroll the matched elements.
 *	  The different options for target are:
 *		- A number position (will be applied to all axes).
 *		- A string position ('44', '100px', '+=90', etc ) will be applied to all axes
 *		- A jQuery/DOM element ( logically, child of the element to scroll )
 *		- A string selector, that will be relative to the element to scroll ( 'li:eq(2)', etc )
 *		- A hash { top:x, left:y }, x and y can be any kind of number/string like above.
 *		- A percentage of the container's dimension/s, for example: 50% to go to the middle.
 *		- The string 'max' for go-to-end. 
 * @param {Number, Function} duration The OVERALL length of the animation, this argument can be the settings object instead.
 * @param {Object,Function} settings Optional set of settings or the onAfter callback.
 *	 @option {String} axis Which axis must be scrolled, use 'x', 'y', 'xy' or 'yx'.
 *	 @option {Number, Function} duration The OVERALL length of the animation.
 *	 @option {String} easing The easing method for the animation.
 *	 @option {Boolean} margin If true, the margin of the target element will be deducted from the final position.
 *	 @option {Object, Number} offset Add/deduct from the end position. One number for both axes or { top:x, left:y }.
 *	 @option {Object, Number} over Add/deduct the height/width multiplied by 'over', can be { top:x, left:y } when using both axes.
 *	 @option {Boolean} queue If true, and both axis are given, the 2nd axis will only be animated after the first one ends.
 *	 @option {Function} onAfter Function to be called after the scrolling ends. 
 *	 @option {Function} onAfterFirst If queuing is activated, this function will be called after the first scrolling ends.
 * @return {jQuery} Returns the same jQuery object, for chaining.
 *
 * @desc Scroll to a fixed position
 * @example $('div').scrollTo( 340 );
 *
 * @desc Scroll relatively to the actual position
 * @example $('div').scrollTo( '+=340px', { axis:'y' } );
 *
 * @desc Scroll using a selector (relative to the scrolled element)
 * @example $('div').scrollTo( 'p.paragraph:eq(2)', 500, { easing:'swing', queue:true, axis:'xy' } );
 *
 * @desc Scroll to a DOM element (same for jQuery object)
 * @example var second_child = document.getElementById('container').firstChild.nextSibling;
 *			$('#container').scrollTo( second_child, { duration:500, axis:'x', onAfter:function(){
 *				alert('scrolled!!');																   
 *			}});
 *
 * @desc Scroll on both axes, to different values
 * @example $('div').scrollTo( { top: 300, left:'+=200' }, { axis:'xy', offset:-20 } );
 */

;(function( $ ){
	
	var $scrollTo = $.scrollTo = function( target, duration, settings ){
		$(window).scrollTo( target, duration, settings );
	};

	$scrollTo.defaults = {
		axis:'xy',
		duration: parseFloat($.fn.jquery) >= 1.3 ? 0 : 1,
		limit:true
	};

	// Returns the element that needs to be animated to scroll the window.
	// Kept for backwards compatibility (specially for localScroll & serialScroll)
	$scrollTo.window = function( scope ){
		return $(window)._scrollable();
	};

	// Hack, hack, hack :)
	// Returns the real elements to scroll (supports window/iframes, documents and regular nodes)
	$.fn._scrollable = function(){
		return this.map(function(){
			var elem = this,
				isWin = !elem.nodeName || $.inArray( elem.nodeName.toLowerCase(), ['iframe','#document','html','body'] ) != -1;

				if( !isWin )
					return elem;

			var doc = (elem.contentWindow || elem).document || elem.ownerDocument || elem;
			
			return /webkit/i.test(navigator.userAgent) || doc.compatMode == 'BackCompat' ?
				doc.body : 
				doc.documentElement;
		});
	};

	$.fn.scrollTo = function( target, duration, settings ){
		if( typeof duration == 'object' ){
			settings = duration;
			duration = 0;
		}
		if( typeof settings == 'function' )
			settings = { onAfter:settings };
			
		if( target == 'max' )
			target = 9e9;
			
		settings = $.extend( {}, $scrollTo.defaults, settings );
		// Speed is still recognized for backwards compatibility
		duration = duration || settings.duration;
		// Make sure the settings are given right
		settings.queue = settings.queue && settings.axis.length > 1;
		
		if( settings.queue )
			// Let's keep the overall duration
			duration /= 2;
		settings.offset = both( settings.offset );
		settings.over = both( settings.over );

		return this._scrollable().each(function(){
			// Null target yields nothing, just like jQuery does
			if (target == null) return;

			var elem = this,
				$elem = $(elem),
				targ = target, toff, attr = {},
				win = $elem.is('html,body');

			switch( typeof targ ){
				// A number will pass the regex
				case 'number':
				case 'string':
					if( /^([+-]=)?\d+(\.\d+)?(px|%)?$/.test(targ) ){
						targ = both( targ );
						// We are done
						break;
					}
					// Relative selector, no break!
					targ = $(targ,this);
					if (!targ.length) return;
				case 'object':
					// DOMElement / jQuery
					if( targ.is || targ.style )
						// Get the real position of the target 
						toff = (targ = $(targ)).offset();
			}
			$.each( settings.axis.split(''), function( i, axis ){
				var Pos	= axis == 'x' ? 'Left' : 'Top',
					pos = Pos.toLowerCase(),
					key = 'scroll' + Pos,
					old = elem[key],
					max = $scrollTo.max(elem, axis);

				if( toff ){// jQuery / DOMElement
					attr[key] = toff[pos] + ( win ? 0 : old - $elem.offset()[pos] );

					// If it's a dom element, reduce the margin
					if( settings.margin ){
						attr[key] -= parseInt(targ.css('margin'+Pos)) || 0;
						attr[key] -= parseInt(targ.css('border'+Pos+'Width')) || 0;
					}
					
					attr[key] += settings.offset[pos] || 0;
					
					if( settings.over[pos] )
						// Scroll to a fraction of its width/height
						attr[key] += targ[axis=='x'?'width':'height']() * settings.over[pos];
				}else{ 
					var val = targ[pos];
					// Handle percentage values
					attr[key] = val.slice && val.slice(-1) == '%' ? 
						parseFloat(val) / 100 * max
						: val;
				}

				// Number or 'number'
				if( settings.limit && /^\d+$/.test(attr[key]) )
					// Check the limits
					attr[key] = attr[key] <= 0 ? 0 : Math.min( attr[key], max );

				// Queueing axes
				if( !i && settings.queue ){
					// Don't waste time animating, if there's no need.
					if( old != attr[key] )
						// Intermediate animation
						animate( settings.onAfterFirst );
					// Don't animate this axis again in the next iteration.
					delete attr[key];
				}
			});

			animate( settings.onAfter );			

			function animate( callback ){
				$elem.animate( attr, duration, settings.easing, callback && function(){
					callback.call(this, target, settings);
				});
			};

		}).end();
	};
	
	// Max scrolling position, works on quirks mode
	// It only fails (not too badly) on IE, quirks mode.
	$scrollTo.max = function( elem, axis ){
		var Dim = axis == 'x' ? 'Width' : 'Height',
			scroll = 'scroll'+Dim;
		
		if( !$(elem).is('html,body') )
			return elem[scroll] - $(elem)[Dim.toLowerCase()]();
		
		var size = 'client' + Dim,
			html = elem.ownerDocument.documentElement,
			body = elem.ownerDocument.body;

		return Math.max( html[scroll], body[scroll] ) 
			 - Math.min( html[size]  , body[size]   );
	};

	function both( val ){
		return typeof val == 'object' ? val : { top:val, left:val };
	};

})( jQuery );

	return jQuery;
});

/* ---- Module:jquery.mixin ---- */

/*
 * @author			Evan Vosberg
 * @copyright		© 2012 by Evan Vosberg
 * @info			http://github.com/evanvosberg
 *
 * @license			Licensed under the MIT (http://www.opensource.org/licenses/mit-license.php) license.
 *
 * @module			jquery/mixin
 */

define("jquery/mixin", ["jquery"], function ($, undefined) {

	var own = Object.prototype.hasOwnProperty;

	$.extend({
		// Similar to $.extend but only works on objects (!prototype)
		mixin: function () {
			// copy reference to target object
			var target = arguments[0] || {},
				i = 1,
				length = arguments.length,
				deep = false,
				options,
				name,
				src,
				copy;

			// Handle a deep copy situation
			if (typeof target === "boolean") {
				deep = target;
				target = arguments[1] || {};
				// skip the boolean and the target
				i = 2;
			}

			// Handle case when target is a string or something (possible in deep copy)
			if (typeof target !== "object" && !$.isFunction(target)) {
				target = {};
			}

			// return target if only one argument is passed
			if (length === i) {
				return target;
			}

			for (; i < length; i++) {
				// Only deal with non-null/undefined values
				if ((options = arguments[i]) !== null) {
					// Extend the base object
					for (name in options) {
						src = target[name];
						copy = options[name];

						// Prevent never-ending loop
						if (target === copy || !own.call(options, name)) {
							continue;
						}
						// Recurse if we're merging object literal values or arrays
						if (deep && copy && ($.isPlainObject(copy) || $.isArray(copy))) {
							var clone = src && ($.isPlainObject(src) || $.isArray(src)) ? src : $.isArray(copy) ? [] : {};

							// Never move original objects, clone them
							target[name] = $.extend(deep, clone, copy);

							// Don't bring in undefined values
						}
						else if (copy !== undefined) {
							target[name] = copy;
						}
					}
				}
			}

			// Return the modified object
			return target;
		}
	});

	return $;
});

/* ---- Module:jquery.dict ---- */

/*
 * @copyright		© 2012 by Evan Vosberg
 * @info			http://github.com/evanvosberg
 *
 * @license			Licensed under the MIT (http://www.opensource.org/licenses/mit-license.php) license.
 *
 * @module			jquery/dict
 */

define("jquery/dict", ["module", "jquery"], function (mod, $, undefined) {

	// Get scope of regional dictionaries
	var dictsByRegion = function (region) {
			return $.dict[region] || ($.dict[region] = {});
		},

		// Text replace
		parseNode = function (node, dict, deep) {
			if (node.nodeType === 3) {
				node.nodeValue = dict.parse(node.nodeValue);
			}
			else if (deep) {
				$.each(node.childNodes, function () {
					parseNode(this, dict, deep);
				});
			}
		},

		config = $.dictSettings = $.extend({
			parser: /(?:^|[^\{\$])(\{(.*?[^\\])\})/g,
			region: "en"
		}, mod.config());

	$.extend({
		// Get already defined dictionary
		dict: function (dict, options) {
			// Merge given options with defaults
			var o = $.extend({}, config, typeof options === "string" ? {
					region: options
				} : options),
				// Regional dictionaries scope
				dicts = dictsByRegion(o.region),
				// Dictionary data
				data;

			if (typeof dict === "string") {
				data = dicts[dict] || {};
			}
			else {
				data = dict || {};
			}

			// Results a dictionary instance
			return new $.Dictionary(data, o);
		},

		// Build dictionary by various data
		dictionary: function (dict, data, options) {
			// Anonymous dictionary
			if (typeof dict !== "string") {
				options = data;
				data = dict;
				dict = undefined;
			}
			// Don't overwrite existing dictionary, just extend it
			else {
				data.unshift(dict);
			}

			// Merge given options with defaults
			var o = $.extend({}, config, typeof options === "string" ? {
					region: options
				} : options),
				// Regional dictionaries scope
				dicts = dictsByRegion(o.region),
				// Base stack to merge dictionaries to a single one
				mixed = [{}];

			// create stack
			$.each(data, function (i, item) {
				// Mix in
				if ($.isPlainObject(item)) {
					mixed.push(item);
				}
				// Mix in already defined dictionary by name
				else if (typeof item === "string") {
					mixed.push(dicts[item] || {});
				}
				// Mix in dictionary instances (only with same region)
				else if (item instanceof $.Dictionary && item.options.region === o.region) {
					mixed.push(item.dict);
				}
			});

			// Merge stack into single data object
			mixed = $.extend.apply($, mixed);

			// Results a dictionary instance
			return new $.Dictionary(dict ? (dicts[dict] = mixed) : mixed, o);
		},

		// Dictionary class
		Dictionary: function (dict, options) {
			this.dict = dict;
			this.options = options;
		}
	});

	// Class methods of dict
	$.extend($.Dictionary.prototype, {
		// Translate by key word, run parse as fall back
		translate: function (key) {
			return this.dict[key] || this.parse(key);
		},

		// Parse translation key word in string
		parse: function (string) {
			var dict = this.dict;

			return string.replace(this.options.parser, function (all, $1, $2) {
				var ret = dict[$2];

				return ret === undefined ? all : all.replace($1, ret);
			});
		}
	});

	// Add dictionary as dom manipulation method
	$.fn.extend({
		dictParse: function (dict, deep, options) {
			// Init recursive parsing
			if (typeof deep !== "boolean") {
				options = deep;
				deep = false;
			}

			// Init dict object
			dict = dict instanceof $.Dictionary ? dict : $.dict(dict, options);

			// Parse DOM content
			return this.contents()
				.each(function () {
					parseNode(this, dict, deep);
				}), this;
		},

		dictParseAttr: function (dict, attributes, options) {
			// Init dict object
			dict = dict instanceof $.Dictionary ? dict : $.dict(dict, options);

			// Ensure attributes is an array
			attributes = $.isArray(attributes) ? attributes : [attributes];

			if (!attributes.length) {
				return this;
			}

			this.filter("[" + attributes.join("], [") + "]")
				.each(function () {
					var elem = $(this);

					$.each(attributes, function (i, name) {
						var value = elem.attr(name);

						if (value) {
							elem.attr(name, dict.parse(value));
						}
					});
				});

			return this;
		}
	});

	return $;
});

/* ---- Module:jquery.jstree ---- */

define("jquery/jstree", ["jquery"], function ($) {

/*
 * jsTree 1.0-rc1
 * http://jstree.com/
 *
 * Copyright (c) 2010 Ivan Bozhanov (vakata.com)
 *
 * Dual licensed under the MIT and GPL licenses (same as jQuery):
 *   http://www.opensource.org/licenses/mit-license.php
 *   http://www.gnu.org/licenses/gpl.html
 *
 * $Date: 2013/04/09 16:14:07 $
 * $Revision: 1.3 $
 */

/*jslint browser: true, onevar: true, undef: true, bitwise: true, strict: true */
/*global window : false, clearInterval: false, clearTimeout: false, document: false, setInterval: false, setTimeout: false, jQuery: false, navigator: false, XSLTProcessor: false, DOMParser: false, XMLSerializer: false*/

// Common functions not related to jsTree
// decided to move them to a `vakata` "namespace"

"use strict";

	$.vakata = {};
	// CSS related functions
	$.vakata.css = {
		get_css : function(rule_name, delete_flag, sheet) {
			rule_name = rule_name.toLowerCase();
			var css_rules = sheet.cssRules || sheet.rules,
				j = 0;
			do {
				if(css_rules.length && j > css_rules.length + 5) { return false; }
				if(css_rules[j].selectorText && css_rules[j].selectorText.toLowerCase() == rule_name) {
					if(delete_flag === true) {
						if(sheet.removeRule) { sheet.removeRule(j); }
						if(sheet.deleteRule) { sheet.deleteRule(j); }
						return true;
					}
					else { return css_rules[j]; }
				}
			}
			while (css_rules[++j]);
			return false;
		},
		add_css : function(rule_name, sheet) {
			if($.jstree.css.get_css(rule_name, false, sheet)) { return false; }
			if(sheet.insertRule) { sheet.insertRule(rule_name + ' { }', 0); } else { sheet.addRule(rule_name, null, 0); }
			return $.vakata.css.get_css(rule_name);
		},
		remove_css : function(rule_name, sheet) {
			return $.vakata.css.get_css(rule_name, true, sheet);
		},
		add_sheet : function(opts) {
			var tmp;
			if(opts.str) {
				tmp = document.createElement("style");
				tmp.setAttribute('type',"text/css");
				if(tmp.styleSheet) {
					document.getElementsByTagName("head")[0].appendChild(tmp);
					tmp.styleSheet.cssText = opts.str;
				}
				else {
					tmp.appendChild(document.createTextNode(opts.str));
					document.getElementsByTagName("head")[0].appendChild(tmp);
				}
				return tmp.sheet || tmp.styleSheet;
			}
			if(opts.url) {
				if(document.createStyleSheet) {
					try { tmp = document.createStyleSheet(opts.url); } catch (e) { }
				}
				else {
					tmp			= document.createElement('link');
					tmp.rel		= 'stylesheet';
					tmp.type	= 'text/css';
					tmp.media	= "all";
					tmp.href	= opts.url;
					document.getElementsByTagName("head")[0].appendChild(tmp);
					return tmp.styleSheet;
				}
			}
		}
	};


/*
 * jsTree core 1.0
 */

	// private variables
	var instances = [],			// instance array (used by $.jstree.reference/create/focused)
		focused_instance = -1,	// the index in the instance array of the currently focused instance
		plugins = {},			// list of included plugins
		prepared_move = {},		// for the move plugin
		is_ie6 = false;

	// jQuery plugin wrapper (thanks to jquery UI widget function)
	$.fn.jstree = function (settings) {
		var isMethodCall = (typeof settings == 'string'), // is this a method call like $().jstree("open_node")
			args = Array.prototype.slice.call(arguments, 1),
			returnValue = this;

		// extend settings and allow for multiple hashes and metadata
		if(!isMethodCall && $.meta) { args.push($.metadata.get(this).jstree); }
		settings = !isMethodCall && args.length ? $.extend.apply(null, [true, settings].concat(args)) : settings;
		// block calls to "private" methods
		if(isMethodCall && settings.substring(0, 1) == '_') { return returnValue; }

		// if a method call execute the method on all selected instances
		if(isMethodCall) {
			this.each(function() {
				var instance = instances[$.data(this, "jstree-instance-id")],
					methodValue = (instance && $.isFunction(instance[settings])) ? instance[settings].apply(instance, args) : instance;
					if(typeof methodValue !== "undefined" && (settings.indexOf("is_" === 0) || (methodValue !== true && methodValue !== false))) { returnValue = methodValue; return false; }
			});
		}
		else {
			this.each(function() {
				var instance_id = $.data(this, "jstree-instance-id"),
					s = false;
				// if an instance already exists, destroy it first
				if(typeof instance_id !== "undefined" && instances[instance_id]) { instances[instance_id].destroy(); }
				// push a new empty object to the instances array
				instance_id = parseInt(instances.push({}),10) - 1;
				// store the jstree instance id to the container element
				$.data(this, "jstree-instance-id", instance_id);
				// clean up all plugins
				if(!settings) { settings = {}; }
				settings.plugins = $.isArray(settings.plugins) ? settings.plugins : $.jstree.defaults.plugins;
				if($.inArray("core", settings.plugins) === -1) { settings.plugins.unshift("core"); }

				// only unique plugins (NOT WORKING)
				// settings.plugins = settings.plugins.sort().join(",,").replace(/(,|^)([^,]+)(,,\2)+(,|$)/g,"$1$2$4").replace(/,,+/g,",").replace(/,$/,"").split(",");

				// extend defaults with passed data
				s = $.extend(true, {}, $.jstree.defaults, settings);
				s.plugins = settings.plugins;
				$.each(plugins, function (i, val) { if($.inArray(i, s.plugins) === -1) { s[i] = null; delete s[i]; } });
				// push the new object to the instances array (at the same time set the default classes to the container) and init
				instances[instance_id] = new $.jstree._instance(instance_id, $(this).addClass("jstree jstree-" + instance_id), s);
				// init all activated plugins for this instance
				$.each(instances[instance_id]._get_settings().plugins, function (i, val) { instances[instance_id].data[val] = {}; });
				$.each(instances[instance_id]._get_settings().plugins, function (i, val) { if(plugins[val]) { plugins[val].__init.apply(instances[instance_id]); } });
				// initialize the instance
				instances[instance_id].init();
			});
		}
		// return the jquery selection (or if it was a method call that returned a value - the returned value)
		return returnValue;
	};
	// object to store exposed functions and objects
	$.jstree = {
		defaults : {
			plugins : []
		},
		_focused : function () { return instances[focused_instance] || null; },
		_reference : function (needle) {
			// get by instance id
			if(instances[needle]) { return instances[needle]; }
			// get by DOM (if still no luck - return null
			var o = $(needle);
			if(!o.length && typeof needle === "string") { o = $("#" + needle); }
			if(!o.length) { return null; }
			return instances[o.closest(".jstree").data("jstree-instance-id")] || null;
		},
		_instance : function (index, container, settings) {
			// for plugins to store data in
			this.data = { core : {} };
			this.get_settings	= function () { return $.extend(true, {}, settings); };
			this._get_settings	= function () { return settings; };
			this.get_index		= function () { return index; };
			this.get_container	= function () { return container; };
			this._set_settings	= function (s) {
				settings = $.extend(true, {}, settings, s);
			};
		},
		_fn : { },
		plugin : function (pname, pdata) {
			pdata = $.extend({}, {
				__init		: $.noop,
				__destroy	: $.noop,
				_fn			: {},
				defaults	: false
			}, pdata);
			plugins[pname] = pdata;

			$.jstree.defaults[pname] = pdata.defaults;
			$.each(pdata._fn, function (i, val) {
				val.plugin		= pname;
				val.old			= $.jstree._fn[i];
				$.jstree._fn[i] = function () {
					var rslt,
						func = val,
						args = Array.prototype.slice.call(arguments),
						evnt = new $.Event("before.jstree"),
						rlbk = false;

					// Check if function belongs to the included plugins of this instance
					do {
						if(func && func.plugin && $.inArray(func.plugin, this._get_settings().plugins) !== -1) { break; }
						func = func.old;
					} while(func);
					if(!func) { return; }

					// a chance to stop execution (or change arguments):
					// * just bind to jstree.before
					// * check the additional data object (func property)
					// * call event.stopImmediatePropagation()
					// * return false (or an array of arguments)
					rslt = this.get_container().triggerHandler(evnt, { "func" : i, "inst" : this, "args" : args });
					if(rslt === false) { return; }
					if(typeof rslt !== "undefined") { args = rslt; }

					// context and function to trigger events, then finally call the function
					if(i.indexOf("_") === 0) {
						rslt = func.apply(this, args);
					}
					else {
						rslt = func.apply(
							$.extend({}, this, {
								__callback : function (data) {
									this.get_container().triggerHandler( i + '.jstree', { "inst" : this, "args" : args, "rslt" : data, "rlbk" : rlbk });
								},
								__rollback : function () {
									rlbk = this.get_rollback();
									return rlbk;
								},
								__call_old : function (replace_arguments) {
									return func.old.apply(this, (replace_arguments ? Array.prototype.slice.call(arguments, 1) : args ) );
								}
							}), args);
					}

					// return the result
					return rslt;
				};
				$.jstree._fn[i].old = val.old;
				$.jstree._fn[i].plugin = pname;
			});
		},
		rollback : function (rb) {
			if(rb) {
				if(!$.isArray(rb)) { rb = [ rb ]; }
				$.each(rb, function (i, val) {
					instances[val.i].set_rollback(val.h, val.d);
				});
			}
		}
	};
	// set the prototype for all instances
	$.jstree._fn = $.jstree._instance.prototype = {};

	// css functions - used internally
/*
 * START * MODIFY * moved to base_jstree.css
	// load the css when DOM is ready
	$(function() {
		// code is copied form jQuery ($.browser is deprecated + there is a bug in IE)
		var u = navigator.userAgent.toLowerCase(),
			v = (u.match( /.+?(?:rv|it|ra|ie)[\/: ]([\d.]+)/ ) || [0,'0'])[1],
			css_string = '' +
				'.jstree ul, .jstree li { display:block; margin:0 0 0 0; padding:0 0 0 0; list-style-type:none; } ' +
				'.jstree li { display:block; min-height:18px; line-height:18px; white-space:nowrap; margin-left:18px; } ' +
				'.jstree-rtl li { margin-left:0; margin-right:18px; } ' +
				'.jstree > ul > li { margin-left:0px; } ' +
				'.jstree-rtl > ul > li { margin-right:0px; } ' +
				'.jstree ins { display:inline-block; text-decoration:none; width:18px; height:18px; margin:0 0 0 0; padding:0; } ' +
				'.jstree a { display:inline-block; line-height:16px; height:16px; color:black; white-space:nowrap; text-decoration:none; padding:1px 2px; margin:0; } ' +
				'.jstree a:focus { outline: none; } ' +
				'.jstree a > ins { height:16px; width:16px; } ' +
				'.jstree a > .jstree-icon { margin-right:3px; } ' +
				'.jstree-rtl a > .jstree-icon { margin-left:3px; margin-right:0; } ' +
				'li.jstree-open > ul { display:block; } ' +
				'li.jstree-closed > ul { display:none; } ';
		// Correct IE 6 (does not support the > CSS selector)
		if(/msie/.test(u) && parseInt(v, 10) == 6) {
			is_ie6 = true;
			css_string += '' +
				'.jstree li { height:18px; margin-left:0; margin-right:0; } ' +
				'.jstree li li { margin-left:18px; } ' +
				'.jstree-rtl li li { margin-left:0px; margin-right:18px; } ' +
				'li.jstree-open ul { display:block; } ' +
				'li.jstree-closed ul { display:none !important; } ' +
				'.jstree li a { display:inline; border-width:0 !important; padding:0px 2px !important; } ' +
				'.jstree li a ins { height:16px; width:16px; margin-right:3px; } ' +
				'.jstree-rtl li a ins { margin-right:0px; margin-left:3px; } ';
		}
		// Correct IE 7 (shifts anchor nodes onhover)
		if(/msie/.test(u) && parseInt(v, 10) == 7) {
			css_string += '.jstree li a { border-width:0 !important; padding:0px 2px !important; } ';
		}
		$.vakata.css.add_sheet({ str : css_string });
	});
 * END * MODIFY
 */
	// core functions (open, close, create, update, delete)
	$.jstree.plugin("core", {
		__init : function () {
			this.data.core.to_open = $.map($.makeArray(this.get_settings().core.initially_open), function (n) { return "#" + n.toString().replace(/^#/,"").replace('\\/','/').replace('/','\\/'); });
		},
		defaults : {
			html_titles	: false,
			animation	: 500,
			initially_open : [],
			rtl			: false,
			strings		: {
				loading		: "Loading ...",
				new_node	: "New node"
			}
		},
		_fn : {
			init	: function () {
				this.set_focus();
				if(this._get_settings().core.rtl) {
					this.get_container().addClass("jstree-rtl").css("direction", "rtl");
				}
				this.get_container().html("<ul><li class='jstree-last jstree-leaf'><ins>&#160;</ins><a class='jstree-loading' href='#'><ins class='jstree-icon'>&#160;</ins>" + this._get_settings().core.strings.loading + "</a></li></ul>");
				this.data.core.li_height = this.get_container().find("ul li.jstree-closed, ul li.jstree-leaf").eq(0).height() || 18;

				this.get_container()
					.on("click.jstree", "li > ins", $.proxy(function (event) {
							var trgt = $(event.target);
							if(trgt.is("ins") && event.pageY - trgt.offset().top < this.data.core.li_height) { this.toggle_node(trgt); }
						}, this))
					.on("mousedown.jstree", $.proxy(function () {
							this.set_focus(); // This used to be setTimeout(set_focus,0) - why?
						}, this))
					.on("dblclick.jstree", function (event) {
						var sel;
						if(document.selection && document.selection.empty) { document.selection.empty(); }
						else {
							if(window.getSelection) {
								sel = window.getSelection();
								try {
									sel.removeAllRanges();
									sel.collapse();
								} catch (err) { }
							}
						}
					});
				this.__callback();
				this.load_node(-1, function () { this.loaded(); this.reopen(); });
			},
			destroy	: function () {
				var i,
					n = this.get_index(),
					s = this._get_settings(),
					_this = this;

				$.each(s.plugins, function (i, val) {
					try { plugins[val].__destroy.apply(_this); } catch(err) { }
				});
				this.__callback();
				// set focus to another instance if this one is focused
				if(this.is_focused()) {
					for(i in instances) {
						if(instances.hasOwnProperty(i) && i != n) {
							instances[i].set_focus();
							break;
						}
					}
				}
				// if no other instance found
				if(n === focused_instance) { focused_instance = -1; }
				// remove all traces of jstree in the DOM (only the ones set using jstree*) and cleans all events
				this.get_container()
					.off(".jstree")
					.off(".jstree")
					.removeData("jstree-instance-id")
					.find("[class^='jstree']")
						.andSelf()
						.attr("class", function () { return this.className.replace(/jstree[^ ]*|$/ig,''); });
				// remove the actual data
				instances[n] = null;
				delete instances[n];
			},
			save_opened : function () {
				var _this = this;
				this.data.core.to_open = [];
				this.get_container().find(".jstree-open").each(function () {
					_this.data.core.to_open.push("#" + this.id.toString().replace(/^#/,"").replace('\\/','/').replace('/','\\/'));
				});
				this.__callback(_this.data.core.to_open);
			},
			reopen : function (is_callback) {
				var _this = this,
					done = true,
					current = [],
					remaining = [];
				if(!is_callback) { this.data.core.reopen = false; this.data.core.refreshing = true; }
				if(this.data.core.to_open.length) {
					$.each(this.data.core.to_open, function (i, val) {
						if(val == "#") { return true; }
						if($(val).length && $(val).is(".jstree-closed")) { current.push(val); }
						else { remaining.push(val); }
					});
					if(current.length) {
						this.data.core.to_open = remaining;
						$.each(current, function (i, val) {
							_this.open_node(val, function () { _this.reopen(true); }, true);
						});
						done = false;
					}
				}
				if(done) {
					// TODO: find a more elegant approach to syncronizing returning requests
					if(this.data.core.reopen) { clearTimeout(this.data.core.reopen); }
					this.data.core.reopen = setTimeout(function () { _this.__callback({}, _this); }, 50);
					this.data.core.refreshing = false;
				}
			},
			refresh : function (obj) {
				var _this = this;
				this.save_opened();
				if(!obj) { obj = -1; }
				obj = this._get_node(obj);
				if(!obj) { obj = -1; }
				if(obj !== -1) { obj.children("UL").remove(); }
				this.load_node(obj, function () { _this.__callback({ "obj" : obj}); _this.reopen(); });
			},
			// Dummy function to fire after the first load (so that there is a jstree.loaded event)
			loaded	: function () {
				this.__callback();
			},
			// deal with focus
			set_focus	: function () {
				var f = $.jstree._focused();
				if(f && f !== this) {
					f.get_container().removeClass("jstree-focused");
				}
				if(f !== this) {
					this.get_container().addClass("jstree-focused");
					focused_instance = this.get_index();
				}
				this.__callback();
			},
			is_focused	: function () {
				return focused_instance == this.get_index();
			},

			// traverse
			_get_node		: function (obj) {
				var $obj = $(obj, this.get_container());
				if($obj.is(".jstree") || obj == -1) { return -1; }
				$obj = $obj.closest("li", this.get_container());
				return $obj.length ? $obj : false;
			},
			_get_next		: function (obj, strict) {
				obj = this._get_node(obj);
				if(obj === -1) { return this.get_container().find("> ul > li:first-child"); }
				if(!obj.length) { return false; }
				if(strict) { return (obj.nextAll("li").size() > 0) ? obj.nextAll("li:eq(0)") : false; }

				if(obj.hasClass("jstree-open")) { return obj.find("li:eq(0)"); }
				else if(obj.nextAll("li").size() > 0) { return obj.nextAll("li:eq(0)"); }
				else { return obj.parentsUntil(".jstree","li").next("li").eq(0); }
			},
			_get_prev		: function (obj, strict) {
				obj = this._get_node(obj);
				if(obj === -1) { return this.get_container().find("> ul > li:last-child"); }
				if(!obj.length) { return false; }
				if(strict) { return (obj.prevAll("li").length > 0) ? obj.prevAll("li:eq(0)") : false; }

				if(obj.prev("li").length) {
					obj = obj.prev("li").eq(0);
					while(obj.hasClass("jstree-open")) { obj = obj.children("ul:eq(0)").children("li:last"); }
					return obj;
				}
				else { var o = obj.parentsUntil(".jstree","li:eq(0)"); return o.length ? o : false; }
			},
			_get_parent		: function (obj) {
				obj = this._get_node(obj);
				if(obj == -1 || !obj.length) { return false; }
				var o = obj.parentsUntil(".jstree", "li:eq(0)");
				return o.length ? o : -1;
			},
			_get_children	: function (obj) {
				obj = this._get_node(obj);
				if(obj === -1) { return this.get_container().children("ul:eq(0)").children("li"); }
				if(!obj.length) { return false; }
				return obj.children("ul:eq(0)").children("li");
			},
			get_path		: function (obj, id_mode) {
				var p = [],
					_this = this;
				obj = this._get_node(obj);
				if(obj === -1 || !obj || !obj.length) { return false; }
				obj.parentsUntil(".jstree", "li").each(function () {
					p.push( id_mode ? this.id : _this.get_text(this) );
				});
				p.reverse();
				p.push( id_mode ? obj.attr("id") : this.get_text(obj) );
				return p;
			},

			is_open		: function (obj) { obj = this._get_node(obj); return obj && obj !== -1 && obj.hasClass("jstree-open"); },
			is_closed	: function (obj) { obj = this._get_node(obj); return obj && obj !== -1 && obj.hasClass("jstree-closed"); },
			is_leaf		: function (obj) { obj = this._get_node(obj); return obj && obj !== -1 && obj.hasClass("jstree-leaf"); },
			// open/close
			open_node	: function (obj, callback, skip_animation) {
				obj = this._get_node(obj);
				if(!obj.length) { return false; }
				if(!obj.hasClass("jstree-closed")) { if(callback) { callback.call(); } return false; }
				var s = skip_animation || is_ie6 ? 0 : this._get_settings().core.animation,
					t = this;
				if(!this._is_loaded(obj)) {
					obj.children("a").addClass("jstree-loading");
					this.load_node(obj, function () { t.open_node(obj, callback, skip_animation); }, callback);
				}
				else {
					if(s) { obj.children("ul").css("display","none"); }
					obj.removeClass("jstree-closed").addClass("jstree-open").children("a").removeClass("jstree-loading");
					if(s) { obj.children("ul").stop(true).slideDown(s, function () { this.style.display = ""; }); }
					this.__callback({ "obj" : obj });
					if(callback) { callback.call(); }
				}
			},
			close_node	: function (obj, skip_animation) {
				obj = this._get_node(obj);
				var s = skip_animation || is_ie6 ? 0 : this._get_settings().core.animation;
				if(!obj.length || !obj.hasClass("jstree-open")) { return false; }
				if(s) { obj.children("ul").attr("style","display:block !important"); }
				obj.removeClass("jstree-open").addClass("jstree-closed");
				if(s) { obj.children("ul").stop(true).slideUp(s, function () { this.style.display = ""; }); }
				this.__callback({ "obj" : obj });
			},
			toggle_node	: function (obj) {
				obj = this._get_node(obj);
				if(obj.hasClass("jstree-closed")) { return this.open_node(obj); }
				if(obj.hasClass("jstree-open")) { return this.close_node(obj); }
			},
			open_all	: function (obj, original_obj) {
				obj = obj ? this._get_node(obj) : this.get_container();
				if(!obj || obj === -1) { obj = this.get_container(); }
				if(original_obj) {
					obj = obj.find("li.jstree-closed");
				}
				else {
					original_obj = obj;
					if(obj.is(".jstree-closed")) { obj = obj.find("li.jstree-closed").andSelf(); }
					else { obj = obj.find("li.jstree-closed"); }
				}
				var _this = this;
				obj.each(function () {
					var __this = this;
					if(!_this._is_loaded(this)) { _this.open_node(this, function() { _this.open_all(__this, original_obj); }, true); }
					else { _this.open_node(this, false, true); }
				});
				// so that callback is fired AFTER all nodes are open
				if(original_obj.find('li.jstree-closed').length === 0) { this.__callback({ "obj" : original_obj }); }
			},
			close_all	: function (obj) {
				var _this = this;
				obj = obj ? this._get_node(obj) : this.get_container();
				if(!obj || obj === -1) { obj = this.get_container(); }
				obj.find("li.jstree-open").andSelf().each(function () { _this.close_node(this); });
				this.__callback({ "obj" : obj });
			},
			clean_node	: function (obj) {
				obj = obj && obj != -1 ? $(obj) : this.get_container();
				obj = obj.is("li") ? obj.find("li").andSelf() : obj.find("li");
				obj.removeClass("jstree-last")
					.filter("li:last-child").addClass("jstree-last").end()
					.filter(":has(li)")
						.not(".jstree-open").removeClass("jstree-leaf").addClass("jstree-closed");
				obj.not(".jstree-open, .jstree-closed").addClass("jstree-leaf").children("ul").remove();
				this.__callback({ "obj" : obj });
			},
			// rollback
			get_rollback : function () {
				this.__callback();
				return { i : this.get_index(), h : this.get_container().children("ul").clone(true), d : this.data };
			},
			set_rollback : function (html, data) {
				this.get_container().empty().append(html);
				this.data = data;
				this.__callback();
			},
			// Dummy functions to be overwritten by any datastore plugin included
			load_node	: function (obj, s_call, e_call) { this.__callback({ "obj" : obj }); },
			_is_loaded	: function (obj) { return true; },

			// Basic operations: create
			create_node	: function (obj, position, js, callback, is_loaded) {
				obj = this._get_node(obj);
				position = typeof position === "undefined" ? "last" : position;
				var d = $("<li>"),
					s = this._get_settings().core,
					tmp;

				if(obj !== -1 && !obj.length) { return false; }
				if(!is_loaded && !this._is_loaded(obj)) { this.load_node(obj, function () { this.create_node(obj, position, js, callback, true); }); return false; }

				this.__rollback();

				if(typeof js === "string") { js = { "data" : js }; }
				if(!js) { js = {}; }
				if(js.attr) { d.attr(js.attr); }
				if(js.state) { d.addClass("jstree-" + js.state); }
				if(!js.data) { js.data = s.strings.new_node; }
				if(!$.isArray(js.data)) { tmp = js.data; js.data = []; js.data.push(tmp); }
				$.each(js.data, function (i, m) {
					tmp = $("<a>");
					if($.isFunction(m)) { m = m.call(this, js); }
					if(typeof m == "string") { tmp.attr('href','#')[ s.html_titles ? "html" : "text" ](m); }
					else {
						if(!m.attr) { m.attr = {}; }
						if(!m.attr.href) { m.attr.href = '#'; }
						tmp.attr(m.attr)[ s.html_titles ? "html" : "text" ](m.title);
						if(m.language) { tmp.addClass(m.language); }
					}
					tmp.prepend("<ins class='jstree-icon'>&#160;</ins>");
					if(m.icon) {
						if(m.icon.indexOf("/") === -1) { tmp.children("ins").addClass(m.icon); }
						else { tmp.children("ins").css("background","url('" + m.icon + "') center center no-repeat"); }
					}
					d.append(tmp);
				});
				d.prepend("<ins class='jstree-icon'>&#160;</ins>");
				if(obj === -1) {
					obj = this.get_container();
					if(position === "before") { position = "first"; }
					if(position === "after") { position = "last"; }
				}
				switch(position) {
					case "before": obj.before(d); tmp = this._get_parent(obj); break;
					case "after" : obj.after(d);  tmp = this._get_parent(obj); break;
					case "inside":
					case "first" :
						if(!obj.children("ul").length) { obj.append("<ul>"); }
						obj.children("ul").prepend(d);
						tmp = obj;
						break;
					case "last":
						if(!obj.children("ul").length) { obj.append("<ul>"); }
						obj.children("ul").append(d);
						tmp = obj;
						break;
					default:
						if(!obj.children("ul").length) { obj.append("<ul>"); }
						if(!position) { position = 0; }
						tmp = obj.children("ul").children("li").eq(position);
						if(tmp.length) { tmp.before(d); }
						else { obj.children("ul").append(d); }
						tmp = obj;
						break;
				}
				if(tmp === -1 || tmp.get(0) === this.get_container().get(0)) { tmp = -1; }
				this.clean_node(tmp);
				this.__callback({ "obj" : d, "parent" : tmp });
				if(callback) { callback.call(this, d); }
				return d;
			},
			// Basic operations: rename (deal with text)
			get_text	: function (obj) {
				obj = this._get_node(obj);
				if(!obj.length) { return false; }
				var s = this._get_settings().core.html_titles;
				obj = obj.children("a:eq(0)");
				if(s) {
					obj = obj.clone();
					obj.children("INS").remove();
					return obj.html();
				}
				else {
					obj = obj.contents().filter(function() { return this.nodeType == 3; })[0];
					return obj.nodeValue;
				}
			},
			set_text	: function (obj, val) {
				obj = this._get_node(obj);
				if(!obj.length) { return false; }
				obj = obj.children("a:eq(0)");
				if(this._get_settings().core.html_titles) {
					var tmp = obj.children("INS").clone();
					obj.html(val).prepend(tmp);
					this.__callback({ "obj" : obj, "name" : val });
					return true;
				}
				else {
					obj = obj.contents().filter(function() { return this.nodeType == 3; })[0];
					this.__callback({ "obj" : obj, "name" : val });
					return (obj.nodeValue = val);
				}
			},
			rename_node : function (obj, val) {
				obj = this._get_node(obj);
				this.__rollback();
				if(obj && obj.length && this.set_text.apply(this, Array.prototype.slice.call(arguments))) { this.__callback({ "obj" : obj, "name" : val }); }
			},
			// Basic operations: deleting nodes
			delete_node : function (obj) {
				obj = this._get_node(obj);
				if(!obj.length) { return false; }
				this.__rollback();
				var p = this._get_parent(obj), prev = this._get_prev(obj);
				obj = obj.remove();
				if(p !== -1 && p.find("> ul > li").length === 0) {
					p.removeClass("jstree-open jstree-closed").addClass("jstree-leaf");
				}
				this.clean_node(p);
				this.__callback({ "obj" : obj, "prev" : prev });
				return obj;
			},
			prepare_move : function (o, r, pos, cb, is_cb) {
				var p = {};

				p.ot = $.jstree._reference(p.o) || this;
				p.o = p.ot._get_node(o);
				p.r = r === - 1 ? -1 : this._get_node(r);
				p.p = (typeof p === "undefined") ? "last" : pos; // TODO: move to a setting
				if(!is_cb && prepared_move.o && prepared_move.o[0] === p.o[0] && prepared_move.r[0] === p.r[0] && prepared_move.p === p.p) {
					this.__callback(prepared_move);
					if(cb) { cb.call(this, prepared_move); }
					return;
				}
				p.ot = $.jstree._reference(p.o) || this;
				p.rt = r === -1 ? p.ot : $.jstree._reference(p.r) || this;
				if(p.r === -1) {
					p.cr = -1;
					switch(p.p) {
						case "first":
						case "before":
						case "inside":
							p.cp = 0;
							break;
						case "after":
						case "last":
							p.cp = p.rt.get_container().find(" > ul > li").length;
							break;
						default:
							p.cp = p.p;
							break;
					}
				}
				else {
					if(!/^(before|after)$/.test(p.p) && !this._is_loaded(p.r)) {
						return this.load_node(p.r, function () { this.prepare_move(o, r, pos, cb, true); });
					}
					switch(p.p) {
						case "before":
							p.cp = p.r.index();
							p.cr = p.rt._get_parent(p.r);
							break;
						case "after":
							p.cp = p.r.index() + 1;
							p.cr = p.rt._get_parent(p.r);
							break;
						case "inside":
						case "first":
							p.cp = 0;
							p.cr = p.r;
							break;
						case "last":
							p.cp = p.r.find(" > ul > li").length;
							p.cr = p.r;
							break;
						default:
							p.cp = p.p;
							p.cr = p.r;
							break;
					}
				}
				p.np = p.cr == -1 ? p.rt.get_container() : p.cr;
				p.op = p.ot._get_parent(p.o);
				p.or = p.np.find(" > ul > li:nth-child(" + (p.cp + 1) + ")");

				prepared_move = p;
				this.__callback(prepared_move);
				if(cb) { cb.call(this, prepared_move); }
			},
			check_move : function () {
				var obj = prepared_move, ret = true;
				if(obj.or[0] === obj.o[0]) { return false; }
				obj.o.each(function () {
					if(obj.r.parentsUntil(".jstree").andSelf().filter("li").index(this) !== -1) { ret = false; return false; }
				});
				return ret;
			},
			move_node : function (obj, ref, position, is_copy, is_prepared, skip_check) {
				if(!is_prepared) {
					return this.prepare_move(obj, ref, position, function (p) {
						this.move_node(p, false, false, is_copy, true, skip_check);
					});
				}
				if(!skip_check && !this.check_move()) { return false; }

				this.__rollback();
				var o = false;
				if(is_copy) {
					o = obj.o.clone();
					o.find("*[id]").andSelf().each(function () {
						if(this.id) { this.id = "copy_" + this.id; }
					});
				}
				else { o = obj.o; }

				if(obj.or.length) { obj.or.before(o); }
				else {
					if(!obj.np.children("ul").length) { $("<ul>").appendTo(obj.np); }
					obj.np.children("ul:eq(0)").append(o);
				}

				try {
					obj.ot.clean_node(obj.op);
					obj.rt.clean_node(obj.np);
					if(!obj.op.find("> ul > li").length) {
						obj.op.removeClass("jstree-open jstree-closed").addClass("jstree-leaf").children("ul").remove();
					}
				} catch (e) { }

				if(is_copy) {
					prepared_move.cy = true;
					prepared_move.oc = o;
				}
				this.__callback(prepared_move);
				return prepared_move;
			},
			_get_move : function () { return prepared_move; }
		}
	});

	return $;

});

/* ---- Module:jquery.jstree.themes ---- */

define("jquery/jstree/themes", ["jquery/jstree"], function ($) {

/*
 * jsTree themes plugin 1.0
 * Handles loading and setting themes, as well as detecting path to themes, etc.
 */

	var themes_loaded = [];
	// this variable stores the path to the themes folder - if left as false - it will be autodetected
	$.jstree._themes = false;
	$.jstree.plugin("themes", {
		__init : function () {
			this.get_container()
				.on("init.jstree", $.proxy(function () {
						var s = this._get_settings().themes;
						this.data.themes.dots = s.dots;
						this.data.themes.icons = s.icons;
						//alert(s.dots);
						this.set_theme(s.theme, s.url);
					}, this))
				.on("loaded.jstree", $.proxy(function () {
						// bound here too, as simple HTML tree's won't honor dots & icons otherwise
						if(!this.data.themes.dots) { this.hide_dots(); }
						else { this.show_dots(); }
						if(!this.data.themes.icons) { this.hide_icons(); }
						else { this.show_icons(); }
					}, this));
		},
		defaults : {
			theme : "default",
			url : false,
			dots : true,
			icons : true
		},
		_fn : {
			set_theme : function (theme_name, theme_url) {
				if(!theme_name) { return false; }
/*
 * START * MODIFY * do not load an other css file for theme
				if(!theme_url) { theme_url = $.jstree._themes + theme_name + '/style.css'; }
				if($.inArray(theme_url, themes_loaded) == -1) {
					$.vakata.css.add_sheet({ "url" : theme_url, "rel" : "jstree" });
					themes_loaded.push(theme_url);
				}
 * END * MODIFY
 */
				if(this.data.themes.theme != theme_name) {
					this.get_container().removeClass('jstree-' + this.data.themes.theme);
					this.data.themes.theme = theme_name;
				}
				this.get_container().addClass('jstree-' + theme_name);
				if(!this.data.themes.dots) { this.hide_dots(); }
				else { this.show_dots(); }
				if(!this.data.themes.icons) { this.hide_icons(); }
				else { this.show_icons(); }
				this.__callback();
			},
			get_theme	: function () { return this.data.themes.theme; },

			show_dots	: function () { this.data.themes.dots = true; this.get_container().children("ul").removeClass("jstree-no-dots"); },
			hide_dots	: function () { this.data.themes.dots = false; this.get_container().children("ul").addClass("jstree-no-dots"); },
			toggle_dots	: function () { if(this.data.themes.dots) { this.hide_dots(); } else { this.show_dots(); } },

			show_icons	: function () { this.data.themes.icons = true; this.get_container().children("ul").removeClass("jstree-no-icons"); },
			hide_icons	: function () { this.data.themes.icons = false; this.get_container().children("ul").addClass("jstree-no-icons"); },
			toggle_icons: function () { if(this.data.themes.icons) { this.hide_icons(); } else { this.show_icons(); } }
		}
	});
	// autodetect themes path
	$(function () {
		if($.jstree._themes === false) {
			$("script").each(function () {
				if(this.src.toString().match(/jquery\.jstree[^\/]*?\.js(\?.*)?$/)) {
					$.jstree._themes = this.src.toString().replace(/jquery\.jstree[^\/]*?\.js(\?.*)?$/, "") + 'themes/';
					return false;
				}
			});
		}
		if($.jstree._themes === false) { $.jstree._themes = "themes/"; }
	});
	// include the themes plugin by default
	$.jstree.defaults.plugins.push("themes");

	return $;

});

/* ---- Module:jquery.jstree.html_data ---- */

define("jquery/jstree/html_data", ["jquery/jstree"], function ($) {

/*
 * jsTree HTML data 1.0
 * The HTML data store. Datastores are build by replacing the `load_node` and `_is_loaded` functions.
 */

	$.jstree.plugin("html_data", {
		__init : function () {
			// this used to use html() and clean the whitespace, but this way any attached data was lost
			this.data.html_data.original_container_html = this.get_container().find(" > ul > li").clone(true);
			// remove white space from LI node - otherwise nodes appear a bit to the right
			this.data.html_data.original_container_html.find("li").andSelf().contents().filter(function() { return this.nodeType == 3; }).remove();
		},
		defaults : {
			data : false,
			ajax : false,
			correct_state : true
		},
		_fn : {
			load_node : function (obj, s_call, e_call) { var _this = this; this.load_node_html(obj, function () { _this.__callback({ "obj" : obj }); s_call.call(this); }, e_call); },
			_is_loaded : function (obj) {
				obj = this._get_node(obj);
				return obj == -1 || !obj || !this._get_settings().html_data.ajax || obj.is(".jstree-open, .jstree-leaf") || obj.children("ul").children("li").size() > 0;
			},
			load_node_html : function (obj, s_call, e_call) {
				var d,
					s = this.get_settings().html_data,
					error_func = function () {},
					success_func = function () {};
				obj = this._get_node(obj);
				if(obj && obj !== -1) {
					if(obj.data("jstree-is-loading")) { return; }
					else { obj.data("jstree-is-loading",true); }
				}
				switch(!0) {
					case (!s.data && !s.ajax):
						if(!obj || obj == -1) {
							this.get_container()
								.children("ul").empty()
								.append(this.data.html_data.original_container_html)
								.find("li, a").filter(function () { return this.firstChild.tagName !== "INS"; }).prepend("<ins class='jstree-icon'>&#160;</ins>").end()
								.filter("a").children("ins:first-child").not(".jstree-icon").addClass("jstree-icon");
							this.clean_node();
						}
						if(s_call) { s_call.call(this); }
						break;
					case (!!s.data && !s.ajax) || (!!s.data && !!s.ajax && (!obj || obj === -1)):
						if(!obj || obj == -1) {
							d = $(s.data);
							if(!d.is("ul")) { d = $("<ul>").append(d); }
							this.get_container()
								.children("ul").empty().append(d.children())
								.find("li, a").filter(function () { return this.firstChild.tagName !== "INS"; }).prepend("<ins class='jstree-icon'>&#160;</ins>").end()
								.filter("a").children("ins:first-child").not(".jstree-icon").addClass("jstree-icon");
							this.clean_node();
						}
						if(s_call) { s_call.call(this); }
						break;
					case (!s.data && !!s.ajax) || (!!s.data && !!s.ajax && obj && obj !== -1):
						obj = this._get_node(obj);
						error_func = function (x, t, e) {
							var ef = this.get_settings().html_data.ajax.error;
							if(ef) { ef.call(this, x, t, e); }
							if(obj != -1 && obj.length) {
								obj.children(".jstree-loading").removeClass("jstree-loading");
								obj.data("jstree-is-loading",false);
								if(t === "success" && s.correct_state) { obj.removeClass("jstree-open jstree-closed").addClass("jstree-leaf"); }
							}
							else {
								if(t === "success" && s.correct_state) { this.get_container().children("ul").empty(); }
							}
							if(e_call) { e_call.call(this); }
						};
						success_func = function (d, t, x) {
							var sf = this.get_settings().html_data.ajax.success;
							if(sf) { d = sf.call(this,d,t,x) || d; }
							if(d == "") {
								return error_func.call(this, x, t, "");
							}
							if(d) {
								d = $(d);
								if(!d.is("ul")) { d = $("<ul>").append(d); }
								if(obj == -1 || !obj) { this.get_container().children("ul").empty().append(d.children()).find("li, a").filter(function () { return this.firstChild.tagName !== "INS"; }).prepend("<ins class='jstree-icon'>&#160;</ins>").end().filter("a").children("ins:first-child").not(".jstree-icon").addClass("jstree-icon"); }
								else { obj.children(".jstree-loading").removeClass("jstree-loading"); obj.append(d).find("li, a").filter(function () { return this.firstChild.tagName !== "INS"; }).prepend("<ins class='jstree-icon'>&#160;</ins>").end().filter("a").children("ins:first-child").not(".jstree-icon").addClass("jstree-icon"); obj.data("jstree-is-loading",false); }
								this.clean_node(obj);
								if(s_call) { s_call.call(this); }
							}
							else {
								if(obj && obj !== -1) {
									obj.children(".jstree-loading").removeClass("jstree-loading");
									obj.data("jstree-is-loading",false);
									if(s.correct_state) {
										obj.removeClass("jstree-open jstree-closed").addClass("jstree-leaf");
										if(s_call) { s_call.call(this); }
									}
								}
								else {
									if(s.correct_state) {
										this.get_container().children("ul").empty();
										if(s_call) { s_call.call(this); }
									}
								}
							}
						};
						s.ajax.context = this;
						s.ajax.error = error_func;
						s.ajax.success = success_func;
						if(!s.ajax.dataType) { s.ajax.dataType = "html"; }
						if($.isFunction(s.ajax.url)) { s.ajax.url = s.ajax.url.call(this, obj); }
						if($.isFunction(s.ajax.data)) { s.ajax.data = s.ajax.data.call(this, obj); }
						$.ajax(s.ajax);
						break;
				}
			}
		}
	});
	// include the HTML data plugin by default
	$.jstree.defaults.plugins.push("html_data");

	return $;

});

/* ---- Module:jquery.effects ---- */

define("jquery/effects", ["jquery"], function (jQuery) {

/*!
 * jQuery UI Effects 1.10.2
 * http://jqueryui.com
 *
 * Copyright 2013 jQuery Foundation and other contributors
 * Released under the MIT license.
 * http://jquery.org/license
 *
 * http://api.jqueryui.com/category/effects-core/
 */
(function($, undefined) {

var dataSpace = "ui-effects-";

$.effects = {
	effect: {}
};

/*!
 * jQuery Color Animations v2.1.2
 * https://github.com/jquery/jquery-color
 *
 * Copyright 2013 jQuery Foundation and other contributors
 * Released under the MIT license.
 * http://jquery.org/license
 *
 * Date: Wed Jan 16 08:47:09 2013 -0600
 */
(function( jQuery, undefined ) {

	var stepHooks = "backgroundColor borderBottomColor borderLeftColor borderRightColor borderTopColor color columnRuleColor outlineColor textDecorationColor textEmphasisColor",

	// plusequals test for += 100 -= 100
	rplusequals = /^([\-+])=\s*(\d+\.?\d*)/,
	// a set of RE's that can match strings and generate color tuples.
	stringParsers = [{
			re: /rgba?\(\s*(\d{1,3})\s*,\s*(\d{1,3})\s*,\s*(\d{1,3})\s*(?:,\s*(\d?(?:\.\d+)?)\s*)?\)/,
			parse: function( execResult ) {
				return [
					execResult[ 1 ],
					execResult[ 2 ],
					execResult[ 3 ],
					execResult[ 4 ]
				];
			}
		}, {
			re: /rgba?\(\s*(\d+(?:\.\d+)?)\%\s*,\s*(\d+(?:\.\d+)?)\%\s*,\s*(\d+(?:\.\d+)?)\%\s*(?:,\s*(\d?(?:\.\d+)?)\s*)?\)/,
			parse: function( execResult ) {
				return [
					execResult[ 1 ] * 2.55,
					execResult[ 2 ] * 2.55,
					execResult[ 3 ] * 2.55,
					execResult[ 4 ]
				];
			}
		}, {
			// this regex ignores A-F because it's compared against an already lowercased string
			re: /#([a-f0-9]{2})([a-f0-9]{2})([a-f0-9]{2})/,
			parse: function( execResult ) {
				return [
					parseInt( execResult[ 1 ], 16 ),
					parseInt( execResult[ 2 ], 16 ),
					parseInt( execResult[ 3 ], 16 )
				];
			}
		}, {
			// this regex ignores A-F because it's compared against an already lowercased string
			re: /#([a-f0-9])([a-f0-9])([a-f0-9])/,
			parse: function( execResult ) {
				return [
					parseInt( execResult[ 1 ] + execResult[ 1 ], 16 ),
					parseInt( execResult[ 2 ] + execResult[ 2 ], 16 ),
					parseInt( execResult[ 3 ] + execResult[ 3 ], 16 )
				];
			}
		}, {
			re: /hsla?\(\s*(\d+(?:\.\d+)?)\s*,\s*(\d+(?:\.\d+)?)\%\s*,\s*(\d+(?:\.\d+)?)\%\s*(?:,\s*(\d?(?:\.\d+)?)\s*)?\)/,
			space: "hsla",
			parse: function( execResult ) {
				return [
					execResult[ 1 ],
					execResult[ 2 ] / 100,
					execResult[ 3 ] / 100,
					execResult[ 4 ]
				];
			}
		}],

	// jQuery.Color( )
	color = jQuery.Color = function( color, green, blue, alpha ) {
		return new jQuery.Color.fn.parse( color, green, blue, alpha );
	},
	spaces = {
		rgba: {
			props: {
				red: {
					idx: 0,
					type: "byte"
				},
				green: {
					idx: 1,
					type: "byte"
				},
				blue: {
					idx: 2,
					type: "byte"
				}
			}
		},

		hsla: {
			props: {
				hue: {
					idx: 0,
					type: "degrees"
				},
				saturation: {
					idx: 1,
					type: "percent"
				},
				lightness: {
					idx: 2,
					type: "percent"
				}
			}
		}
	},
	propTypes = {
		"byte": {
			floor: true,
			max: 255
		},
		"percent": {
			max: 1
		},
		"degrees": {
			mod: 360,
			floor: true
		}
	},
	support = color.support = {},

	// element for support tests
	supportElem = jQuery( "<p>" )[ 0 ],

	// colors = jQuery.Color.names
	colors,

	// local aliases of functions called often
	each = jQuery.each;

// determine rgba support immediately
supportElem.style.cssText = "background-color:rgba(1,1,1,.5)";
support.rgba = supportElem.style.backgroundColor.indexOf( "rgba" ) > -1;

// define cache name and alpha properties
// for rgba and hsla spaces
each( spaces, function( spaceName, space ) {
	space.cache = "_" + spaceName;
	space.props.alpha = {
		idx: 3,
		type: "percent",
		def: 1
	};
});

function clamp( value, prop, allowEmpty ) {
	var type = propTypes[ prop.type ] || {};

	if ( value == null ) {
		return (allowEmpty || !prop.def) ? null : prop.def;
	}

	// ~~ is an short way of doing floor for positive numbers
	value = type.floor ? ~~value : parseFloat( value );

	// IE will pass in empty strings as value for alpha,
	// which will hit this case
	if ( isNaN( value ) ) {
		return prop.def;
	}

	if ( type.mod ) {
		// we add mod before modding to make sure that negatives values
		// get converted properly: -10 -> 350
		return (value + type.mod) % type.mod;
	}

	// for now all property types without mod have min and max
	return 0 > value ? 0 : type.max < value ? type.max : value;
}

function stringParse( string ) {
	var inst = color(),
		rgba = inst._rgba = [];

	string = string.toLowerCase();

	each( stringParsers, function( i, parser ) {
		var parsed,
			match = parser.re.exec( string ),
			values = match && parser.parse( match ),
			spaceName = parser.space || "rgba";

		if ( values ) {
			parsed = inst[ spaceName ]( values );

			// if this was an rgba parse the assignment might happen twice
			// oh well....
			inst[ spaces[ spaceName ].cache ] = parsed[ spaces[ spaceName ].cache ];
			rgba = inst._rgba = parsed._rgba;

			// exit each( stringParsers ) here because we matched
			return false;
		}
	});

	// Found a stringParser that handled it
	if ( rgba.length ) {

		// if this came from a parsed string, force "transparent" when alpha is 0
		// chrome, (and maybe others) return "transparent" as rgba(0,0,0,0)
		if ( rgba.join() === "0,0,0,0" ) {
			jQuery.extend( rgba, colors.transparent );
		}
		return inst;
	}

	// named colors
	return colors[ string ];
}

color.fn = jQuery.extend( color.prototype, {
	parse: function( red, green, blue, alpha ) {
		if ( red === undefined ) {
			this._rgba = [ null, null, null, null ];
			return this;
		}
		if ( red.jquery || red.nodeType ) {
			red = jQuery( red ).css( green );
			green = undefined;
		}

		var inst = this,
			type = jQuery.type( red ),
			rgba = this._rgba = [];

		// more than 1 argument specified - assume ( red, green, blue, alpha )
		if ( green !== undefined ) {
			red = [ red, green, blue, alpha ];
			type = "array";
		}

		if ( type === "string" ) {
			return this.parse( stringParse( red ) || colors._default );
		}

		if ( type === "array" ) {
			each( spaces.rgba.props, function( key, prop ) {
				rgba[ prop.idx ] = clamp( red[ prop.idx ], prop );
			});
			return this;
		}

		if ( type === "object" ) {
			if ( red instanceof color ) {
				each( spaces, function( spaceName, space ) {
					if ( red[ space.cache ] ) {
						inst[ space.cache ] = red[ space.cache ].slice();
					}
				});
			} else {
				each( spaces, function( spaceName, space ) {
					var cache = space.cache;
					each( space.props, function( key, prop ) {

						// if the cache doesn't exist, and we know how to convert
						if ( !inst[ cache ] && space.to ) {

							// if the value was null, we don't need to copy it
							// if the key was alpha, we don't need to copy it either
							if ( key === "alpha" || red[ key ] == null ) {
								return;
							}
							inst[ cache ] = space.to( inst._rgba );
						}

						// this is the only case where we allow nulls for ALL properties.
						// call clamp with alwaysAllowEmpty
						inst[ cache ][ prop.idx ] = clamp( red[ key ], prop, true );
					});

					// everything defined but alpha?
					if ( inst[ cache ] && jQuery.inArray( null, inst[ cache ].slice( 0, 3 ) ) < 0 ) {
						// use the default of 1
						inst[ cache ][ 3 ] = 1;
						if ( space.from ) {
							inst._rgba = space.from( inst[ cache ] );
						}
					}
				});
			}
			return this;
		}
	},
	is: function( compare ) {
		var is = color( compare ),
			same = true,
			inst = this;

		each( spaces, function( _, space ) {
			var localCache,
				isCache = is[ space.cache ];
			if (isCache) {
				localCache = inst[ space.cache ] || space.to && space.to( inst._rgba ) || [];
				each( space.props, function( _, prop ) {
					if ( isCache[ prop.idx ] != null ) {
						same = ( isCache[ prop.idx ] === localCache[ prop.idx ] );
						return same;
					}
				});
			}
			return same;
		});
		return same;
	},
	_space: function() {
		var used = [],
			inst = this;
		each( spaces, function( spaceName, space ) {
			if ( inst[ space.cache ] ) {
				used.push( spaceName );
			}
		});
		return used.pop();
	},
	transition: function( other, distance ) {
		var end = color( other ),
			spaceName = end._space(),
			space = spaces[ spaceName ],
			startColor = this.alpha() === 0 ? color( "transparent" ) : this,
			start = startColor[ space.cache ] || space.to( startColor._rgba ),
			result = start.slice();

		end = end[ space.cache ];
		each( space.props, function( key, prop ) {
			var index = prop.idx,
				startValue = start[ index ],
				endValue = end[ index ],
				type = propTypes[ prop.type ] || {};

			// if null, don't override start value
			if ( endValue === null ) {
				return;
			}
			// if null - use end
			if ( startValue === null ) {
				result[ index ] = endValue;
			} else {
				if ( type.mod ) {
					if ( endValue - startValue > type.mod / 2 ) {
						startValue += type.mod;
					} else if ( startValue - endValue > type.mod / 2 ) {
						startValue -= type.mod;
					}
				}
				result[ index ] = clamp( ( endValue - startValue ) * distance + startValue, prop );
			}
		});
		return this[ spaceName ]( result );
	},
	blend: function( opaque ) {
		// if we are already opaque - return ourself
		if ( this._rgba[ 3 ] === 1 ) {
			return this;
		}

		var rgb = this._rgba.slice(),
			a = rgb.pop(),
			blend = color( opaque )._rgba;

		return color( jQuery.map( rgb, function( v, i ) {
			return ( 1 - a ) * blend[ i ] + a * v;
		}));
	},
	toRgbaString: function() {
		var prefix = "rgba(",
			rgba = jQuery.map( this._rgba, function( v, i ) {
				return v == null ? ( i > 2 ? 1 : 0 ) : v;
			});

		if ( rgba[ 3 ] === 1 ) {
			rgba.pop();
			prefix = "rgb(";
		}

		return prefix + rgba.join() + ")";
	},
	toHslaString: function() {
		var prefix = "hsla(",
			hsla = jQuery.map( this.hsla(), function( v, i ) {
				if ( v == null ) {
					v = i > 2 ? 1 : 0;
				}

				// catch 1 and 2
				if ( i && i < 3 ) {
					v = Math.round( v * 100 ) + "%";
				}
				return v;
			});

		if ( hsla[ 3 ] === 1 ) {
			hsla.pop();
			prefix = "hsl(";
		}
		return prefix + hsla.join() + ")";
	},
	toHexString: function( includeAlpha ) {
		var rgba = this._rgba.slice(),
			alpha = rgba.pop();

		if ( includeAlpha ) {
			rgba.push( ~~( alpha * 255 ) );
		}

		return "#" + jQuery.map( rgba, function( v ) {

			// default to 0 when nulls exist
			v = ( v || 0 ).toString( 16 );
			return v.length === 1 ? "0" + v : v;
		}).join("");
	},
	toString: function() {
		return this._rgba[ 3 ] === 0 ? "transparent" : this.toRgbaString();
	}
});
color.fn.parse.prototype = color.fn;

// hsla conversions adapted from:
// https://code.google.com/p/maashaack/source/browse/packages/graphics/trunk/src/graphics/colors/HUE2RGB.as?r=5021

function hue2rgb( p, q, h ) {
	h = ( h + 1 ) % 1;
	if ( h * 6 < 1 ) {
		return p + (q - p) * h * 6;
	}
	if ( h * 2 < 1) {
		return q;
	}
	if ( h * 3 < 2 ) {
		return p + (q - p) * ((2/3) - h) * 6;
	}
	return p;
}

spaces.hsla.to = function ( rgba ) {
	if ( rgba[ 0 ] == null || rgba[ 1 ] == null || rgba[ 2 ] == null ) {
		return [ null, null, null, rgba[ 3 ] ];
	}
	var r = rgba[ 0 ] / 255,
		g = rgba[ 1 ] / 255,
		b = rgba[ 2 ] / 255,
		a = rgba[ 3 ],
		max = Math.max( r, g, b ),
		min = Math.min( r, g, b ),
		diff = max - min,
		add = max + min,
		l = add * 0.5,
		h, s;

	if ( min === max ) {
		h = 0;
	} else if ( r === max ) {
		h = ( 60 * ( g - b ) / diff ) + 360;
	} else if ( g === max ) {
		h = ( 60 * ( b - r ) / diff ) + 120;
	} else {
		h = ( 60 * ( r - g ) / diff ) + 240;
	}

	// chroma (diff) == 0 means greyscale which, by definition, saturation = 0%
	// otherwise, saturation is based on the ratio of chroma (diff) to lightness (add)
	if ( diff === 0 ) {
		s = 0;
	} else if ( l <= 0.5 ) {
		s = diff / add;
	} else {
		s = diff / ( 2 - add );
	}
	return [ Math.round(h) % 360, s, l, a == null ? 1 : a ];
};

spaces.hsla.from = function ( hsla ) {
	if ( hsla[ 0 ] == null || hsla[ 1 ] == null || hsla[ 2 ] == null ) {
		return [ null, null, null, hsla[ 3 ] ];
	}
	var h = hsla[ 0 ] / 360,
		s = hsla[ 1 ],
		l = hsla[ 2 ],
		a = hsla[ 3 ],
		q = l <= 0.5 ? l * ( 1 + s ) : l + s - l * s,
		p = 2 * l - q;

	return [
		Math.round( hue2rgb( p, q, h + ( 1 / 3 ) ) * 255 ),
		Math.round( hue2rgb( p, q, h ) * 255 ),
		Math.round( hue2rgb( p, q, h - ( 1 / 3 ) ) * 255 ),
		a
	];
};


each( spaces, function( spaceName, space ) {
	var props = space.props,
		cache = space.cache,
		to = space.to,
		from = space.from;

	// makes rgba() and hsla()
	color.fn[ spaceName ] = function( value ) {

		// generate a cache for this space if it doesn't exist
		if ( to && !this[ cache ] ) {
			this[ cache ] = to( this._rgba );
		}
		if ( value === undefined ) {
			return this[ cache ].slice();
		}

		var ret,
			type = jQuery.type( value ),
			arr = ( type === "array" || type === "object" ) ? value : arguments,
			local = this[ cache ].slice();

		each( props, function( key, prop ) {
			var val = arr[ type === "object" ? key : prop.idx ];
			if ( val == null ) {
				val = local[ prop.idx ];
			}
			local[ prop.idx ] = clamp( val, prop );
		});

		if ( from ) {
			ret = color( from( local ) );
			ret[ cache ] = local;
			return ret;
		} else {
			return color( local );
		}
	};

	// makes red() green() blue() alpha() hue() saturation() lightness()
	each( props, function( key, prop ) {
		// alpha is included in more than one space
		if ( color.fn[ key ] ) {
			return;
		}
		color.fn[ key ] = function( value ) {
			var vtype = jQuery.type( value ),
				fn = ( key === "alpha" ? ( this._hsla ? "hsla" : "rgba" ) : spaceName ),
				local = this[ fn ](),
				cur = local[ prop.idx ],
				match;

			if ( vtype === "undefined" ) {
				return cur;
			}

			if ( vtype === "function" ) {
				value = value.call( this, cur );
				vtype = jQuery.type( value );
			}
			if ( value == null && prop.empty ) {
				return this;
			}
			if ( vtype === "string" ) {
				match = rplusequals.exec( value );
				if ( match ) {
					value = cur + parseFloat( match[ 2 ] ) * ( match[ 1 ] === "+" ? 1 : -1 );
				}
			}
			local[ prop.idx ] = value;
			return this[ fn ]( local );
		};
	});
});

// add cssHook and .fx.step function for each named hook.
// accept a space separated string of properties
color.hook = function( hook ) {
	var hooks = hook.split( " " );
	each( hooks, function( i, hook ) {
		jQuery.cssHooks[ hook ] = {
			set: function( elem, value ) {
				var parsed, curElem,
					backgroundColor = "";

				if ( value !== "transparent" && ( jQuery.type( value ) !== "string" || ( parsed = stringParse( value ) ) ) ) {
					value = color( parsed || value );
					if ( !support.rgba && value._rgba[ 3 ] !== 1 ) {
						curElem = hook === "backgroundColor" ? elem.parentNode : elem;
						while (
							(backgroundColor === "" || backgroundColor === "transparent") &&
							curElem && curElem.style
						) {
							try {
								backgroundColor = jQuery.css( curElem, "backgroundColor" );
								curElem = curElem.parentNode;
							} catch ( e ) {
							}
						}

						value = value.blend( backgroundColor && backgroundColor !== "transparent" ?
							backgroundColor :
							"_default" );
					}

					value = value.toRgbaString();
				}
				try {
					elem.style[ hook ] = value;
				} catch( e ) {
					// wrapped to prevent IE from throwing errors on "invalid" values like 'auto' or 'inherit'
				}
			}
		};
		jQuery.fx.step[ hook ] = function( fx ) {
			if ( !fx.colorInit ) {
				fx.start = color( fx.elem, hook );
				fx.end = color( fx.end );
				fx.colorInit = true;
			}
			jQuery.cssHooks[ hook ].set( fx.elem, fx.start.transition( fx.end, fx.pos ) );
		};
	});

};

color.hook( stepHooks );

jQuery.cssHooks.borderColor = {
	expand: function( value ) {
		var expanded = {};

		each( [ "Top", "Right", "Bottom", "Left" ], function( i, part ) {
			expanded[ "border" + part + "Color" ] = value;
		});
		return expanded;
	}
};

// Basic color names only.
// Usage of any of the other color names requires adding yourself or including
// jquery.color.svg-names.js.
colors = jQuery.Color.names = {
	// 4.1. Basic color keywords
	aqua: "#00ffff",
	black: "#000000",
	blue: "#0000ff",
	fuchsia: "#ff00ff",
	gray: "#808080",
	green: "#008000",
	lime: "#00ff00",
	maroon: "#800000",
	navy: "#000080",
	olive: "#808000",
	purple: "#800080",
	red: "#ff0000",
	silver: "#c0c0c0",
	teal: "#008080",
	white: "#ffffff",
	yellow: "#ffff00",

	// 4.2.3. "transparent" color keyword
	transparent: [ null, null, null, 0 ],

	_default: "#ffffff"
};

})( jQuery );


/******************************************************************************/
/****************************** CLASS ANIMATIONS ******************************/
/******************************************************************************/
(function() {

var classAnimationActions = [ "add", "remove", "toggle" ],
	shorthandStyles = {
		border: 1,
		borderBottom: 1,
		borderColor: 1,
		borderLeft: 1,
		borderRight: 1,
		borderTop: 1,
		borderWidth: 1,
		margin: 1,
		padding: 1
	};

$.each([ "borderLeftStyle", "borderRightStyle", "borderBottomStyle", "borderTopStyle" ], function( _, prop ) {
	$.fx.step[ prop ] = function( fx ) {
		if ( fx.end !== "none" && !fx.setAttr || fx.pos === 1 && !fx.setAttr ) {
			jQuery.style( fx.elem, prop, fx.end );
			fx.setAttr = true;
		}
	};
});

function getElementStyles( elem ) {
	var key, len,
		style = elem.ownerDocument.defaultView ?
			elem.ownerDocument.defaultView.getComputedStyle( elem, null ) :
			elem.currentStyle,
		styles = {};

	if ( style && style.length && style[ 0 ] && style[ style[ 0 ] ] ) {
		len = style.length;
		while ( len-- ) {
			key = style[ len ];
			if ( typeof style[ key ] === "string" ) {
				styles[ $.camelCase( key ) ] = style[ key ];
			}
		}
	// support: Opera, IE <9
	} else {
		for ( key in style ) {
			if ( typeof style[ key ] === "string" ) {
				styles[ key ] = style[ key ];
			}
		}
	}

	return styles;
}


function styleDifference( oldStyle, newStyle ) {
	var diff = {},
		name, value;

	for ( name in newStyle ) {
		value = newStyle[ name ];
		if ( oldStyle[ name ] !== value ) {
			if ( !shorthandStyles[ name ] ) {
				if ( $.fx.step[ name ] || !isNaN( parseFloat( value ) ) ) {
					diff[ name ] = value;
				}
			}
		}
	}

	return diff;
}

// support: jQuery <1.8
if ( !$.fn.addBack ) {
	$.fn.addBack = function( selector ) {
		return this.add( selector == null ?
			this.prevObject : this.prevObject.filter( selector )
		);
	};
}

$.effects.animateClass = function( value, duration, easing, callback ) {
	var o = $.speed( duration, easing, callback );

	return this.queue( function() {
		var animated = $( this ),
			baseClass = animated.attr( "class" ) || "",
			applyClassChange,
			allAnimations = o.children ? animated.find( "*" ).addBack() : animated;

		// map the animated objects to store the original styles.
		allAnimations = allAnimations.map(function() {
			var el = $( this );
			return {
				el: el,
				start: getElementStyles( this )
			};
		});

		// apply class change
		applyClassChange = function() {
			$.each( classAnimationActions, function(i, action) {
				if ( value[ action ] ) {
					animated[ action + "Class" ]( value[ action ] );
				}
			});
		};
		applyClassChange();

		// map all animated objects again - calculate new styles and diff
		allAnimations = allAnimations.map(function() {
			this.end = getElementStyles( this.el[ 0 ] );
			this.diff = styleDifference( this.start, this.end );
			return this;
		});

		// apply original class
		animated.attr( "class", baseClass );

		// map all animated objects again - this time collecting a promise
		allAnimations = allAnimations.map(function() {
			var styleInfo = this,
				dfd = $.Deferred(),
				opts = $.extend({}, o, {
					queue: false,
					complete: function() {
						dfd.resolve( styleInfo );
					}
				});

			this.el.animate( this.diff, opts );
			return dfd.promise();
		});

		// once all animations have completed:
		$.when.apply( $, allAnimations.get() ).done(function() {

			// set the final class
			applyClassChange();

			// for each animated element,
			// clear all css properties that were animated
			$.each( arguments, function() {
				var el = this.el;
				$.each( this.diff, function(key) {
					el.css( key, "" );
				});
			});

			// this is guarnteed to be there if you use jQuery.speed()
			// it also handles dequeuing the next anim...
			o.complete.call( animated[ 0 ] );
		});
	});
};

$.fn.extend({
	addClass: (function( orig ) {
		return function( classNames, speed, easing, callback ) {
			return speed ?
				$.effects.animateClass.call( this,
					{ add: classNames }, speed, easing, callback ) :
				orig.apply( this, arguments );
		};
	})( $.fn.addClass ),

	removeClass: (function( orig ) {
		return function( classNames, speed, easing, callback ) {
			return arguments.length > 1 ?
				$.effects.animateClass.call( this,
					{ remove: classNames }, speed, easing, callback ) :
				orig.apply( this, arguments );
		};
	})( $.fn.removeClass ),

	toggleClass: (function( orig ) {
		return function( classNames, force, speed, easing, callback ) {
			if ( typeof force === "boolean" || force === undefined ) {
				if ( !speed ) {
					// without speed parameter
					return orig.apply( this, arguments );
				} else {
					return $.effects.animateClass.call( this,
						(force ? { add: classNames } : { remove: classNames }),
						speed, easing, callback );
				}
			} else {
				// without force parameter
				return $.effects.animateClass.call( this,
					{ toggle: classNames }, force, speed, easing );
			}
		};
	})( $.fn.toggleClass ),

	switchClass: function( remove, add, speed, easing, callback) {
		return $.effects.animateClass.call( this, {
			add: add,
			remove: remove
		}, speed, easing, callback );
	}
});

})();

/******************************************************************************/
/*********************************** EFFECTS **********************************/
/******************************************************************************/

(function() {

$.extend( $.effects, {
	version: "1.10.2",

	// Saves a set of properties in a data storage
	save: function( element, set ) {
		for( var i=0; i < set.length; i++ ) {
			if ( set[ i ] !== null ) {
				element.data( dataSpace + set[ i ], element[ 0 ].style[ set[ i ] ] );
			}
		}
	},

	// Restores a set of previously saved properties from a data storage
	restore: function( element, set ) {
		var val, i;
		for( i=0; i < set.length; i++ ) {
			if ( set[ i ] !== null ) {
				val = element.data( dataSpace + set[ i ] );
				// support: jQuery 1.6.2
				// http://bugs.jquery.com/ticket/9917
				// jQuery 1.6.2 incorrectly returns undefined for any falsy value.
				// We can't differentiate between "" and 0 here, so we just assume
				// empty string since it's likely to be a more common value...
				if ( val === undefined ) {
					val = "";
				}
				element.css( set[ i ], val );
			}
		}
	},

	setMode: function( el, mode ) {
		if (mode === "toggle") {
			mode = el.is( ":hidden" ) ? "show" : "hide";
		}
		return mode;
	},

	// Translates a [top,left] array into a baseline value
	// this should be a little more flexible in the future to handle a string & hash
	getBaseline: function( origin, original ) {
		var y, x;
		switch ( origin[ 0 ] ) {
			case "top": y = 0; break;
			case "middle": y = 0.5; break;
			case "bottom": y = 1; break;
			default: y = origin[ 0 ] / original.height;
		}
		switch ( origin[ 1 ] ) {
			case "left": x = 0; break;
			case "center": x = 0.5; break;
			case "right": x = 1; break;
			default: x = origin[ 1 ] / original.width;
		}
		return {
			x: x,
			y: y
		};
	},

	// Wraps the element around a wrapper that copies position properties
	createWrapper: function( element ) {

		// if the element is already wrapped, return it
		if ( element.parent().is( ".ui-effects-wrapper" )) {
			return element.parent();
		}

		// wrap the element
		var props = {
				width: element.outerWidth(true),
				height: element.outerHeight(true),
				"float": element.css( "float" )
			},
			wrapper = $( "<div></div>" )
				.addClass( "ui-effects-wrapper" )
				.css({
					fontSize: "100%",
					background: "transparent",
					border: "none",
					margin: 0,
					padding: 0
				}),
			// Store the size in case width/height are defined in % - Fixes #5245
			size = {
				width: element.width(),
				height: element.height()
			},
			active = document.activeElement;

		// support: Firefox
		// Firefox incorrectly exposes anonymous content
		// https://bugzilla.mozilla.org/show_bug.cgi?id=561664
		try {
			active.id;
		} catch( e ) {
			active = document.body;
		}

		element.wrap( wrapper );

		// Fixes #7595 - Elements lose focus when wrapped.
		if ( element[ 0 ] === active || $.contains( element[ 0 ], active ) ) {
			$( active ).focus();
		}

		wrapper = element.parent(); //Hotfix for jQuery 1.4 since some change in wrap() seems to actually lose the reference to the wrapped element

		// transfer positioning properties to the wrapper
		if ( element.css( "position" ) === "static" ) {
			wrapper.css({ position: "relative" });
			element.css({ position: "relative" });
		} else {
			$.extend( props, {
				position: element.css( "position" ),
				zIndex: element.css( "z-index" )
			});
			$.each([ "top", "left", "bottom", "right" ], function(i, pos) {
				props[ pos ] = element.css( pos );
				if ( isNaN( parseInt( props[ pos ], 10 ) ) ) {
					props[ pos ] = "auto";
				}
			});
			element.css({
				position: "relative",
				top: 0,
				left: 0,
				right: "auto",
				bottom: "auto"
			});
		}
		element.css(size);

		return wrapper.css( props ).show();
	},

	removeWrapper: function( element ) {
		var active = document.activeElement;

		if ( element.parent().is( ".ui-effects-wrapper" ) ) {
			element.parent().replaceWith( element );

			// Fixes #7595 - Elements lose focus when wrapped.
			if ( element[ 0 ] === active || $.contains( element[ 0 ], active ) ) {
				$( active ).focus();
			}
		}


		return element;
	},

	setTransition: function( element, list, factor, value ) {
		value = value || {};
		$.each( list, function( i, x ) {
			var unit = element.cssUnit( x );
			if ( unit[ 0 ] > 0 ) {
				value[ x ] = unit[ 0 ] * factor + unit[ 1 ];
			}
		});
		return value;
	}
});

// return an effect options object for the given parameters:
function _normalizeArguments( effect, options, speed, callback ) {

	// allow passing all options as the first parameter
	if ( $.isPlainObject( effect ) ) {
		options = effect;
		effect = effect.effect;
	}

	// convert to an object
	effect = { effect: effect };

	// catch (effect, null, ...)
	if ( options == null ) {
		options = {};
	}

	// catch (effect, callback)
	if ( $.isFunction( options ) ) {
		callback = options;
		speed = null;
		options = {};
	}

	// catch (effect, speed, ?)
	if ( typeof options === "number" || $.fx.speeds[ options ] ) {
		callback = speed;
		speed = options;
		options = {};
	}

	// catch (effect, options, callback)
	if ( $.isFunction( speed ) ) {
		callback = speed;
		speed = null;
	}

	// add options to effect
	if ( options ) {
		$.extend( effect, options );
	}

	speed = speed || options.duration;
	effect.duration = $.fx.off ? 0 :
		typeof speed === "number" ? speed :
		speed in $.fx.speeds ? $.fx.speeds[ speed ] :
		$.fx.speeds._default;

	effect.complete = callback || options.complete;

	return effect;
}

function standardAnimationOption( option ) {
	// Valid standard speeds (nothing, number, named speed)
	if ( !option || typeof option === "number" || $.fx.speeds[ option ] ) {
		return true;
	}

	// Invalid strings - treat as "normal" speed
	if ( typeof option === "string" && !$.effects.effect[ option ] ) {
		return true;
	}

	// Complete callback
	if ( $.isFunction( option ) ) {
		return true;
	}

	// Options hash (but not naming an effect)
	if ( typeof option === "object" && !option.effect ) {
		return true;
	}

	// Didn't match any standard API
	return false;
}

$.fn.extend({
	effect: function( /* effect, options, speed, callback */ ) {
		var args = _normalizeArguments.apply( this, arguments ),
			mode = args.mode,
			queue = args.queue,
			effectMethod = $.effects.effect[ args.effect ];

		if ( $.fx.off || !effectMethod ) {
			// delegate to the original method (e.g., .show()) if possible
			if ( mode ) {
				return this[ mode ]( args.duration, args.complete );
			} else {
				return this.each( function() {
					if ( args.complete ) {
						args.complete.call( this );
					}
				});
			}
		}

		function run( next ) {
			var elem = $( this ),
				complete = args.complete,
				mode = args.mode;

			function done() {
				if ( $.isFunction( complete ) ) {
					complete.call( elem[0] );
				}
				if ( $.isFunction( next ) ) {
					next();
				}
			}

			// If the element already has the correct final state, delegate to
			// the core methods so the internal tracking of "olddisplay" works.
			if ( elem.is( ":hidden" ) ? mode === "hide" : mode === "show" ) {
				elem[ mode ]();
				done();
			} else {
				effectMethod.call( elem[0], args, done );
			}
		}

		return queue === false ? this.each( run ) : this.queue( queue || "fx", run );
	},

	show: (function( orig ) {
		return function( option ) {
			if ( standardAnimationOption( option ) ) {
				return orig.apply( this, arguments );
			} else {
				var args = _normalizeArguments.apply( this, arguments );
				args.mode = "show";
				return this.effect.call( this, args );
			}
		};
	})( $.fn.show ),

	hide: (function( orig ) {
		return function( option ) {
			if ( standardAnimationOption( option ) ) {
				return orig.apply( this, arguments );
			} else {
				var args = _normalizeArguments.apply( this, arguments );
				args.mode = "hide";
				return this.effect.call( this, args );
			}
		};
	})( $.fn.hide ),

	toggle: (function( orig ) {
		return function( option ) {
			if ( standardAnimationOption( option ) || typeof option === "boolean" ) {
				return orig.apply( this, arguments );
			} else {
				var args = _normalizeArguments.apply( this, arguments );
				args.mode = "toggle";
				return this.effect.call( this, args );
			}
		};
	})( $.fn.toggle ),

	// helper functions
	cssUnit: function(key) {
		var style = this.css( key ),
			val = [];

		$.each( [ "em", "px", "%", "pt" ], function( i, unit ) {
			if ( style.indexOf( unit ) > 0 ) {
				val = [ parseFloat( style ), unit ];
			}
		});
		return val;
	}
});

})();

/******************************************************************************/
/*********************************** EASING ***********************************/
/******************************************************************************/

(function() {

// based on easing equations from Robert Penner (http://www.robertpenner.com/easing)

var baseEasings = {};

$.each( [ "Quad", "Cubic", "Quart", "Quint", "Expo" ], function( i, name ) {
	baseEasings[ name ] = function( p ) {
		return Math.pow( p, i + 2 );
	};
});

$.extend( baseEasings, {
	Sine: function ( p ) {
		return 1 - Math.cos( p * Math.PI / 2 );
	},
	Circ: function ( p ) {
		return 1 - Math.sqrt( 1 - p * p );
	},
	Elastic: function( p ) {
		return p === 0 || p === 1 ? p :
			-Math.pow( 2, 8 * (p - 1) ) * Math.sin( ( (p - 1) * 80 - 7.5 ) * Math.PI / 15 );
	},
	Back: function( p ) {
		return p * p * ( 3 * p - 2 );
	},
	Bounce: function ( p ) {
		var pow2,
			bounce = 4;

		while ( p < ( ( pow2 = Math.pow( 2, --bounce ) ) - 1 ) / 11 ) {}
		return 1 / Math.pow( 4, 3 - bounce ) - 7.5625 * Math.pow( ( pow2 * 3 - 2 ) / 22 - p, 2 );
	}
});

$.each( baseEasings, function( name, easeIn ) {
	$.easing[ "easeIn" + name ] = easeIn;
	$.easing[ "easeOut" + name ] = function( p ) {
		return 1 - easeIn( 1 - p );
	};
	$.easing[ "easeInOut" + name ] = function( p ) {
		return p < 0.5 ?
			easeIn( p * 2 ) / 2 :
			1 - easeIn( p * -2 + 2 ) / 2;
	};
});

})();

})(jQuery);


	return jQuery;
});

/* ---- Module:jquery.effects.fade ---- */

define("jquery/effects/fade", ["jquery/effects"], function (jQuery) {

/*!
 * jQuery UI Effects Fade 1.10.2
 * http://jqueryui.com
 *
 * Copyright 2013 jQuery Foundation and other contributors
 * Released under the MIT license.
 * http://jquery.org/license
 *
 * http://api.jqueryui.com/fade-effect/
 *
 * Depends:
 *	jquery.ui.effect.js
 */
(function( $, undefined ) {

$.effects.effect.fade = function( o, done ) {
	var el = $( this ),
		mode = $.effects.setMode( el, o.mode || "toggle" );

	el.animate({
		opacity: mode
	}, {
		queue: false,
		duration: o.duration,
		easing: o.easing,
		complete: done
	});
};

})( jQuery );


	return jQuery;
});

/* ---- Module:jquery.effects.slide ---- */

define("jquery/effects/slide", ["jquery/effects"], function (jQuery) {

/*!
 * jQuery UI Effects Slide 1.10.2
 * http://jqueryui.com
 *
 * Copyright 2013 jQuery Foundation and other contributors
 * Released under the MIT license.
 * http://jquery.org/license
 *
 * http://api.jqueryui.com/slide-effect/
 *
 * Depends:
 *	jquery.ui.effect.js
 */
(function( $, undefined ) {

$.effects.effect.slide = function( o, done ) {

	// Create element
	var el = $( this ),
		props = [ "position", "top", "bottom", "left", "right", "width", "height" ],
		mode = $.effects.setMode( el, o.mode || "show" ),
		show = mode === "show",
		direction = o.direction || "left",
		ref = (direction === "up" || direction === "down") ? "top" : "left",
		positiveMotion = (direction === "up" || direction === "left"),
		distance,
		animation = {};

	// Adjust
	$.effects.save( el, props );
	el.show();
	distance = o.distance || el[ ref === "top" ? "outerHeight" : "outerWidth" ]( true );

	$.effects.createWrapper( el ).css({
		overflow: "hidden"
	});

	if ( show ) {
		el.css( ref, positiveMotion ? (isNaN(distance) ? "-" + distance : -distance) : distance );
	}

	// Animation
	animation[ ref ] = ( show ?
		( positiveMotion ? "+=" : "-=") :
		( positiveMotion ? "-=" : "+=")) +
		distance;

	// Animate
	el.animate( animation, {
		queue: false,
		duration: o.duration,
		easing: o.easing,
		complete: function() {
			if ( mode === "hide" ) {
				el.hide();
			}
			$.effects.restore( el, props );
			$.effects.removeWrapper( el );
			done();
		}
	});
};

})(jQuery);


	return jQuery;
});

/* ---- Module:jquery.ui.widget ---- */

define("jquery/ui/widget", ["jquery"], function (jQuery) {

/*!
 * jQuery UI Widget 1.10.2
 * http://jqueryui.com
 *
 * Copyright 2013 jQuery Foundation and other contributors
 * Released under the MIT license.
 * http://jquery.org/license
 *
 * http://api.jqueryui.com/jQuery.widget/
 */
(function( $, undefined ) {

var uuid = 0,
	slice = Array.prototype.slice,
	_cleanData = $.cleanData;
$.cleanData = function( elems ) {
	for ( var i = 0, elem; (elem = elems[i]) != null; i++ ) {
		try {
			$( elem ).triggerHandler( "remove" );
		// http://bugs.jquery.com/ticket/8235
		} catch( e ) {}
	}
	_cleanData( elems );
};

$.widget = function( name, base, prototype ) {
	var fullName, existingConstructor, constructor, basePrototype,
		// proxiedPrototype allows the provided prototype to remain unmodified
		// so that it can be used as a mixin for multiple widgets (#8876)
		proxiedPrototype = {},
		namespace = name.split( "." )[ 0 ];

	name = name.split( "." )[ 1 ];
	fullName = namespace + "-" + name;

	if ( !prototype ) {
		prototype = base;
		base = $.Widget;
	}

	// create selector for plugin
	$.expr[ ":" ][ fullName.toLowerCase() ] = function( elem ) {
		return !!$.data( elem, fullName );
	};

	$[ namespace ] = $[ namespace ] || {};
	existingConstructor = $[ namespace ][ name ];
	constructor = $[ namespace ][ name ] = function( options, element ) {
		// allow instantiation without "new" keyword
		if ( !this._createWidget ) {
			return new constructor( options, element );
		}

		// allow instantiation without initializing for simple inheritance
		// must use "new" keyword (the code above always passes args)
		if ( arguments.length ) {
			this._createWidget( options, element );
		}
	};
	// extend with the existing constructor to carry over any static properties
	$.extend( constructor, existingConstructor, {
		version: prototype.version,
		// copy the object used to create the prototype in case we need to
		// redefine the widget later
		_proto: $.extend( {}, prototype ),
		// track widgets that inherit from this widget in case this widget is
		// redefined after a widget inherits from it
		_childConstructors: []
	});

	basePrototype = new base();
	// we need to make the options hash a property directly on the new instance
	// otherwise we'll modify the options hash on the prototype that we're
	// inheriting from
	basePrototype.options = $.widget.extend( {}, basePrototype.options );
	$.each( prototype, function( prop, value ) {
		if ( !$.isFunction( value ) ) {
			proxiedPrototype[ prop ] = value;
			return;
		}
		proxiedPrototype[ prop ] = (function() {
			var _super = function() {
					return base.prototype[ prop ].apply( this, arguments );
				},
				_superApply = function( args ) {
					return base.prototype[ prop ].apply( this, args );
				};
			return function() {
				var __super = this._super,
					__superApply = this._superApply,
					returnValue;

				this._super = _super;
				this._superApply = _superApply;

				returnValue = value.apply( this, arguments );

				this._super = __super;
				this._superApply = __superApply;

				return returnValue;
			};
		})();
	});
	constructor.prototype = $.widget.extend( basePrototype, {
		// TODO: remove support for widgetEventPrefix
		// always use the name + a colon as the prefix, e.g., draggable:start
		// don't prefix for widgets that aren't DOM-based
		widgetEventPrefix: existingConstructor ? basePrototype.widgetEventPrefix : name
	}, proxiedPrototype, {
		constructor: constructor,
		namespace: namespace,
		widgetName: name,
		widgetFullName: fullName
	});

	// If this widget is being redefined then we need to find all widgets that
	// are inheriting from it and redefine all of them so that they inherit from
	// the new version of this widget. We're essentially trying to replace one
	// level in the prototype chain.
	if ( existingConstructor ) {
		$.each( existingConstructor._childConstructors, function( i, child ) {
			var childPrototype = child.prototype;

			// redefine the child widget using the same prototype that was
			// originally used, but inherit from the new version of the base
			$.widget( childPrototype.namespace + "." + childPrototype.widgetName, constructor, child._proto );
		});
		// remove the list of existing child constructors from the old constructor
		// so the old child constructors can be garbage collected
		delete existingConstructor._childConstructors;
	} else {
		base._childConstructors.push( constructor );
	}

	$.widget.bridge( name, constructor );
};

$.widget.extend = function( target ) {
	var input = slice.call( arguments, 1 ),
		inputIndex = 0,
		inputLength = input.length,
		key,
		value;
	for ( ; inputIndex < inputLength; inputIndex++ ) {
		for ( key in input[ inputIndex ] ) {
			value = input[ inputIndex ][ key ];
			if ( input[ inputIndex ].hasOwnProperty( key ) && value !== undefined ) {
				// Clone objects
				if ( $.isPlainObject( value ) ) {
					target[ key ] = $.isPlainObject( target[ key ] ) ?
						$.widget.extend( {}, target[ key ], value ) :
						// Don't extend strings, arrays, etc. with objects
						$.widget.extend( {}, value );
				// Copy everything else by reference
				} else {
					target[ key ] = value;
				}
			}
		}
	}
	return target;
};

$.widget.bridge = function( name, object ) {
	var fullName = object.prototype.widgetFullName || name;
	$.fn[ name ] = function( options ) {
		var isMethodCall = typeof options === "string",
			args = slice.call( arguments, 1 ),
			returnValue = this;

		// allow multiple hashes to be passed on init
		options = !isMethodCall && args.length ?
			$.widget.extend.apply( null, [ options ].concat(args) ) :
			options;

		if ( isMethodCall ) {
			this.each(function() {
				var methodValue,
					instance = $.data( this, fullName );
				if ( !instance ) {
					return $.error( "cannot call methods on " + name + " prior to initialization; " +
						"attempted to call method '" + options + "'" );
				}
				/* >>>> DEPRECATED >>>> */
				if ( options === "Instance" ) {
					returnValue = instance;
					return false;
				}
				/* <<<< DEPRECATED <<<< */
				if ( !$.isFunction( instance[options] ) || options.charAt( 0 ) === "_" ) {
					return $.error( "no such method '" + options + "' for " + name + " widget instance" );
				}
				methodValue = instance[ options ].apply( instance, args );
				if ( methodValue !== instance && methodValue !== undefined ) {
					returnValue = methodValue && methodValue.jquery ?
						returnValue.pushStack( methodValue.get() ) :
						methodValue;
					return false;
				}
			});
		} else {
			this.each(function() {
				var instance = $.data( this, fullName );
				if ( instance ) {
					instance.option( options || {} )._init();
				} else {
					$.data( this, fullName, new object( options, this ) );
				}
			});
		}

		return returnValue;
	};
};

$.Widget = function( /* options, element */ ) {};
$.Widget._childConstructors = [];

$.Widget.prototype = {
	widgetName: "widget",
	widgetEventPrefix: "",
	defaultElement: "<div>",
	options: {
		disabled: false,

		// callbacks
		create: null
	},
	_createWidget: function( options, element ) {
		element = $( element || this.defaultElement || this )[ 0 ];
		this.element = $( element );
		this.uuid = uuid++;
		this.eventNamespace = "." + this.widgetName + this.uuid;
		this.options = $.widget.extend( {},
			this.options,
			this._getCreateOptions(),
			options );

		this.bindings = $();
		this.hoverable = $();
		this.focusable = $();

		if ( element !== this ) {
			$.data( element, this.widgetFullName, this );
			this._on( true, this.element, {
				remove: function( event ) {
					if ( event.target === element ) {
						this.destroy();
					}
				}
			});
			this.document = $( element.style ?
				// element within the document
				element.ownerDocument :
				// element is window or document
				element.document || element );
			this.window = $( this.document[0].defaultView || this.document[0].parentWindow );
		}

		this._create();
		this._trigger( "create", null, this._getCreateEventData() );
		this._init();
	},
	_getCreateOptions: $.noop,
	_getCreateEventData: $.noop,
	_create: $.noop,
	_init: $.noop,

	destroy: function() {
		this._destroy();
		// we can probably remove the unbind calls in 2.0
		// all event bindings should go through this._on()
		this.element
			.unbind( this.eventNamespace )
			// 1.9 BC for #7810
			// TODO remove dual storage
			.removeData( this.widgetName )
			.removeData( this.widgetFullName )
			// support: jquery <1.6.3
			// http://bugs.jquery.com/ticket/9413
			.removeData( $.camelCase( this.widgetFullName ) );
		this.widget()
			.unbind( this.eventNamespace )
			.removeAttr( "aria-disabled" )
			.removeClass(
				this.widgetFullName + "-disabled " +
				"ui-state-disabled" );

		// clean up events and states
		this.bindings.unbind( this.eventNamespace );
		this.hoverable.removeClass( "ui-state-hover" );
		this.focusable.removeClass( "ui-state-focus" );
	},
	_destroy: $.noop,

	widget: function() {
		return this.element;
	},

	option: function( key, value ) {
		var options = key,
			parts,
			curOption,
			i;

		if ( arguments.length === 0 ) {
			// don't return a reference to the internal hash
			return $.widget.extend( {}, this.options );
		}

		if ( typeof key === "string" ) {
			// handle nested keys, e.g., "foo.bar" => { foo: { bar: ___ } }
			options = {};
			parts = key.split( "." );
			key = parts.shift();
			if ( parts.length ) {
				curOption = options[ key ] = $.widget.extend( {}, this.options[ key ] );
				for ( i = 0; i < parts.length - 1; i++ ) {
					curOption[ parts[ i ] ] = curOption[ parts[ i ] ] || {};
					curOption = curOption[ parts[ i ] ];
				}
				key = parts.pop();
				if ( value === undefined ) {
					return curOption[ key ] === undefined ? null : curOption[ key ];
				}
				curOption[ key ] = value;
			} else {
				if ( value === undefined ) {
					return this.options[ key ] === undefined ? null : this.options[ key ];
				}
				options[ key ] = value;
			}
		}

		this._setOptions( options );

		return this;
	},
	_setOptions: function( options ) {
		var key;

		for ( key in options ) {
			this._setOption( key, options[ key ] );
		}

		return this;
	},
	_setOption: function( key, value ) {
		this.options[ key ] = value;

		if ( key === "disabled" ) {
			this.widget()
				.toggleClass( this.widgetFullName + "-disabled ui-state-disabled", !!value )
				.attr( "aria-disabled", value );
			this.hoverable.removeClass( "ui-state-hover" );
			this.focusable.removeClass( "ui-state-focus" );
		}

		return this;
	},

	enable: function() {
		return this._setOption( "disabled", false );
	},
	disable: function() {
		return this._setOption( "disabled", true );
	},

	_on: function( suppressDisabledCheck, element, handlers ) {
		var delegateElement,
			instance = this;

		// no suppressDisabledCheck flag, shuffle arguments
		if ( typeof suppressDisabledCheck !== "boolean" ) {
			handlers = element;
			element = suppressDisabledCheck;
			suppressDisabledCheck = false;
		}

		// no element argument, shuffle and use this.element
		if ( !handlers ) {
			handlers = element;
			element = this.element;
			delegateElement = this.widget();
		} else {
			// accept selectors, DOM elements
			element = delegateElement = $( element );
			this.bindings = this.bindings.add( element );
		}

		$.each( handlers, function( event, handler ) {
			function handlerProxy() {
				// allow widgets to customize the disabled handling
				// - disabled as an array instead of boolean
				// - disabled class as method for disabling individual parts
				if ( !suppressDisabledCheck &&
						( instance.options.disabled === true ||
							$( this ).hasClass( "ui-state-disabled" ) ) ) {
					return;
				}
				return ( typeof handler === "string" ? instance[ handler ] : handler )
					.apply( instance, arguments );
			}

			// copy the guid so direct unbinding works
			if ( typeof handler !== "string" ) {
				handlerProxy.guid = handler.guid =
					handler.guid || handlerProxy.guid || $.guid++;
			}

			var match = event.match( /^(\w+)\s*(.*)$/ ),
				eventName = match[1] + instance.eventNamespace,
				selector = match[2];
			if ( selector ) {
				delegateElement.delegate( selector, eventName, handlerProxy );
			} else {
				element.bind( eventName, handlerProxy );
			}
		});
	},

	_off: function( element, eventName ) {
		eventName = (eventName || "").split( " " ).join( this.eventNamespace + " " ) + this.eventNamespace;
		element.unbind( eventName ).undelegate( eventName );
	},

	_delay: function( handler, delay ) {
		function handlerProxy() {
			return ( typeof handler === "string" ? instance[ handler ] : handler )
				.apply( instance, arguments );
		}
		var instance = this;
		return setTimeout( handlerProxy, delay || 0 );
	},

	_hoverable: function( element ) {
		this.hoverable = this.hoverable.add( element );
		this._on( element, {
			mouseenter: function( event ) {
				$( event.currentTarget ).addClass( "ui-state-hover" );
			},
			mouseleave: function( event ) {
				$( event.currentTarget ).removeClass( "ui-state-hover" );
			}
		});
	},

	_focusable: function( element ) {
		this.focusable = this.focusable.add( element );
		this._on( element, {
			focusin: function( event ) {
				$( event.currentTarget ).addClass( "ui-state-focus" );
			},
			focusout: function( event ) {
				$( event.currentTarget ).removeClass( "ui-state-focus" );
			}
		});
	},

	_trigger: function( type, event, data ) {
		var prop, orig,
			callback = this.options[ type ];

		data = data || {};
		event = $.Event( event );
		event.type = ( type === this.widgetEventPrefix ?
			type :
			this.widgetEventPrefix + type ).toLowerCase();
		// the original event may come from any element
		// so we need to reset the target on the new event
		event.target = this.element[ 0 ];

		// copy original event properties over to the new event
		orig = event.originalEvent;
		if ( orig ) {
			for ( prop in orig ) {
				if ( !( prop in event ) ) {
					event[ prop ] = orig[ prop ];
				}
			}
		}

		this.element.trigger( event, data );
		return !( $.isFunction( callback ) &&
			callback.apply( this.element[0], [ event ].concat( data ) ) === false ||
			event.isDefaultPrevented() );
	}
};

$.each( { show: "fadeIn", hide: "fadeOut" }, function( method, defaultEffect ) {
	$.Widget.prototype[ "_" + method ] = function( element, options, callback ) {
		if ( typeof options === "string" ) {
			options = { effect: options };
		}
		var hasOptions,
			effectName = !options ?
				method :
				options === true || typeof options === "number" ?
					defaultEffect :
					options.effect || defaultEffect;
		options = options || {};
		if ( typeof options === "number" ) {
			options = { duration: options };
		}
		hasOptions = !$.isEmptyObject( options );
		options.complete = callback;
		if ( options.delay ) {
			element.delay( options.delay );
		}
		if ( hasOptions && $.effects && $.effects.effect[ effectName ] ) {
			element[ method ]( options );
		} else if ( effectName !== method && element[ effectName ] ) {
			element[ effectName ]( options.duration, options.easing, callback );
		} else {
			element.queue(function( next ) {
				$( this )[ method ]();
				if ( callback ) {
					callback.call( element[ 0 ] );
				}
				next();
			});
		}
	};
});

})( jQuery );


	return jQuery;
});

/* ---- Module:jquery.ui.core ---- */

define("jquery/ui/core", ["jquery"], function (jQuery) {

/*!
 * jQuery UI Core 1.10.2
 * http://jqueryui.com
 *
 * Copyright 2013 jQuery Foundation and other contributors
 * Released under the MIT license.
 * http://jquery.org/license
 *
 * http://api.jqueryui.com/category/ui-core/
 */
(function( $, undefined ) {

var uuid = 0,
	runiqueId = /^ui-id-\d+$/;

// $.ui might exist from components with no dependencies, e.g., $.ui.position
$.ui = $.ui || {};

$.extend( $.ui, {
	version: "1.10.2",

	keyCode: {
		BACKSPACE: 8,
		COMMA: 188,
		DELETE: 46,
		DOWN: 40,
		END: 35,
		ENTER: 13,
		ESCAPE: 27,
		HOME: 36,
		LEFT: 37,
		NUMPAD_ADD: 107,
		NUMPAD_DECIMAL: 110,
		NUMPAD_DIVIDE: 111,
		NUMPAD_ENTER: 108,
		NUMPAD_MULTIPLY: 106,
		NUMPAD_SUBTRACT: 109,
		PAGE_DOWN: 34,
		PAGE_UP: 33,
		PERIOD: 190,
		RIGHT: 39,
		SPACE: 32,
		TAB: 9,
		UP: 38
	}
});

// plugins
$.fn.extend({
	focus: (function( orig ) {
		return function( delay, fn ) {
			return typeof delay === "number" ?
				this.each(function() {
					var elem = this;
					setTimeout(function() {
						$( elem ).focus();
						if ( fn ) {
							fn.call( elem );
						}
					}, delay );
				}) :
				orig.apply( this, arguments );
		};
	})( $.fn.focus ),

	scrollParent: function() {
		var scrollParent;
		if (($.ui.ie && (/(static|relative)/).test(this.css("position"))) || (/absolute/).test(this.css("position"))) {
			scrollParent = this.parents().filter(function() {
				return (/(relative|absolute|fixed)/).test($.css(this,"position")) && (/(auto|scroll)/).test($.css(this,"overflow")+$.css(this,"overflow-y")+$.css(this,"overflow-x"));
			}).eq(0);
		} else {
			scrollParent = this.parents().filter(function() {
				return (/(auto|scroll)/).test($.css(this,"overflow")+$.css(this,"overflow-y")+$.css(this,"overflow-x"));
			}).eq(0);
		}

		return (/fixed/).test(this.css("position")) || !scrollParent.length ? $(document) : scrollParent;
	},

	zIndex: function( zIndex ) {
		if ( zIndex !== undefined ) {
			return this.css( "zIndex", zIndex );
		}

		if ( this.length ) {
			var elem = $( this[ 0 ] ), position, value;
			while ( elem.length && elem[ 0 ] !== document ) {
				// Ignore z-index if position is set to a value where z-index is ignored by the browser
				// This makes behavior of this function consistent across browsers
				// WebKit always returns auto if the element is positioned
				position = elem.css( "position" );
				if ( position === "absolute" || position === "relative" || position === "fixed" ) {
					// IE returns 0 when zIndex is not specified
					// other browsers return a string
					// we ignore the case of nested elements with an explicit value of 0
					// <div style="z-index: -10;"><div style="z-index: 0;"></div></div>
					value = parseInt( elem.css( "zIndex" ), 10 );
					if ( !isNaN( value ) && value !== 0 ) {
						return value;
					}
				}
				elem = elem.parent();
			}
		}

		return 0;
	},

	uniqueId: function() {
		return this.each(function() {
			if ( !this.id ) {
				this.id = "ui-id-" + (++uuid);
			}
		});
	},

	removeUniqueId: function() {
		return this.each(function() {
			if ( runiqueId.test( this.id ) ) {
				$( this ).removeAttr( "id" );
			}
		});
	}
});

// selectors
function focusable( element, isTabIndexNotNaN ) {
	var map, mapName, img,
		nodeName = element.nodeName.toLowerCase();
	if ( "area" === nodeName ) {
		map = element.parentNode;
		mapName = map.name;
		if ( !element.href || !mapName || map.nodeName.toLowerCase() !== "map" ) {
			return false;
		}
		img = $( "img[usemap=#" + mapName + "]" )[0];
		return !!img && visible( img );
	}
	return ( /input|select|textarea|button|object/.test( nodeName ) ?
		!element.disabled :
		"a" === nodeName ?
			element.href || isTabIndexNotNaN :
			isTabIndexNotNaN) &&
		// the element and all of its ancestors must be visible
		visible( element );
}

function visible( element ) {
	return $.expr.filters.visible( element ) &&
		!$( element ).parents().addBack().filter(function() {
			return $.css( this, "visibility" ) === "hidden";
		}).length;
}

$.extend( $.expr[ ":" ], {
	data: $.expr.createPseudo ?
		$.expr.createPseudo(function( dataName ) {
			return function( elem ) {
				return !!$.data( elem, dataName );
			};
		}) :
		// support: jQuery <1.8
		function( elem, i, match ) {
			return !!$.data( elem, match[ 3 ] );
		},

	focusable: function( element ) {
		return focusable( element, !isNaN( $.attr( element, "tabindex" ) ) );
	},

	tabbable: function( element ) {
		var tabIndex = $.attr( element, "tabindex" ),
			isTabIndexNaN = isNaN( tabIndex );
		return ( isTabIndexNaN || tabIndex >= 0 ) && focusable( element, !isTabIndexNaN );
	}
});

// support: jQuery <1.8
if ( !$( "<a>" ).outerWidth( 1 ).jquery ) {
	$.each( [ "Width", "Height" ], function( i, name ) {
		var side = name === "Width" ? [ "Left", "Right" ] : [ "Top", "Bottom" ],
			type = name.toLowerCase(),
			orig = {
				innerWidth: $.fn.innerWidth,
				innerHeight: $.fn.innerHeight,
				outerWidth: $.fn.outerWidth,
				outerHeight: $.fn.outerHeight
			};

		function reduce( elem, size, border, margin ) {
			$.each( side, function() {
				size -= parseFloat( $.css( elem, "padding" + this ) ) || 0;
				if ( border ) {
					size -= parseFloat( $.css( elem, "border" + this + "Width" ) ) || 0;
				}
				if ( margin ) {
					size -= parseFloat( $.css( elem, "margin" + this ) ) || 0;
				}
			});
			return size;
		}

		$.fn[ "inner" + name ] = function( size ) {
			if ( size === undefined ) {
				return orig[ "inner" + name ].call( this );
			}

			return this.each(function() {
				$( this ).css( type, reduce( this, size ) + "px" );
			});
		};

		$.fn[ "outer" + name] = function( size, margin ) {
			if ( typeof size !== "number" ) {
				return orig[ "outer" + name ].call( this, size );
			}

			return this.each(function() {
				$( this).css( type, reduce( this, size, true, margin ) + "px" );
			});
		};
	});
}

// support: jQuery <1.8
if ( !$.fn.addBack ) {
	$.fn.addBack = function( selector ) {
		return this.add( selector == null ?
			this.prevObject : this.prevObject.filter( selector )
		);
	};
}

// support: jQuery 1.6.1, 1.6.2 (http://bugs.jquery.com/ticket/9413)
if ( $( "<a>" ).data( "a-b", "a" ).removeData( "a-b" ).data( "a-b" ) ) {
	$.fn.removeData = (function( removeData ) {
		return function( key ) {
			if ( arguments.length ) {
				return removeData.call( this, $.camelCase( key ) );
			} else {
				return removeData.call( this );
			}
		};
	})( $.fn.removeData );
}





// deprecated
$.ui.ie = !!/msie [\w.]+/.exec( navigator.userAgent.toLowerCase() );

$.support.selectstart = "onselectstart" in document.createElement( "div" );
$.fn.extend({
	disableSelection: function() {
		return this.bind( ( $.support.selectstart ? "selectstart" : "mousedown" ) +
			".ui-disableSelection", function( event ) {
				event.preventDefault();
			});
	},

	enableSelection: function() {
		return this.unbind( ".ui-disableSelection" );
	}
});

$.extend( $.ui, {
	// $.ui.plugin is deprecated.  Use the proxy pattern instead.
	plugin: {
		add: function( module, option, set ) {
			var i,
				proto = $.ui[ module ].prototype;
			for ( i in set ) {
				proto.plugins[ i ] = proto.plugins[ i ] || [];
				proto.plugins[ i ].push( [ option, set[ i ] ] );
			}
		},
		call: function( instance, name, args ) {
			var i,
				set = instance.plugins[ name ];
			if ( !set || !instance.element[ 0 ].parentNode || instance.element[ 0 ].parentNode.nodeType === 11 ) {
				return;
			}

			for ( i = 0; i < set.length; i++ ) {
				if ( instance.options[ set[ i ][ 0 ] ] ) {
					set[ i ][ 1 ].apply( instance.element, args );
				}
			}
		}
	},

	// only used by resizable
	hasScroll: function( el, a ) {

		//If overflow is hidden, the element might have extra content, but the user wants to hide it
		if ( $( el ).css( "overflow" ) === "hidden") {
			return false;
		}

		var scroll = ( a && a === "left" ) ? "scrollLeft" : "scrollTop",
			has = false;

		if ( el[ scroll ] > 0 ) {
			return true;
		}

		// TODO: determine which cases actually cause this to happen
		// if the element doesn't have the scroll set, see if it's possible to
		// set the scroll
		el[ scroll ] = 1;
		has = ( el[ scroll ] > 0 );
		el[ scroll ] = 0;
		return has;
	}
});

})( jQuery );


	return jQuery;
});

/* ---- Module:jquery.ui.position ---- */

define("jquery/ui/position", ["jquery"], function (jQuery) {

/*!
 * jQuery UI Position 1.10.2
 * http://jqueryui.com
 *
 * Copyright 2013 jQuery Foundation and other contributors
 * Released under the MIT license.
 * http://jquery.org/license
 *
 * http://api.jqueryui.com/position/
 */
(function( $, undefined ) {

$.ui = $.ui || {};

var cachedScrollbarWidth,
	max = Math.max,
	abs = Math.abs,
	round = Math.round,
	rhorizontal = /left|center|right/,
	rvertical = /top|center|bottom/,
	roffset = /[\+\-]\d+(\.[\d]+)?%?/,
	rposition = /^\w+/,
	rpercent = /%$/,
	_position = $.fn.position;

function getOffsets( offsets, width, height ) {
	return [
		parseFloat( offsets[ 0 ] ) * ( rpercent.test( offsets[ 0 ] ) ? width / 100 : 1 ),
		parseFloat( offsets[ 1 ] ) * ( rpercent.test( offsets[ 1 ] ) ? height / 100 : 1 )
	];
}

function parseCss( element, property ) {
	return parseInt( $.css( element, property ), 10 ) || 0;
}

function getDimensions( elem ) {
	var raw = elem[0];
	if ( raw.nodeType === 9 ) {
		return {
			width: elem.width(),
			height: elem.height(),
			offset: { top: 0, left: 0 }
		};
	}
	if ( $.isWindow( raw ) ) {
		return {
			width: elem.width(),
			height: elem.height(),
			offset: { top: elem.scrollTop(), left: elem.scrollLeft() }
		};
	}
	if ( raw.preventDefault ) {
		return {
			width: 0,
			height: 0,
			offset: { top: raw.pageY, left: raw.pageX }
		};
	}
	return {
		width: elem.outerWidth(),
		height: elem.outerHeight(),
		offset: elem.offset()
	};
}

$.position = {
	scrollbarWidth: function() {
		if ( cachedScrollbarWidth !== undefined ) {
			return cachedScrollbarWidth;
		}
		var w1, w2,
			div = $( "<div style='display:block;width:50px;height:50px;overflow:hidden;'><div style='height:100px;width:auto;'></div></div>" ),
			innerDiv = div.children()[0];

		$( "body" ).append( div );
		w1 = innerDiv.offsetWidth;
		div.css( "overflow", "scroll" );

		w2 = innerDiv.offsetWidth;

		if ( w1 === w2 ) {
			w2 = div[0].clientWidth;
		}

		div.remove();

		return (cachedScrollbarWidth = w1 - w2);
	},
	getScrollInfo: function( within ) {
		var overflowX = within.isWindow ? "" : within.element.css( "overflow-x" ),
			overflowY = within.isWindow ? "" : within.element.css( "overflow-y" ),
			hasOverflowX = overflowX === "scroll" ||
				( overflowX === "auto" && within.width < within.element[0].scrollWidth ),
			hasOverflowY = overflowY === "scroll" ||
				( overflowY === "auto" && within.height < within.element[0].scrollHeight );
		return {
			width: hasOverflowY ? $.position.scrollbarWidth() : 0,
			height: hasOverflowX ? $.position.scrollbarWidth() : 0
		};
	},
	getWithinInfo: function( element ) {
		var withinElement = $( element || window ),
			isWindow = $.isWindow( withinElement[0] );
		return {
			element: withinElement,
			isWindow: isWindow,
			offset: withinElement.offset() || { left: 0, top: 0 },
			scrollLeft: withinElement.scrollLeft(),
			scrollTop: withinElement.scrollTop(),
			width: isWindow ? withinElement.width() : withinElement.outerWidth(),
			height: isWindow ? withinElement.height() : withinElement.outerHeight()
		};
	}
};

$.fn.position = function( options ) {
	if ( !options || !options.of ) {
		return _position.apply( this, arguments );
	}

	// make a copy, we don't want to modify arguments
	options = $.extend( {}, options );

	var atOffset, targetWidth, targetHeight, targetOffset, basePosition, dimensions,
		target = $( options.of ),
		within = $.position.getWithinInfo( options.within ),
		scrollInfo = $.position.getScrollInfo( within ),
		collision = ( options.collision || "flip" ).split( " " ),
		offsets = {};

	dimensions = getDimensions( target );
	if ( target[0].preventDefault ) {
		// force left top to allow flipping
		options.at = "left top";
	}
	targetWidth = dimensions.width;
	targetHeight = dimensions.height;
	targetOffset = dimensions.offset;
	// clone to reuse original targetOffset later
	basePosition = $.extend( {}, targetOffset );

	// force my and at to have valid horizontal and vertical positions
	// if a value is missing or invalid, it will be converted to center
	$.each( [ "my", "at" ], function() {
		var pos = ( options[ this ] || "" ).split( " " ),
			horizontalOffset,
			verticalOffset;

		if ( pos.length === 1) {
			pos = rhorizontal.test( pos[ 0 ] ) ?
				pos.concat( [ "center" ] ) :
				rvertical.test( pos[ 0 ] ) ?
					[ "center" ].concat( pos ) :
					[ "center", "center" ];
		}
		pos[ 0 ] = rhorizontal.test( pos[ 0 ] ) ? pos[ 0 ] : "center";
		pos[ 1 ] = rvertical.test( pos[ 1 ] ) ? pos[ 1 ] : "center";

		// calculate offsets
		horizontalOffset = roffset.exec( pos[ 0 ] );
		verticalOffset = roffset.exec( pos[ 1 ] );
		offsets[ this ] = [
			horizontalOffset ? horizontalOffset[ 0 ] : 0,
			verticalOffset ? verticalOffset[ 0 ] : 0
		];

		// reduce to just the positions without the offsets
		options[ this ] = [
			rposition.exec( pos[ 0 ] )[ 0 ],
			rposition.exec( pos[ 1 ] )[ 0 ]
		];
	});

	// normalize collision option
	if ( collision.length === 1 ) {
		collision[ 1 ] = collision[ 0 ];
	}

	if ( options.at[ 0 ] === "right" ) {
		basePosition.left += targetWidth;
	} else if ( options.at[ 0 ] === "center" ) {
		basePosition.left += targetWidth / 2;
	}

	if ( options.at[ 1 ] === "bottom" ) {
		basePosition.top += targetHeight;
	} else if ( options.at[ 1 ] === "center" ) {
		basePosition.top += targetHeight / 2;
	}

	atOffset = getOffsets( offsets.at, targetWidth, targetHeight );
	basePosition.left += atOffset[ 0 ];
	basePosition.top += atOffset[ 1 ];

	return this.each(function() {
		var collisionPosition, using,
			elem = $( this ),
			elemWidth = elem.outerWidth(),
			elemHeight = elem.outerHeight(),
			marginLeft = parseCss( this, "marginLeft" ),
			marginTop = parseCss( this, "marginTop" ),
			collisionWidth = elemWidth + marginLeft + parseCss( this, "marginRight" ) + scrollInfo.width,
			collisionHeight = elemHeight + marginTop + parseCss( this, "marginBottom" ) + scrollInfo.height,
			position = $.extend( {}, basePosition ),
			myOffset = getOffsets( offsets.my, elem.outerWidth(), elem.outerHeight() );

		if ( options.my[ 0 ] === "right" ) {
			position.left -= elemWidth;
		} else if ( options.my[ 0 ] === "center" ) {
			position.left -= elemWidth / 2;
		}

		if ( options.my[ 1 ] === "bottom" ) {
			position.top -= elemHeight;
		} else if ( options.my[ 1 ] === "center" ) {
			position.top -= elemHeight / 2;
		}

		position.left += myOffset[ 0 ];
		position.top += myOffset[ 1 ];

		// if the browser doesn't support fractions, then round for consistent results
		if ( !$.support.offsetFractions ) {
			position.left = round( position.left );
			position.top = round( position.top );
		}

		collisionPosition = {
			marginLeft: marginLeft,
			marginTop: marginTop
		};

		$.each( [ "left", "top" ], function( i, dir ) {
			if ( $.ui.position[ collision[ i ] ] ) {
				$.ui.position[ collision[ i ] ][ dir ]( position, {
					targetWidth: targetWidth,
					targetHeight: targetHeight,
					elemWidth: elemWidth,
					elemHeight: elemHeight,
					collisionPosition: collisionPosition,
					collisionWidth: collisionWidth,
					collisionHeight: collisionHeight,
					offset: [ atOffset[ 0 ] + myOffset[ 0 ], atOffset [ 1 ] + myOffset[ 1 ] ],
					my: options.my,
					at: options.at,
					within: within,
					elem : elem
				});
			}
		});

		if ( options.using ) {
			// adds feedback as second argument to using callback, if present
			using = function( props ) {
				var left = targetOffset.left - position.left,
					right = left + targetWidth - elemWidth,
					top = targetOffset.top - position.top,
					bottom = top + targetHeight - elemHeight,
					feedback = {
						target: {
							element: target,
							left: targetOffset.left,
							top: targetOffset.top,
							width: targetWidth,
							height: targetHeight
						},
						element: {
							element: elem,
							left: position.left,
							top: position.top,
							width: elemWidth,
							height: elemHeight
						},
						horizontal: right < 0 ? "left" : left > 0 ? "right" : "center",
						vertical: bottom < 0 ? "top" : top > 0 ? "bottom" : "middle"
					};
				if ( targetWidth < elemWidth && abs( left + right ) < targetWidth ) {
					feedback.horizontal = "center";
				}
				if ( targetHeight < elemHeight && abs( top + bottom ) < targetHeight ) {
					feedback.vertical = "middle";
				}
				if ( max( abs( left ), abs( right ) ) > max( abs( top ), abs( bottom ) ) ) {
					feedback.important = "horizontal";
				} else {
					feedback.important = "vertical";
				}
				options.using.call( this, props, feedback );
			};
		}

		elem.offset( $.extend( position, { using: using } ) );
	});
};

$.ui.position = {
	fit: {
		left: function( position, data ) {
			var within = data.within,
				withinOffset = within.isWindow ? within.scrollLeft : within.offset.left,
				outerWidth = within.width,
				collisionPosLeft = position.left - data.collisionPosition.marginLeft,
				overLeft = withinOffset - collisionPosLeft,
				overRight = collisionPosLeft + data.collisionWidth - outerWidth - withinOffset,
				newOverRight;

			// element is wider than within
			if ( data.collisionWidth > outerWidth ) {
				// element is initially over the left side of within
				if ( overLeft > 0 && overRight <= 0 ) {
					newOverRight = position.left + overLeft + data.collisionWidth - outerWidth - withinOffset;
					position.left += overLeft - newOverRight;
				// element is initially over right side of within
				} else if ( overRight > 0 && overLeft <= 0 ) {
					position.left = withinOffset;
				// element is initially over both left and right sides of within
				} else {
					if ( overLeft > overRight ) {
						position.left = withinOffset + outerWidth - data.collisionWidth;
					} else {
						position.left = withinOffset;
					}
				}
			// too far left -> align with left edge
			} else if ( overLeft > 0 ) {
				position.left += overLeft;
			// too far right -> align with right edge
			} else if ( overRight > 0 ) {
				position.left -= overRight;
			// adjust based on position and margin
			} else {
				position.left = max( position.left - collisionPosLeft, position.left );
			}
		},
		top: function( position, data ) {
			var within = data.within,
				withinOffset = within.isWindow ? within.scrollTop : within.offset.top,
				outerHeight = data.within.height,
				collisionPosTop = position.top - data.collisionPosition.marginTop,
				overTop = withinOffset - collisionPosTop,
				overBottom = collisionPosTop + data.collisionHeight - outerHeight - withinOffset,
				newOverBottom;

			// element is taller than within
			if ( data.collisionHeight > outerHeight ) {
				// element is initially over the top of within
				if ( overTop > 0 && overBottom <= 0 ) {
					newOverBottom = position.top + overTop + data.collisionHeight - outerHeight - withinOffset;
					position.top += overTop - newOverBottom;
				// element is initially over bottom of within
				} else if ( overBottom > 0 && overTop <= 0 ) {
					position.top = withinOffset;
				// element is initially over both top and bottom of within
				} else {
					if ( overTop > overBottom ) {
						position.top = withinOffset + outerHeight - data.collisionHeight;
					} else {
						position.top = withinOffset;
					}
				}
			// too far up -> align with top
			} else if ( overTop > 0 ) {
				position.top += overTop;
			// too far down -> align with bottom edge
			} else if ( overBottom > 0 ) {
				position.top -= overBottom;
			// adjust based on position and margin
			} else {
				position.top = max( position.top - collisionPosTop, position.top );
			}
		}
	},
	flip: {
		left: function( position, data ) {
			var within = data.within,
				withinOffset = within.offset.left + within.scrollLeft,
				outerWidth = within.width,
				offsetLeft = within.isWindow ? within.scrollLeft : within.offset.left,
				collisionPosLeft = position.left - data.collisionPosition.marginLeft,
				overLeft = collisionPosLeft - offsetLeft,
				overRight = collisionPosLeft + data.collisionWidth - outerWidth - offsetLeft,
				myOffset = data.my[ 0 ] === "left" ?
					-data.elemWidth :
					data.my[ 0 ] === "right" ?
						data.elemWidth :
						0,
				atOffset = data.at[ 0 ] === "left" ?
					data.targetWidth :
					data.at[ 0 ] === "right" ?
						-data.targetWidth :
						0,
				offset = -2 * data.offset[ 0 ],
				newOverRight,
				newOverLeft;

			if ( overLeft < 0 ) {
				newOverRight = position.left + myOffset + atOffset + offset + data.collisionWidth - outerWidth - withinOffset;
				if ( newOverRight < 0 || newOverRight < abs( overLeft ) ) {
					position.left += myOffset + atOffset + offset;
				}
			}
			else if ( overRight > 0 ) {
				newOverLeft = position.left - data.collisionPosition.marginLeft + myOffset + atOffset + offset - offsetLeft;
				if ( newOverLeft > 0 || abs( newOverLeft ) < overRight ) {
					position.left += myOffset + atOffset + offset;
				}
			}
		},
		top: function( position, data ) {
			var within = data.within,
				withinOffset = within.offset.top + within.scrollTop,
				outerHeight = within.height,
				offsetTop = within.isWindow ? within.scrollTop : within.offset.top,
				collisionPosTop = position.top - data.collisionPosition.marginTop,
				overTop = collisionPosTop - offsetTop,
				overBottom = collisionPosTop + data.collisionHeight - outerHeight - offsetTop,
				top = data.my[ 1 ] === "top",
				myOffset = top ?
					-data.elemHeight :
					data.my[ 1 ] === "bottom" ?
						data.elemHeight :
						0,
				atOffset = data.at[ 1 ] === "top" ?
					data.targetHeight :
					data.at[ 1 ] === "bottom" ?
						-data.targetHeight :
						0,
				offset = -2 * data.offset[ 1 ],
				newOverTop,
				newOverBottom;
			if ( overTop < 0 ) {
				newOverBottom = position.top + myOffset + atOffset + offset + data.collisionHeight - outerHeight - withinOffset;
				if ( ( position.top + myOffset + atOffset + offset) > overTop && ( newOverBottom < 0 || newOverBottom < abs( overTop ) ) ) {
					position.top += myOffset + atOffset + offset;
				}
			}
			else if ( overBottom > 0 ) {
				newOverTop = position.top -  data.collisionPosition.marginTop + myOffset + atOffset + offset - offsetTop;
				if ( ( position.top + myOffset + atOffset + offset) > overBottom && ( newOverTop > 0 || abs( newOverTop ) < overBottom ) ) {
					position.top += myOffset + atOffset + offset;
				}
			}
		}
	},
	flipfit: {
		left: function() {
			$.ui.position.flip.left.apply( this, arguments );
			$.ui.position.fit.left.apply( this, arguments );
		},
		top: function() {
			$.ui.position.flip.top.apply( this, arguments );
			$.ui.position.fit.top.apply( this, arguments );
		}
	}
};

// fraction support test
(function () {
	var testElement, testElementParent, testElementStyle, offsetLeft, i,
		body = document.getElementsByTagName( "body" )[ 0 ],
		div = document.createElement( "div" );

	//Create a "fake body" for testing based on method used in jQuery.support
	testElement = document.createElement( body ? "div" : "body" );
	testElementStyle = {
		visibility: "hidden",
		width: 0,
		height: 0,
		border: 0,
		margin: 0,
		background: "none"
	};
	if ( body ) {
		$.extend( testElementStyle, {
			position: "absolute",
			left: "-1000px",
			top: "-1000px"
		});
	}
	for ( i in testElementStyle ) {
		testElement.style[ i ] = testElementStyle[ i ];
	}
	testElement.appendChild( div );
	testElementParent = body || document.documentElement;
	testElementParent.insertBefore( testElement, testElementParent.firstChild );

	div.style.cssText = "position: absolute; left: 10.7432222px;";

	offsetLeft = $( div ).offset().left;
	$.support.offsetFractions = offsetLeft > 10 && offsetLeft < 11;

	testElement.innerHTML = "";
	testElementParent.removeChild( testElement );
})();

}( jQuery ) );


	return jQuery;
});

/* ---- Module:jquery.ui.mouse ---- */

define("jquery/ui/mouse", ["jquery/ui/widget"], function (jQuery) {

/*!
 * jQuery UI Mouse 1.10.2
 * http://jqueryui.com
 *
 * Copyright 2013 jQuery Foundation and other contributors
 * Released under the MIT license.
 * http://jquery.org/license
 *
 * http://api.jqueryui.com/mouse/
 *
 * Depends:
 *	jquery.ui.widget.js
 */
(function( $, undefined ) {

var mouseHandled = false;
$( document ).mouseup( function() {
	mouseHandled = false;
});

$.widget("ui.mouse", {
	version: "1.10.2",
	options: {
		cancel: "input,textarea,button,select,option",
		distance: 1,
		delay: 0
	},
	_mouseInit: function() {
		var that = this;

		this.element
			.bind("mousedown."+this.widgetName, function(event) {
				return that._mouseDown(event);
			})
			.bind("click."+this.widgetName, function(event) {
				if (true === $.data(event.target, that.widgetName + ".preventClickEvent")) {
					$.removeData(event.target, that.widgetName + ".preventClickEvent");
					event.stopImmediatePropagation();
					return false;
				}
			});

		this.started = false;
	},

	// TODO: make sure destroying one instance of mouse doesn't mess with
	// other instances of mouse
	_mouseDestroy: function() {
		this.element.unbind("."+this.widgetName);
		if ( this._mouseMoveDelegate ) {
			$(document)
				.unbind("mousemove."+this.widgetName, this._mouseMoveDelegate)
				.unbind("mouseup."+this.widgetName, this._mouseUpDelegate);
		}
	},

	_mouseDown: function(event) {
		// don't let more than one widget handle mouseStart
		if( mouseHandled ) { return; }

		// we may have missed mouseup (out of window)
		(this._mouseStarted && this._mouseUp(event));

		this._mouseDownEvent = event;

		var that = this,
			btnIsLeft = (event.which === 1),
			// event.target.nodeName works around a bug in IE 8 with
			// disabled inputs (#7620)
			elIsCancel = (typeof this.options.cancel === "string" && event.target.nodeName ? $(event.target).closest(this.options.cancel).length : false);
		if (!btnIsLeft || elIsCancel || !this._mouseCapture(event)) {
			return true;
		}

		this.mouseDelayMet = !this.options.delay;
		if (!this.mouseDelayMet) {
			this._mouseDelayTimer = setTimeout(function() {
				that.mouseDelayMet = true;
			}, this.options.delay);
		}

		if (this._mouseDistanceMet(event) && this._mouseDelayMet(event)) {
			this._mouseStarted = (this._mouseStart(event) !== false);
			if (!this._mouseStarted) {
				event.preventDefault();
				return true;
			}
		}

		// Click event may never have fired (Gecko & Opera)
		if (true === $.data(event.target, this.widgetName + ".preventClickEvent")) {
			$.removeData(event.target, this.widgetName + ".preventClickEvent");
		}

		// these delegates are required to keep context
		this._mouseMoveDelegate = function(event) {
			return that._mouseMove(event);
		};
		this._mouseUpDelegate = function(event) {
			return that._mouseUp(event);
		};
		$(document)
			.bind("mousemove."+this.widgetName, this._mouseMoveDelegate)
			.bind("mouseup."+this.widgetName, this._mouseUpDelegate);

		event.preventDefault();

		mouseHandled = true;
		return true;
	},

	_mouseMove: function(event) {
		// IE mouseup check - mouseup happened when mouse was out of window
		if ($.ui.ie && ( !document.documentMode || document.documentMode < 9 ) && !event.button) {
			return this._mouseUp(event);
		}

		if (this._mouseStarted) {
			this._mouseDrag(event);
			return event.preventDefault();
		}

		if (this._mouseDistanceMet(event) && this._mouseDelayMet(event)) {
			this._mouseStarted =
				(this._mouseStart(this._mouseDownEvent, event) !== false);
			(this._mouseStarted ? this._mouseDrag(event) : this._mouseUp(event));
		}

		return !this._mouseStarted;
	},

	_mouseUp: function(event) {
		$(document)
			.unbind("mousemove."+this.widgetName, this._mouseMoveDelegate)
			.unbind("mouseup."+this.widgetName, this._mouseUpDelegate);

		if (this._mouseStarted) {
			this._mouseStarted = false;

			if (event.target === this._mouseDownEvent.target) {
				$.data(event.target, this.widgetName + ".preventClickEvent", true);
			}

			this._mouseStop(event);
		}

		return false;
	},

	_mouseDistanceMet: function(event) {
		return (Math.max(
				Math.abs(this._mouseDownEvent.pageX - event.pageX),
				Math.abs(this._mouseDownEvent.pageY - event.pageY)
			) >= this.options.distance
		);
	},

	_mouseDelayMet: function(/* event */) {
		return this.mouseDelayMet;
	},

	// These are placeholder methods, to be overriden by extending plugin
	_mouseStart: function(/* event */) {},
	_mouseDrag: function(/* event */) {},
	_mouseStop: function(/* event */) {},
	_mouseCapture: function(/* event */) { return true; }
});

})(jQuery);


	return jQuery;
});

/* ---- Module:jquery.ui.dialog ---- */

define("jquery/ui/dialog", ["jquery/ui/core", "jquery/ui/widget", "jquery/ui/button", "jquery/ui/draggable", "jquery/ui/mouse", "jquery/ui/position", "jquery/ui/resizable"], function (jQuery) {

/*!
 * jQuery UI Dialog 1.10.2
 * http://jqueryui.com
 *
 * Copyright 2013 jQuery Foundation and other contributors
 * Released under the MIT license.
 * http://jquery.org/license
 *
 * http://api.jqueryui.com/dialog/
 *
 * Depends:
 *	jquery.ui.core.js
 *	jquery.ui.widget.js
 *  jquery.ui.button.js
 *	jquery.ui.draggable.js
 *	jquery.ui.mouse.js
 *	jquery.ui.position.js
 *	jquery.ui.resizable.js
 */
(function( $, undefined ) {

var sizeRelatedOptions = {
		buttons: true,
		height: true,
		maxHeight: true,
		maxWidth: true,
		minHeight: true,
		minWidth: true,
		width: true
	},
	resizableRelatedOptions = {
		maxHeight: true,
		maxWidth: true,
		minHeight: true,
		minWidth: true
	};

$.widget( "ui.dialog", {
	version: "1.10.2",
	options: {
		appendTo: "body",
		autoOpen: true,
		buttons: [],
		closeOnEscape: true,
		closeText: "close",
		dialogClass: "",
		draggable: true,
		hide: null,
		height: "auto",
		maxHeight: null,
		maxWidth: null,
		minHeight: 150,
		minWidth: 150,
		modal: false,
		position: {
			my: "center",
			at: "center",
			of: window,
			collision: "fit",
			// Ensure the titlebar is always visible
			using: function( pos ) {
				var topOffset = $( this ).css( pos ).offset().top;
				if ( topOffset < 0 ) {
					$( this ).css( "top", pos.top - topOffset );
				}
			}
		},
		resizable: true,
		show: null,
		title: null,
		width: 300,

		// callbacks
		beforeClose: null,
		close: null,
		drag: null,
		dragStart: null,
		dragStop: null,
		focus: null,
		open: null,
		resize: null,
		resizeStart: null,
		resizeStop: null
	},

	_create: function() {
		this.originalCss = {
			display: this.element[0].style.display,
			width: this.element[0].style.width,
			minHeight: this.element[0].style.minHeight,
			maxHeight: this.element[0].style.maxHeight,
			height: this.element[0].style.height
		};
		this.originalPosition = {
			parent: this.element.parent(),
			index: this.element.parent().children().index( this.element )
		};
		this.originalTitle = this.element.attr("title");
		this.options.title = this.options.title || this.originalTitle;

		this._createWrapper();

		this.element
			.show()
			.removeAttr("title")
			.addClass("ui-dialog-content ui-widget-content")
			.appendTo( this.uiDialog );

		this._createTitlebar();
		this._createButtonPane();

		if ( this.options.draggable && $.fn.draggable ) {
			this._makeDraggable();
		}
		if ( this.options.resizable && $.fn.resizable ) {
			this._makeResizable();
		}

		this._isOpen = false;
	},

	_init: function() {
		if ( this.options.autoOpen ) {
			this.open();
		}
	},

	_appendTo: function() {
		var element = this.options.appendTo;
		if ( element && (element.jquery || element.nodeType) ) {
			return $( element );
		}
		return this.document.find( element || "body" ).eq( 0 );
	},

	_destroy: function() {
		var next,
			originalPosition = this.originalPosition;

		this._destroyOverlay();

		this.element
			.removeUniqueId()
			.removeClass("ui-dialog-content ui-widget-content")
			.css( this.originalCss )
			// Without detaching first, the following becomes really slow
			.detach();

		this.uiDialog.stop( true, true ).remove();

		if ( this.originalTitle ) {
			this.element.attr( "title", this.originalTitle );
		}

		next = originalPosition.parent.children().eq( originalPosition.index );
		// Don't try to place the dialog next to itself (#8613)
		if ( next.length && next[0] !== this.element[0] ) {
			next.before( this.element );
		} else {
			originalPosition.parent.append( this.element );
		}
	},

	widget: function() {
		return this.uiDialog;
	},

	disable: $.noop,
	enable: $.noop,

	close: function( event ) {
		var that = this;

		if ( !this._isOpen || this._trigger( "beforeClose", event ) === false ) {
			return;
		}

		this._isOpen = false;
		this._destroyOverlay();

		if ( !this.opener.filter(":focusable").focus().length ) {
			// Hiding a focused element doesn't trigger blur in WebKit
			// so in case we have nothing to focus on, explicitly blur the active element
			// https://bugs.webkit.org/show_bug.cgi?id=47182
			$( this.document[0].activeElement ).blur();
		}

		this._hide( this.uiDialog, this.options.hide, function() {
			that._trigger( "close", event );
		});
	},

	isOpen: function() {
		return this._isOpen;
	},

	moveToTop: function() {
		this._moveToTop();
	},

	_moveToTop: function( event, silent ) {
		var moved = !!this.uiDialog.nextAll(":visible").insertBefore( this.uiDialog ).length;
		if ( moved && !silent ) {
			this._trigger( "focus", event );
		}
		return moved;
	},

	open: function() {
		var that = this;
		if ( this._isOpen ) {
			if ( this._moveToTop() ) {
				this._focusTabbable();
			}
			return;
		}

		this._isOpen = true;
		this.opener = $( this.document[0].activeElement );

		this._size();
		this._position();
		this._createOverlay();
		this._moveToTop( null, true );
		this._show( this.uiDialog, this.options.show, function() {
			that._focusTabbable();
			that._trigger("focus");
		});

		this._trigger("open");
	},

	_focusTabbable: function() {
		// Set focus to the first match:
		// 1. First element inside the dialog matching [autofocus]
		// 2. Tabbable element inside the content element
		// 3. Tabbable element inside the buttonpane
		// 4. The close button
		// 5. The dialog itself
		var hasFocus = this.element.find("[autofocus]");
		if ( !hasFocus.length ) {
			hasFocus = this.element.find(":tabbable");
		}
		if ( !hasFocus.length ) {
			hasFocus = this.uiDialogButtonPane.find(":tabbable");
		}
		if ( !hasFocus.length ) {
			hasFocus = this.uiDialogTitlebarClose.filter(":tabbable");
		}
		if ( !hasFocus.length ) {
			hasFocus = this.uiDialog;
		}
		hasFocus.eq( 0 ).focus();
	},

	_keepFocus: function( event ) {
		function checkFocus() {
			var activeElement = this.document[0].activeElement,
				isActive = this.uiDialog[0] === activeElement ||
					$.contains( this.uiDialog[0], activeElement );
			if ( !isActive ) {
				this._focusTabbable();
			}
		}
		event.preventDefault();
		checkFocus.call( this );
		// support: IE
		// IE <= 8 doesn't prevent moving focus even with event.preventDefault()
		// so we check again later
		this._delay( checkFocus );
	},

	_createWrapper: function() {
		this.uiDialog = $("<div>")
			.addClass( "ui-dialog ui-widget ui-widget-content ui-corner-all ui-front " +
				this.options.dialogClass )
			.hide()
			.attr({
				// Setting tabIndex makes the div focusable
				tabIndex: -1,
				role: "dialog"
			})
			.appendTo( this._appendTo() );

		this._on( this.uiDialog, {
			keydown: function( event ) {
				if ( this.options.closeOnEscape && !event.isDefaultPrevented() && event.keyCode &&
						event.keyCode === $.ui.keyCode.ESCAPE ) {
					event.preventDefault();
					this.close( event );
					return;
				}

				// prevent tabbing out of dialogs
				if ( event.keyCode !== $.ui.keyCode.TAB ) {
					return;
				}
				var tabbables = this.uiDialog.find(":tabbable"),
					first = tabbables.filter(":first"),
					last  = tabbables.filter(":last");

				if ( ( event.target === last[0] || event.target === this.uiDialog[0] ) && !event.shiftKey ) {
					first.focus( 1 );
					event.preventDefault();
				} else if ( ( event.target === first[0] || event.target === this.uiDialog[0] ) && event.shiftKey ) {
					last.focus( 1 );
					event.preventDefault();
				}
			},
			mousedown: function( event ) {
				if ( this._moveToTop( event ) ) {
					this._focusTabbable();
				}
			}
		});

		// We assume that any existing aria-describedby attribute means
		// that the dialog content is marked up properly
		// otherwise we brute force the content as the description
		if ( !this.element.find("[aria-describedby]").length ) {
			this.uiDialog.attr({
				"aria-describedby": this.element.uniqueId().attr("id")
			});
		}
	},

	_createTitlebar: function() {
		var uiDialogTitle;

		this.uiDialogTitlebar = $("<div>")
			.addClass("ui-dialog-titlebar ui-widget-header ui-corner-all ui-helper-clearfix")
			.prependTo( this.uiDialog );
		this._on( this.uiDialogTitlebar, {
			mousedown: function( event ) {
				// Don't prevent click on close button (#8838)
				// Focusing a dialog that is partially scrolled out of view
				// causes the browser to scroll it into view, preventing the click event
				if ( !$( event.target ).closest(".ui-dialog-titlebar-close") ) {
					// Dialog isn't getting focus when dragging (#8063)
					this.uiDialog.focus();
				}
			}
		});

		this.uiDialogTitlebarClose = $("<button></button>")
/*
 * ePages: BEGIN
 */
			.attr("type", "button")
/*
 * ePages: END
 */
			.button({
				label: this.options.closeText,
				icons: {
					primary: "ui-icon-closethick"
				},
				text: false
			})
			.addClass("ui-dialog-titlebar-close")
			.appendTo( this.uiDialogTitlebar );
		this._on( this.uiDialogTitlebarClose, {
			click: function( event ) {
				event.preventDefault();
				this.close( event );
			}
		});

		uiDialogTitle = $("<span>")
			.uniqueId()
			.addClass("ui-dialog-title")
			.prependTo( this.uiDialogTitlebar );
		this._title( uiDialogTitle );

		this.uiDialog.attr({
			"aria-labelledby": uiDialogTitle.attr("id")
		});
	},

	_title: function( title ) {
		if ( !this.options.title ) {
			title.html("&#160;");
		}
		title.text( this.options.title );
	},

	_createButtonPane: function() {
		this.uiDialogButtonPane = $("<div>")
			.addClass("ui-dialog-buttonpane ui-widget-content ui-helper-clearfix");

		this.uiButtonSet = $("<div>")
			.addClass("ui-dialog-buttonset")
			.appendTo( this.uiDialogButtonPane );

		this._createButtons();
	},

	_createButtons: function() {
		var that = this,
			buttons = this.options.buttons;

		// if we already have a button pane, remove it
		this.uiDialogButtonPane.remove();
		this.uiButtonSet.empty();

		if ( $.isEmptyObject( buttons ) || ($.isArray( buttons ) && !buttons.length) ) {
			this.uiDialog.removeClass("ui-dialog-buttons");
			return;
		}

		$.each( buttons, function( name, props ) {
			var click, buttonOptions;
			props = $.isFunction( props ) ?
				{ click: props, text: name } :
				props;
			// Default to a non-submitting button
			props = $.extend( { type: "button" }, props );
			// Change the context for the click callback to be the main element
			click = props.click;
			props.click = function() {
				click.apply( that.element[0], arguments );
			};
			buttonOptions = {
				icons: props.icons,
				text: props.showText
			};
			delete props.icons;
			delete props.showText;
			$( "<button></button>", props )
				.button( buttonOptions )
				.appendTo( that.uiButtonSet );
		});
		this.uiDialog.addClass("ui-dialog-buttons");
		this.uiDialogButtonPane.appendTo( this.uiDialog );
	},

	_makeDraggable: function() {
		var that = this,
			options = this.options;

		function filteredUi( ui ) {
			return {
				position: ui.position,
				offset: ui.offset
			};
		}

		this.uiDialog.draggable({
			cancel: ".ui-dialog-content, .ui-dialog-titlebar-close",
			handle: ".ui-dialog-titlebar",
			containment: "document",
			start: function( event, ui ) {
				$( this ).addClass("ui-dialog-dragging");
				that._blockFrames();
				that._trigger( "dragStart", event, filteredUi( ui ) );
			},
			drag: function( event, ui ) {
				that._trigger( "drag", event, filteredUi( ui ) );
			},
			stop: function( event, ui ) {
				options.position = [
					ui.position.left - that.document.scrollLeft(),
					ui.position.top - that.document.scrollTop()
				];
				$( this ).removeClass("ui-dialog-dragging");
				that._unblockFrames();
				that._trigger( "dragStop", event, filteredUi( ui ) );
			}
		});
	},

	_makeResizable: function() {
		var that = this,
			options = this.options,
			handles = options.resizable,
			// .ui-resizable has position: relative defined in the stylesheet
			// but dialogs have to use absolute or fixed positioning
			position = this.uiDialog.css("position"),
			resizeHandles = typeof handles === "string" ?
				handles	:
				"n,e,s,w,se,sw,ne,nw";

		function filteredUi( ui ) {
			return {
				originalPosition: ui.originalPosition,
				originalSize: ui.originalSize,
				position: ui.position,
				size: ui.size
			};
		}

		this.uiDialog.resizable({
			cancel: ".ui-dialog-content",
			containment: "document",
			alsoResize: this.element,
			maxWidth: options.maxWidth,
			maxHeight: options.maxHeight,
			minWidth: options.minWidth,
			minHeight: this._minHeight(),
			handles: resizeHandles,
			start: function( event, ui ) {
				$( this ).addClass("ui-dialog-resizing");
				that._blockFrames();
				that._trigger( "resizeStart", event, filteredUi( ui ) );
			},
			resize: function( event, ui ) {
				that._trigger( "resize", event, filteredUi( ui ) );
			},
			stop: function( event, ui ) {
				options.height = $( this ).height();
				options.width = $( this ).width();
				$( this ).removeClass("ui-dialog-resizing");
				that._unblockFrames();
				that._trigger( "resizeStop", event, filteredUi( ui ) );
			}
		})
		.css( "position", position );
	},

	_minHeight: function() {
		var options = this.options;

		return options.height === "auto" ?
			options.minHeight :
			Math.min( options.minHeight, options.height );
	},

	_position: function() {
		// Need to show the dialog to get the actual offset in the position plugin
		var isVisible = this.uiDialog.is(":visible");
		if ( !isVisible ) {
			this.uiDialog.show();
		}
		this.uiDialog.position( this.options.position );
		if ( !isVisible ) {
			this.uiDialog.hide();
		}
	},

	_setOptions: function( options ) {
		var that = this,
			resize = false,
			resizableOptions = {};

		$.each( options, function( key, value ) {
			that._setOption( key, value );

			if ( key in sizeRelatedOptions ) {
				resize = true;
			}
			if ( key in resizableRelatedOptions ) {
				resizableOptions[ key ] = value;
			}
		});

		if ( resize ) {
			this._size();
			this._position();
		}
		if ( this.uiDialog.is(":data(ui-resizable)") ) {
			this.uiDialog.resizable( "option", resizableOptions );
		}
	},

	_setOption: function( key, value ) {
		/*jshint maxcomplexity:15*/
		var isDraggable, isResizable,
			uiDialog = this.uiDialog;

		if ( key === "dialogClass" ) {
			uiDialog
				.removeClass( this.options.dialogClass )
				.addClass( value );
		}

		if ( key === "disabled" ) {
			return;
		}

		this._super( key, value );

		if ( key === "appendTo" ) {
			this.uiDialog.appendTo( this._appendTo() );
		}

		if ( key === "buttons" ) {
			this._createButtons();
		}

		if ( key === "closeText" ) {
			this.uiDialogTitlebarClose.button({
				// Ensure that we always pass a string
				label: "" + value
			});
		}

		if ( key === "draggable" ) {
			isDraggable = uiDialog.is(":data(ui-draggable)");
			if ( isDraggable && !value ) {
				uiDialog.draggable("destroy");
			}

			if ( !isDraggable && value ) {
				this._makeDraggable();
			}
		}

		if ( key === "position" ) {
			this._position();
		}

		if ( key === "resizable" ) {
			// currently resizable, becoming non-resizable
			isResizable = uiDialog.is(":data(ui-resizable)");
			if ( isResizable && !value ) {
				uiDialog.resizable("destroy");
			}

			// currently resizable, changing handles
			if ( isResizable && typeof value === "string" ) {
				uiDialog.resizable( "option", "handles", value );
			}

			// currently non-resizable, becoming resizable
			if ( !isResizable && value !== false ) {
				this._makeResizable();
			}
		}

		if ( key === "title" ) {
			this._title( this.uiDialogTitlebar.find(".ui-dialog-title") );
		}
	},

	_size: function() {
		// If the user has resized the dialog, the .ui-dialog and .ui-dialog-content
		// divs will both have width and height set, so we need to reset them
		var nonContentHeight, minContentHeight, maxContentHeight,
			options = this.options;

		// Reset content sizing
		this.element.show().css({
			width: "auto",
			minHeight: 0,
			maxHeight: "none",
			height: 0
		});

		if ( options.minWidth > options.width ) {
			options.width = options.minWidth;
		}

		// reset wrapper sizing
		// determine the height of all the non-content elements
		nonContentHeight = this.uiDialog.css({
				height: "auto",
				width: options.width
			})
			.outerHeight();
		minContentHeight = Math.max( 0, options.minHeight - nonContentHeight );
		maxContentHeight = typeof options.maxHeight === "number" ?
			Math.max( 0, options.maxHeight - nonContentHeight ) :
			"none";

		if ( options.height === "auto" ) {
			this.element.css({
				minHeight: minContentHeight,
				maxHeight: maxContentHeight,
				height: "auto"
			});
		} else {
			this.element.height( Math.max( 0, options.height - nonContentHeight ) );
		}

		if (this.uiDialog.is(":data(ui-resizable)") ) {
			this.uiDialog.resizable( "option", "minHeight", this._minHeight() );
		}
	},

	_blockFrames: function() {
		this.iframeBlocks = this.document.find( "iframe" ).map(function() {
			var iframe = $( this );

			return $( "<div>" )
				.css({
					position: "absolute",
					width: iframe.outerWidth(),
					height: iframe.outerHeight()
				})
				.appendTo( iframe.parent() )
				.offset( iframe.offset() )[0];
		});
	},

	_unblockFrames: function() {
		if ( this.iframeBlocks ) {
			this.iframeBlocks.remove();
			delete this.iframeBlocks;
		}
	},

	_allowInteraction: function( event ) {
/*
 * ePages: BEGIN
 *		EPG-29085 - MBO: Color Picker: Inserting color code in setup assistant doesn't work!
 *		if ( $( event.target ).closest(".ui-dialog").length ) {
 */
		if ( $( event.target ).closest(".ui-front").length ) {
/*
 * ePages: END
 */
			return true;
		}

		// TODO: Remove hack when datepicker implements
		// the .ui-front logic (#8989)
		return !!$( event.target ).closest(".ui-datepicker").length;
	},

	_createOverlay: function() {
		if ( !this.options.modal ) {
			return;
		}

		var that = this,
			widgetFullName = this.widgetFullName;
		if ( !$.ui.dialog.overlayInstances ) {
			// Prevent use of anchors and inputs.
			// We use a delay in case the overlay is created from an
			// event that we're going to be cancelling. (#2804)
			this._delay(function() {
				// Handle .dialog().dialog("close") (#4065)
				if ( $.ui.dialog.overlayInstances ) {
					this.document.bind( "focusin.dialog", function( event ) {
						if ( !that._allowInteraction( event ) ) {
							event.preventDefault();
							$(".ui-dialog:visible:last .ui-dialog-content")
								.data( widgetFullName )._focusTabbable();
						}
					});
				}
			});
		}

		this.overlay = $("<div>")
			.addClass("ui-widget-overlay ui-front")
			.appendTo( this._appendTo() );
		this._on( this.overlay, {
			mousedown: "_keepFocus"
		});
		$.ui.dialog.overlayInstances++;
	},

	_destroyOverlay: function() {
		if ( !this.options.modal ) {
			return;
		}

		if ( this.overlay ) {
			$.ui.dialog.overlayInstances--;

			if ( !$.ui.dialog.overlayInstances ) {
				this.document.unbind( "focusin.dialog" );
			}
			this.overlay.remove();
			this.overlay = null;
		}
	}
});

$.ui.dialog.overlayInstances = 0;

// DEPRECATED
if ( $.uiBackCompat !== false ) {
	// position option with array notation
	// just override with old implementation
	$.widget( "ui.dialog", $.ui.dialog, {
		_position: function() {
			var position = this.options.position,
				myAt = [],
				offset = [ 0, 0 ],
				isVisible;

			if ( position ) {
				if ( typeof position === "string" || (typeof position === "object" && "0" in position ) ) {
					myAt = position.split ? position.split(" ") : [ position[0], position[1] ];
					if ( myAt.length === 1 ) {
						myAt[1] = myAt[0];
					}

					$.each( [ "left", "top" ], function( i, offsetPosition ) {
						if ( +myAt[ i ] === myAt[ i ] ) {
							offset[ i ] = myAt[ i ];
							myAt[ i ] = offsetPosition;
						}
					});

					position = {
						my: myAt[0] + (offset[0] < 0 ? offset[0] : "+" + offset[0]) + " " +
							myAt[1] + (offset[1] < 0 ? offset[1] : "+" + offset[1]),
						at: myAt.join(" ")
					};
				}

				position = $.extend( {}, $.ui.dialog.prototype.options.position, position );
			} else {
				position = $.ui.dialog.prototype.options.position;
			}

			// need to show the dialog to get the actual offset in the position plugin
			isVisible = this.uiDialog.is(":visible");
			if ( !isVisible ) {
				this.uiDialog.show();
			}
			this.uiDialog.position( position );
			if ( !isVisible ) {
				this.uiDialog.hide();
			}
		}
	});
}

}( jQuery ) );


	return jQuery;
});

/* ---- Module:jquery.ui.tabs ---- */

define("jquery/ui/tabs", ["jquery/ui/core", "jquery/ui/widget"], function (jQuery) {

/*!
 * jQuery UI Tabs 1.10.2
 * http://jqueryui.com
 *
 * Copyright 2013 jQuery Foundation and other contributors
 * Released under the MIT license.
 * http://jquery.org/license
 *
 * http://api.jqueryui.com/tabs/
 *
 * Depends:
 *	jquery.ui.core.js
 *	jquery.ui.widget.js
 */
(function( $, undefined ) {

var tabId = 0,
	rhash = /#.*$/;

function getNextTabId() {
	return ++tabId;
}

function isLocal( anchor ) {
/*
 * ePages: BEGIN
 */
 	if (/^#/.test(anchor.getAttribute("href"))) {
		return true;
	}
/*
 * ePages: END
 */
	return anchor.hash.length > 1 &&
		decodeURIComponent( anchor.href.replace( rhash, "" ) ) ===
			decodeURIComponent( location.href.replace( rhash, "" ) );
}

$.widget( "ui.tabs", {
	version: "1.10.2",
	delay: 300,
	options: {
		active: null,
		collapsible: false,
		event: "click",
		heightStyle: "content",
		hide: null,
		show: null,

		// callbacks
		activate: null,
		beforeActivate: null,
		beforeLoad: null,
		load: null
	},

	_create: function() {
		var that = this,
			options = this.options;

		this.running = false;

		this.element
			.addClass( "ui-tabs ui-widget ui-widget-content ui-corner-all" )
			.toggleClass( "ui-tabs-collapsible", options.collapsible )
			// Prevent users from focusing disabled tabs via click
			.delegate( ".ui-tabs-nav > li", "mousedown" + this.eventNamespace, function( event ) {
				if ( $( this ).is( ".ui-state-disabled" ) ) {
					event.preventDefault();
				}
			})
			// support: IE <9
			// Preventing the default action in mousedown doesn't prevent IE
			// from focusing the element, so if the anchor gets focused, blur.
			// We don't have to worry about focusing the previously focused
			// element since clicking on a non-focusable element should focus
			// the body anyway.
			.delegate( ".ui-tabs-anchor", "focus" + this.eventNamespace, function() {
				if ( $( this ).closest( "li" ).is( ".ui-state-disabled" ) ) {
					this.blur();
				}
			});

		this._processTabs();
		options.active = this._initialActive();

		// Take disabling tabs via class attribute from HTML
		// into account and update option properly.
		if ( $.isArray( options.disabled ) ) {
			options.disabled = $.unique( options.disabled.concat(
				$.map( this.tabs.filter( ".ui-state-disabled" ), function( li ) {
					return that.tabs.index( li );
				})
			) ).sort();
		}

		// check for length avoids error when initializing empty list
		if ( this.options.active !== false && this.anchors.length ) {
			this.active = this._findActive( options.active );
		} else {
			this.active = $();
		}

		this._refresh();

		if ( this.active.length ) {
			this.load( options.active );
		}
	},

	_initialActive: function() {
		var active = this.options.active,
			collapsible = this.options.collapsible,
			locationHash = location.hash.substring( 1 );

		if ( active === null ) {
			// check the fragment identifier in the URL
			if ( locationHash ) {
				this.tabs.each(function( i, tab ) {
					if ( $( tab ).attr( "aria-controls" ) === locationHash ) {
						active = i;
						return false;
					}
				});
			}

			// check for a tab marked active via a class
			if ( active === null ) {
				active = this.tabs.index( this.tabs.filter( ".ui-tabs-active" ) );
			}

			// no active tab, set to false
			if ( active === null || active === -1 ) {
				active = this.tabs.length ? 0 : false;
			}
		}

		// handle numbers: negative, out of range
		if ( active !== false ) {
			active = this.tabs.index( this.tabs.eq( active ) );
			if ( active === -1 ) {
				active = collapsible ? false : 0;
			}
		}

		// don't allow collapsible: false and active: false
		if ( !collapsible && active === false && this.anchors.length ) {
			active = 0;
		}

		return active;
	},

	_getCreateEventData: function() {
		return {
			tab: this.active,
			panel: !this.active.length ? $() : this._getPanelForTab( this.active )
		};
	},

	_tabKeydown: function( event ) {
		/*jshint maxcomplexity:15*/
		var focusedTab = $( this.document[0].activeElement ).closest( "li" ),
			selectedIndex = this.tabs.index( focusedTab ),
			goingForward = true;

		if ( this._handlePageNav( event ) ) {
			return;
		}

		switch ( event.keyCode ) {
			case $.ui.keyCode.RIGHT:
			case $.ui.keyCode.DOWN:
				selectedIndex++;
				break;
			case $.ui.keyCode.UP:
			case $.ui.keyCode.LEFT:
				goingForward = false;
				selectedIndex--;
				break;
			case $.ui.keyCode.END:
				selectedIndex = this.anchors.length - 1;
				break;
			case $.ui.keyCode.HOME:
				selectedIndex = 0;
				break;
			case $.ui.keyCode.SPACE:
				// Activate only, no collapsing
				event.preventDefault();
				clearTimeout( this.activating );
				this._activate( selectedIndex );
				return;
			case $.ui.keyCode.ENTER:
				// Toggle (cancel delayed activation, allow collapsing)
				event.preventDefault();
				clearTimeout( this.activating );
				// Determine if we should collapse or activate
				this._activate( selectedIndex === this.options.active ? false : selectedIndex );
				return;
			default:
				return;
		}

		// Focus the appropriate tab, based on which key was pressed
		event.preventDefault();
		clearTimeout( this.activating );
		selectedIndex = this._focusNextTab( selectedIndex, goingForward );

		// Navigating with control key will prevent automatic activation
		if ( !event.ctrlKey ) {
			// Update aria-selected immediately so that AT think the tab is already selected.
			// Otherwise AT may confuse the user by stating that they need to activate the tab,
			// but the tab will already be activated by the time the announcement finishes.
			focusedTab.attr( "aria-selected", "false" );
			this.tabs.eq( selectedIndex ).attr( "aria-selected", "true" );

			this.activating = this._delay(function() {
				this.option( "active", selectedIndex );
			}, this.delay );
		}
	},

	_panelKeydown: function( event ) {
		if ( this._handlePageNav( event ) ) {
			return;
		}

		// Ctrl+up moves focus to the current tab
		if ( event.ctrlKey && event.keyCode === $.ui.keyCode.UP ) {
			event.preventDefault();
			this.active.focus();
		}
	},

	// Alt+page up/down moves focus to the previous/next tab (and activates)
	_handlePageNav: function( event ) {
		if ( event.altKey && event.keyCode === $.ui.keyCode.PAGE_UP ) {
			this._activate( this._focusNextTab( this.options.active - 1, false ) );
			return true;
		}
		if ( event.altKey && event.keyCode === $.ui.keyCode.PAGE_DOWN ) {
			this._activate( this._focusNextTab( this.options.active + 1, true ) );
			return true;
		}
	},

	_findNextTab: function( index, goingForward ) {
		var lastTabIndex = this.tabs.length - 1;

		function constrain() {
			if ( index > lastTabIndex ) {
				index = 0;
			}
			if ( index < 0 ) {
				index = lastTabIndex;
			}
			return index;
		}

		while ( $.inArray( constrain(), this.options.disabled ) !== -1 ) {
			index = goingForward ? index + 1 : index - 1;
		}

		return index;
	},

	_focusNextTab: function( index, goingForward ) {
		index = this._findNextTab( index, goingForward );
		this.tabs.eq( index ).focus();
		return index;
	},

	_setOption: function( key, value ) {
		if ( key === "active" ) {
			// _activate() will handle invalid values and update this.options
			this._activate( value );
			return;
		}

		if ( key === "disabled" ) {
			// don't use the widget factory's disabled handling
			this._setupDisabled( value );
			return;
		}

		this._super( key, value);

		if ( key === "collapsible" ) {
			this.element.toggleClass( "ui-tabs-collapsible", value );
			// Setting collapsible: false while collapsed; open first panel
			if ( !value && this.options.active === false ) {
				this._activate( 0 );
			}
		}

		if ( key === "event" ) {
			this._setupEvents( value );
		}

		if ( key === "heightStyle" ) {
			this._setupHeightStyle( value );
		}
	},

	_tabId: function( tab ) {
		return tab.attr( "aria-controls" ) || "ui-tabs-" + getNextTabId();
	},

	_sanitizeSelector: function( hash ) {
		return hash ? hash.replace( /[!"$%&'()*+,.\/:;<=>?@\[\]\^`{|}~]/g, "\\$&" ) : "";
	},

	refresh: function() {
		var options = this.options,
			lis = this.tablist.children( ":has(a[href])" );

		// get disabled tabs from class attribute from HTML
		// this will get converted to a boolean if needed in _refresh()
		options.disabled = $.map( lis.filter( ".ui-state-disabled" ), function( tab ) {
			return lis.index( tab );
		});

		this._processTabs();

		// was collapsed or no tabs
		if ( options.active === false || !this.anchors.length ) {
			options.active = false;
			this.active = $();
		// was active, but active tab is gone
		} else if ( this.active.length && !$.contains( this.tablist[ 0 ], this.active[ 0 ] ) ) {
			// all remaining tabs are disabled
			if ( this.tabs.length === options.disabled.length ) {
				options.active = false;
				this.active = $();
			// activate previous tab
			} else {
				this._activate( this._findNextTab( Math.max( 0, options.active - 1 ), false ) );
			}
		// was active, active tab still exists
		} else {
			// make sure active index is correct
			options.active = this.tabs.index( this.active );
		}

		this._refresh();
	},

	_refresh: function() {
		this._setupDisabled( this.options.disabled );
		this._setupEvents( this.options.event );
		this._setupHeightStyle( this.options.heightStyle );

		this.tabs.not( this.active ).attr({
			"aria-selected": "false",
			tabIndex: -1
		});
		this.panels.not( this._getPanelForTab( this.active ) )
			.hide()
			.attr({
				"aria-expanded": "false",
				"aria-hidden": "true"
			});

		// Make sure one tab is in the tab order
		if ( !this.active.length ) {
			this.tabs.eq( 0 ).attr( "tabIndex", 0 );
		} else {
			this.active
				.addClass( "ui-tabs-active ui-state-active" )
				.attr({
					"aria-selected": "true",
					tabIndex: 0
				});
			this._getPanelForTab( this.active )
				.show()
				.attr({
					"aria-expanded": "true",
					"aria-hidden": "false"
				});
		}
	},

	_processTabs: function() {
		var that = this;

		this.tablist = this._getList()
			.addClass( "ui-tabs-nav ui-helper-reset ui-helper-clearfix ui-widget-header ui-corner-all" )
			.attr( "role", "tablist" );

		this.tabs = this.tablist.find( "> li:has(a[href])" )
			.addClass( "ui-state-default ui-corner-top" )
			.attr({
				role: "tab",
				tabIndex: -1
			});

		this.anchors = this.tabs.map(function() {
				return $( "a", this )[ 0 ];
			})
			.addClass( "ui-tabs-anchor" )
			.attr({
				role: "presentation",
				tabIndex: -1
			});

		this.panels = $();

		this.anchors.each(function( i, anchor ) {
			var selector, panel, panelId,
				anchorId = $( anchor ).uniqueId().attr( "id" ),
				tab = $( anchor ).closest( "li" ),
				originalAriaControls = tab.attr( "aria-controls" );

			// inline tab
			if ( isLocal( anchor ) ) {
				selector = anchor.hash;
				panel = that.element.find( that._sanitizeSelector( selector ) );
			// remote tab
			} else {
				panelId = that._tabId( tab );
				selector = "#" + panelId;
				panel = that.element.find( selector );
				if ( !panel.length ) {
					panel = that._createPanel( panelId );
					panel.insertAfter( that.panels[ i - 1 ] || that.tablist );
				}
				panel.attr( "aria-live", "polite" );
			}

			if ( panel.length) {
				that.panels = that.panels.add( panel );
			}
			if ( originalAriaControls ) {
				tab.data( "ui-tabs-aria-controls", originalAriaControls );
			}
			tab.attr({
				"aria-controls": selector.substring( 1 ),
				"aria-labelledby": anchorId
			});
			panel.attr( "aria-labelledby", anchorId );
		});

		this.panels
			.addClass( "ui-tabs-panel ui-widget-content ui-corner-bottom" )
			.attr( "role", "tabpanel" );
	},

	// allow overriding how to find the list for rare usage scenarios (#7715)
	_getList: function() {
		return this.element.find( "ol,ul" ).eq( 0 );
	},

	_createPanel: function( id ) {
		return $( "<div>" )
			.attr( "id", id )
			.addClass( "ui-tabs-panel ui-widget-content ui-corner-bottom" )
			.data( "ui-tabs-destroy", true );
	},

	_setupDisabled: function( disabled ) {
		if ( $.isArray( disabled ) ) {
			if ( !disabled.length ) {
				disabled = false;
			} else if ( disabled.length === this.anchors.length ) {
				disabled = true;
			}
		}

		// disable tabs
		for ( var i = 0, li; ( li = this.tabs[ i ] ); i++ ) {
			if ( disabled === true || $.inArray( i, disabled ) !== -1 ) {
				$( li )
					.addClass( "ui-state-disabled" )
					.attr( "aria-disabled", "true" );
			} else {
				$( li )
					.removeClass( "ui-state-disabled" )
					.removeAttr( "aria-disabled" );
			}
		}

		this.options.disabled = disabled;
	},

	_setupEvents: function( event ) {
		var events = {
			click: function( event ) {
				event.preventDefault();
			}
		};
		if ( event ) {
			$.each( event.split(" "), function( index, eventName ) {
				events[ eventName ] = "_eventHandler";
			});
		}

		this._off( this.anchors.add( this.tabs ).add( this.panels ) );
		this._on( this.anchors, events );
		this._on( this.tabs, { keydown: "_tabKeydown" } );
		this._on( this.panels, { keydown: "_panelKeydown" } );

		this._focusable( this.tabs );
		this._hoverable( this.tabs );
	},

	_setupHeightStyle: function( heightStyle ) {
		var maxHeight,
			parent = this.element.parent();

		if ( heightStyle === "fill" ) {
			maxHeight = parent.height();
			maxHeight -= this.element.outerHeight() - this.element.height();

			this.element.siblings( ":visible" ).each(function() {
				var elem = $( this ),
					position = elem.css( "position" );

				if ( position === "absolute" || position === "fixed" ) {
					return;
				}
				maxHeight -= elem.outerHeight( true );
			});

			this.element.children().not( this.panels ).each(function() {
				maxHeight -= $( this ).outerHeight( true );
			});

			this.panels.each(function() {
				$( this ).height( Math.max( 0, maxHeight -
					$( this ).innerHeight() + $( this ).height() ) );
			})
			.css( "overflow", "auto" );
		} else if ( heightStyle === "auto" ) {
			maxHeight = 0;
			this.panels.each(function() {
				maxHeight = Math.max( maxHeight, $( this ).height( "" ).height() );
			}).height( maxHeight );
		}
	},

	_eventHandler: function( event ) {
		var options = this.options,
			active = this.active,
			anchor = $( event.currentTarget ),
			tab = anchor.closest( "li" ),
			clickedIsActive = tab[ 0 ] === active[ 0 ],
			collapsing = clickedIsActive && options.collapsible,
			toShow = collapsing ? $() : this._getPanelForTab( tab ),
			toHide = !active.length ? $() : this._getPanelForTab( active ),
			eventData = {
				oldTab: active,
				oldPanel: toHide,
				newTab: collapsing ? $() : tab,
				newPanel: toShow
			};

		event.preventDefault();

		if ( tab.hasClass( "ui-state-disabled" ) ||
				// tab is already loading
				tab.hasClass( "ui-tabs-loading" ) ||
				// can't switch durning an animation
				this.running ||
				// click on active header, but not collapsible
				( clickedIsActive && !options.collapsible ) ||
				// allow canceling activation
				( this._trigger( "beforeActivate", event, eventData ) === false ) ) {
			return;
		}

		options.active = collapsing ? false : this.tabs.index( tab );

		this.active = clickedIsActive ? $() : tab;
		if ( this.xhr ) {
			this.xhr.abort();
		}

		if ( !toHide.length && !toShow.length ) {
			$.error( "jQuery UI Tabs: Mismatching fragment identifier." );
		}

		if ( toShow.length ) {
			this.load( this.tabs.index( tab ), event );
		}
		this._toggle( event, eventData );
	},

	// handles show/hide for selecting tabs
	_toggle: function( event, eventData ) {
		var that = this,
			toShow = eventData.newPanel,
			toHide = eventData.oldPanel;

		this.running = true;

		function complete() {
			that.running = false;
			that._trigger( "activate", event, eventData );
		}

		function show() {
			eventData.newTab.closest( "li" ).addClass( "ui-tabs-active ui-state-active" );

			if ( toShow.length && that.options.show ) {
				that._show( toShow, that.options.show, complete );
			} else {
				toShow.show();
				complete();
			}
		}

		// start out by hiding, then showing, then completing
		if ( toHide.length && this.options.hide ) {
			this._hide( toHide, this.options.hide, function() {
				eventData.oldTab.closest( "li" ).removeClass( "ui-tabs-active ui-state-active" );
				show();
			});
		} else {
			eventData.oldTab.closest( "li" ).removeClass( "ui-tabs-active ui-state-active" );
			toHide.hide();
			show();
		}

		toHide.attr({
			"aria-expanded": "false",
			"aria-hidden": "true"
		});
		eventData.oldTab.attr( "aria-selected", "false" );
		// If we're switching tabs, remove the old tab from the tab order.
		// If we're opening from collapsed state, remove the previous tab from the tab order.
		// If we're collapsing, then keep the collapsing tab in the tab order.
		if ( toShow.length && toHide.length ) {
			eventData.oldTab.attr( "tabIndex", -1 );
		} else if ( toShow.length ) {
			this.tabs.filter(function() {
				return $( this ).attr( "tabIndex" ) === 0;
			})
			.attr( "tabIndex", -1 );
		}

		toShow.attr({
			"aria-expanded": "true",
			"aria-hidden": "false"
		});
		eventData.newTab.attr({
			"aria-selected": "true",
			tabIndex: 0
		});
	},

	_activate: function( index ) {
		var anchor,
			active = this._findActive( index );

		// trying to activate the already active panel
		if ( active[ 0 ] === this.active[ 0 ] ) {
			return;
		}

		// trying to collapse, simulate a click on the current active header
		if ( !active.length ) {
			active = this.active;
		}

		anchor = active.find( ".ui-tabs-anchor" )[ 0 ];
		this._eventHandler({
			target: anchor,
			currentTarget: anchor,
			preventDefault: $.noop
		});
	},

	_findActive: function( index ) {
		return index === false ? $() : this.tabs.eq( index );
	},

	_getIndex: function( index ) {
		// meta-function to give users option to provide a href string instead of a numerical index.
		if ( typeof index === "string" ) {
			index = this.anchors.index( this.anchors.filter( "[href$='" + index + "']" ) );
		}

		return index;
	},

	_destroy: function() {
		if ( this.xhr ) {
			this.xhr.abort();
		}

		this.element.removeClass( "ui-tabs ui-widget ui-widget-content ui-corner-all ui-tabs-collapsible" );

		this.tablist
			.removeClass( "ui-tabs-nav ui-helper-reset ui-helper-clearfix ui-widget-header ui-corner-all" )
			.removeAttr( "role" );

		this.anchors
			.removeClass( "ui-tabs-anchor" )
			.removeAttr( "role" )
			.removeAttr( "tabIndex" )
			.removeUniqueId();

		this.tabs.add( this.panels ).each(function() {
			if ( $.data( this, "ui-tabs-destroy" ) ) {
				$( this ).remove();
			} else {
				$( this )
					.removeClass( "ui-state-default ui-state-active ui-state-disabled " +
						"ui-corner-top ui-corner-bottom ui-widget-content ui-tabs-active ui-tabs-panel" )
					.removeAttr( "tabIndex" )
					.removeAttr( "aria-live" )
					.removeAttr( "aria-busy" )
					.removeAttr( "aria-selected" )
					.removeAttr( "aria-labelledby" )
					.removeAttr( "aria-hidden" )
					.removeAttr( "aria-expanded" )
					.removeAttr( "role" );
			}
		});

		this.tabs.each(function() {
			var li = $( this ),
				prev = li.data( "ui-tabs-aria-controls" );
			if ( prev ) {
				li
					.attr( "aria-controls", prev )
					.removeData( "ui-tabs-aria-controls" );
			} else {
				li.removeAttr( "aria-controls" );
			}
		});

		this.panels.show();

		if ( this.options.heightStyle !== "content" ) {
			this.panels.css( "height", "" );
		}
	},

	enable: function( index ) {
		var disabled = this.options.disabled;
		if ( disabled === false ) {
			return;
		}

		if ( index === undefined ) {
			disabled = false;
		} else {
			index = this._getIndex( index );
			if ( $.isArray( disabled ) ) {
				disabled = $.map( disabled, function( num ) {
					return num !== index ? num : null;
				});
			} else {
				disabled = $.map( this.tabs, function( li, num ) {
					return num !== index ? num : null;
				});
			}
		}
		this._setupDisabled( disabled );
	},

	disable: function( index ) {
		var disabled = this.options.disabled;
		if ( disabled === true ) {
			return;
		}

		if ( index === undefined ) {
			disabled = true;
		} else {
			index = this._getIndex( index );
			if ( $.inArray( index, disabled ) !== -1 ) {
				return;
			}
			if ( $.isArray( disabled ) ) {
				disabled = $.merge( [ index ], disabled ).sort();
			} else {
				disabled = [ index ];
			}
		}
		this._setupDisabled( disabled );
	},

	load: function( index, event ) {
		index = this._getIndex( index );
		var that = this,
			tab = this.tabs.eq( index ),
			anchor = tab.find( ".ui-tabs-anchor" ),
			panel = this._getPanelForTab( tab ),
			eventData = {
				tab: tab,
				panel: panel
			};

		// not remote
		if ( isLocal( anchor[ 0 ] ) ) {
			return;
		}

		this.xhr = $.ajax( this._ajaxSettings( anchor, event, eventData ) );

		// support: jQuery <1.8
		// jQuery <1.8 returns false if the request is canceled in beforeSend,
		// but as of 1.8, $.ajax() always returns a jqXHR object.
		if ( this.xhr && this.xhr.statusText !== "canceled" ) {
			tab.addClass( "ui-tabs-loading" );
			panel.attr( "aria-busy", "true" );

			this.xhr
				.success(function( response ) {
					// support: jQuery <1.8
					// http://bugs.jquery.com/ticket/11778
					setTimeout(function() {
						panel.html( response );
						that._trigger( "load", event, eventData );
					}, 1 );
				})
				.complete(function( jqXHR, status ) {
					// support: jQuery <1.8
					// http://bugs.jquery.com/ticket/11778
					setTimeout(function() {
						if ( status === "abort" ) {
							that.panels.stop( false, true );
						}

						tab.removeClass( "ui-tabs-loading" );
						panel.removeAttr( "aria-busy" );

						if ( jqXHR === that.xhr ) {
							delete that.xhr;
						}
					}, 1 );
				});
		}
	},

	_ajaxSettings: function( anchor, event, eventData ) {
		var that = this;
		return {
			url: anchor.attr( "href" ),
			beforeSend: function( jqXHR, settings ) {
				return that._trigger( "beforeLoad", event,
					$.extend( { jqXHR : jqXHR, ajaxSettings: settings }, eventData ) );
			}
		};
	},

	_getPanelForTab: function( tab ) {
		var id = $( tab ).attr( "aria-controls" );
		return this.element.find( this._sanitizeSelector( "#" + id ) );
	}
});

})( jQuery );


	return jQuery;
});

/* ---- Module:jquery.ui.slider ---- */

define("jquery/ui/slider", ["jquery/ui/core", "jquery/ui/mouse", "jquery/ui/widget"], function (jQuery) {

/*!
 * jQuery UI Slider 1.10.2
 * http://jqueryui.com
 *
 * Copyright 2013 jQuery Foundation and other contributors
 * Released under the MIT license.
 * http://jquery.org/license
 *
 * http://api.jqueryui.com/slider/
 *
 * Depends:
 *	jquery.ui.core.js
 *	jquery.ui.mouse.js
 *	jquery.ui.widget.js
 */
(function( $, undefined ) {

// number of pages in a slider
// (how many times can you page up/down to go through the whole range)
var numPages = 5;

$.widget( "ui.slider", $.ui.mouse, {
	version: "1.10.2",
	widgetEventPrefix: "slide",

	options: {
		animate: false,
		distance: 0,
		max: 100,
		min: 0,
		orientation: "horizontal",
		range: false,
		step: 1,
		value: 0,
		values: null,

		// callbacks
		change: null,
		slide: null,
		start: null,
		stop: null
	},

	_create: function() {
		this._keySliding = false;
		this._mouseSliding = false;
		this._animateOff = true;
		this._handleIndex = null;
		this._detectOrientation();
		this._mouseInit();

		this.element
			.addClass( "ui-slider" +
				" ui-slider-" + this.orientation +
				" ui-widget" +
				" ui-widget-content" +
				" ui-corner-all");

		this._refresh();
		this._setOption( "disabled", this.options.disabled );

		this._animateOff = false;
	},

	_refresh: function() {
		this._createRange();
		this._createHandles();
		this._setupEvents();
		this._refreshValue();
	},

	_createHandles: function() {
		var i, handleCount,
			options = this.options,
			existingHandles = this.element.find( ".ui-slider-handle" ).addClass( "ui-state-default ui-corner-all" ),
			handle = "<a class='ui-slider-handle ui-state-default ui-corner-all' href='#'></a>",
			handles = [];

		handleCount = ( options.values && options.values.length ) || 1;

		if ( existingHandles.length > handleCount ) {
			existingHandles.slice( handleCount ).remove();
			existingHandles = existingHandles.slice( 0, handleCount );
		}

		for ( i = existingHandles.length; i < handleCount; i++ ) {
			handles.push( handle );
		}

		this.handles = existingHandles.add( $( handles.join( "" ) ).appendTo( this.element ) );

		this.handle = this.handles.eq( 0 );

		this.handles.each(function( i ) {
			$( this ).data( "ui-slider-handle-index", i );
		});
	},

	_createRange: function() {
		var options = this.options,
			classes = "";

		if ( options.range ) {
			if ( options.range === true ) {
				if ( !options.values ) {
					options.values = [ this._valueMin(), this._valueMin() ];
				} else if ( options.values.length && options.values.length !== 2 ) {
					options.values = [ options.values[0], options.values[0] ];
				} else if ( $.isArray( options.values ) ) {
					options.values = options.values.slice(0);
				}
			}

			if ( !this.range || !this.range.length ) {
				this.range = $( "<div></div>" )
					.appendTo( this.element );

				classes = "ui-slider-range" +
				// note: this isn't the most fittingly semantic framework class for this element,
				// but worked best visually with a variety of themes
				" ui-widget-header ui-corner-all";
			} else {
				this.range.removeClass( "ui-slider-range-min ui-slider-range-max" )
					// Handle range switching from true to min/max
					.css({
						"left": "",
						"bottom": ""
					});
			}

			this.range.addClass( classes +
				( ( options.range === "min" || options.range === "max" ) ? " ui-slider-range-" + options.range : "" ) );
		} else {
			this.range = $([]);
		}
	},

	_setupEvents: function() {
		var elements = this.handles.add( this.range ).filter( "a" );
		this._off( elements );
		this._on( elements, this._handleEvents );
		this._hoverable( elements );
		this._focusable( elements );
	},

	_destroy: function() {
		this.handles.remove();
		this.range.remove();

		this.element
			.removeClass( "ui-slider" +
				" ui-slider-horizontal" +
				" ui-slider-vertical" +
				" ui-widget" +
				" ui-widget-content" +
				" ui-corner-all" );

		this._mouseDestroy();
	},

	_mouseCapture: function( event ) {
		var position, normValue, distance, closestHandle, index, allowed, offset, mouseOverHandle,
			that = this,
			o = this.options;

		if ( o.disabled ) {
			return false;
		}

		this.elementSize = {
			width: this.element.outerWidth(),
			height: this.element.outerHeight()
		};
		this.elementOffset = this.element.offset();

		position = { x: event.pageX, y: event.pageY };
		normValue = this._normValueFromMouse( position );
		distance = this._valueMax() - this._valueMin() + 1;
		this.handles.each(function( i ) {
			var thisDistance = Math.abs( normValue - that.values(i) );
			if (( distance > thisDistance ) ||
				( distance === thisDistance &&
					(i === that._lastChangedValue || that.values(i) === o.min ))) {
				distance = thisDistance;
				closestHandle = $( this );
				index = i;
			}
		});

		allowed = this._start( event, index );
		if ( allowed === false ) {
			return false;
		}
		this._mouseSliding = true;

		this._handleIndex = index;

		closestHandle
			.addClass( "ui-state-active" )
			.focus();

		offset = closestHandle.offset();
		mouseOverHandle = !$( event.target ).parents().addBack().is( ".ui-slider-handle" );
		this._clickOffset = mouseOverHandle ? { left: 0, top: 0 } : {
			left: event.pageX - offset.left - ( closestHandle.width() / 2 ),
			top: event.pageY - offset.top -
				( closestHandle.height() / 2 ) -
				( parseInt( closestHandle.css("borderTopWidth"), 10 ) || 0 ) -
				( parseInt( closestHandle.css("borderBottomWidth"), 10 ) || 0) +
				( parseInt( closestHandle.css("marginTop"), 10 ) || 0)
		};

		if ( !this.handles.hasClass( "ui-state-hover" ) ) {
			this._slide( event, index, normValue );
		}
		this._animateOff = true;
		return true;
	},

	_mouseStart: function() {
		return true;
	},

	_mouseDrag: function( event ) {
		var position = { x: event.pageX, y: event.pageY },
			normValue = this._normValueFromMouse( position );

		this._slide( event, this._handleIndex, normValue );

		return false;
	},

	_mouseStop: function( event ) {
		this.handles.removeClass( "ui-state-active" );
		this._mouseSliding = false;

		this._stop( event, this._handleIndex );
		this._change( event, this._handleIndex );

		this._handleIndex = null;
		this._clickOffset = null;
		this._animateOff = false;

		return false;
	},

	_detectOrientation: function() {
		this.orientation = ( this.options.orientation === "vertical" ) ? "vertical" : "horizontal";
	},

	_normValueFromMouse: function( position ) {
		var pixelTotal,
			pixelMouse,
			percentMouse,
			valueTotal,
			valueMouse;

		if ( this.orientation === "horizontal" ) {
			pixelTotal = this.elementSize.width;
			pixelMouse = position.x - this.elementOffset.left - ( this._clickOffset ? this._clickOffset.left : 0 );
		} else {
			pixelTotal = this.elementSize.height;
			pixelMouse = position.y - this.elementOffset.top - ( this._clickOffset ? this._clickOffset.top : 0 );
		}

		percentMouse = ( pixelMouse / pixelTotal );
		if ( percentMouse > 1 ) {
			percentMouse = 1;
		}
		if ( percentMouse < 0 ) {
			percentMouse = 0;
		}
		if ( this.orientation === "vertical" ) {
			percentMouse = 1 - percentMouse;
		}

		valueTotal = this._valueMax() - this._valueMin();
		valueMouse = this._valueMin() + percentMouse * valueTotal;

		return this._trimAlignValue( valueMouse );
	},

	_start: function( event, index ) {
		var uiHash = {
			handle: this.handles[ index ],
			value: this.value()
		};
		if ( this.options.values && this.options.values.length ) {
			uiHash.value = this.values( index );
			uiHash.values = this.values();
		}
		return this._trigger( "start", event, uiHash );
	},

	_slide: function( event, index, newVal ) {
		var otherVal,
			newValues,
			allowed;

		if ( this.options.values && this.options.values.length ) {
			otherVal = this.values( index ? 0 : 1 );

			if ( ( this.options.values.length === 2 && this.options.range === true ) &&
					( ( index === 0 && newVal > otherVal) || ( index === 1 && newVal < otherVal ) )
				) {
				newVal = otherVal;
			}

			if ( newVal !== this.values( index ) ) {
				newValues = this.values();
				newValues[ index ] = newVal;
				// A slide can be canceled by returning false from the slide callback
				allowed = this._trigger( "slide", event, {
					handle: this.handles[ index ],
					value: newVal,
					values: newValues
				} );
				otherVal = this.values( index ? 0 : 1 );
				if ( allowed !== false ) {
					this.values( index, newVal, true );
				}
			}
		} else {
			if ( newVal !== this.value() ) {
				// A slide can be canceled by returning false from the slide callback
				allowed = this._trigger( "slide", event, {
					handle: this.handles[ index ],
					value: newVal
				} );
				if ( allowed !== false ) {
					this.value( newVal );
				}
			}
		}
	},

	_stop: function( event, index ) {
		var uiHash = {
			handle: this.handles[ index ],
			value: this.value()
		};
		if ( this.options.values && this.options.values.length ) {
			uiHash.value = this.values( index );
			uiHash.values = this.values();
		}

		this._trigger( "stop", event, uiHash );
	},

	_change: function( event, index ) {
		if ( !this._keySliding && !this._mouseSliding ) {
			var uiHash = {
				handle: this.handles[ index ],
				value: this.value()
			};
			if ( this.options.values && this.options.values.length ) {
				uiHash.value = this.values( index );
				uiHash.values = this.values();
			}

			//store the last changed value index for reference when handles overlap
			this._lastChangedValue = index;

			this._trigger( "change", event, uiHash );
		}
	},

	value: function( newValue ) {
		if ( arguments.length ) {
			this.options.value = this._trimAlignValue( newValue );
			this._refreshValue();
			this._change( null, 0 );
			return;
		}

		return this._value();
	},

	values: function( index, newValue ) {
		var vals,
			newValues,
			i;

		if ( arguments.length > 1 ) {
			this.options.values[ index ] = this._trimAlignValue( newValue );
			this._refreshValue();
			this._change( null, index );
			return;
		}

		if ( arguments.length ) {
			if ( $.isArray( arguments[ 0 ] ) ) {
				vals = this.options.values;
				newValues = arguments[ 0 ];
				for ( i = 0; i < vals.length; i += 1 ) {
					vals[ i ] = this._trimAlignValue( newValues[ i ] );
					this._change( null, i );
				}
				this._refreshValue();
			} else {
				if ( this.options.values && this.options.values.length ) {
					return this._values( index );
				} else {
					return this.value();
				}
			}
		} else {
			return this._values();
		}
	},

	_setOption: function( key, value ) {
		var i,
			valsLength = 0;

		if ( key === "range" && this.options.range === true ) {
			if ( value === "min" ) {
				this.options.value = this._values( 0 );
				this.options.values = null;
			} else if ( value === "max" ) {
				this.options.value = this._values( this.options.values.length-1 );
				this.options.values = null;
			}
		}

		if ( $.isArray( this.options.values ) ) {
			valsLength = this.options.values.length;
		}

		$.Widget.prototype._setOption.apply( this, arguments );

		switch ( key ) {
			case "orientation":
				this._detectOrientation();
				this.element
					.removeClass( "ui-slider-horizontal ui-slider-vertical" )
					.addClass( "ui-slider-" + this.orientation );
				this._refreshValue();
				break;
			case "value":
				this._animateOff = true;
				this._refreshValue();
				this._change( null, 0 );
				this._animateOff = false;
				break;
			case "values":
				this._animateOff = true;
				this._refreshValue();
				for ( i = 0; i < valsLength; i += 1 ) {
					this._change( null, i );
				}
				this._animateOff = false;
				break;
			case "min":
			case "max":
				this._animateOff = true;
				this._refreshValue();
				this._animateOff = false;
				break;
			case "range":
				this._animateOff = true;
				this._refresh();
				this._animateOff = false;
				break;
		}
	},

	//internal value getter
	// _value() returns value trimmed by min and max, aligned by step
	_value: function() {
		var val = this.options.value;
		val = this._trimAlignValue( val );

		return val;
	},

	//internal values getter
	// _values() returns array of values trimmed by min and max, aligned by step
	// _values( index ) returns single value trimmed by min and max, aligned by step
	_values: function( index ) {
		var val,
			vals,
			i;

		if ( arguments.length ) {
			val = this.options.values[ index ];
			val = this._trimAlignValue( val );

			return val;
		} else if ( this.options.values && this.options.values.length ) {
			// .slice() creates a copy of the array
			// this copy gets trimmed by min and max and then returned
			vals = this.options.values.slice();
			for ( i = 0; i < vals.length; i+= 1) {
				vals[ i ] = this._trimAlignValue( vals[ i ] );
			}

			return vals;
		} else {
			return [];
		}
	},

	// returns the step-aligned value that val is closest to, between (inclusive) min and max
	_trimAlignValue: function( val ) {
		if ( val <= this._valueMin() ) {
			return this._valueMin();
		}
		if ( val >= this._valueMax() ) {
			return this._valueMax();
		}
		var step = ( this.options.step > 0 ) ? this.options.step : 1,
			valModStep = (val - this._valueMin()) % step,
			alignValue = val - valModStep;

		if ( Math.abs(valModStep) * 2 >= step ) {
			alignValue += ( valModStep > 0 ) ? step : ( -step );
		}

		// Since JavaScript has problems with large floats, round
		// the final value to 5 digits after the decimal point (see #4124)
		return parseFloat( alignValue.toFixed(5) );
	},

	_valueMin: function() {
		return this.options.min;
	},

	_valueMax: function() {
		return this.options.max;
	},

	_refreshValue: function() {
		var lastValPercent, valPercent, value, valueMin, valueMax,
			oRange = this.options.range,
			o = this.options,
			that = this,
			animate = ( !this._animateOff ) ? o.animate : false,
			_set = {};

		if ( this.options.values && this.options.values.length ) {
			this.handles.each(function( i ) {
				valPercent = ( that.values(i) - that._valueMin() ) / ( that._valueMax() - that._valueMin() ) * 100;
				_set[ that.orientation === "horizontal" ? "left" : "bottom" ] = valPercent + "%";
				$( this ).stop( 1, 1 )[ animate ? "animate" : "css" ]( _set, o.animate );
				if ( that.options.range === true ) {
					if ( that.orientation === "horizontal" ) {
						if ( i === 0 ) {
							that.range.stop( 1, 1 )[ animate ? "animate" : "css" ]( { left: valPercent + "%" }, o.animate );
						}
						if ( i === 1 ) {
							that.range[ animate ? "animate" : "css" ]( { width: ( valPercent - lastValPercent ) + "%" }, { queue: false, duration: o.animate } );
						}
					} else {
						if ( i === 0 ) {
							that.range.stop( 1, 1 )[ animate ? "animate" : "css" ]( { bottom: ( valPercent ) + "%" }, o.animate );
						}
						if ( i === 1 ) {
							that.range[ animate ? "animate" : "css" ]( { height: ( valPercent - lastValPercent ) + "%" }, { queue: false, duration: o.animate } );
						}
					}
				}
				lastValPercent = valPercent;
			});
		} else {
			value = this.value();
			valueMin = this._valueMin();
			valueMax = this._valueMax();
			valPercent = ( valueMax !== valueMin ) ?
					( value - valueMin ) / ( valueMax - valueMin ) * 100 :
					0;
			_set[ this.orientation === "horizontal" ? "left" : "bottom" ] = valPercent + "%";
			this.handle.stop( 1, 1 )[ animate ? "animate" : "css" ]( _set, o.animate );

			if ( oRange === "min" && this.orientation === "horizontal" ) {
				this.range.stop( 1, 1 )[ animate ? "animate" : "css" ]( { width: valPercent + "%" }, o.animate );
			}
			if ( oRange === "max" && this.orientation === "horizontal" ) {
				this.range[ animate ? "animate" : "css" ]( { width: ( 100 - valPercent ) + "%" }, { queue: false, duration: o.animate } );
			}
			if ( oRange === "min" && this.orientation === "vertical" ) {
				this.range.stop( 1, 1 )[ animate ? "animate" : "css" ]( { height: valPercent + "%" }, o.animate );
			}
			if ( oRange === "max" && this.orientation === "vertical" ) {
				this.range[ animate ? "animate" : "css" ]( { height: ( 100 - valPercent ) + "%" }, { queue: false, duration: o.animate } );
			}
		}
	},

	_handleEvents: {
		keydown: function( event ) {
			/*jshint maxcomplexity:25*/
			var allowed, curVal, newVal, step,
				index = $( event.target ).data( "ui-slider-handle-index" );

			switch ( event.keyCode ) {
				case $.ui.keyCode.HOME:
				case $.ui.keyCode.END:
				case $.ui.keyCode.PAGE_UP:
				case $.ui.keyCode.PAGE_DOWN:
				case $.ui.keyCode.UP:
				case $.ui.keyCode.RIGHT:
				case $.ui.keyCode.DOWN:
				case $.ui.keyCode.LEFT:
					event.preventDefault();
					if ( !this._keySliding ) {
						this._keySliding = true;
						$( event.target ).addClass( "ui-state-active" );
						allowed = this._start( event, index );
						if ( allowed === false ) {
							return;
						}
					}
					break;
			}

			step = this.options.step;
			if ( this.options.values && this.options.values.length ) {
				curVal = newVal = this.values( index );
			} else {
				curVal = newVal = this.value();
			}

			switch ( event.keyCode ) {
				case $.ui.keyCode.HOME:
					newVal = this._valueMin();
					break;
				case $.ui.keyCode.END:
					newVal = this._valueMax();
					break;
				case $.ui.keyCode.PAGE_UP:
					newVal = this._trimAlignValue( curVal + ( (this._valueMax() - this._valueMin()) / numPages ) );
					break;
				case $.ui.keyCode.PAGE_DOWN:
					newVal = this._trimAlignValue( curVal - ( (this._valueMax() - this._valueMin()) / numPages ) );
					break;
				case $.ui.keyCode.UP:
				case $.ui.keyCode.RIGHT:
					if ( curVal === this._valueMax() ) {
						return;
					}
					newVal = this._trimAlignValue( curVal + step );
					break;
				case $.ui.keyCode.DOWN:
				case $.ui.keyCode.LEFT:
					if ( curVal === this._valueMin() ) {
						return;
					}
					newVal = this._trimAlignValue( curVal - step );
					break;
			}

			this._slide( event, index, newVal );
		},
		click: function( event ) {
			event.preventDefault();
		},
		keyup: function( event ) {
			var index = $( event.target ).data( "ui-slider-handle-index" );

			if ( this._keySliding ) {
				this._keySliding = false;
				this._stop( event, index );
				this._change( event, index );
				$( event.target ).removeClass( "ui-state-active" );
			}
		}
	}

});

}(jQuery));


	return jQuery;
});

/* ---- Module:jquery.i18n ---- */

/*
 * @copyright		© 2012 by Evan Vosberg
 * @info			http://github.com/evanvosberg
 *
 * @license			Licensed under the MIT (http://www.opensource.org/licenses/mit-license.php) license.
 *
 * @based			Microsoft Open Source jQuery Globalization Plugin (http://github.com/nje/jquery-glob)
 *
 * @module			jquery/i18n
 */

(function (undefined) {

	// alias of jQuery
	var $,

		// Module object
		module,

		// Helper script id
		helperId = "$pub!__i18n__",

		// Define the helper
		helperDefine = function () {
			define(helperId, [], function () {

			});
		},

		// Module id/path
		moduleId = "jquery/i18n",

		// Define the module
		moduleDefine = function () {
			define("jquery/i18n", ["jquery", helperId], function ($) {
				return $;
			});
		},

		// Load extened module dependencies
		moduleDepends = function (dependencies) {
			var when = [];

			$.each(dependencies, function (i, name) {
				if (!module[(/^[A-Z]+$/)
					.test(name) ? "currencies" : "regions"][name]) {
					when.push($.ajax({
						// Full url
						url: require.toUrl(moduleConfig.path + "/" + name + ".js"),

						// Cache request in browser
						cache: true,

						// Load as Javascript
						dataType: "script"
					}));
				}
			});

			// Define helper when dependencies loaded;
			$.when.apply($, when)
				.done(helperDefine);
		},

		// Config settings of the module
		moduleConfig;

	// Initialize i18n for jQuery
	require(["jquery"], function (jQuery) {

		// Expose local alias of jQuery
		$ = jQuery;

		// Read module config
		// - Hack to access the module config
		// - In future hopefully it's possible to get access via a global .config method
		// - Example: moduleConfig =  req.config("config")[moduleId] || {}
		moduleConfig = require.s.contexts._.config.config[moduleId] || {};

		var
			// Default regions and currencies are dependencies for the module
			dependencies = [],

			// Map of format shortcuts
			typeMap = {
				"date": "d",
				"dateLong": "D",
				"dateLong-time": "f",
				"dateLong-timeLong": "F",
				"date-time": "l",
				"date-timeLong": "L",
				"time": "t",
				"timeLong": "T",
				"currency": "c",
				"number": "n",
				"percent": "p"
			},

			shortTypeExp = /[dDfFlLtTcnp]/,

			nTypeExp = /[cnp]/,

			curSymbolExp = /\$/,

			escRegexpExp = /([\.$?*|{}\(\)\[\]\\\/\+\^])/g,

			dayPartRegExp = /([^d]|^)(d|dd)([^d]|$)/g,

			infinityExp = /^[+\-]?infinity$/i,

			hexExp = /^0x[a-f0-9]+$/i,

			parseFloatExp = /^[+\-]?\d*\.?\d*(e[+\-]?\d+)?$/,

			// Regular expression for matching date and time tokens in format strings.
			tokenDateExp = /\/|dddd|ddd|dd|d|MMMM|MMM|MM|M|yyyy|yy|y|hh|h|HH|H|mm|m|ss|s|tt|t|fff|ff|f|W|zzz|zz|z|gg|g/g,

			// Regular expression for matching number tokens in format strings.
			tokenNumberExp = /(c\d*|n\d*|p\d*)/g,

			expandFormatExp = /([\^\$\.\*\+\?\|\[\]\(\)\{\}])/g,

			expandSplitExp = /e/i,

			numberTypeExp = /(c|n|p)(\d*)/,

			whiteSpaceExp = /\s+/g,

			cSymbolStrictExp = /(\s*)(\\\$)(\s*)/g,

			cSymbolExp = /\\\$/g,

			pSymbolStrictExp = /(\s*)(%)(\s*)/g,

			pSymbolExp = /%/g,

			nSymbolExp = /n/,

			positiveNumberExp = /[1-9]/,

			altGroupExp = /\u00A0/g,

			patternPartsExp = /n|\$|-|%/g,

			// Build region data object
			regionBuild = function (self, options) {
				var o = $.extend({}, self.settings, options),
					region = module.regions[o.region] || module.regions.en,
					currencies = region.numberFormat.currencies;

				// If a special currency selected
				if (o.currency) {
					var cGlob = module.currencies[o.currency],
						cExtd = currencies[o.currency];

					// Merge special currency with standart currency
					if (!cExtd && cGlob) {
						cExtd = region.numberFormat.currencies[o.currency] = $.extend({}, currencies[""]);
						cExtd.pattern = $.merge($.merge([], cExtd.pattern), cGlob.pattern);
						cExtd.symbol = cGlob.symbol;
						cExtd.decimals = cGlob.decimals;
					}
				}

				// Set current used currency and calendar
				region.numberFormat.currency = currencies[o.currency] || currencies[""];
				region.calendar = region.calendars[o.calendar] || region.calendars.standart;

				return region;
			},

			// Quick i18n call
			quick = function (type, value, options) {
				type = typeMap[type] || type;

				if (!shortTypeExp.test(type)) {
					return null;
				}
				else if (typeof value === "string") {
					if (nTypeExp.test(type)) {
						return this.parseNumber(value, 10, options);
					}
					else {
						return this.parseDate(value, type, options);
					}
				}
				else {
					return this[nTypeExp.test(type) ? "formatNumber" : "formatDate"](value, type, options);
				}
			},

			// Extended module methods and properties
			extended = {
				// module.expStrDate()
				expStrDate: function (format, strict, options) {
					if (typeof strict !== "boolean") {
						options = strict;
						strict = false;
					}
					var region = regionBuild(this, options),
						ret = getParseRegExp(region.calendar, format, strict)
							.regExp;
					return ret.substr(1, ret.length - 2);
				},

				// module.expStrNumber()
				expStrNumber: function (format, strict, options) {
					if (typeof strict !== "boolean") {
						options = strict;
						strict = false;
					}
					var region = regionBuild(this, options),
						ret = getNumberRegExp([region.numberFormat, (options || {})
							.currency], format, strict)
							.regExp;
					return ret.substr(1, ret.length - 2);
				},

				// module.formatNumber()
				formatNumber: function (value, format, options) {
					var region = regionBuild(this, options);
					return formatNumber(value, format, region);
				},

				// module.formatDate()
				formatDate: function (value, format, options) {
					var region = regionBuild(this, options);
					return formatDate(value, format, region);
				},

				// module.parseNumber()
				parseNumber: function (value, radix, options) {
					if (isNaN(radix)) {
						options = radix;
						radix = 10;
					}
					var region = regionBuild(this, options),
						ret = parseNumber(value, radix, region);
					return ret;
				},

				// module.parseDate()
				parseDate: function (value, formats, options) {
					var region = regionBuild(this, options),
						ret = parseDate(value, formats, region);
					return ret;
				},

				// module.settings
				settings: (moduleConfig = $.extend({
					path: "jquery/i18n", // path to load regions and currencies
					region: "en", // default region
					currency: "", // default currency
					calendar: "standard" // default calendar
				}, moduleConfig))
			};

		// module()
		module = $.extend(function (options) {
			if (typeof options !== "string") {
				var context = $.extend(true, function () {
						return quick.apply(context, arguments);
					}, extended, {
						settings: options
					});

				return context;
			}
			else {
				return quick.apply(module, arguments);
			}
		}, extended, {
			regions: {},
			currencies: {}
		});

		// Handle defaults and dependencies
		$.each({
			region: module.settings.region,
			currency: module.settings.currency
		}, function (type, depends) {
			if (depends) {
				// Set dafaults
				if ($.type(depends) === "array") {
					module.settings[type] = depends[0];
				}
				else {
					depends = [depends];
				}

				// Add to dependencies stack
				$.merge(dependencies, depends);
			}
		});

		// Expose i18n module to jQuery
		$.i18n = module;

		// Normalize path
		moduleConfig.path = moduleConfig.path.replace(/\/$/, "");

		// 1.	When defining a region, all fields are required except the ones stated as optional.
		// 2.	You can use $.extend to copy an existing region and provide only the differing values,
		//			a good practice since most regions do not differ too much from the 'default' region.
		//			DO use the 'default' region if you do this, as it is the only one that definitely
		//			exists.
		// 3.	Other plugins may add to the region information provided by extending it. However,
		//			that plugin may extend it prior to the region being defined, or after. Therefore,
		//			do not overwrite values that already exist when defining the baseline for a region,
		//			by extending your region object with the existing one.
		// 4.	Each region should have a ".calendars" object with at least one calendar named "standard"
		//			which serves as the default calendar in use by that region.
		// 5.	Each region should have a ".calendar" object which is the current calendar being used,
		//			it may be dynamically changed at any time to one of the calendars in ".calendars".

		// To define a region, use the following pattern, which handles defining the region based
		// on the 'default region, extending it with the existing region if it exists, and defining
		// it if it does not exist.
		// module.regions.foo = $.extend(true, $.extend(true, {}, module.regions['default'], fooRegion), module.regions.foo)

		var regions = module.regions;
		var en = regions.en = $.extend(true, {
				// A unique name for the region in the form <language code>-<country/region code>
				name: "en",
				// the name of the region in the english language
				englishName: "English",
				// the name of the region in its own language
				nativeName: "English",
				// whether the region uses right-to-left text
				isRTL: false,
				// 'language' is used for so-called "specific" regions.
				// For example, the region "es-CL" means "Spanish, in Chili".
				// It represents the Spanish-speaking region as it is in Chili,
				// which might have different formatting rules or even translations
				// than Spanish in Spain. A "neutral" region is one that is not
				// specific to a region. For example, the region "es" is the generic
				// Spanish region, which may be a more generalized version of the language
				// that may or may not be what a specific region expects.
				// For a specific region like "es-CL", the 'language' field refers to the
				// neutral, generic region information for the language it is using.
				// This is not always a simple matter of the string before the dash.
				// For example, the "zh-Hans" region is netural (Simplified Chinese).
				// And the 'zh-SG' region is Simplified Chinese in Singapore, whose lanugage
				// field is "zh-CHS", not "zh".
				// This field should be used to navigate from a specific region to it's
				// more general, neutral region. If a region is already as general as it
				// can get, the language may refer to itself.
				language: "en",
				// numberFormat defines general number formatting rules, like the digits in
				// each grouping, the group separator, and how negative numbers are displayed.
				numberFormat: {
					_parseRegExp: {},
					// [negativePattern]
					// Note, numberFormat.pattern has no 'positivePattern' unlike percent and currency,
					// but is still defined as an array for consistency with them.
					//  negativePattern: one of "(n)|-n|- n|n-|n -"
					pattern: ["-n"],
					// number of decimal places normally shown
					decimals: 2,
					// string that separates number groups, as in 1,000,000
					",": ",",
					// string that separates a number from the fractional portion, as in 1.99
					".": ".",
					// array of numbers indicating the size of each number group.
					// TODO: more detailed description and example
					groupSizes: [3],
					// symbol used for positive numbers
					"+": "+",
					// symbol used for negative numbers
					"-": "-",
					percent: {
						// [negativePattern, positivePattern]
						//		negativePattern: one of "-n %|-n%|-%n|%-n|%n-|n-%|n%-|-% n|n %-|% n-|% -n|n- %"
						//		positivePattern: one of "n %|n%|%n|% n"
						pattern: ["-n %", "n %"],
						// number of decimal places normally shown
						decimals: 2,
						// array of numbers indicating the size of each number group.
						// TODO: more detailed description and example
						groupSizes: [3],
						// string that separates number groups, as in 1,000,000
						",": ",",
						// string that separates a number from the fractional portion, as in 1.99
						".": ".",
						// symbol used to represent a percentage
						symbol: "%"
					},
					currencies: {
						"": {
							// [negativePattern, positivePattern]
							//		negativePattern: one of "($n)|-$n|$-n|$n-|(n$)|-n$|n-$|n$-|-n $|-$ n|n $-|$ n-|$ -n|n- $|($ n)|(n $)"
							//		positivePattern: one of "$n|n$|$ n|n $"
							pattern: ["($n)", "$n"],
							// number of decimal places normally shown
							decimals: 2,
							// array of numbers indicating the size of each number group.
							// TODO: more detailed description and example
							groupSizes: [3],
							// string that separates number groups, as in 1,000,000
							",": ",",
							// string that separates a number from the fractional portion, as in 1.99
							".": ".",
							// symbol used to represent currency
							symbol: "$"
						}
					}
				},
				// calendars defines all the possible calendars used by this region.
				// There should be at least one defined with name 'standard', and is the default
				// calendar used by the region.
				// A calendar contains information about how dates are formatted, information about
				// the calendar's eras, a standard set of the date formats,
				// translations for day and month names, and if the calendar is not based on the Gregorian
				// calendar, conversion functions to and from the Gregorian calendar.
				calendars: {
					standard: {
						// name that identifies the type of calendar this is
						name: "Gregorian_USEnglish",
						// separator of parts of a date (e.g. '/' in 11/05/1955)
						"/": "/",
						// separator of parts of a time (e.g. ':' in 05:44 PM)
						":": ":",
						// the first day of the week (0 = Sunday, 1 = Monday, etc)
						firstDay: 0,
						days: {
							// full day names
							names: ["Sunday", "Monday", "Tuesday", "Wednesday", "Thursday", "Friday", "Saturday"],
							// abbreviated day names
							namesAbbr: ["Sun", "Mon", "Tue", "Wed", "Thu", "Fri", "Sat"],
							// shortest day names
							namesShort: ["Su", "Mo", "Tu", "We", "Th", "Fr", "Sa"]
						},
						months: {
							// full month names (13 months for lunar calendards -- 13th month should be "" if not lunar)
							names: ["January", "February", "March", "April", "May", "June", "July", "August", "September", "October", "November", "December", ""],
							// abbreviated month names
							namesAbbr: ["Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul", "Aug", "Sep", "Oct", "Nov", "Dec", ""]
						},
						// AM and PM designators in one of these forms:
						// The usual view, and the upper and lower case versions
						//		[standard,lowercase,uppercase]
						// The region does not use AM or PM (likely all standard date formats use 24 hour time)
						//		null
						AM: ["AM", "am", "AM"],
						PM: ["PM", "pm", "PM"],
						eras: [
						// eras in reverse chronological order.
						// name: the name of the era in this region (e.g. A.D., C.E.)
						// start: when the era starts in ticks (gregorian, gmt), null if it is the earliest supported era.
						// offset: offset in years from gregorian calendar
						{
							"name": "A.D.",
							"start": null,
							"offset": 0
						}],
						// minimum of days in the first week of a year
						firstWeekMin: 1,
						// when a two digit year is given, it will never be parsed as a four digit
						// year greater than this year (in the appropriate era for the region)
						// Set it as a full year (e.g. 2031) or use an offset format starting from
						// the current year: "+19" would correspond to 2031 if the current year 2012.
						twoDigitYearMax: 2032,
						// set of predefined date and time patterns used by the region
						// these represent the format someone in this region would expect
						// to see given the portions of the date that are shown.
						patterns: {
							// short date pattern
							d: "M/d/yyyy",
							// long date pattern
							D: "dddd, MMMM dd, yyyy",
							// short time pattern
							t: "h:mm tt",
							// long time pattern
							T: "h:mm:ss tt",
							// short date, short time pattern
							l: "M/d/yyyy h:mm tt",
							// short date, long time pattern
							L: "M/d/yyyy h:mm:ss tt",
							// long date, short time pattern
							f: "dddd, MMMM dd, yyyy h:mm tt",
							// long date, long time pattern
							F: "dddd, MMMM dd, yyyy h:mm:ss tt",
							// month/day pattern
							M: "MMMM dd",
							// month/year pattern
							Y: "yyyy MMMM",
							// S is a sortable format that does not vary by region
							S: "yyyy'/'MM'/'dd' 'HH':'mm':'ss"
						}
						// optional fields for each calendar:
						/*
					monthsGenitive:
						Same as months but used when the day preceeds the month.
						Omit if the region has no genitive distinction in month names.
						For an explaination of genitive months, see http://blogs.msdn.com/michkap/archive/2004/12/25/332259.aspx
					convert:
						Allows for the support of non-gregorian based calendars. This convert object is used to
						to convert a date to and from a gregorian calendar date to handle parsing and formatting.
						The two functions:
							fromGregorian(date)
								Given the date as a parameter, return an array with parts [year, month, day]
								corresponding to the non-gregorian based year, month, and day for the calendar.
							toGregorian(year, month, day)
								Given the non-gregorian year, month, and day, return a new Date() object
								set to the corresponding date in the gregorian calendar.
					*/
					}
				}
			}, regions.en);
		en.calendar = en.calendars.standard;
		en.numberFormat.currency = en.numberFormat.currencies[""];

		// save en as defaults
		module.defaults = $.extend({}, en);

		function startsWith(value, pattern) {
			return value.indexOf(pattern) === 0;
		}

		function endsWith(value, pattern) {
			return value.substr(value.length - pattern.length) === pattern;
		}

		function zeroPad(str, count, left) {
			for (var l = str.length; l < count; l++) {
				str = (left ? ("0" + str) : (str + "0"));
			}
			return str;
		}

		function escRegexpStr(string, except) {
			return string.replace(escRegexpExp, function (ch) {
				if (except && except.indexOf(ch) !== -1) {
					return ch;
				}
				return "\\" + ch;
			});
		}

		// *************************************** Numbers ***************************************

		function parseNumber(value, radix, region) {
			var ret = NaN,
				nf = region.numberFormat,
				pattern = nf.pattern[0];

			// parse currncy and percent also
			if (new RegExp(escRegexpStr(nf.currency.symbol), "")
				.test(value)) {
				nf = nf.currency;
				pattern = $.trim(nf.pattern[0].replace(curSymbolExp, ""));
				value = value.replace(new RegExp(escRegexpStr(nf.symbol), ""), "");
			}
			else if (new RegExp(escRegexpStr(nf.percent.symbol), "")
				.test(value)) {
				nf = nf.percent;
				pattern = $.trim(nf.pattern[0].replace(curSymbolExp, ""));
				value = value.replace(new RegExp(escRegexpStr(nf.symbol), ""), "");
			}

			// $.trim leading and trailing whitespace
			value = $.trim(value);
			nf["+"] = region.numberFormat["+"];
			nf["-"] = region.numberFormat["-"];

			// allow infinity or hexidecimal
			if (infinityExp.test(value)) {
				ret = parseFloat(value, radix);
			}
			else if (!radix && hexExp.test(value)) {
				ret = parseInt(value, 16);
			}
			else {
				var signInfo = parseNegativePattern(value, nf, pattern);
				// determine sign and number
				if (signInfo[0] === "" && pattern !== "-n" && nf.pattern[2]) {
					pattern = $.trim(nf.pattern[0].replace(curSymbolExp, ""));
					signInfo = parseNegativePattern(value, nf, pattern);
				}
				// determine sign and number
				if (signInfo[0] === "" && pattern !== "-n") {
					signInfo = parseNegativePattern(value, nf, "-n");
				}
				var sign = signInfo[0],
					num = signInfo[1];

				sign = sign || "+";
				// determine exponent and number
				var exponent,
					intAndFraction,
					exponentPos = num.indexOf("e");
				if (exponentPos < 0) {
					exponentPos = num.indexOf("E");
				}
				if (exponentPos < 0) {
					intAndFraction = num;
					exponent = null;
				}
				else {
					intAndFraction = num.substr(0, exponentPos);
					exponent = num.substr(exponentPos + 1);
				}
				// determine decimal position
				var integer,
					fraction,
					decSep = nf["."],
					decimalPos = intAndFraction.indexOf(decSep);
				if (decimalPos < 0) {
					integer = intAndFraction;
					fraction = null;
				}
				else {
					integer = intAndFraction.substr(0, decimalPos);
					fraction = intAndFraction.substr(decimalPos + decSep.length);
				}
				// handle groups (e.g. 1,000,000)
				var groupSep = nf[","];
				integer = integer.split(groupSep)
					.join("");
				var altGroupSep = groupSep.replace(altGroupExp, " ");
				if (groupSep !== altGroupSep) {
					integer = integer.split(altGroupSep)
						.join("");
				}
				// build a natively parsable number string
				var p = sign + integer;
				if (fraction !== null) {
					p += "." + fraction;
				}
				if (exponent !== null) {
					// exponent itself may have a number patternd
					var expSignInfo = parseNegativePattern(exponent, nf, "-n");
					p += "e" + (expSignInfo[0] || "+") + expSignInfo[1];
				}
				if (parseFloatExp.test(p)) {
					ret = parseFloat(p);
				}
			}
			return ret;
		}

		function regexpNumber(format, length, strict) {
			var lengthInt = parseInt(length, 10);
			length = isNaN(lengthInt) ? format.decimals : lengthInt;

			var num = "\\d+(?:",
				patterns = format.pattern;


			for (var i = format.groupSizes.length - 1, l = i; i >= 0; i--) {
				var size = format.groupSizes[i];
				num += size === 0 ? "\\d*" : "(?:" + escRegexpStr(format[","]) + "?\\d{" + size + "})" + (i === l ? "*" : (i === 0 ? "{1}|(?:" + escRegexpStr(format[","]) + "?\\d{" + size + "})?" : "?"));
			}
			num += ")";

			if (length === 0) {
				num += "";
			}
			else {
				num += strict ? (escRegexpStr(format["."]) + "{1}\\d{" + length + "}") : ("(?:" + escRegexpStr(format["."]) + "{1}\\d{0," + length + "})?");
			}

			var ret = [];
			$.each(patterns, function (i, name) {
				ret.push(escRegexpStr(name)
					.replace(nSymbolExp, num));
			});
			if (patterns.length === 1) {
				ret.push(("n")
					.replace(nSymbolExp, num));
			}

			return "(" + ret.join("|") + ")";
		}

		function getNumberRegExp(nf, format, strict) {
			var c = nf[1] || "";
			nf = nf[0];
			var re = nf._parseRegExp[c];
			if (!re) {
				re = nf._parseRegExp[c] = {};
			}
			else {
				var reFormat = re[format];
				if (reFormat && reFormat.strict === strict) {
					return reFormat;
				}
			}

			var expFormat = format.replace(expandFormatExp, "\\\\$1"),
				groups = [],
				regexp = ["^"],
				index = 0,
				quoteCount = 0,
				match;

			// iterate through each date token found.
			while ((match = tokenNumberExp.exec(expFormat)) !== null) {
				var preMatch = expFormat.slice(index, match.index);
				index = tokenNumberExp.lastIndex;

				// don't replace any matches that occur inside a string literal.
				quoteCount += appendPreOrPostMatch(preMatch, regexp);
				if (quoteCount % 2) {
					regexp.push(match[0]);
					continue;
				}
				var m = numberTypeExp.exec(match[0]),
					add;

				switch (m[1]) {
					case "c":
						add = regexpNumber(nf.currency, m[2], strict)
							.replace(cSymbolStrictExp, strict ? "$1$2$3" : "\\s*$2\\s*")
							.replace(cSymbolExp, "(?:" + escRegexpStr(nf.currency.symbol) + ")" + (strict ? "" : "?"));
						break;
					case "n":
						add = regexpNumber(nf, m[2], strict);
						break;
					case "p":
						add = regexpNumber(nf.percent, m[2], strict)
							.replace(pSymbolStrictExp, strict ? "$1$2$3" : "\\s*$2\\s*")
							.replace(pSymbolExp, "(?:" + escRegexpStr(nf.percent.symbol) + ")" + (strict ? "" : "?"));
						break;
				}

				if (add) {
					regexp.push(add);
				}
				groups.push(match[0]);
			}
			appendPreOrPostMatch(expFormat.slice(index), regexp);
			regexp.push("$");

			var regexpStr = regexp.join("")
					.replace(whiteSpaceExp, "\\s+"), // allow whitespace to differ when matching formats.
				parseRegExp = {
					"regExp": regexpStr,
					"groups": groups,
					strict: strict
				},
				ret = re[format] = parseRegExp; // cache the regex for this format.
			return ret;
		}

		function expandNumber(number, precision, formatInfo) {
			var groupSizes = formatInfo.groupSizes,
				curSize = groupSizes[0],
				curGroupIndex = 1,
				factor = Math.pow(10, precision),
				rounded = Math.round(number * factor) / factor;
			if (!isFinite(rounded)) {
				rounded = number;
			}
			number = rounded;

			var numberString = number + "",
				right = "",
				split = numberString.split(expandSplitExp),
				exponent = split.length > 1 ? parseInt(split[1], 10) : 0;
			numberString = split[0];
			split = numberString.split(".");
			numberString = split[0];
			right = split.length > 1 ? split[1] : "";

			if (exponent > 0) {
				right = zeroPad(right, exponent, false);
				numberString += right.slice(0, exponent);
				right = right.substr(exponent);
			}
			else if (exponent < 0) {
				exponent = -exponent;
				numberString = zeroPad(numberString, exponent + 1);
				right = numberString.slice(-exponent, numberString.length) + right;
				numberString = numberString.slice(0, - exponent);
			}

			if (precision > 0) {
				right = formatInfo["."] + ((right.length > precision) ? right.slice(0, precision) : zeroPad(right, precision));
			}
			else {
				right = "";
			}

			var stringIndex = numberString.length - 1,
				sep = formatInfo[","],
				ret = "";

			while (stringIndex >= 0) {
				if (curSize === 0 || curSize > stringIndex) {
					return numberString.slice(0, stringIndex + 1) + (ret.length ? (sep + ret + right) : right);
				}
				ret = numberString.slice(stringIndex - curSize + 1, stringIndex + 1) + (ret.length ? (sep + ret) : "");

				stringIndex -= curSize;

				if (curGroupIndex < groupSizes.length) {
					curSize = groupSizes[curGroupIndex];
					curGroupIndex++;
				}
			}
			return numberString.slice(0, stringIndex + 1) + sep + ret + right;
		}

		function parseNegativePattern(value, nf, negativePattern) {
			var neg = nf["-"],
				pos = nf["+"],
				ret;
			switch (negativePattern) {
				case "n -":
					neg = " " + neg;
					pos = " " + pos;
					/*falls through*/
				case "n-":
					if (endsWith(value, neg)) {
						ret = ["-", value.substr(0, value.length - neg.length)];
					}
					else if (endsWith(value, pos)) {
						ret = ["+", value.substr(0, value.length - pos.length)];
					}
					break;
				case "- n":
					neg += " ";
					pos += " ";
					/*falls through*/
				case "-n":
					if (startsWith(value, neg)) {
						ret = ["-", value.substr(neg.length)];
					}
					else if (startsWith(value, pos)) {
						ret = ["+", value.substr(pos.length)];
					}
					break;
				case "(n)":
					if (startsWith(value, "(") && endsWith(value, ")")) {
						ret = ["-", value.substr(1, value.length - 2)];
					}
					break;
			}
			return ret || ["", value];
		}

		function formatNumber(value, format, region) {
			if (!format || format === "i") {
				return region.name.length ? value.toLocaleString() : value.toString();
			}
			format = format || "D";

			var nf = region.numberFormat,
				number = Math.abs(value),
				precision = -1,
				pattern;
			if (format.length > 1) {
				precision = parseInt(format.slice(1), 10);
			}

			var current = format.charAt(0)
					.toUpperCase(),
				formatInfo;

			switch (current) {
				case "D":
					pattern = "n";
					if (precision !== -1) {
						number = zeroPad("" + number, precision, true);
					}
					if (value < 0) {
						number = -number;
					}
					break;
				case "N":
					formatInfo = nf;
					/*falls through*/
				case "C":
					formatInfo = formatInfo || nf.currency;
					/*falls through*/
				case "P":
					formatInfo = formatInfo || nf.percent;
					pattern = value < 0 ? formatInfo.pattern[0] : (formatInfo.pattern[1] || "n");
					if (precision === -1) {
						precision = formatInfo.decimals;
					}
					number = expandNumber(number, precision, formatInfo);
					break;
				default:
					throw "Bad number format specifier: " + current;
			}

			var ret = "";
			for (;;) {
				var index = patternPartsExp.lastIndex,
					ar = patternPartsExp.exec(pattern);

				ret += pattern.slice(index, ar ? ar.index : pattern.length);

				if (!ar) {
					break;
				}

				switch (ar[0]) {
					case "n":
						ret += number;
						break;
					case "$":
						ret += nf.currency.symbol;
						break;
					case "-":
						// don't make 0 negative
						if (positiveNumberExp.test(number)) {
							ret += nf["-"];
						}
						break;
					case "%":
						ret += nf.percent.symbol;
						break;
				}
			}

			return ret;
		}

		// *************************************** Dates ***************************************

		function parseDate(value, formats, region) {
			var date,
				prop,
				patterns;

			if (formats) {
				if (typeof formats === "string") {
					formats = [formats];
				}
				if (formats.length) {
					for (var i = 0, l = formats.length; i < l; i++) {
						var format = formats[i];
						if (format) {
							date = parseExact(value, format, region);
							if (date) {
								break;
							}
						}
					}
				}
			}
			else {
				patterns = region.calendar.patterns;
				for (prop in patterns) {
					date = parseExact(value, patterns[prop], region);
					if (date) {
						break;
					}
				}
			}
			return date || null;
		}

		function outOfRange(value, low, high) {
			return value < low || value > high;
		}

		function expandYear(cal, year) {
			// expands 2-digit year into 4 digits.
			var now = new Date(),
				era = getEra(now);
			if (year < 100) {
				var twoDigitYearMax = cal.twoDigitYearMax;
				twoDigitYearMax = typeof twoDigitYearMax === "string" ? new Date()
					.getFullYear() % 100 + parseInt(twoDigitYearMax, 10) : twoDigitYearMax;
				var curr = getEraYear(now, cal, era);
				year += curr - (curr % 100);
				if (year > twoDigitYearMax) {
					year -= 100;
				}
			}
			return year;
		}

		function getEra(date, eras) {
			if (!eras) {
				return 0;
			}
			var start, ticks = date.getTime();
			for (var i = 0, l = eras.length; i < l; i++) {
				start = eras[i].start;
				if (start === null || ticks >= start) {
					return i;
				}
			}
			return 0;
		}

		function toUpper(value) {
			// 'he-IL' has non-breaking space in weekday names.
			return value.split("\u00A0")
				.join(" ")
				.toUpperCase();
		}

		function toUpperArray(arr) {
			var results = [];
			for (var i = 0, l = arr.length; i < l; i++) {
				results[i] = toUpper(arr[i]);
			}
			return results;
		}

		function getEraYear(date, cal, era, sortable) {
			var year = date.getFullYear();
			if (!sortable && cal.eras) {
				// convert normal gregorian year to era-shifted gregorian
				// year by subtracting the era offset
				year -= cal.eras[era].offset;
			}
			return year;
		}

		function getDayIndex(cal, value, abbr) {
			var ret,
				days = cal.days,
				upperDays = cal._upperDays;
			if (!upperDays) {
				cal._upperDays = upperDays = [
				toUpperArray(days.names),
				toUpperArray(days.namesAbbr),
				toUpperArray(days.namesShort)];
			}
			value = toUpper(value);
			if (abbr) {
				ret = $.inArray(value, upperDays[1]);
				if (ret === -1) {
					ret = $.inArray(value, upperDays[2]);
				}
			}
			else {
				ret = $.inArray(value, upperDays[0]);
			}
			return ret;
		}

		function getMonthIndex(cal, value, abbr) {
			var months = cal.months,
				monthsGen = cal.monthsGenitive || cal.months,
				upperMonths = cal._upperMonths,
				upperMonthsGen = cal._upperMonthsGen;
			if (!upperMonths) {
				cal._upperMonths = upperMonths = [
				toUpperArray(months.names),
				toUpperArray(months.namesAbbr)];
				cal._upperMonthsGen = upperMonthsGen = [
				toUpperArray(monthsGen.names),
				toUpperArray(monthsGen.namesAbbr)];
			}
			value = toUpper(value);
			var i = $.inArray(value, abbr ? upperMonths[1] : upperMonths[0]);
			if (i < 0) {
				i = $.inArray(value, abbr ? upperMonthsGen[1] : upperMonthsGen[0]);
			}
			return i;
		}

		function appendPreOrPostMatch(preMatch, strings) {
			// appends pre- and post- token match strings while removing escaped characters.
			// Returns a single quote count which is used to determine if the token occurs
			// in a string literal.
			var quoteCount = 0,
				escaped = false;
			for (var i = 0, il = preMatch.length; i < il; i++) {
				var c = preMatch.charAt(i);
				switch (c) {
					case "\'":
						if (escaped) {
							strings.push("\"");
						}
						else {
							quoteCount++;
						}
						escaped = false;
						break;
					case "\\":
						if (escaped) {
							strings.push("\\");
						}
						escaped = !escaped;
						break;
					default:
						strings.push(c);
						escaped = false;
						break;
				}
			}
			return quoteCount;
		}

		function expandFormat(cal, format) {
			// expands unspecified or single character date formats into the full pattern.
			format = format || "F";
			var pattern,
				patterns = cal.patterns,
				len = format.length;
			if (len === 1) {
				pattern = patterns[format];
				if (!pattern) {
					throw "Invalid date format string '" + format + "'.";
				}
				format = pattern;
			}
			else if (len === 2 && format.charAt(0) === "%") {
				// %X escape format -- intended as a custom format string that is only one character, not a built-in format.
				format = format.charAt(1);
			}
			return format;
		}

		function getParseRegExp(cal, format, strict) {
			// converts a format string into a regular expression with groups that
			// can be used to extract date fields from a date string.
			// check for a cached parse regex.
			var re = cal._parseRegExp;
			if (!re) {
				cal._parseRegExp = re = {};
			}
			else {
				var reFormat = re[format];
				if (reFormat && reFormat.strict === strict) {
					return reFormat;
				}
			}


			// expand single digit formats, then escape regular expression characters.
			var expFormat = expandFormat(cal, format)
					.replace(expandFormatExp, "\\\\$1"),
				regexp = ["^"],
				groups = [],
				index = 0,
				quoteCount = 0,
				match;

			// iterate through each date token found.
			while ((match = tokenDateExp.exec(expFormat)) !== null) {
				var preMatch = expFormat.slice(index, match.index);
				index = tokenDateExp.lastIndex;

				// don't replace any matches that occur inside a string literal.
				quoteCount += appendPreOrPostMatch(preMatch, regexp);
				if (quoteCount % 2) {
					regexp.push(match[0]);
					continue;
				}

				// add a regex group for the token.
				var m = match[0],
					len = m.length,
					add,
					/*jshint loopfunc:true*/
					lastSpace = function () {
						var last = regexp.length - 1;
						if (regexp[last] === " " && !strict) {
							regexp[last] = "\\s?";
						}
					},
					/*jshint loopfunc:true*/
					each = function (array, deep) {
						var arr = [];
						$.each(array, function (i, val) {
							if (deep) {
								val = val[deep];
							}
							if (val && $.type(val) === "string") {
								arr.push(escRegexpStr(val));
							}

						});
						return arr.length > 0 ? "(" + arr.join("|") + ")" : "";
					};

				switch (m) {
					case "dddd":
						add = strict ? each(cal.days.names) : each($.merge(cal.days.names, cal.days.namesAbbr));
						break;
					case "ddd":
						add = strict ? each(cal.days.namesAbbr) : each($.merge(cal.days.names, cal.days.namesAbbr));
						break;
					case "MMMM":
						add = strict ? each(cal.months.names) : each($.merge(cal.months.names, cal.months.namesAbbr));
						break;
					case "MMM":
						add = strict ? each(cal.months.namesAbbr) : each($.merge(cal.months.names, cal.months.namesAbbr));
						break;
					case "gg":
					case "g":
						lastSpace();
						add = each(cal.eras, "name");
						break;
					case "tt":
					case "t":
						lastSpace();
						add = each($.merge(cal.AM || [], cal.PM || []));
						break;
					case "f":
					case "ff":
					case "fff":
						add = "(\\d{" + len + "})";
						break;
					case "d":
						add = strict ? "([1-9]{1}|[1-2]{1}\\d{1}|3[0-1]{1})" : "(0?[1-9]{1}|[1-2]{1}\\d{1}|3[0-1]{1})";
						break;
					case "dd":
						add = strict ? "(0[1-9]{1}|[1-2]{1}\\d{1}|3[0-1]{1})" : "(0?[1-9]{1}|[1-2]{1}\\d{1}|3[0-1]{1})";
						break;
					case "M":
						add = strict ? "([1-9]{1}|1[0-2]{1})" : "(0?[1-9]{1}|1[0-2]{1})";
						break;
					case "MM":
						add = strict ? "(0[1-9]{1}|1[0-2]{1})" : "(0?[1-9]{1}|1[0-2]{1})";
						break;
					case "y":
					case "yy":
						add = strict ? "(\\d{2})" : "(\\d{2}|\\d{4})";
						break;
					case "yyyy":
						add = "(\\d{4})";
						break;
					case "h":
						add = strict ? "([1-9]{1}|1[0-2]{1})" : "(0?[1-9]{1}|1[0-2]{1})";
						break;
					case "hh":
						add = strict ? "(0[1-9]{1}|1[0-2]{1})" : "(0?[1-9]{1}|1[0-2]{1})";
						break;
					case "H":
						add = strict ? "(\\d{1}|1\\d{1}|2[0-3]{1})" : "([0-1]?\\d{1}|2[0-3]{1})";
						break;
					case "HH":
						add = strict ? "(0\\d{1}|1\\d{1}|2[0-3]{1})" : "([0-1]?\\d{1}|2[0-3]{1})";
						break;
					case "m":
						add = strict ? "(\\d{1}|[1-5]{1}\\d{1})" : "([0-5]?\\d{1})";
						break;
					case "mm":
						add = strict ? "([0-5]{1}\\d{1})" : "([0-5]?\\d{1})";
						break;
					case "s":
						add = strict ? "(\\d{1}|[1-5]{1}\\d{1})" : "([0-5]?\\d{1})";
						break;
					case "ss":
						add = strict ? "([0-5]{1}\\d{1})" : "([0-5]?\\d{1})";
						break;
					case "zz":
					case "z":
						add = "([+-]?\\d\\d?)";
						break;
					case "zzz":
						add = "([+-]?\\d\\d?:\\d{2})";
						break;
					case "W":
						add = "([1-9]{1}|[2-4]{1}\\d{1}|5[0-3]{1})";
						break;
					case "/":
						add = "(\\" + cal["/"] + ")";
						break;
					default:
						$.error("Invalid date format pattern '" + m + "'.");
						break;
				}
				if (add) {
					regexp.push(add);
				}
				groups.push(match[0]);
			}
			appendPreOrPostMatch(expFormat.slice(index), regexp);
			regexp.push("$");

			var regexpStr = regexp.join("")
					.replace(whiteSpaceExp, "\\s+"), // allow whitespace to differ when matching formats.
				parseRegExp = {
					"regExp": regexpStr,
					"groups": groups,
					strict: strict
				},
				ret = re[format] = parseRegExp; // cache the regex for this format.
			return ret;
		}

		function parseExact(value, format, region) {
			// try to parse the date string by matching against the format string
			// while using the specified region for date field names.
			value = $.trim(value);
			var cal = region.calendar,
				// convert date formats into regular expressions with groupings.
				// use the regexp to determine the input format and extract the date fields.
				parseInfo = getParseRegExp(cal, format),
				match = new RegExp(parseInfo.regExp)
					.exec(value);
			if (match === null) {
				return null;
			}
			// found a date format that matches the input.
			var groups = parseInfo.groups,
				era = null,
				year = null,
				month = null,
				date = null,
				weekDay = null,
				hour = 0,
				hourOffset, min = 0,
				sec = 0,
				msec = 0,
				tzMinOffset = null,
				pmHour = false;
			// iterate the format groups to extract and set the date fields.
			for (var j = 0, jl = groups.length; j < jl; j++) {
				var matchGroup = match[j + 1];
				if (matchGroup) {
					var current = groups[j],
						clength = current.length,
						matchInt = parseInt(matchGroup, 10);
					switch (current) {
						case "dd":
						case "d":
							// Day of month.
							date = matchInt;
							// check that date is generally in valid range, also checking overflow below.
							if (outOfRange(date, 1, 31)) {
								return null;
							}
							break;
						case "MMM":
						case "MMMM":
							month = getMonthIndex(cal, matchGroup, clength === 3);
							if (outOfRange(month, 0, 11)) {
								return null;
							}
							break;
						case "M":
						case "MM":
							// Month.
							month = matchInt - 1;
							if (outOfRange(month, 0, 11)) {
								return null;
							}
							break;
						case "y":
						case "yy":
						case "yyyy":
							year = clength < 4 ? expandYear(cal, matchInt) : matchInt;
							if (outOfRange(year, 0, 9999)) {
								return null;
							}
							break;
						case "h":
						case "hh":
							// Hours (12-hour clock).
							hour = matchInt;
							if (hour === 12) {
								hour = 0;
							}
							if (outOfRange(hour, 0, 11)) {
								return null;
							}
							break;
						case "H":
						case "HH":
							// Hours (24-hour clock).
							hour = matchInt;
							if (outOfRange(hour, 0, 23)) {
								return null;
							}
							break;
						case "m":
						case "mm":
							// Minutes.
							min = matchInt;
							if (outOfRange(min, 0, 59)) {
								return null;
							}
							break;
						case "s":
						case "ss":
							// Seconds.
							sec = matchInt;
							if (outOfRange(sec, 0, 59)) {
								return null;
							}
							break;
						case "tt":
						case "t":
							// AM/PM designator.
							// see if it is standard, upper, or lower case PM. If not, ensure it is at least one of
							// the AM tokens. If not, fail the parse for this format.
							pmHour = cal.PM && (matchGroup === cal.PM[0] || matchGroup === cal.PM[1] || matchGroup === cal.PM[2]);
							if (!pmHour && (!cal.AM || (matchGroup !== cal.AM[0] && matchGroup !== cal.AM[1] && matchGroup !== cal.AM[2]))) {
								return null;
							}
							break;
						case "f":
							// Deciseconds.
						case "ff":
							// Centiseconds.
						case "fff":
							// Milliseconds.
							msec = matchInt * Math.pow(10, 3 - clength);
							if (outOfRange(msec, 0, 999)) {
								return null;
							}
							break;
						case "ddd":
							// Day of week.
						case "dddd":
							// Day of week.
							weekDay = getDayIndex(cal, matchGroup, clength === 3);
							if (outOfRange(weekDay, 0, 6)) {
								return null;
							}
							break;
						case "zzz":
							// Time zone offset in +/- hours:min.
							var offsets = matchGroup.split(/:/);
							if (offsets.length !== 2) {
								return null;
							}
							hourOffset = parseInt(offsets[0], 10);
							if (outOfRange(hourOffset, - 12, 13)) {
								return null;
							}
							var minOffset = parseInt(offsets[1], 10);
							if (outOfRange(minOffset, 0, 59)) {
								return null;
							}
							tzMinOffset = (hourOffset * 60) + (startsWith(matchGroup, "-") ? -minOffset : minOffset);
							break;
						case "z":
						case "zz":
							// Time zone offset in +/- hours.
							hourOffset = matchInt;
							if (outOfRange(hourOffset, - 12, 13)) {
								return null;
							}
							tzMinOffset = hourOffset * 60;
							break;
						case "g":
						case "gg":
							var eraName = matchGroup;
							if (!eraName || !cal.eras) {
								return null;
							}
							eraName = $.trim(eraName.toLowerCase());
							for (var i = 0, l = cal.eras.length; i < l; i++) {
								if (eraName === cal.eras[i].name.toLowerCase()) {
									era = i;
									break;
								}
							}
							// could not find an era with that name
							if (era === null) {
								return null;
							}
							break;
					}
				}
			}
			var result = new Date(),
				defaultYear, convert = cal.convert;
			defaultYear = convert ? convert.fromGregorian(result)[0] : result.getFullYear();
			if (year === null) {
				year = defaultYear;
			}
			else if (cal.eras) {
				// year must be shifted to normal gregorian year
				// but not if year was not specified, its already normal gregorian
				// per the main if clause above.
				year += cal.eras[(era || 0)].offset;
			}
			// set default day and month to 1 and January, so if unspecified, these are the defaults
			// instead of the current day/month.
			if (month === null) {
				month = 0;
			}
			if (date === null) {
				date = 1;
			}
			// now have year, month, and date, but in the region's calendar.
			// convert to gregorian if necessary
			if (convert) {
				result = convert.toGregorian(year, month, date);
				// conversion failed, must be an invalid match
				if (result === null) {
					return null;
				}
			}
			else {
				// have to set year, month and date together to avoid overflow based on current date.
				result.setFullYear(year, month, date);
				// check to see if date overflowed for specified month (only checked 1-31 above).
				if (result.getDate() !== date) {
					return null;
				}
				// invalid day of week.
				if (weekDay !== null && result.getDay() !== weekDay) {
					return null;
				}
			}
			// if pm designator token was found make sure the hours fit the 24-hour clock.
			if (pmHour && hour < 12) {
				hour += 12;
			}
			result.setHours(hour, min, sec, msec);
			if (tzMinOffset !== null) {
				// adjust timezone to utc before applying local offset.
				var adjustedMin = result.getMinutes() - (tzMinOffset + result.getTimezoneOffset());
				// Safari limits hours and minutes to the range of -127 to 127.  We need to use setHours
				// to ensure both these fields will not exceed this range.  adjustedMin will range
				// somewhere between -1440 and 1500, so we only need to split this into hours.
				result.setHours(result.getHours() + parseInt(adjustedMin / 60, 10), adjustedMin % 60);
			}
			return result;
		}

		function formatDate(value, format, region) {
			var cal = region.calendar,
				convert = cal.convert,
				ret;
			if (!format || !format.length || format === "i") {
				if (region && region.name.length) {
					if (convert) {
						// non-gregorian calendar, so we cannot use built-in toLocaleString()
						ret = formatDate(value, cal.patterns.F, region);
					}
					else {
						var eraDate = new Date(value.getTime()),
							era = getEra(value, cal.eras);
						eraDate.setFullYear(getEraYear(value, cal, era));
						ret = eraDate.toLocaleString();
					}
				}
				else {
					ret = value.toString();
				}
				return ret;
			}

			var eras = cal.eras,
				sortable = format === "s";
			format = expandFormat(cal, format);

			// Start with an empty string
			ret = [];
			var hour,
				zeros = ["0", "00", "000"],
				foundDay,
				checkedDay,
				quoteCount = 0,
				converted;

			function padZeros(num, c) {
				var r, s = num + "";
				if (c > 1 && s.length < c) {
					r = (zeros[c - 2] + s);
					return r.substr(r.length - c, c);
				}
				else {
					r = s;
				}
				return r;
			}

			function hasDay() {
				if (foundDay || checkedDay) {
					return foundDay;
				}
				foundDay = dayPartRegExp.test(format);
				checkedDay = true;
				return foundDay;
			}

			function getPart(date, part) {
				if (converted) {
					return converted[part];
				}
				switch (part) {
					case 0:
						return date.getFullYear();
					case 1:
						return date.getMonth();
					case 2:
						return date.getDate();
				}
			}

			if (!sortable && convert) {
				converted = convert.fromGregorian(value);
			}

			for (;;) {
				// Save the current index
				var index = tokenDateExp.lastIndex,
					// Look for the next pattern
					ar = tokenDateExp.exec(format);

				// Append the text before the pattern (or the end of the string if not found)
				var preMatch = format.slice(index, ar ? ar.index : format.length);
				quoteCount += appendPreOrPostMatch(preMatch, ret);

				if (!ar) {
					break;
				}

				// do not replace any matches that occur inside a string literal.
				if (quoteCount % 2) {
					ret.push(ar[0]);
					continue;
				}

				var current = ar[0],
					clength = current.length,
					names;

				switch (current) {
					case "ddd":
						//Day of the week, as a three-letter abbreviation
					case "dddd":
						// Day of the week, using the full name
						names = (clength === 3) ? cal.days.namesAbbr : cal.days.names;
						ret.push(names[value.getDay()]);
						break;
					case "d":
						// Day of month, without leading zero for single-digit days
					case "dd":
						// Day of month, with leading zero for single-digit days
						foundDay = true;
						ret.push(padZeros(getPart(value, 2), clength));
						break;
					case "MMM":
						// Month, as a three-letter abbreviation
					case "MMMM":
						// Month, using the full name
						var part = getPart(value, 1);
						ret.push(
						(cal.monthsGenitive && hasDay()) ? cal.monthsGenitive[clength === 3 ? "namesAbbr" : "names"][part] : cal.months[clength === 3 ? "namesAbbr" : "names"][part]);
						break;
					case "M":
						// Month, as digits, with no leading zero for single-digit months
					case "MM":
						// Month, as digits, with leading zero for single-digit months
						ret.push(padZeros(getPart(value, 1) + 1, clength));
						break;
					case "y":
						// Year, as two digits, but with no leading zero for years less than 10
					case "yy":
						// Year, as two digits, with leading zero for years less than 10
					case "yyyy":
						// Year represented by four full digits
						part = converted ? converted[0] : getEraYear(value, cal, getEra(value, eras), sortable);
						if (clength < 4) {
							part = part % 100;
						}
						ret.push(padZeros(part, clength));
						break;
					case "h":
						// Hours with no leading zero for single-digit hours, using 12-hour clock
					case "hh":
						// Hours with leading zero for single-digit hours, using 12-hour clock
						hour = value.getHours() % 12;
						if (hour === 0) {
							hour = 12;
						}
						ret.push(padZeros(hour, clength));
						break;
					case "H":
						// Hours with no leading zero for single-digit hours, using 24-hour clock
					case "HH":
						// Hours with leading zero for single-digit hours, using 24-hour clock
						ret.push(padZeros(value.getHours(), clength));
						break;
					case "m":
						// Minutes with no leading zero  for single-digit minutes
					case "mm":
						// Minutes with leading zero  for single-digit minutes
						ret.push(padZeros(value.getMinutes(), clength));
						break;
					case "s":
						// Seconds with no leading zero for single-digit seconds
					case "ss":
						// Seconds with leading zero for single-digit seconds
						ret.push(padZeros(value.getSeconds(), clength));
						break;
					case "t":
						// One character am/pm indicator ("a" or "p")
					case "tt":
						// Multicharacter am/pm indicator
						part = value.getHours() < 12 ? (cal.AM ? cal.AM[0] : " ") : (cal.PM ? cal.PM[0] : " ");
						ret.push(clength === 1 ? part.charAt(0) : part);
						break;
					case "f":
						// Deciseconds
					case "ff":
						// Centiseconds
					case "fff":
						// Milliseconds
						ret.push(padZeros(value.getMilliseconds(), 3)
							.substr(0, clength));
						break;
					case "z":
						// Time zone offset, no leading zero
					case "zz":
						// Time zone offset with leading zero
						hour = value.getTimezoneOffset() / 60;
						ret.push((hour <= 0 ? "+" : "-") + padZeros(Math.floor(Math.abs(hour)), clength));
						break;
					case "zzz":
						// Time zone offset with leading zero
						hour = value.getTimezoneOffset() / 60;
						ret.push((hour <= 0 ? "+" : "-") + padZeros(Math.floor(Math.abs(hour)), 2) +
						// Hard coded ":" separator, rather than using cal.TimeSeparator
						// Repeated here for consistency, plus ":" was already assumed in date parsing.
						":" + padZeros(Math.abs(value.getTimezoneOffset() % 60), 2));
						break;
					case "g":
					case "gg":
						if (cal.eras) {
							ret.push(cal.eras[getEra(value, eras)].name);
						}
						break;
					case "/":
						ret.push(cal["/"]);
						break;
					case "W":
						var Y = value.getYear(),
							M = value.getMonth(),
							d = value.getDate(),
							dateObj = new Date(Y, M, d),
							Wd = dateObj.getDay() || 7,
							Wmin = cal.firstWeekMin;

						if (M === 11 && d >= (35 - Wmin) && Wd < d - (35 - Wmin)) {
							return 1;
						}
						else if (M === 0 && d <= Wmin && Wd <= d + (Wmin - 1)) {
							return 1;
						}
						else if (M === 0 && d <= Wmin) {
							Y -= 1;
						}

						ret.push(Math.floor((dateObj - new Date(Y, 0, (Wmin + 1) - (new Date(Y, 0, Wmin)
							.getDay() || 7))) / 604800000) + 1);
						break;
					default:
						$.error("Invalid date format pattern '" + current + "'.");
						break;
				}
			}
			return ret.join("");
		}

		// start loading of extended dependencies
		moduleDepends(dependencies);
	});

	// define the jquery/i18n module
	moduleDefine();

}());

/* ---- Module:ep ---- */

/*
 * @copyright		© Copyright 2006-2010, epages GmbH, All Rights Reserved.
 *
 * @module			ep
 *
 * @revision		$Revision: 1.4.2.1 $
 */

define("ep", [
	"module",
	"jquery",
	"util/string",

	"jquery/each",
	"jquery/mixin",
	"jquery/event/fix",
	"ep/modify"
], function (mod, $, str) {

	// Simulate subclass of jQuery
	var rootjQuery = $(document),
		ep = function ( selector, context ) {
			return new $.fn.init( selector, context, rootjQuery );
		};
	// Get all properties of jQuery to ep
	$.extend( true, ep, $ );
	// Setup prototype context
	ep.fn = $.fn = $.prototype;

	// Merge config params
	ep.config = $.extend({
		debugLevel:					0,
		version:					'',
		webRoot:					'',
		storeWebRoot:				'',
		storeRoot:					'',
		storeTypeRoot:				'',
		siteRoot:					'',
		siteId:						'0',
		baseUrl:					undefined,
		iconsRoot:					'',
		objectId:					'0',
		viewAction:					'',
		storeFrontUrl:				'',
		requestProtocolAndServer:	'',
		maxContentLength:			'',
		currency:					'',
		autoMetaparse:				true
	}, mod.config());

	var splice = Array.prototype.splice,
		push = Array.prototype.push,
		extend = $.extend,
		mixin = $.mixin,
		ready = $.fn.ready,
		browser = $.browser,
		browserClass = (/khtml/i).test(navigator.userAgent) ? 'khtml' : '';

	// add browser engine name as class to html tag
	$.each( ['mozilla', 'msie', 'webkit', 'opera'], function( i, name ){
		if( browser[name] ){
			browserClass = name;
			return false;
		}
	});
	$('html').addClass( browserClass );

	$.extend(ep,{
		// similar to $.extend; if only 1 hash in arguments ep will extend with this hash
		extend: function() {
			return extend.apply( this, arguments );
		},
		// similar to $.mixin; if only 1 hash in arguments ep will mixin with this hash
		mixin: function() {
			return mixin.apply( this, arguments );
		}
	});

	ep.extend({
		// Warn handle for deprecated functionality
		deprecated: function (msg, trace) {
			if (typeof console !== "undefined") {
				if (console.warn) {
					console.warn("EP deprecated: " + msg);
				}
				if (trace && console.trace) {
					console.trace();
				}
			}
		},

		// find a key by the givn value in a hash
		inHash: function( val, obj ){
			var ret;
			if( !$.isPlainObject(obj) ){
				return ret;
			}
			$.each( obj, function( key, value ){
				if( value === val ){
					ret = key;
					return false;
				}
			});
			return ret;
		},

		// return array of keys, values or keys and values from hash
		hashToArray: function( obj, type ){
			var keys = [],
				values = [];
			$.each( obj, function( key, value ){
				keys.push( key );
				values.push( value );
			});
			return (/^k/i).test(type) ? keys : ( (/^v/i).test(type) ? values : [keys,values] );
		},

		// build a hash from 2 arrays (keys values)
		arrayToHash: function( keys, values ){
			if( !values ){
				values = keys;
				keys = [];
			}

			var hash = {};
			$.each( values, function( i, elm ){
				hash[ keys[i] || i ] = elm;
			});
			return hash;
		},

		// add item(s) to an array or array-like object at an indexed position without overwrite existing items
		insert: function( target, insert, index ){
			ep.deprecated("use native array method '.unsplice()' instead of 'ep.insert()'", true);

			index = typeof index !== 'number' ? target.length : index;

			var end = splice.call( target, index, target.length-index );

			if( $.isArray(insert) ){
				push.apply( target, insert );
			}
			else if( typeof insert === 'object' && typeof insert.length === 'number' ){
				$.merge( target, insert );
			}
			else{
				push.call( target, insert );
			}

			return $.merge( target, end );
		},

		// escape string to use it for RegExp
		escapeExpStr: function( string, except ){
			ep.deprecated("'ep.escapeExpStr()' is replaced by '.escExpStr()' in module 'util/string'", true);

			return str.escExpStr(string, except);
		},

		// scrunch a string [ fulltext... , full...text , ...fulltext ]
		scrunch: function( string, length, options ) {
			ep.deprecated("'ep.scrunch()' is replaced by '.shrink()' in module 'util/string'", true);

			if( typeof length === 'object' ){
				options = length;
				length = null;
			}
			
			if (!options) {
				options = {};
			}

			if (length) {
				options.length = length;
			}

			return str.shrink(string, options);
		},

		// reverse a string or number or array
		reverse: function( string ) {
			if( $.isArray(string) ){
				ep.deprecated("use native array method '.reverse()' instead of 'ep.reverse()'", true);

				return string.reverse();
			}
			else {
				ep.deprecated("'ep.reverse()' is replaced by '.reverse()' in module 'util/string'", true);

				return str.reverse(string);
			}
		},

		// remove xml/xhtml/html tags
		stripTags: function( string ) {
			ep.deprecated("'ep.stripTags()' is replaced by '.stripTags()' in module 'util/string'", true);

			return str.stripTags(string);
		},

		// hash to address functions as global object in inline scripts
		local: {

		}
	});

	ep.fn.setDefault = function(value){
		this.each( function(i, element){
			var $element = $(element),
					tagName = element.tagName.toLowerCase();

			if(tagName === 'input' || tagName === 'textarea'){
				if( element.type === 'radio' || element.type === 'checkbox' ){
					$element
						.attr('checked', value)
						.prop('defaultChecked', value);
				}
				else{
					$element
						.val(value)
						.prop('defaultValue', value);
				}
			}
			else if(tagName === 'select'){
				element.options[element.selectedIndex].defaultSelected = false;
				element.value = value;
				element.options[element.selectedIndex].defaultSelected = true;
			}
		});

		return this;
	};

	// Expose ep to the global object
	window.ep = ep;

	return ep;
});

/* ---- Module:ep.ajax ---- */

/**
 * @class ep
 *
 */

/*
 * @copyright		© Copyright 2006-2010, epages GmbH, All Rights Reserved.
 *
 * @module			ep.ajax
 *
 * @revision		$Revision: 1.5.2.1.10.1 $
 */

define("ep/ajax", [
	"jquery",
	"ep",

    "jquery/cookie",
], function ($, ep) {

	$.ajaxSetup({
		fileSizeMax: (ep.config.maxContentLength || 5120) * 1024
	});

	ep.extend({
		/**
		 * Perform an asynchronous HTTP (Ajax) request.
		 *
		 * The `ep.ajax()` function is a modified alias of `jQuery.ajax()`.
		 *
		 * If dataType json, `ep.ajax()` add "Accept", "text/x-json" to the requestHeader and set the url to `ep.config.baseUrl`.
		 * If dataType json and the response contains the ''Error'' object, `ep.ajax()` interprets the request as error.
		 *
		 * This plugin setup the default ajax-type of `jQuery.ajax()` and `ep.ajax()` to '''get'''. To change this
		 * add a "type: post" to the parameters.
		 *
		 * To do a sync requests instead of async just add "async: false" to the parameters.
		 *
		 * To prevent browser caching of the request use the parameter: "cache: false". The default behaviour is "cache: true".
		 *
		 * ====New API standard in 6.14.0====
		 * For AJAX use `deferred object` methods instead of setting `success`, `error` and `complete` methods as arguments.
		 *
		 * Properties to methods:
		 *
		 * + `success` => `.done()`
		 * + `error` => `.fail()`
		 * + `complete` => `.always()`
		 *
		 * ### Examples
		 * Perform an ajax request.
		 *
		 * JavaScript:
		 *
		 *     ep.ajax({
		 *         data: {
		 *             ObjectID: 5,
		 *             ViewAction : 'JSONGet'
		 *         },
		 *         cache: false,
		 *         type: "post",
		 *         async: false,
		 *         dataType: "json",
		 *         success:
		 *     })
		 *     .done(function( jsonData ){
		 *
		 *     });
		 *
		 *
		 * ### Dependencies
		 *
		 *  + `ep`
		 *
		 * @param {Object} options A set of key/value pairs that configure the Ajax request. All settings are optional.
		 *
		 * @method ajax
		 * @static
		 * @member ep
		 *
		 * @since 6.11.0
		 */
		ajax: function (settings) {

			var jqXHR,
				tokenName = "SecToken",
				cookie = $.cookie(tokenName);

			if (!settings.url) {
				settings.url = ep.config.baseUrl;
			}

			// check if security token exists and add hidden input with security cookie information
			if (cookie && cookie !== null) {
				settings.data = settings.data || {};
				settings.data[tokenName] = cookie;
			}

			if (settings.dataType === 'json') {
				var _beforeSend = settings.beforeSend;

				// add special header for epages
				$.extend(settings, {
					beforeSend: function (xhr, s) {
						xhr.setRequestHeader("Accept", "application/json");
						if (_beforeSend) {
							_beforeSend(xhr, s);
						}
					}
				});

				// save deprecated properties as locals
				var success = settings.success,
					error = settings.error,
					complete = settings.complete;

				// delete deprecated properties
				settings.success = settings.error = settings.complete = undefined;

				// create AJAX object
				jqXHR = $.ajax(settings);

				// init
				var context = settings.context || jqXHR,
					deferred = $.Deferred(),
					complete = $.Deferred(),
					// save original deferrd methods
					originalDone = jqXHR.done,
					originalFail = jqXHR.fail;

				// set bridge for .done() calls
				originalDone(function (data, status, jqXHR) {
					if (data && data.Errors) {
						var errorThrown = data.Errors;
						jqXHR.status = 400;
						jqXHR.statusText = status = "error";
						deferred.rejectWith(context, [jqXHR, status, errorThrown]);
					} else {
						deferred.resolveWith(context, [data, status, jqXHR]);
					}
				});

				// set bridge for .fail() calls
				originalFail(function (jqXHR, status, errorThrown) {
					deferred.rejectWith(context, [jqXHR, status, errorThrown]);
				});

				// set bridge for .always() calls
				deferred.always(function () {
					complete.resolveWith(context, [jqXHR]);
				});

				// map .done() to own deferrd
				jqXHR.done = function () {
					deferred.done.apply(deferred, arguments);
					return jqXHR;
				};

				// map .fail() to own deferrd
				jqXHR.fail = function () {
					deferred.fail.apply(deferred, arguments);
					return jqXHR;
				};

				// map .always() to own deferrd
				jqXHR.always = function () {
					complete.done.apply(complete, arguments);
					return jqXHR;
				};

				// restore deprecated properties from locals
				if (success) {
					jqXHR.done(success);
				}
				if (error) {
					jqXHR.fail(error);
				}
				if (complete) {
					jqXHR.always(complete);
				}
			} else {
				jqXHR = $.ajax(settings);
			}

			return jqXHR;
		}
	});

	return ep;

});


/* ---- Module:ep.sslswitch ---- */

/**
 * @class ep.sslSwitch
 *
 */

/*
 * @copyright		© Copyright 2006-2010, epages GmbH, All Rights Reserved.
 *
 * @module			ep.sslSwitch
 *
 * @revision		$Revision: 1.6.2.1.10.1 $
 */

define("ep/sslswitch", [
    "jquery",
    "ep",

    'jquery/cookie'
], function ($, ep) {

    ep.sslSwitch = {
        handles: [],

        controller: function (event) {
            var elem = $(this),
                form = elem.filter('form'),
                tokenName = 'SecToken',
                cookie;

            if (!form.length) {
                form = $('<form method="post" action="' + elem.attr('href') + '"/>');
                cookie = $.cookie(tokenName);

                if (cookie && cookie !== null && form.find("input[name='" + tokenName + "']").length === 0) {
                    form.append('<input type="hidden" name="' + tokenName + '" value="' + cookie + '" />');
                }
                form.appendTo('body');
            }

            $.each(ep.sslSwitch.handles, function (i, handle) {
                handle(event, form);
            });

            if (!event.isDefaultPrevented()) {
                event.preventDefault();
                ep.sslSwitch['submit'](form, true);
            }
        },

        /**
         * Add an handle to the SSL switch controller.
         *
         * The `ep.sslSwitch.addHandle()` method adds handles to SSL switch controller, the controller
         * execute all handles before the location switch to SSL mode on submit the form.
         *
         * The `ep.sslSwitch.addHandle()` method handles all `form` and `a` elements which are marked with the `SSLSwitch` class.
         *
         * ### Examples
         * Send an additional parameter on switch to SSL mode.
         *
         * JavaScript:
         *
         *     ep.sslSwitch.addHandle(function( event, form ){
         *         $('<input type="hidden">')
         *             .attr({
         *                 'name':     'example',
         *                 'value':    'test'
         *             })
         *             .appendTo(form);
         *     });
         *
         *
         * ### Dependencies
         *
         *  + `ep`
         *
         * @param {Function} "function(event, form)" Add an handle to the SSL switch controller. Receives the triggered event and the form element(jQuery object) as arguments
         *
         * @method addHandle
         * @static
         * @member ep.sslSwitch
         *
         * @since 6.11.2
         */
        addHandle: function (fn) {
            ep.sslSwitch.handles.push(fn);
        },

        //#JSCOVERAGE_IF false
        /**
         * Submit the givn SSL switch form.
         *
         * The `ep.sslSwitch.submit()` method submits the givn form and switch location to SSL mode.
         *
         * You can overwrite this method to perform an way to submit the form, note that a form can be sent only once.
         * If you only want to modify the form or perform a method before the location switch to SSL mode, use the
         * `ep.sslSwitch.addHandle()` method.
         *
         * ### Examples
         * Overwrite the SSL switch submit method.
         *
         * JavaScript:
         *
         *     ep.sslSwitch.submit = function( form ){
         *         form[0].submit();
         *     };
         *
         *
         * ### Dependencies
         *
         *  + `ep`
         *
         * @param {Object} form A form element(jQuery object).
         *
         * @method submit
         * @static
         * @member ep.sslSwitch
         *
         * @since 6.11.2
         */
        submit: function (form) {
            if (arguments[1]) {
                form[0].submit();
            } else {
                form.trigger('submit');
            }
        }
        //#JSCOVERAGE_ENDIF
    };

    $(document)
        .on('click', 'a.SSLSwitch', ep.sslSwitch.controller)
        .on('submit', 'form.SSLSwitch', ep.sslSwitch.controller);

    return ep;

});


/* ---- Module:ep.color ---- */

/**
 * @class ep.color
 * 
 */

/*
 * @copyright		© Copyright 2006-2010, epages GmbH, All Rights Reserved.
 *
 * @module			ep.color
 *
 * @revision		$Revision: 1.6.2.1 $
 */

define("ep/color", [
	"jquery",
	"ep"
], function ($, ep) {

	var nameMap = {
			'aliceblue':			'f0f8ff',
			'antiquewhite':			'faebd7',
			'aqua':					'00ffff',
			'aquamarine':			'7fffd4',
			'azure':				'f0ffff',
			'beige':				'f5f5dc',
			'bisque':				'ffe4c4',
			'black':				'000000',
			'blanchedalmond':		'ffebcd',
			'blue':					'0000ff',
			'blueviolet':			'8a2be2',
			'brown':				'a52a2a',
			'burlywood':			'deb887',
			'cadetblue':			'5f9ea0',
			'chartreuse':			'7fff00',
			'chocolate':			'd2691e',
			'coral':				'ff7f50',
			'cornflowerblue':		'6495ed',
			'cornsilk':				'fff8dc',
			'crimson':				'dc143c',
			'cyan':					'00ffff',
			'darkblue':				'00008b',
			'darkcyan':				'008b8b',
			'darkgoldenrod':		'b8860b',
			'darkgray':				'a9a9a9',
			'darkgrey':				'a9a9a9',
			'darkgreen':			'006400',
			'darkkhaki':			'bdb76b',
			'darkmagenta':			'8b008b',
			'darkolivegreen':		'556b2f',
			'darkorange':			'ff8c00',
			'darkorchid':			'9932cc',
			'darkred':				'8b0000',
			'darksalmon':			'e9967a',
			'darkseagreen':			'8fbc8f',
			'darkslateblue':		'483d8b',
			'darkslategray':		'2f4f4f',
			'darkslategrey':		'2f4f4f',
			'darkturquoise':		'00ced1',
			'darkviolet':			'9400d3',
			'deeppink':				'ff1493',
			'deepskyblue':			'00bfff',
			'dimgray':				'696969',
			'dimgrey':				'696969',
			'dodgerblue':			'1e90ff',
			'firebrick':			'b22222',
			'floralwhite':			'fffaf0',
			'forestgreen':			'228b22',
			'fuchsia':				'ff00ff',
			'gainsboro':			'dcdcdc',
			'ghostwhite':			'f8f8ff',
			'gold':					'ffd700',
			'goldenrod':			'daa520',
			'gray':					'808080',
			'grey':					'808080',
			'green':				'008000',
			'greenyellow':			'adff2f',
			'honeydew':				'f0fff0',
			'hotpink':				'ff69b4',
			'indianred':			'cd5c5c',
			'indigo':				'4b0082',
			'ivory':				'fffff0',
			'khaki':				'f0e68c',
			'lavender':				'e6e6fa',
			'lavenderblush':		'fff0f5',
			'lawngreen':			'7cfc00',
			'lemonchiffon':			'fffacd',
			'lightblue':			'add8e6',
			'lightcoral':			'f08080',
			'lightcyan':			'e0ffff',
			'lightgoldenrodyellow':	'fafad2',
			'lightgray':			'd3d3d3',
			'lightgrey':			'd3d3d3',
			'lightgreen':			'90ee90',
			'lightpink':			'ffb6c1',
			'lightsalmon':			'ffa07a',
			'lightseagreen':		'20b2aa',
			'lightskyblue':			'87cefa',
			'lightslategray':		'778899',
			'lightslategrey':		'778899',
			'lightsteelblue':		'b0c4de',
			'lightyellow':			'ffffe0',
			'lime':					'00ff00',
			'limegreen':			'32cd32',
			'linen':				'faf0e6',
			'magenta':				'ff00ff',
			'maroon':				'800000',
			'mediumaquamarine':		'66cdaa',
			'mediumblue':			'0000cd',
			'mediumorchid':			'ba55d3',
			'mediumpurple':			'9370d8',
			'mediumseagreen':		'3cb371',
			'mediumslateblue':		'7b68ee',
			'mediumspringgreen':	'00fa9a',
			'mediumturquoise':		'48d1cc',
			'mediumvioletred':		'c71585',
			'midnightblue':			'191970',
			'mintcream':			'f5fffa',
			'mistyrose':			'ffe4e1',
			'moccasin':				'ffe4b5',
			'navajowhite':			'ffdead',
			'navy':					'000080',
			'oldlace':				'fdf5e6',
			'olive':				'808000',
			'olivedrab':			'6b8e23',
			'orange':				'ffa500',
			'orangered':			'ff4500',
			'orchid':				'da70d6',
			'palegoldenrod':		'eee8aa',
			'palegreen':			'98fb98',
			'paleturquoise':		'afeeee',
			'palevioletred':		'd87093',
			'papayawhip':			'ffefd5',
			'peachpuff':			'ffdab9',
			'peru':					'cd853f',
			'pink':					'ffc0cb',
			'plum':					'dda0dd',
			'powderblue':			'b0e0e6',
			'purple':				'800080',
			'red':					'ff0000',
			'rosybrown':			'bc8f8f',
			'royalblue':			'4169e1',
			'saddlebrown':			'8b4513',
			'salmon':				'fa8072',
			'sandybrown':			'f4a460',
			'seagreen':				'2e8b57',
			'seashell':				'fff5ee',
			'sienna':				'a0522d',
			'silver':				'c0c0c0',
			'skyblue':				'87ceeb',
			'slateblue':			'6a5acd',
			'slategray':			'708090',
			'slategrey':			'708090',
			'snow':					'fffafa',
			'springgreen':			'00ff7f',
			'steelblue':			'4682b4',
			'tan':					'd2b48c',
			'teal':					'008080',
			'thistle':				'd8bfd8',
			'tomato':				'ff6347',
			'turquoise':			'40e0d0',
			'violet':				'ee82ee',
			'wheat':				'f5deb3',
			'white':				'ffffff',
			'whitesmoke':			'f5f5f5',
			'yellow':				'ffff00',
			'yellowgreen':			'9acd32'
		},

		hexMap = null,

		createHexMap = function(){
			hexMap = {};
			for( var i in nameMap ){
				hexMap[ nameMap[i] ] = i;
			}
		},

		toHex = function(c){
			c = parseInt( c, 10 ).toString(16);
			return c.length < 2 ? "0" + c : c;
		};

	$.extend(ep.color = {}, {

		/**
		 * Convert rgb color to hex color format.
		 * 
		 * Convert a rgb or rgba color object to hex color string.
		 * 
		 * ### Examples
		 * Convert rgb color to hex color format.
		 * 
		 * JavaScript:
		 * 
		 *     ep.color.rgbToHex({
		 *         r:255,
		 *         g:125,
		 *         b:44
		 *     });
		 * 
		 * Results:
		 * 
		 *     #ff7d2c
		 * 
		 * 
		 * @param {Object} rgb A rgb color object.
		 * 
		 * @method rgbToHex
		 * @static 
		 * @member ep.color
		 * 
		 * @since 6.12.0
		 */
		rgbToHex: function( rgb ){
			return rgb.a === 0 ? "transparent" : toHex(rgb.r) + toHex(rgb.g) + toHex(rgb.b);
		},

		/**
		 * Convert rgb color to hsb color format.
		 * 
		 * Convert a rgb or rgba color object to hsb color object.
		 * 
		 * ### Examples
		 * Convert rgb color to hsb color format.
		 * 
		 * JavaScript:
		 * 
		 *     ep.color.rgbToHsb({
		 *         r:255,
		 *         g:125,
		 *         b:44
		 *     });
		 * 
		 * Results:
		 * 
		 *     {
		 *         h:330,
		 *         s:67,
		 *         b:39
		 *     }
		 * 
		 * 
		 * @param {Object} rgb A rgb color object.
		 * 
		 * @method rgbToHsb
		 * @static 
		 * @member ep.color
		 * 
		 * @since 6.12.0
		 */
		rgbToHsb: function(rgb) {
			var min = Math.min( Math.min(rgb.r,rgb.g), rgb.b ),
				max = Math.max( Math.max(rgb.r,rgb.g), rgb.b ),
				delta = (max - min),
				sat = 0,
				lum = 0,
				hue = 0;

			if( max !== 0 ){
				sat = (delta / max) * 100;
				lum = (max / 255) * 100;
			}

			if( delta !== 0 ){
				if( rgb.r===max ){
					hue = (rgb.g - rgb.b) / delta;
				}
				else if( rgb.g===max ){
					hue = 2 + ( (rgb.b - rgb.r) / delta );
				}
				else{
					hue = 4 + ( (rgb.r - rgb.g) / delta );
				}
				hue = (hue * 60);
				hue = hue < 0 ? hue + 360 : hue;
			}

			return {
				h: Math.round(hue),
				s: Math.round(sat),
				b: Math.round(lum)
			};
		},

		/**
		 * Convert rgb color to color name.
		 * 
		 * Convert a rgb or rgba color object to color name string.
		 * Only the '''css color names''' are supported.
		 * 
		 * ### Examples
		 * Convert rgb color to color name.
		 * 
		 * JavaScript:
		 * 
		 *     ep.color.rgbToName({
		 *         r:0,
		 *         g:128,
		 *         b:0
		 *     });
		 * 
		 * Results:
		 * 
		 *     green
		 * 
		 * 
		 * @param {Object} rgb A rgb color object.
		 * 
		 * @method rgbToName
		 * @static 
		 * @member ep.color
		 * 
		 * @since 6.12.0
		 */
		rgbToName: function( rgb ){
			var hex = this.rgbToHex(rgb);
			return this.hexToName( hex );
		},

		/**
		 * Convert hex color to rgb color format.
		 * 
		 * Convert a hex color string to rgba color object.
		 * 
		 * ### Examples
		 * Convert hex color to rgb color format.
		 * 
		 * JavaScript:
		 * 
		 *     ep.color.hexToRgb('#ff7d2c');
		 * 
		 * Results:
		 * 
		 *     {
		 *         r:255,
		 *         g:125,
		 *         b:44,
		 *         a:1
		 *     }
		 * 
		 * 
		 * @param {String} hex A hex color string.
		 * 
		 * @method hexToRgb
		 * @static 
		 * @member ep.color
		 * 
		 * @since 6.12.0
		 */
		hexToRgb: function( hex ) {
			hex = hex.toUpperCase();

			var rgb;

			if( /^(transparent|none)$/.test(hex) ){
				return {
					r:255,
					g:255,
					b:255,
					a:0
				};
			}

			hex = hex.charAt(0) === "#" ? hex.substring(1,hex.length) : hex;

			if( hex.length === 6 ){
				rgb = {
					r: parseInt(hex.substring(0,2),16),
					g: parseInt(hex.substring(2,4),16),
					b: parseInt(hex.substring(4,6),16),
					a: 1
				};
			}
			else if( hex.length === 3){
				rgb = {
					r: parseInt(hex.substring(0,1) + hex.substring(0,1),16),
					g: parseInt(hex.substring(1,2) + hex.substring(1,2),16),
					b: parseInt(hex.substring(2,3) + hex.substring(2,3),16),
					a: 1
				};
			}
			else{
				//return white if no hex value was given
				rgb = {
					r: 255,
					g: 255,
					b: 255,
					a: 1
				};
			}

			rgb.r =  isNaN(rgb.r) ? 0 : Math.round(rgb.r);
			rgb.g =  isNaN(rgb.g) ? 0 : Math.round(rgb.g);
			rgb.b =  isNaN(rgb.b) ? 0 : Math.round(rgb.b);

			return rgb;
		},

		/**
		 * Convert hex color to hsb color format.
		 * 
		 * Convert a hex color string to hsb color object.
		 * 
		 * ### Examples
		 * Convert hex color to hsb color format.
		 * 
		 * JavaScript:
		 * 
		 *     ep.color.hexToHsb('#ff7d2c');
		 * 
		 * Results:
		 * 
		 *     {
		 *         h:23,
		 *         s:83,
		 *         b:100
		 *     }
		 * 
		 * 
		 * @param {String} hex A hex color string.
		 * 
		 * @method hexToHsb
		 * @static 
		 * @member ep.color
		 * 
		 * @since 6.12.0
		 */
		hexToHsb: function( hex ){
			return this.rgbToHsb( this.hexToRgb(hex) );
		},

		/**
		 * Convert hex color to color name.
		 * 
		 * Convert hex color to color name string.
		 * Only the '''css color names''' are supported.
		 * 
		 * ### Examples
		 * Convert hex color to hsb color format.
		 * 
		 * JavaScript:
		 * 
		 *     ep.color.hexToHsb('#008000');
		 * 
		 * Results:
		 * 
		 *     green
		 * 
		 * 
		 * @param {String} hex A hex color string.
		 * 
		 * @method hexToName
		 * @static 
		 * @member ep.color
		 * 
		 * @since 6.12.0
		 */
		hexToName: function( hex ){
			hex = hex.charAt(0) === "#" ? hex.substring(1,hex.length) : hex;

			if(!hexMap){
				createHexMap();
			}

			return hexMap[hex];
		},

		/**
		 * Convert hsb color to rgb color.
		 * 
		 * Convert hsb color object to rgb color object.
		 * 
		 * ### Examples
		 * Convert hsb color to rgb color.
		 * 
		 * JavaScript:
		 * 
		 *     ep.color.hsbToRgb({
		 *         h:23,
		 *         s:83,
		 *         b:100
		 *     });
		 * 
		 * Results:
		 * 
		 *     {
		 *         r:255,
		 *         g:124,
		 *         b:43,
		 *         a:1
		 *     }
		 * 
		 * 
		 * @param {Object} hsb A hsb color object.
		 * 
		 * @method hsbToRgb
		 * @static 
		 * @member ep.color
		 * 
		 * @since 6.12.0
		 */
		hsbToRgb: function(hsb) {
			var rgb = {},
				r = 0,
				g = 0,
				b = 0,
				hue = hsb.h/60,
				sat = hsb.s/100,
				lum = hsb.b/100;

			if( sat === 0 ) {
				r = g = b = lum;
			}
			else {
				var i = parseInt( hue, 10 ),
					p = lum * ( 1.0-sat ),
					q = lum * ( 1.0-sat * (hue-i) ),
					t = lum * ( 1.0-sat * ( 1 - (hue-i) ) );

				switch (i) {
					case 0: r = lum; g = t;   b = p;   break;
					case 1: r = q;   g = lum; b = p;   break;
					case 2: r = p;   g = lum; b = t;   break;
					case 3: r = p;   g = q;   b = lum; break;
					case 4: r = t;   g = p;   b = lum; break;
					case 5: r = lum; g = p;   b = q;   break;
					case 6: r = lum; g = t;   b = p;   break;
				}
			}

			return {
				r: Math.round( r * 255 ),
				g: Math.round( g * 255 ),
				b: Math.round( b * 255 ),
				a: 1
			};
		},

		/**
		 * Convert hsb color to hex color.
		 * 
		 * Convert hsb color object to hex color string.
		 * 
		 * ### Examples
		 * Convert hsb color to hex color.
		 * 
		 * JavaScript:
		 * 
		 *     ep.color.hsbToRgb({
		 *         h:23,
		 *         s:83,
		 *         b:100
		 *     });
		 * 
		 * Results:
		 * 
		 *     #ff7c2b
		 * 
		 * 
		 * @param {Object} hsb A hsb color object.
		 * 
		 * @method hsbToHex
		 * @static 
		 * @member ep.color
		 * 
		 * @since 6.12.0
		 */
		hsbToHex: function( hsb ){
			return this.rgbToHex( this.hsbToRgb(hsb) );
		},

		/**
		 * Convert hsb color to color name.
		 * 
		 * Convert hsb color object to color name.
		 * Only the '''css color names''' are supported.
		 * 
		 * ### Examples
		 * Convert hsb color to color name.
		 * 
		 * JavaScript:
		 * 
		 *     ep.color.hsbToRgb({
		 *         h:120,
		 *         s:100,
		 *         b:50
		 *     });
		 * 
		 * Results:
		 * 
		 *     green
		 * 
		 * 
		 * @param {Object} hsb A hsb color object.
		 * 
		 * @method hsbToName
		 * @static 
		 * @member ep.color
		 * 
		 * @since 6.12.0
		 */
		hsbToName: function( hsb ){
			return this.hexToName( this.hsbToHex(hsb) );
		},

		/**
		 * Convert color name to hex color.
		 * 
		 * Convert a color name string to hex color string.
		 * Only the '''css color names''' are supported.
		 * 
		 * ### Examples
		 * Convert color name to hex color.
		 * 
		 * JavaScript:
		 * 
		 *     ep.color.nameToHex('green');
		 * 
		 * Results:
		 * 
		 *     #008000
		 * 
		 * 
		 * @param {String} color A color name string.
		 * 
		 * @method nameToHex
		 * @static 
		 * @member ep.color
		 * 
		 * @since 6.12.0
		 */
		nameToHex: function( name ){
			name = $.trim( name.toLowerCase() );
			return (/^(transparent|none)$/).test(name) ? 'transparent' : nameMap[name];
		},

		/**
		 * Convert color name to rgb color.
		 * 
		 * Convert a color name string to rgb color object.
		 * Only the '''css color names''' are supported.
		 * 
		 * ### Examples
		 * Convert color name to rgb color.
		 * 
		 * JavaScript:
		 * 
		 *     ep.color.nameToRgb('green');
		 * 
		 * Results:
		 * 
		 *     {
		 *         r:0,
		 *         g:128,
		 *         b:0,
		 *         a:1
		 *     }
		 * 
		 * 
		 * @param {String} color A color name string.
		 * 
		 * @method nameToRgb
		 * @static 
		 * @member ep.color
		 * 
		 * @since 6.12.0
		 */
		nameToRgb: function( name ){
			var hex = this.nameToHex(name);
			return hex ? this.hexToRgb( hex ) : hex;
		},

		/**
		 * Convert color name to hsb color.
		 * 
		 * Convert a color name string to hsb color object.
		 * Only the '''css color names''' are supported.
		 * 
		 * ### Examples
		 * Convert color name to hsb color.
		 * 
		 * JavaScript:
		 * 
		 *     ep.color.nameToHsb('green');
		 * 
		 * Results:
		 * 
		 *     {
		 *         h:120,
		 *         s:100,
		 *         b:50
		 *     }
		 * 
		 * 
		 * @param {String} color A color name string.
		 * 
		 * @method nameToHsb
		 * @static 
		 * @member ep.color
		 * 
		 * @since 6.12.0
		 */
		nameToHsb: function( name ){
			var rgb = this.nameToRgb(name);
			return rgb ? this.rgbToHsb(rgb) : rgb;
		},

		/**
		 * Convert css color string to hex color.
		 * 
		 * Convert a css color string to hex color string.
		 * 
		 * ### Examples
		 * Convert css color string to hex color.
		 * 
		 * JavaScript:
		 * 
		 *     ep.color.stringToHex('green');
		 * 
		 * Results:
		 * 
		 *     #008000
		 * 
		 * Convert css color string to hex color.
		 * 
		 * JavaScript:
		 * 
		 *     ep.color.stringToHex('rgb(0,128,0)');
		 * 
		 * Results:
		 * 
		 *     #008000
		 * 
		 * Convert css color string to hex color.
		 * 
		 * JavaScript:
		 * 
		 *     ep.color.stringToHex('rgba(0,128,0,1)');
		 * 
		 * Results:
		 * 
		 *     #008000
		 * 
		 * 
		 * @param {String} string A css color string.
		 * 
		 * @method stringToHex
		 * @static 
		 * @member ep.color
		 * 
		 * @since 6.12.0
		 */
		stringToHex: function( string, /* internal */ strict ){
			string = $.trim( string.toLowerCase() );

			var result,
				found;

			if( (/^(transparent|none)$/).test(string) ){
				result = "transparent";
			}
			else if( found = (/^#?([0-9a-f]{6})$/).exec(string) ){
				result = found[1];
			}
			else if( found = (/^#?([0-9a-f])([0-9a-f])([0-9a-f])$/).exec(string) ) {
				result = found[1] + found[1] + found[2] + found[2] + found[3] + found[3];
			}
			else if( found = (/^rgb\(\s*([0-9]{1,3})\s*,\s*([0-9]{1,3})\s*,\s*([0-9]{1,3})\s*\)$/).exec(string) ){
				result = this.rgbToHex( {r: found[1], g: found[2], b: found[3]} );
			}
			else if( found = (/^rgba\(\s*([0-9]{1,3})\s*,\s*([0-9]{1,3})\s*,\s*([0-9]{1,3})\s*,\s*([0-1]{1}(:?\.?[0-9]{1})?)\s*\)$/).exec(string) ){
				result = this.rgbToHex( {r: found[1], g: found[2], b: found[3], a: found[4]} );
			}
			else{
				result = this.nameToHex( string );
			}

			return result===undefined && !strict ? "ffffff" : result;
		},

		/**
		 * Convert css color string to rgb color.
		 * 
		 * Convert a css color string to hex color string.
		 * 
		 * ### Examples
		 * Convert css color string to hex color.
		 * 
		 * JavaScript:
		 * 
		 *     ep.color.stringToRgb('green');
		 * 
		 * Results:
		 * 
		 *     {
		 *         r:0,
		 *         g:128,
		 *         b:0,
		 *         a:1
		 *     }
		 * 
		 * Convert css color string to hex color.
		 * 
		 * JavaScript:
		 * 
		 *     ep.color.stringToRgb('rgb(0,128,0)');
		 * 
		 * Results:
		 * 
		 *     {
		 *         r:0,
		 *         g:128,
		 *         b:0,
		 *         a:1
		 *     }
		 * 
		 * Convert css color string to hex color.
		 * 
		 * JavaScript:
		 * 
		 *     ep.color.stringToRgb('rgba(0,128,0,0.5)');
		 * 
		 * Results:
		 * 
		 *     {
		 *         r:0,
		 *         g:128,
		 *         b:0,
		 *         a:0.5
		 *     }
		 * 
		 * 
		 * @param {String} string A css color string.
		 * 
		 * @method stringToRgb
		 * @static 
		 * @member ep.color
		 * 
		 * @since 6.12.0
		 */
		stringToRgb: function( string ){
			var hex = this.stringToHex(string);
			return hex ? this.hexToRgb(hex) : hex;
		},

		/**
		 * Convert css color string to hsb color.
		 * 
		 * Convert a css color string to hex color string.
		 * 
		 * ### Examples
		 * Convert css color string to hsb color.
		 * 
		 * JavaScript:
		 * 
		 *     ep.color.stringToHsb('green');
		 * 
		 * Results:
		 * 
		 *     {
		 *         h:120,
		 *         s:100,
		 *         b:50
		 *     }
		 * 
		 * Convert css color string to hsb color.
		 * 
		 * JavaScript:
		 * 
		 *     ep.color.stringToHsb('rgb(0,128,0)');
		 * 
		 * Results:
		 * 
		 *     {
		 *         h:120,
		 *         s:100,
		 *         b:50
		 *     }
		 * 
		 * Convert css color string to hsb color.
		 * 
		 * JavaScript:
		 * 
		 *     ep.color.stringToHsb('rgba(0,128,0,0.5)');
		 * 
		 * Results:
		 * 
		 *     {
		 *         h:120,
		 *         s:100,
		 *         b:50
		 *     }
		 * 
		 * 
		 * @param {String} string A css color string.
		 * 
		 * @method stringToHsb
		 * @static 
		 * @member ep.color
		 * 
		 * @since 6.12.0
		 */
		stringToHsb: function( string ){
			var hex = this.stringToHex(string);
			return hex ? this.hexToHsb(hex) : hex;
		},

		/**
		 * Convert css color string to color name.
		 * 
		 * Convert a css color string to color name string.
		 * Only the '''css color names''' are supported.
		 * 
		 * ### Examples
		 * Convert css color string to color name.
		 * 
		 * JavaScript:
		 * 
		 *     ep.color.stringToName('#008000');
		 * 
		 * Results:
		 * 
		 *     green
		 * 
		 * Convert css color string to color name.
		 * 
		 * JavaScript:
		 * 
		 *     ep.color.stringToHsb('rgb(0,128,0)');
		 * 
		 * Results:
		 * 
		 *     green
		 * 
		 * Convert css color string to color name.
		 * 
		 * JavaScript:
		 * 
		 *     ep.color.stringToHsb('rgba(0,128,0,0.5)');
		 * 
		 * Results:
		 * 
		 *     green
		 * 
		 * 
		 * @param {String} string A css color string.
		 * 
		 * @method stringToName
		 * @static 
		 * @member ep.color
		 * 
		 * @since 6.12.0
		 */
		stringToName: function( string ){
			var hex = this.stringToHex(string);
			return hex ? this.hexToName(hex) : hex;
		}
	});

	return ep;

});

/* ---- Module:ep.date ---- */

/**
 * @class ep.Date
 * 
 */

/**
 * Sum or subtract days for the date object.
 * 
 * ### Dependencies
 * 
 *  + `ep`
 *  + `jQuery.i18n`
 *  + `jQuery.class`
 * 
 * @param {Integer} days A number of days.
 * 
 * @method addDate
 * @member ep.Date
 * 
 * @since 6.11.0
 */

/**
 * Sum or subtract days for the date object.
 * 
 * ### Dependencies
 * 
 *  + `ep`
 *  + `jQuery.i18n`
 *  + `jQuery.class`
 * 
 * @param {Integer} days A number of days.
 * 
 * @method addDay
 * @member ep.Date
 * 
 * @since 6.11.0
 */

/**
 * Sum or subtract years for the date object.
 * 
 * ### Dependencies
 * 
 *  + `ep`
 *  + `jQuery.i18n`
 *  + `jQuery.class`
 * 
 * @param {Integer} years A number of years.
 * 
 * @method addFullYear
 * @member ep.Date
 * 
 * @since 6.11.0
 */

/**
 * Sum or subtract hours for the date object.
 * 
 * ### Dependencies
 * 
 *  + `ep`
 *  + `jQuery.i18n`
 *  + `jQuery.class`
 * 
 * @param {Integer} hours A number of hours.
 * 
 * @method addHours
 * @member ep.Date
 * 
 * @since 6.11.0
 */

/**
 * Sum or subtract milliseconds for the date object.
 * 
 * ### Dependencies
 * 
 *  + `ep`
 *  + `jQuery.i18n`
 *  + `jQuery.class`
 * 
 * @param {Integer} milliseconds A number of milliseconds.
 * 
 * @method addMilliseconds
 * @member ep.Date
 * 
 * @since 6.11.0
 */

/**
 * Sum or subtract minutes for the date object.
 * 
 * ### Dependencies
 * 
 *  + `ep`
 *  + `jQuery.i18n`
 *  + `jQuery.class`
 * 
 * @param {Integer} minutes A number of minutes.
 * 
 * @method addMinutes
 * @member ep.Date
 * 
 * @since 6.11.0
 */

/**
 * Sum or subtract months for the date object.
 * 
 * ### Dependencies
 * 
 *  + `ep`
 *  + `jQuery.i18n`
 *  + `jQuery.class`
 * 
 * @param {Integer} months A number of months.
 * 
 * @method addMonth
 * @member ep.Date
 * 
 * @since 6.11.0
 */

/**
 * Sum or subtract seconds for the date object.
 * 
 * ### Dependencies
 * 
 *  + `ep`
 *  + `jQuery.i18n`
 *  + `jQuery.class`
 * 
 * @param {Integer} seconds A number of seconds.
 * 
 * @method addSeconds
 * @member ep.Date
 * 
 * @since 6.11.0
 */

/**
 * Sum or subtract milliseconds for the date object.
 * 
 * ### Dependencies
 * 
 *  + `ep`
 *  + `jQuery.i18n`
 *  + `jQuery.class`
 * 
 * @param {Integer} milliseconds A number of milliseconds.
 * 
 * @method addTime
 * @member ep.Date
 * 
 * @since 6.11.0
 */

/**
 * Sum or subtract seconds for the date object.
 * 
 * ### Dependencies
 * 
 *  + `ep`
 *  + `jQuery.i18n`
 *  + `jQuery.class`
 * 
 * @param {Integer} seconds A number of seconds.
 * 
 * @method addUnixTime
 * @member ep.Date
 * 
 * @since 6.11.0
 */

/**
 * The `.compareDate()` method compares a date with the current date without consideration of the time.
 * Returns an integer indication:
 * 
 *  + date(current date) > date(givn date) = 1
 *  + date(current date) == date(givn date) = 0
 *  + date(current date) < date(givn date) = -1
 * 
 * ### Dependencies
 * 
 *  + `ep`
 *  + `jQuery.i18n`
 *  + `jQuery.class`
 * 
 * @param {Object} date A date object to compare.
 * 
 * @method compareDate
 * @member ep.Date
 * 
 * @since 6.11.0
 */

/**
 * The `.compareTime()` method compares a the time between a date and the current date without consideration of the date.
 * Returns an integer indication:
 * 
 *  + time(current date) > time(givn date) = 1
 *  + time(current date) == time(givn date) = 0
 *  + time(current date) < time(givn date) = -1
 * 
 * ### Dependencies
 * 
 *  + `ep`
 *  + `jQuery.i18n`
 *  + `jQuery.class`
 * 
 * @param {Object} date A date object to compare.
 * 
 * @method compareTime
 * @member ep.Date
 * 
 * @since 6.11.0
 */

/**
 * The `.diffDate()` method returns difference of days between current date and givn date.
 * 
 * ### Dependencies
 * 
 *  + `ep`
 *  + `jQuery.i18n`
 *  + `jQuery.class`
 * 
 * @param {Object} date A date object to get a diff.
 * 
 * @method diffDate
 * @member ep.Date
 * 
 * @since 6.11.0
 */

/**
 * The `.diffDay()` method returns difference of days between current date and givn date.
 * 
 * ### Dependencies
 * 
 *  + `ep`
 *  + `jQuery.i18n`
 *  + `jQuery.class`
 * 
 * @param {Object} date A date object to get a diff.
 * 
 * @method diffDay
 * @member ep.Date
 * 
 * @since 6.11.0
 */

/**
 * The `.diffFullYear()` method returns difference of years between current date and givn date.
 * 
 * ### Dependencies
 * 
 *  + `ep`
 *  + `jQuery.i18n`
 *  + `jQuery.class`
 * 
 * @param {Object} date A date object to get a diff.
 * 
 * @method diffFullYear
 * @member ep.Date
 * 
 * @since 6.11.0
 */

/**
 * The `.diffHours()` method returns difference of hours between current date and givn date.
 * 
 * ### Dependencies
 * 
 *  + `ep`
 *  + `jQuery.i18n`
 *  + `jQuery.class`
 * 
 * @param {Object} date A date object to get a diff.
 * 
 * @method diffHours
 * @member ep.Date
 * 
 * @since 6.11.0
 */

/**
 * The `.diffMilliseconds()` method returns difference of milliseconds between current date and givn date.
 * 
 * ### Dependencies
 * 
 *  + `ep`
 *  + `jQuery.i18n`
 *  + `jQuery.class`
 * 
 * @param {Object} date A date object to get a diff.
 * 
 * @method diffMilliseconds
 * @member ep.Date
 * 
 * @since 6.11.0
 */

/**
 * The `.diffMinutes()` method returns difference of minutes between current date and givn date.
 * 
 * ### Dependencies
 * 
 *  + `ep`
 *  + `jQuery.i18n`
 *  + `jQuery.class`
 * 
 * @param {Object} date A date object to get a diff.
 * 
 * @method diffMinutes
 * @member ep.Date
 * 
 * @since 6.11.0
 */

/**
 * The `.diffMonth()` method returns difference of months between current date and givn date.
 * 
 * ### Dependencies
 * 
 *  + `ep`
 *  + `jQuery.i18n`
 *  + `jQuery.class`
 * 
 * @param {Object} date A date object to get a diff.
 * 
 * @method diffMonth
 * @member ep.Date
 * 
 * @since 6.11.0
 */

/**
 * The `.diffSeconds()` method returns difference of seconds between current date and givn date.
 * 
 * ### Dependencies
 * 
 *  + `ep`
 *  + `jQuery.i18n`
 *  + `jQuery.class`
 * 
 * @param {Object} date A date object to get a diff.
 * 
 * @method diffSeconds
 * @member ep.Date
 * 
 * @since 6.11.0
 */

/**
 * The `.diffTime()` method returns difference of miliseconds between current date and givn date.
 * 
 * ### Dependencies
 * 
 *  + `ep`
 *  + `jQuery.i18n`
 *  + `jQuery.class`
 * 
 * @param {Object} date A date object to get a diff.
 * 
 * @method diffTime
 * @member ep.Date
 * 
 * @since 6.11.0
 */

/**
 * The `.diffUnixTime()` method returns difference of seconds between current date and givn date.
 * 
 * ### Dependencies
 * 
 *  + `ep`
 *  + `jQuery.i18n`
 *  + `jQuery.class`
 * 
 * @param {Object} date A date object to get a diff.
 * 
 * @method diffUnixTime
 * @member ep.Date
 * 
 * @since 6.11.0
 */

/*
 * @copyright		© Copyright 2006-2010, epages GmbH, All Rights Reserved.
 *
 * @module			ep.date
 *
 * @revision		$Revision: 1.5.2.2 $
 */

define("ep/date", [
	"jquery",
	"ep",
	"class",

	"jquery/i18n"
], function ($, ep, Class) {

	var noGetExp = /^(UnixTime)/,
		noSetExp = /^(Day|UnixTime)$/,
		noAddExp = /^UTC/,
		proto = {};

	// $.extend with property prototype doesn't work in IE lte 8
	/**
	 * Using advanced date operations.
	 * 
	 * The `ep.Date()` method works like the native javascript `Date()` method and supports the same prototype methods.
	 * 
	 * If no parameter is provided, the created date object represents the current time.
	 * 
	 * If only one parameter is provided, and this parameter is a string, the date is created from this string. It is assumed
	 * that the string has the format "monthName day, year hours:minutes:seconds".
	 * 
	 * If only one parameter is provided, and this parameter is an integer, the date is created from this number, which is
	 * interpreted as the milliseconds since Januar 1th 1970.
	 * 
	 * Getter in `ep.Date()` return the same value as the native function:
	 * 
	 *  + toGMTString, UTC, getDate, getDay, getFullYear, getHours, getMilliseconds, getMinutes, getMonth, getSeconds, getTime, getTimezoneOffset, getUTCDate, getUTCFullYear, getUTCHours, getUTCMilliseconds, getUTCMinutes, getUTCMonth, getUTCSeconds, getYear
	 * 
	 * Setter in `ep.Date()` set the same value(s) as the native function but return the current instance of ep.Date:
	 * 
	 *  + parse, setDate, setFullYear, setHours, setMilliseconds, setMinutes, setMonth, setSeconds, setTime, setUTCDate, setUTCFullYear, setUTCHours, setUTCMilliseconds, setUTCMinutes, setUTCMonth, setUTCSeconds, setYear
	 * 
	 * ### Examples
	 * Simply date operation.
	 * 
	 * JavaScript:
	 * 
	 *     new ep.Date(2009,1,17)
	 *             .addDate(4)
	 *             .addFullYear(-2)
	 *             .toGMTString();
	 * 
	 * Results:
	 * 
	 *     Tue, 20 Feb 2009 00:00:00 GMT
	 * 
	 * 
	 * ### Dependencies
	 * 
	 *  + `ep`
	 *  + `jQuery.i18n`
	 *  + `jQuery.class`
	 * 
	 * @param {Integer} year A full year number.
	 * @param {Integer} month A zero indexed month of the year.
	 * @param {Integer} day A day of the month.
	 * @param {Integer} [hours] An hour in 24 hours format.
	 * @param {Integer} [minutes] A minute.
	 * @param {Integer} [seconds] A second.
	 * 
	 * @method constructor
	 * @member ep.Date
	 * 
	 * @since 6.11.0
	 */
	proto.constructor = function( a, b, c, d, e, f, g ){
		switch( arguments.length ) {
			case 1:
				this.date = new Date( (/^-?\d+$/).test(a) ? parseInt(a,10) : a instanceof Date || a instanceof ep.Date ? a.getTime() : a );
			break;
			case 3:
				this.date = new Date( a, b, c );
			break;
			case 6:
				this.date = new Date( a, b, c, d, e, f );
			break;
			case 7:
				this.date = new Date( a, b, c, d, e, f, g );
			break;
			default:
				this.date = new Date();
			break;
		}
		return this;
	};

	// advanced
	$.extend(proto,{
		// clone
		/**
		 * Clone the current date object, `.clone()` returns a new instance of `ep.Date()` with the same date as the current date object.
		 * 
		 * ### Dependencies
		 * 
		 *  + `ep`
		 *  + `jQuery.i18n`
		 *  + `jQuery.class`
		 * 
		 * @method clone
		 * @member ep.Date
		 * 
		 * @since 6.11.0
		 */
		clone: function(){
			return new ep.Date( this.getTime() );
		},
		// i18n format
		/**
		 * The `.getFormat()` returns a formatted string of the date using `jQuery.i18n`.
		 * 
		 * ### Dependencies
		 * 
		 *  + `ep`
		 *  + `jQuery.i18n`
		 *  + `jQuery.class`
		 * 
		 * @param {String} format A formatter string.
		 * @param {Object} [options] A map of additional options pass to the method.
		 * 
		 * @method getFormat
		 * @member ep.Date
		 * 
		 * @since 6.11.0
		 */
		getFormat: function( format, options ){
			return $.i18n.formatDate( this.date, format, options );
		},
		/**
		 * The `.setFormat()` set a date from a string with specified format using `jQuery.i18n`.
		 * 
		 * ### Dependencies
		 * 
		 *  + `ep`
		 *  + `jQuery.i18n`
		 *  + `jQuery.class`
		 * 
		 * @param {String} value A value to set as date.
		 * @param {String} format A formatter to patse the value.
		 * @param {Object} [options] A map of additional options pass to the method.
		 * 
		 * @method setFormat
		 * @member ep.Date
		 * 
		 * @since 6.11.0
		 */
		setFormat: function( value, format, options ){
			var date = $.i18n.parseDate( value, format,  options );

			if( date ){
				this.setTime( date.getTime() );
			}
			return this;
		},
		// leap year
		/**
		 * The `.isLeapYear()` method returns a boolean indication wether the current date is in a leap year.
		 * 
		 * ### Dependencies
		 * 
		 *  + `ep`
		 *  + `jQuery.i18n`
		 *  + `jQuery.class`
		 * 
		 * @method isLeapYear
		 * @member ep.Date
		 * 
		 * @since 6.11.0
		 */
		isLeapYear: function(){
			var year = this.getFullYear();
			return !(year%400) || (!(year%4) && !!(year%100));
		},
		// days of month
		/**
		 * The `.getMonthLength()` method returns the the count of days in current month.
		 * 
		 * ### Dependencies
		 * 
		 *  + `ep`
		 *  + `jQuery.i18n`
		 *  + `jQuery.class`
		 * 
		 * @method getMonthLength
		 * @member ep.Date
		 * 
		 * @since 6.11.0
		 */
		getMonthLength: function(){
			var month = this.getMonth(),
				days = [31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31];

			if( month===1 && this.isLeapYear() ){
				return 29;
			}
			return days[month];
		},
		/**
		 * The `.setFirstMonthDay()` method sets the date to to the first day of the current month.
		 * 
		 * ### Dependencies
		 * 
		 *  + `ep`
		 *  + `jQuery.i18n`
		 *  + `jQuery.class`
		 * 
		 * @method setFirstMonthDay
		 * @member ep.Date
		 * 
		 * @since 6.11.0
		 */
		setFirstMonthDay: function(){
			this.setDate( 1 );
			return this;
		},
		/**
		 * The `.setLastMonthDay()` method sets the date to to the last day of the current month.
		 * 
		 * ### Dependencies
		 * 
		 *  + `ep`
		 *  + `jQuery.i18n`
		 *  + `jQuery.class`
		 * 
		 * @method setLastMonthDay
		 * @member ep.Date
		 * 
		 * @since 6.11.0
		 */
		setLastMonthDay: function(){
			this.setDate( this.getMonthLength() );
			return this;
		},
		// day of week
		/**
		 * The `.setDay()` method sets the date to an other speciefied weekday in the current week.
		 * 
		 * ### Dependencies
		 * 
		 *  + `ep`
		 *  + `jQuery.i18n`
		 *  + `jQuery.class`
		 * 
		 * @param {Integer} day A zero index weekday.
		 * 
		 * @method setDay
		 * @member ep.Date
		 * 
		 * @since 6.11.0
		 */
		setDay: function( set ){
			this.setDate( this.getDate() + ( set - this.getDay() ) );
			return this;
		},
		// unix time
		/**
		 * The `.getUnixTime()` method returns the date as unixtime (seconds since Januar 1th 1970).
		 * 
		 * ### Dependencies
		 * 
		 *  + `ep`
		 *  + `jQuery.i18n`
		 *  + `jQuery.class`
		 * 
		 * @method getUnixTime
		 * @member ep.Date
		 * 
		 * @since 6.11.0
		 */
		getUnixTime: function(){
			return Math.round( this.getTime() / 1000 );
		},
		/**
		 * The `.setUnixTime()` method set the current date to the givn unixtime.
		 * 
		 * ### Dependencies
		 * 
		 *  + `ep`
		 *  + `jQuery.i18n`
		 *  + `jQuery.class`
		 * 
		 * @param {Integer} unixtime A unixtime (seconds since Januar 1th 1970).
		 * 
		 * @method setUnixTime
		 * @member ep.Date
		 * 
		 * @since 6.11.0
		 */
		setUnixTime: function( set ){
			this.setTime( set * 1000 );
			return this;
		},
		// UTC unix time
		/**
		 * The `.getUTCUnixTime()` method returns the date as unixtime (seconds since Januar 1th 1970).
		 * However, it is not the local time but the Universal Coordinated Time (UTC) time get.
		 * 
		 * ### Dependencies
		 * 
		 *  + `ep`
		 *  + `jQuery.i18n`
		 *  + `jQuery.class`
		 * 
		 * @method getUTCUnixTime
		 * @member ep.Date
		 * 
		 * @since 6.11.0
		 */
		getUTCUnixTime: function(){
			return this.getUnixTime() - this.getTimezoneOffset()*60;
		},
		/**
		 * The `.setUTCUnixTime()` method is the same as `.setUnixTime()`. However, it is not the local time but the Universal Coordinated Time (UTC) time set.
		 * 
		 * ### Dependencies
		 * 
		 *  + `ep`
		 *  + `jQuery.i18n`
		 *  + `jQuery.class`
		 * 
		 * @param {Integer} unixtime A unixtime (seconds since Januar 1th 1970).
		 * 
		 * @method setUTCUnixTime
		 * @member ep.Date
		 * 
		 * @since 6.11.0
		 */
		setUTCUnixTime: function( set ){
			this.setUnixTime(set);
			this.addTime( this.getTimezoneOffset()*60000 );
			return this;
		}
	});

	// compare
	$.each({
		'Date': 'Hours',
		'Time': 'FullYear'
	},function( name, set ){
		proto[ 'compare' + name ] = function( date ){
			if( !date){
				date = new Date();
			}
			var thisDate = new Date( this.getTime() ),
				compDate = new Date( date.getTime() );

			thisDate[ 'set' + set ](0,0,0,0);
			compDate[ 'set' + set ](0,0,0,0);

			var thisTime = thisDate.getTime(),
				compTime = compDate.getTime();

			if( thisTime > compTime ){
				return 1;
			}
			else if( thisTime < compTime ){
				return -1;
			}
			else{
				return 0;
			}
		};
	});

	// get only
	$.each([
		'toGMTString',
		'toLocaleString',
		'getTimezoneOffset'
	],function( i, name ){
		proto[ name ] = function(){
			return this.date[ name ]();
		};
	});

	// add, get, set, diff
	$.each({
		'FullYear':			31536000000,
		'Month':			2592000000,
		'Day':				604800000,
		'Date':				86400000,
		'Hours':			3600000,
		'Minutes':			60000,
		'Seconds':			1000,
		'Milliseconds':		1,
		'Time':				1,
		'UTCDate':			0,
		'UTCFullYear':		0,
		'UTCHours':			0,
		'UTCMilliseconds':	0,
		'UTCMinutes':		0,
		'UTCMonth':			0,
		'UTCSeconds':		0,
		'UnixTime':			1000
	},function( name, math ){
		// get methods
		if( !noGetExp.test(name) ){
			proto[ 'get' + name ] = function(){
				return this.date[ 'get' + name ]();
			};
		}
		// set methods
		if( !noSetExp.test(name) ){
			proto[ 'set' + name ] = function(){
				this.date[ 'set' + name ].apply( this.date, arguments );
				return this;
			};
		}
		if( !noAddExp.test(name) ){
		// add methods
			proto[ 'add' + name ] = function( add ){
				this[ 'set' + name ]( this[ 'get' + name ]() + add );
				return this;
			};
		// diff methods
			proto[ 'diff' + name ] = function( date ){
				if( !date){
					date = new Date();
				}
				return Math.round( ( date.getTime() - this.getTime() ) / math );
			};
		}
	});

	Class('ep.Date', proto);

	return ep;

});

/* ---- Module:ep.i18n ---- */

/**
 * @class ep.i18n
 * 
 */

/*
 * @copyright		© Copyright 2006-2010, epages GmbH, All Rights Reserved.
 *
 * @module			ep.i18n
 *
 * @revision		$Revision: 1.5.2.1 $
 */

define("ep/i18n", [
	"jquery",
	"ep",

	"jquery/i18n"
], function ($, ep){

	$.extend((ep.i18n = {}),{

		/**
		 * Format a number as Bytes.
		 * 
		 * The `ep.i18n.formatBytes()` method uses the `jQuery.i18n.formatNumber()` method to format the givn value and
		 * add the correct unit (Byte, kB, MB, GB).
		 * 
		 *  + default adds '''Byte'''
		 *  + value is bigger or equal ''1024'' and smaller than ''1048576'' adds '''kb'''
		 *  + value is bigger or equal ''1048576'' and smaller than ''1073741824'' adds '''MB''Ä'
		 *  + value is bigger or equal ''1073741824'' adds '''GB'''
		 * 
		 * ### Examples
		 * Format an number with default options.
		 * 
		 * JavaScript:
		 * 
		 *     ep.i18n.formatBytes( 12000 );
		 * 
		 * Results:
		 * 
		 *     11.72 kB
		 * 
		 * Format an number with 4 after decimal places.
		 * 
		 * JavaScript:
		 * 
		 *     ep.i18n.formatBytes( 10240, 4 );
		 * 
		 * Results:
		 * 
		 *     10.0000 kB
		 * 
		 * Format an number with 2 after decimal places and german language settings.
		 * 
		 * JavaScript:
		 * 
		 *     ep.i18n.formatBytes( 10240, 2, {region: 'de'} );
		 * 
		 * Results:
		 * 
		 *     10,00 kB
		 * 
		 * 
		 * ### Dependencies
		 * 
		 *  + `ep`
		 *  + `jQuery.i18n`
		 * 
		 * @param {Number} value A number to format.
		 * @param {Integer} [decimals] A count of after decimal places.
		 * @param {Object} [options] A map of key/values settings like the options of jQuery.i18n.formatNumber().
		 * 
		 * @method formatBytes
		 * @static 
		 * @member ep.i18n
		 * 
		 * @since 6.11.0
		 */
		formatBytes: function( value, decimals, options ){
			if( typeof decimals !== 'number' ){
				if( !options ){
					options = decimals;
				}
				decimals = 2;
			}

			var unit = 'Byte';

			if( value >= 1073741824 ) {
				value /= 1073741824;
				unit = 'GB';
			}
			else if( value >= 1048576 ) {
				value /= 1048576;
				unit = 'MB';
			}
			else if( value >= 1024 ) {
				value /= 1024;
				unit = 'kB';
			}

			return $.i18n.formatNumber( value, 'n'+decimals, options ) + ' ' + unit;
		}

	});

	return ep;

});

/* ---- Module:ep.validate ---- */

/**
 * @class ep.validate
 * 
 */

/*
 * @copyright		© Copyright 2006-2010, epages GmbH, All Rights Reserved.
 *
 * @module			ep.validate
 *
 * @revision		$Revision: 1.6.2.1 $
 */

define("ep/validate", [
	"jquery",
	"ep",
	"util/mime",

	"ep/color",
	"ep/i18n"
], function ($, ep, mime) {

/*
 * @dictionary			ep.dict
 *
 * @translation			{NOT_VALID}
 *						{REQUIRED}
 *						{NOT_IN_RANGELENGTH}
 *						{LOWER_THAN_MINLENGTH}
 *						{GREATER_THAN_MAXLENGTH}
 *						{NOT_IN_RANGE}
 *						{LOWER_THAN_MIN}
 *						{GREATER_THAN_MAX}
 *						{NO_EMAIL}
 *						{NO_URL}
 *						{NO_MIME}
 *						{MIME_NOT_ACCEPT}
 *						{NO_CREDITCARD_NUMBER}
 *						{NO_NUMBER}
 *						{NO_CURRENCY}
 *						{NO_PERCENT}
 *						{NO_DATE}
 *						{NO_DATETIME}
 *						{NO_TIME}
 *						{NO_COLOR_VALUE}
 *						{NO_UNIT}
 *						{NO_UNIT_VALUE}
 *						{NO_CSS_NUMBER}
 *						{FLOAT_NOT_ALLOWED}
 *						{UNKOWN_UNIT}
 */

	var invalid = 'NOT_VALID',

		isN = function( value ){
			return !isNaN(value);
		},

		pattern = function( value, pattern ) {
			return pattern ? ( new RegExp( ((/^\^/).test(pattern)?'':'^') + pattern + ((/\$$/).test(pattern)?'':'$') , '' ).test( value ) || invalid ) : true;
		},

		required = function( value, req ) {
			return !value && req ? 'REQUIRED' : true;
		},

		rangelength = function( value, min, max ) {
			min = min<0 ? 0 : min;
			max = max<0 ? 0 : max;

			var val = $.trim(value).length;

			if( isN(min) && min>val ){
				return isN(max) ? 'NOT_IN_RANGELENGTH' : 'LOWER_THAN_MINLENGTH';
			}
			if( isN(max) && val>max ){
				return isN(min) ? 'NOT_IN_RANGELENGTH' : 'GREATER_THAN_MAXLENGTH';
			}
			return true;
		},

		range = function( value, min, max ) {
			var val = typeof value !== 'number' ? parseFloat(value,10) : value;

			if( isN(min) && min>val ){
				return isN(max) ? 'NOT_IN_RANGE' : 'LOWER_THAN_MIN';
			}
			if( isN(max) && val>max ){
				return isN(min) ? 'NOT_IN_RANGE' : 'GREATER_THAN_MAX';
			}
			return true;
		},

		i18nMap = {
			'date':					'd',
			'dateLong':				'D',
			'dateLong-time':		'f',
			'dateLong-timeLong':	'F',
			'date-time':			'l',
			'date-timeLong':		'L',
			'time':					't',
			'timeLong':				'T',
			'currency':				'c',
			'number':				'n',
			'percent':				'p'
		};

	$.extend( $.scope('ep.validate'), {

		/**
		 * Validate a email address.
		 * 
		 * The `ep.validate.email()` method checks if the givn string an valid email address.
		 * 
		 * ### Examples
		 * Validate an email address.
		 * 
		 * JavaScript:
		 * 
		 *     ep.validate.email( 'mmustermann@epages.com' );
		 * 
		 * Results:
		 * 
		 *     true
		 * 
		 * Validate an email address with error return.
		 * 
		 * JavaScript:
		 * 
		 *     ep.validate.email( 'mmustermann@epages' );
		 * 
		 * Results:
		 * 
		 *     NO_EMAIL
		 * 
		 * 
		 * ### Dependencies
		 * 
		 *  + `ep`
		 *  + `ep.color`
		 *  + `jQuery.mime`
		 *  + `jQuery.i18n`
		 * 
		 * @param {String} value A text to validate
		 * @param {Object} [options] A map of additional options pass to the method.
		 * @param {Boolean} options.required A boolean indication wether the value is required.
		 * @param {Integer} options.minlength A minimum number of chars.
		 * @param {Integer} options.maxlength A maximum number of chars.
		 * 
		 * @method email
		 * @static 
		 * @member ep.validate
		 * 
		 * @since 6.11.0
		 */
		email: function( value, options ){
			value = $.trim(value);

			var opt = $.extend({},options||{}),
				valid = required( value, opt.required );

			if( value && valid===true ){
				valid = /^((([a-z]|\d|[!#\$%&'\*\+\-\/=\?\^_`{\|}~]|[\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF])+(\.([a-z]|\d|[!#\$%&'\*\+\-\/=\?\^_`{\|}~]|[\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF])+)*)|((\x22)((((\x20|\x09)*(\x0d\x0a))?(\x20|\x09)+)?(([\x01-\x08\x0b\x0c\x0e-\x1f\x7f]|\x21|[\x23-\x5b]|[\x5d-\x7e]|[\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF])|(\\([\x01-\x09\x0b\x0c\x0d-\x7f]|[\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF]))))*(((\x20|\x09)*(\x0d\x0a))?(\x20|\x09)+)?(\x22)))@((([a-z]|\d|[\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF])|(([a-z]|\d|[\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF])([a-z]|\d|-|\.|_|~|[\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF])*([a-z]|\d|[\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF])))\.)+(([a-z]|[\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF])|(([a-z]|[\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF])([a-z]|\d|-|\.|_|~|[\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF])*([a-z]|[\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF])))\.?$/i.test(value) || 'NO_EMAIL';
				// EPG-24121: check the local part of an email address for non-ASCII characters
				if( valid===true ){
					var localatoms = value.split('@')[0].split('.');
					$.each(localatoms, function(index) {
						valid = /^[\x00-\x7F]+$/.test(localatoms[index]) || 'NO_EMAIL';
						return valid=='NO_EMAIL' ? false : true;
					});
				}
			}
			return valid===true ? range( value, opt.minlength, opt.maxlength ) : valid;
		},
		// url must be absolute
		/**
		 * Validate a url.
		 * 
		 * The `ep.validate.url()` method checks if the givn string an valid url.
		 * 
		 * ### Examples
		 * Validate an url.
		 * 
		 * JavaScript:
		 * 
		 *     ep.validate.email( 'http://www.epages.com' )
		 * 
		 * Results:
		 * 
		 *     true
		 * 
		 * Validate an url with error return.
		 * 
		 * JavaScript:
		 * 
		 *     ep.validate.email( 'epages' );
		 * 
		 * Results:
		 * 
		 *     NO_URL
		 * 
		 * 
		 * ### Dependencies
		 * 
		 *  + `ep`
		 *  + `ep.color`
		 *  + `jQuery.mime`
		 *  + `jQuery.i18n`
		 * 
		 * @param {String} value A text to validate
		 * @param {Object} [options] A map of additional options pass to the method.
		 * @param {Boolean} options.required A boolean indication wether the value is required.
		 * @param {Integer} options.minlength A minimum number of chars.
		 * @param {Integer} options.maxlength A maximum number of chars.
		 * 
		 * @method url
		 * @static 
		 * @member ep.validate
		 * 
		 * @since 6.11.0
		 */
		url: function( value, options ){
			value = $.trim(value);

			var opt = $.extend({},options||{}),
				valid = required( value, opt.required );

			if( value && valid===true ){
				valid = /^((https?|ftp):\/\/)?(((([a-z]|\d|-|\.|_|~|[\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF])|(%[\da-f]{2})|[!\$&'\(\)\*\+,;=]|:)*@)?(((\d|[1-9]\d|1\d\d|2[0-4]\d|25[0-5])\.(\d|[1-9]\d|1\d\d|2[0-4]\d|25[0-5])\.(\d|[1-9]\d|1\d\d|2[0-4]\d|25[0-5])\.(\d|[1-9]\d|1\d\d|2[0-4]\d|25[0-5]))|((([a-z]|\d|[\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF])|(([a-z]|\d|[\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF])([a-z]|\d|-|\.|_|~|[\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF])*([a-z]|\d|[\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF])))\.)+(([a-z]|[\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF])|(([a-z]|[\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF])([a-z]|\d|-|\.|_|~|[\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF])*([a-z]|[\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF])))\.?)(:\d*)?)(\/((([a-z]|\d|-|\.|_|~|[\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF])|(%[\da-f]{2})|[!\$&'\(\)\*\+,;=]|:|@)+(\/(([a-z]|\d|-|\.|_|~|[\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF])|(%[\da-f]{2})|[!\$&'\(\)\*\+,;=]|:|@)*)*)?)?(\?((([a-z]|\d|-|\.|_|~|[\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF])|(%[\da-f]{2})|[!\$&'\(\)\*\+,;=]|:|@)|[\uE000-\uF8FF]|\/|\?)*)?(\#((([a-z]|\d|-|\.|_|~|[\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF])|(%[\da-f]{2})|[!\$&'\(\)\*\+,;=]|:|@)|\/|\?)*)?$/i.test(value) || 'NO_URL';
			}
			return valid===true ? range( value, opt.minlength, opt.maxlength ) : valid;
		},

		/**
		 * Validate a mimetype.
		 * 
		 * The `ep.validate.mimetype()` method checks if the givn string an valid mimetype and optional an accepted mimetype.
		 * 
		 * ### Examples
		 * Validate a mimetype.
		 * 
		 * JavaScript:
		 * 
		 *     ep.validate.mimetype( 'image/jpeg' )
		 * 
		 * Results:
		 * 
		 *     true
		 * 
		 * Validate a mimetype with error return.
		 * 
		 * JavaScript:
		 * 
		 *     ep.validate.mimetype( 'img' );
		 * 
		 * Results:
		 * 
		 *     NO_MIME
		 * 
		 * Validate an mimetype with accept option.
		 * 
		 * JavaScript:
		 * 
		 *     ep.validate.mimetype( 'image/jpeg', {accept:'text/*'} );
		 * 
		 * Results:
		 * 
		 *     MIME_NOT_ACCEPT
		 * 
		 * 
		 * ### Dependencies
		 * 
		 *  + `ep`
		 *  + `ep.color`
		 *  + `jQuery.mime`
		 *  + `jQuery.i18n`
		 * 
		 * @param {String} value A text to validate
		 * @param {Object} [options] A map of additional options pass to the method.
		 * @param {Boolean} options.required A boolean indication wether the value is required.
		 * @param {String} options.accept A list of accepted mimetypes or mimetype groups.
		 * 
		 * @method mimetype
		 * @static 
		 * @member ep.validate
		 * 
		 * @since 6.11.0
		 */
		mimetype: function( value, options ){
			value = $.trim(value);

			var opt = $.extend({
					accept: undefined
				},options||{}),
				valid = required( value, opt.required );

			if( value && valid===true ){
				valid = /^[a-z]+\/[a-z\d\.-]+$/i.test(value) || 'NO_MIME';
			}
			if( value && opt.accept && valid===true ){
				valid = mime.mime( value, opt.accept ) || 'MIME_NOT_ACCEPT';
			}
			return valid;
		},

		/**
		 * Validate a creditcard number.
		 * 
		 * The `ep.validate.creditcard()` method checks if the givn string an valid creditcard number.
		 * 
		 * ### Examples
		 * Validate a creditcard number.
		 * 
		 * JavaScript:
		 * 
		 *     ep.validate.creditcard( '4111111111111111' )
		 * 
		 * Results:
		 * 
		 *     true
		 * 
		 * Validate a creditcard with error return.
		 * 
		 * JavaScript:
		 * 
		 *     ep.validate.creditcard( '4112334589700711' );
		 * 
		 * Results:
		 * 
		 *     NO_CREDITCARD_NUMBER
		 * 
		 * 
		 * ### Dependencies
		 * 
		 *  + `ep`
		 *  + `ep.color`
		 *  + `jQuery.mime`
		 *  + `jQuery.i18n`
		 * 
		 * @param {String} value A text to validate
		 * @param {Object} [options] A map of additional options pass to the method.
		 * @param {Boolean} options.required A boolean indication wether the value is required.
		 * 
		 * @method creditcard
		 * @static 
		 * @member ep.validate
		 * 
		 * @since 6.11.0
		 */
		creditcard: function( value, options ) {
			value = $.trim(value);

			var opt = $.extend({},options||{}),
				valid = required( value, opt.required );

			if( value && valid===true ){
				if( /[^0-9-]+/.test(value) ){
					return false;
				}

				var nCheck = 0,
					nDigit = 0,
					bEven = false,
					cDigit;

				value = value.replace(/\D/g, "");

				for( var n=value.length-1 ; n>=0 ; n-- ){
					cDigit = value.charAt(n);
					nDigit = parseInt(cDigit, 10);
					if( bEven ){
						if( (nDigit *= 2) > 9 ){
							nDigit -= 9;
						}
					}
					nCheck += nDigit;
					bEven = !bEven;
				}

				valid = (nCheck % 10) === 0 || 'NO_CREDITCARD_NUMBER';
			}
			return valid;
		},

		/**
		 * Validate a date.
		 * 
		 * The `ep.validate.date()` method checks if the givn string an valid date.
		 * 
		 * ### Examples
		 * Validate a date.
		 * 
		 * JavaScript:
		 * 
		 *     ep.validate.date( '01.02.2011', {format: 'd', region: 'de'} );
		 * 
		 * Results:
		 * 
		 *     true
		 * 
		 * Validate a date with error return.
		 * 
		 * JavaScript:
		 * 
		 *     ep.validate.date( '01/02/2011', {format: 'd', region: 'de'} );
		 * 
		 * Results:
		 * 
		 *     NO_DATE
		 * 
		 * 
		 * ### Dependencies
		 * 
		 *  + `ep`
		 *  + `ep.color`
		 *  + `jQuery.mime`
		 *  + `jQuery.i18n`
		 * 
		 * @param {String} value A text to validate
		 * @param {Object} [options] A map of additional options pass to the method.
		 * @param {Boolean} options.required A boolean indication wether the value is required.
		 * @param {String} options.format A date formatter [look at jQuery.i18n plugin].
		 * @param {String} options.region An i18n region [look at jQuery.i18n plugin].
		 * @param {Boolean} options.strict A boolean indication wether to validate in strict mode.
		 * @param {Integer} options.min A local timestamp (not UTC) as minimum valid date.
		 * @param {Integer} options.max A local timestamp (not UTC) as maximum valid date.
		 * 
		 * @method date
		 * @static 
		 * @member ep.validate
		 * 
		 * @since 6.11.0
		 */
		date: function( value, options ){
			value = $.trim(value);

			var opt = $.extend({
					format: 'd',
					strict: false
				},options||{}),
				region = {region:opt.region},
				valid = required( value, opt.required );

			opt.format = i18nMap[opt.format] || opt.format;

			if( value && valid===true ){
				switch(true){
					case (/^(d|D)$/).test(opt.format):
						valid = 'NO_DATE';
					break;
					case (/^(f|F|l|L)$/).test(opt.format):
						valid = 'NO_DATETIME';
					break;
					case (/^(t|T)$/).test(opt.format):
						valid = 'NO_TIME';
					break;
					default:
						valid = invalid;
					break;
				}
				valid = new RegExp( '^' + $.i18n.expStrDate( opt.format, opt.strict, region ) + '$', '' ).test(value) || valid;

				if( valid===true && value ){
					var date = $.i18n.parseDate( value, opt.format, region );

					valid = date instanceof Date ? range( date.getTime(), opt.min, opt.max ) : invalid;
				}
			}
			return valid;
		},

		/**
		 * Validate a number.
		 * 
		 * The `ep.validate.number()` method checks if the givn string an valid number.
		 * 
		 * ### Examples
		 * Validate a number.
		 * 
		 * JavaScript:
		 * 
		 *     ep.validate.date( '12,50', {format: 'n', region: 'de'} );
		 * 
		 * Results:
		 * 
		 *     true
		 * 
		 * Validate a percent number.
		 * 
		 * JavaScript:
		 * 
		 *     ep.validate.date( '12,50 %', {format: 'p2', region: 'de'} );
		 * 
		 * Results:
		 * 
		 *     true
		 * 
		 * Validate a number with error return.
		 * 
		 * JavaScript:
		 * 
		 *     ep.validate.date( '12.50', {format: 'n', region: 'de'} );
		 * 
		 * Results:
		 * 
		 *     NO_NUMBER
		 * 
		 * 
		 * ### Dependencies
		 * 
		 *  + `ep`
		 *  + `ep.color`
		 *  + `jQuery.mime`
		 *  + `jQuery.i18n`
		 * 
		 * @param {String} value A text to validate
		 * @param {Object} [options] A map of additional options pass to the method.
		 * @param {Boolean} options.required A boolean indication wether the value is required.
		 * @param {String} options.format A date formatter [look at the jQuery.i18n plugin].
		 * @param {String} options.region An i18n region [look at the jQuery.i18n plugin].
		 * @param {Boolean} options.strict A boolean indication wether to validate in strict mode.
		 * @param {Integer} options.min A minimum valid number.
		 * @param {Integer} options.max A maximum valid number.
		 * 
		 * @method number
		 * @static 
		 * @member ep.validate
		 * 
		 * @since 6.11.0
		 */
		number: function( value, options ){
			value = $.trim(value);

			var opt = $.extend({
					format: 'n',
					strict: false
				},options||{}),
				region = {region:opt.region,currency:opt.currency},
				valid = required( value, opt.required );

			opt.format = i18nMap[opt.format] || opt.format;

			if( value && valid===true ){
				var msg = {
					n:'NO_NUMBER',
					c:'NO_CURRENCY',
					p:'NO_PERCENT'
				};
				opt.format.replace(/^(n|c|p)\d*$/,function(str,$1){
					valid = msg[$1] || invalid;
				});
				valid = new RegExp( '^' + $.i18n.expStrNumber( opt.format, opt.strict, region ) + '$', '' ).test(value) || valid;
			}
			if( value && valid===true ){
				var num = $.i18n.parseNumber( value, 10, region );

				valid = isNaN(num) ? invalid : range( num, opt.min, opt.max );
			}
			return valid;
		},

		/**
		 * Validate a css color.
		 * 
		 * The `ep.validate.cssColor()` method checks if the givn string an css color.
		 * 
		 * ### Examples
		 * Validate a css color.
		 * 
		 * JavaScript:
		 * 
		 *     ep.validate.cssColor( '#336699' );
		 *     
		 *     ep.validate.cssColor( 'green' );
		 *     
		 *     ep.validate.cssColor( 'rgb(100,200,50)' );
		 * 
		 * Results:
		 * 
		 *     true
		 * 
		 * Validate a css color with error return.
		 * 
		 * JavaScript:
		 * 
		 *     ep.validate.cssColor( 'dunkelblau' );
		 * 
		 * Results:
		 * 
		 *     NO_COLOR_VALUE
		 * 
		 * 
		 * ### Dependencies
		 * 
		 *  + `ep`
		 *  + `ep.color`
		 *  + `jQuery.mime`
		 *  + `jQuery.i18n`
		 * 
		 * @param {String} value A text to validate
		 * 
		 * @method cssColor
		 * @static 
		 * @member ep.validate
		 * 
		 * @since 6.11.0
		 */
		cssColor: function( value ){
			value = $.trim(value);
			return ep.color.stringToHex(value, true)!==undefined || 'NO_COLOR_VALUE';
		},

		/**
		 * Validate a css size.
		 * 
		 * The `ep.validate.cssSize()` method checks if the givn string an valid css size.
		 * 
		 * ### Examples
		 * Validate an css size.
		 * 
		 * JavaScript:
		 * 
		 *     ep.validate.cssSize( '24em' );
		 * 
		 * Results:
		 * 
		 *     true
		 * 
		 * Validate an css size with error return.
		 * 
		 * JavaScript:
		 * 
		 *     ep.validate.cssSize( '24pixel' );
		 * 
		 * Results:
		 * 
		 *     UNKNOWN_UNIT
		 * 
		 * 
		 * ### Dependencies
		 * 
		 *  + `ep`
		 *  + `ep.color`
		 *  + `jQuery.mime`
		 *  + `jQuery.i18n`
		 * 
		 * @param {String} value A text to validate
		 * @param {Object} [options] A map of additional options pass to the method.
		 * @param {Boolean} options.required A boolean indication wether the value is required.
		 * @param {Integer} options.min A minimum valid number.
		 * @param {Integer} options.max A maximum valid number.
		 * 
		 * @method cssSize
		 * @static 
		 * @member ep.validate
		 * 
		 * @since 6.11.0
		 */
		cssSize: function( value, options ){
			value = $.trim(value);

			var opt = $.extend({},options||{}),
				valid = required( value, opt.required );

			if( ( value || value==="" ) && valid===true ){
				switch(true){
					case (/^[0-9]+(px|pt)$/i).test(value) || /^[0-9]*\.?[0-9]+(pc|%|mm|cm|em|in|ex)$/i.test(value) || /^[0]+$/.test(value):
						valid = true;
					break;
					case (/^[0-9]+$/).test(value):
						valid = 'NO_UNIT';
					break;
					case value === "":
						valid = 'NO_UNIT_VALUE';
					break;
					case (/^[^0-9]*\.?[^0-9]/).test(value):
						valid = 'NO_CSS_NUMBER';
					break;
					case (/^[0-9]*\.[0-9]+(?:px|pt)$/i).test(value):
						valid = 'FLOAT_NOT_ALLOWED';
					break;
					case (/^[0-9]*\.[0-9]$/).test(value):
						valid = 'NO_UNIT';
					break;
					case (/^[0-9]*\.?[0-9]+[a-z]+$/).test(value):
						valid = 'UNKNOWN_UNIT';
					break;
					default:
						valid = invalid;
					break;
				}
			}
			if( value && valid===true ){
				var num = parseFloat(value.replace(/\W+$/,''),10);

				valid = isNaN(num) ? invalid : range( num, opt.min, opt.max );
			}
			return valid;
		},

		/**
		 * Basic validate method.
		 * 
		 * The `ep.validate.basic()` method is a basic method for validation.
		 * 
		 * ### Examples
		 * Validate a string.
		 * 
		 * JavaScript:
		 * 
		 *     ep.validate.basic( 'Lorem ipsum ...', {
		 *         required:   true,
		 *         pattern:    '^[\w\.]+$',
		 *         minlegth:   10,
		 *         maxlength:  20
		 *     });
		 * 
		 * Results:
		 * 
		 *     true
		 * 
		 * Validate a string with error return.
		 * 
		 * JavaScript:
		 * 
		 *     ep.validate.basic( 'Lorem ipsum ...', {
		 *         required:   true,
		 *         pattern:    '^[\w\.]+$',
		 *         minlegth:   10,
		 *         maxlength:  15
		 *     });
		 * 
		 * Results:
		 * 
		 *     NOT_IN_RANGELENGTH
		 * 
		 * 
		 * ### Dependencies
		 * 
		 *  + `ep`
		 *  + `ep.color`
		 *  + `jQuery.mime`
		 *  + `jQuery.i18n`
		 * 
		 * @param {String} value A text to validate
		 * @param {Object} [options] A map of additional options pass to the method.
		 * @param {Boolean} options.required A boolean indication wether the value is required.
		 * @param {String} options.pattern A pattern string for regular expression.
		 * @param {Integer} options.minlength A minimum number of chars.
		 * @param {Integer} options.maxlength A maximum number of chars.
		 * 
		 * @method basic
		 * @static 
		 * @member ep.validate
		 * 
		 * @since 6.11.0
		 */
		basic: function( value, options ){
			var opt = $.extend({},options||{}),
				valid = required( value, opt.required );

			if( value && valid===true ){
				valid = pattern( value, opt.pattern);
			}

			if( value && valid===true ){
				valid = rangelength( value, opt.minlength, opt.maxlength );
			}

			return valid;
		}
/* TODO: validate by server,
		ajax: function( value, options ){

		}
*/
	});

	return ep;

});

/* ---- Module:ep.dict ---- */

/**
 * @class ep.dict
 * 
 */

/**
 * Get a translation for a keyword.
 * 
 * ### Dependencies
 * 
 *  + `ep`
 *  + `jQuery.dict`
 *  + `jQuery.tmpl`
 * 
 * @param {String} keyword A keyword to translate.
 * 
 * @method translate
 * @member ep.dict
 * 
 * @since 6.11.0
 */

/**
 * Parse a text with keyword markers and translate them with the dictionary.
 * 
 * ### Dependencies
 * 
 *  + `ep`
 *  + `jQuery.dict`
 *  + `jQuery.tmpl`
 * 
 * @param {String} text A text with keyword markers to translate.
 * 
 * @method parse
 * @member ep.dict
 * 
 * @since 6.11.0
 */

/**
 * Get a translation for a keyword and fill the data markers in translation.
 * 
 * ### Dependencies
 * 
 *  + `ep`
 *  + `jQuery.dict`
 *  + `jQuery.tmpl`
 * 
 * @param {String} keyword A keyword to translate.
 * @param {Object} data A key/value set to fill data markers in the translated keyword
 * 
 * @method translateData
 * @member ep.dict
 * 
 * @since 6.11.0
 */

/**
 * Parse a text with keyword markers and translate them with the dictionary and fill the data markers in the parsed text.
 * 
 * ### Dependencies
 * 
 *  + `ep`
 *  + `jQuery.dict`
 *  + `jQuery.tmpl`
 * 
 * @param {String} text A text with keyword markers to translate.
 * @param {Object} data A key/value set to fill data markers in the translated parsed text.
 * 
 * @method parseData
 * @member ep.dict
 * 
 * @since 6.11.0
 */

/**
 * Get a dictionary object for translation.
 * 
 * Get a dictionary object for translation.
 * 
 * ### Examples
 * Use an existing dictionary.
 * 
 * JavaScript:
 * 
 *     // The example dictionary is already defined.
 *     
 *     // use default region/language
 *     ep.dict( 'example' );
 *     
 *     // use german
 *     ep.dict( 'example', {region:'de'} );
 * 
 * Create a foo dictionary.
 * 
 * JavaScript:
 * 
 *     // The example dictionary is already defined.
 *     
 *     // use default region/language
 *     ep.dict( 'foo', [ 'example', {"strawberry":"Strawberry"} ] );
 *     
 *     // use german
 *     ep.dict( 'foo', [ 'example', {"strawberry":"Erdbeere"} ], {region:'de'} );
 * 
 * Translate keywors and parse text with a dict.
 * 
 * JavaScript:
 * 
 *     var obj = ep.dict( 'ep.dict', {region:'de'} );
 *     
 *     obj.translate('Close')
 *     //
 * 
 * 
 * ### Dependencies
 * 
 *  + `ep`
 *  + `jQuery.dict`
 *  + `jQuery.tmpl`
 * 
 * @param {String} name The name of the dictionary.
 * @param {Array} [data] An array containing names of other dictionaries, dictionary objects or a map of keyword/translation pairs to add.
 * @param {Object} [options] A map of additional options pass to the method.
 * @param {String} options.region A region/language to use for this dict.
 * @param {Array} options.parser An array of an regular expression to find translate keys and a match index. The match index setup which match will translate.
 * 
 * @method constructor
 * @member ep.dict
 * 
 * @since 6.11.0
 */

/*
 * @copyright		© Copyright 2006-2010, epages GmbH, All Rights Reserved.
 *
 * @module			ep.dict
 *
 * @revision		$Revision: 1.5.2.2 $
 */

define("ep/dict", [
	"jquery",
	"ep",
	"$dict!ep/dict",

	"jquery/dict",
	"jquery/tmpl"
], function ($, ep, epDict) {

	// Prevent fail of dictionay test case
	// backward compatible -> require module ep/dict expects $dict!ep/dict is also defined
	// epDict.translate('Save')
	$.each( ['translate', 'parse'], function( i, name ){
		$.Dictionary.prototype[ name + 'Data' ] = function( key, data ){
			return $.tmpl( '<span>' + this[ name ](key) + '</span>', [data] )	// replace key marker in translated string with given data
				.html()															// get inner HTML
				.replace(/(^|[^ ])(&nbsp;)([^ ]|$)/g,"$1 $3");					// replace strange &nbsp; to regular space
		};
	});

	// set ep.dict as alias of $.dict
	ep.extend({
		dict: $.dict
	});

	return ep;
});

/* ---- Module:ep.debug ---- */

/**
 * @class ep.debug
 * 
 */

/*
 * @copyright		© Copyright 2006-2010, epages GmbH, All Rights Reserved.
 *
 * @module			ep.debug
 *
 * @revision		$Revision: 1.5.2.1 $
 */

define("ep/debug", [
	"jquery",
	"ep",
	"util/scope"
], function ($, ep, scope) {

	// set console (sometimes not set in time and hence throws an error)
	try{
		window.console =			window.console || {};
		window.console.debug =		window.console.debug || function(){return;};
		window.console.log =		window.console.log || function(){return;};
		window.console.warn =		window.console.warn || function(){return;};
	}
	catch(error){
	}

	if(ep.config && !ep.config.debugLevel){
		if(window.console){
			window.console.debug = function(){
				return;
			};
			window.console.log = function(){
				return;
			};
			window.console.warn = function(){
				return;
			};
		}
	}

	ep.extend( scope('ep.debug'),{
		/**
		 * take ststistic for given function
		 * 
		 * The `ep.debug.statistic()` without a parameter prints the previously taken statistic to the debug console
		 * activate Firebug to see the output or open the debug console in chrome for example
		 * 
		 * The `ep.debug.statistic()` function take a statistic and collects running time for the given function
		 * the statistics which are taken are:
		 * 
		 *  + sum      | total running time for all iterations of functions with given statistic id
		 *  + count    | count of iterations
		 *  + min      | fastest run time
		 *  + max      | slowest run time
		 *  + innersum  | time inside the function when it was calling itself
		 * 
		 * ### Examples
		 * Run a function named randomTest 100 times and take the statistic. Then print the statistic to the console
		 * 
		 * JavaScript:
		 * 
		 *     function randomTest(){
		 *       for(var i = 0; i < 100; i++){
		 *         var a = Math.random();
		 *       }
		 *      };
		 *      for(var i = 0; i < 100; i++){
		 *        ep.debug.statistic('randomStatistic',randomTest);
		 *      }
		 *      ep.debug.statistic();
		 * 
		 * Results:
		 * 
		 *     print statistic
		 *     statistic for id: helloWorld : sum: 14 : count: 100 : min: 0 : max: 1 : innersum: 0
		 * 
		 * 
		 * ### Dependencies
		 * 
		 *  + `ep`
		 * 
		 * @param {undefined} id a unique id for the current function
		 * @param {undefined} function a function for which the statistic should be taken
		 * 
		 * @method statistic
		 * @static 
		 * @member ep.debug
		 * 
		 * @since 6.11.0
		 */
		statistic: function(/*string*/statId, /*func*/statFunc){
			var stats = ep.debug.statistic.data;
			if(arguments.length){
				//if there are arguments we take the statistic for a function
				var startTime = new Date();
				ep.debug.statistic.isRunning = true;
				statFunc();
				ep.debug.statistic.isRunning = false;

				var runningTime = new Date() - startTime;
				// sum, count, min, max, innersum
				if(!stats[statId]){
					stats[statId] = {
						"sum"      : 0,
						"count"    : 0,
						"min"      : 0,
						"max"      : 0,
						"innersum" : 0
					};
				}
				var currentStat = stats[statId];
				if(ep.debug.statistic.isRunning){
					currentStat.innersum += runningTime;
				}
				else{
					currentStat.sum += runningTime;
				}
				currentStat.count++;
				if(runningTime > currentStat.max){
					currentStat.max = runningTime;
				}
				if(runningTime < currentStat.min){
					currentStat.min = runningTime;
		}
			}
			else{
				//if there are no arguments we print the statistic to the console
				var sum = 0;
				console['log']('print statistic');
				$.each(stats,function(index,value){
					console['log']('statistic for id:',
						index,': sum: ',stats[index].sum,
						': count: ',stats[index].count,
						': min: ',stats[index].min,
						': max: ',stats[index].max,
						': innersum: ',stats[index].innersum);
				});
			}
		}
	});

	ep.extend(ep.debug.statistic,{
		data: {}, //define data-object for statistic function
		isRunning: false
	});

	return ep;

});

/* ---- Module:ep.fn.sprite ---- */

/*
 * @copyright		© Copyright 2006-2010, epages GmbH, All Rights Reserved.
 *
 * @module			ep.fn.sprite
 *
 * @revision		$Revision: 1.5.2.1 $
 */

define("ep/fn/sprite", [
	"jquery",
	"ep",

	"jquery/fn/class"
], function ($, ep) {

	var spriteExprMap = {
			'ico_image':		/^(image\/png|image\/jpeg|image\/jpg|image\/gif|image\/bmp|image\/vnd.microsoft.icon|image\/tiff|image\/svg+xml|image\/x-win-bitmap)$/i,
			'ico_box':			/^(application\/octet-stream|text\/x-actionscript|audio\/basic|audio\/x-wav|audio\/mpeg|audio\/x-ms-wma|audio\/ogg|audio\/flac|application\/msword|application\/x-dot|application\/vnd.ms-excel|application\/vnd.ms-powerpoint|text\/plain|text\/css|application\/javascript|application\/json|application\/xml)$/i,
			'ico_file_avi':		/^(video\/x-msvideo|video\/mpeg|video\/mp4)$/i,
			'ico_file_wmv':		/^(video\/x-ms-wmv)$/i,
			'ico_file_swf':		/^(video\/x-flv|application\/x-shockwave-flash)$/i,
			'ico_file_mov':		/^(video\/quicktime|video\/ogg)$/i,
			'ico_file_rm':		/^(application\/vnd.rn-realmedia)$/i,
			'ico_file_ram':		/^(audio\/x-pn-realaudio)$/i,
			'ico_file_dcr':		/^(application\/x-director)$/i,
			'ico_file_pdf':		/^(application\/pdf)$/i,
			'ico_file_htm':		/^(text\/html)$/i,
			'ico_folder':		/^(application\/zip|application\/x-rar-compressed|application\/gzip|application\/x-tar)$/i
		},

		removeExpr = /(ep-sprite[\w\d-]*|[^\s]*ico_[^\s]*)/;

	ep.fn.extend({
		/**
		 * Add sprite icon classes to each of the set of matched elements.
		 * 
		 * The `.addSprite()` method adds classes, which set size an an background image (icon),
		 * to each of the set of matched elements.
		 * 
		 * ### Examples
		 * Create classes for arrow top-bottom icon in size of 16px to matched element.
		 * 
		 * JavaScript:
		 * 
		 *     ep('#icon').addSprite( 'arrow-tb', 's' );
		 * 
		 * 
		 * @param {String} name A sprite icon name.
		 * @param {String} [size] Size of the icon (xs, s, l, m, l, xl, 64, 128), Default: m.
		 * 
		 * @method addSprite
		 * @member jQuery
		 * 
		 * @since 6.11.0
		 */
		addSprite: function( name, size ){

			// get name by mimetype
			if(/\//.test(name)){
				var mime = name;
				$.each( spriteExprMap, function( i, expr ){
					if( expr.test(mime) ){
						mime = i;
						return false;
					}
				});
				name = mime===name ? 'unknow' : mime;
			}

			size = size || 'm';

			return this.each(function(){
				$(this)
					.removeClass(removeExpr)
					.addClass( 'ep-sprite ep-sprite-'+size + ( (/[^\s]*ico_[^\s]*/).test(name) ? ' '+name : ' ep-sprite-'+name ) );
			});
		},
		/**
		 * Remove sprite icon classes from each of the set of matched elements.
		 * 
		 * The `.removeSprite()` method removes classes, which were set by the `.addSprite()` method,
		 * from each of the set of matched elements.
		 * 
		 * ### Examples
		 * Remove sprite icon classes from matched element.
		 * 
		 * JavaScript:
		 * 
		 *     ep('#icon').removeSprite();
		 * 
		 * 
		 * @method removeSprite
		 * @member jQuery
		 * 
		 * @since 6.11.0
		 */
		removeSprite: function(){
			return this.removeClass(removeExpr);
		},
		/**
		 * Determine whether the first of the matched elements are assigned spite icon classes.
		 * 
		 * The `.hasSprite()` method determine whether the first of the matched elements are assigned
		 * the given sprite icon or spite icon classes in generell.
		 * 
		 * ### Examples
		 * Determine whether the matched element has the arrow top-bottom icon.
		 * 
		 * JavaScript:
		 * 
		 *     ep('#icon').hasSprite('arrow-tb');
		 * 
		 * 
		 * @param {String} name A sprite icon name.
		 * 
		 * @method hasSprite
		 * @member jQuery
		 * 
		 * @since 6.11.0
		 */
		hasSprite: function( name ){
			return this.hasClass( 'ep-sprite' + (name ? '-'+name : '') );
		}
	});

	return ep;

});

/* ---- Module:ep.fn.busy ---- */

/*
 * @copyright		© Copyright 2006-2010, epages GmbH, All Rights Reserved.
 *
 * @module			ep.fn.busy
 *
 * @revision		$Revision: 1.5.2.1 $
 */

define("ep/fn/busy", [
	"jquery",
	"ep"
], function ($, ep) {

	var stack = [];

	// remove all busy layers on page leave
	$(window)
		.on("unload", function(){
			$(stack)
				.remove();
			stack = [];
		});

	ep.fn.extend({
		/**
		 * Add or remove a busy layer to each of the set of matched elements.
		 * 
		 * The `.busy()` method adds/removes a busy layer to/from each of the set of matched elements.
		 * 
		 * On page unload every busy layer will be removed. This prevents showing busy layer after
		 * come back via browsers back button.
		 * 
		 * ### Examples
		 * Show a busy layer on body.
		 * 
		 * JavaScript:
		 * 
		 *     ep('div').busy('show');
		 * 
		 * HTML:
		 * 
		 *     <body>
		 *       <h1>Example</h1>
		 *       <div>My test case ...</div>
		 *       <div>A footer.</div>
		 *     </body>
		 * 
		 * Results:
		 * 
		 *     <body>
		 *       <h1>Example</h1>
		 *       <div>My test case ...</div>
		 *       <div>A footer.</div>
		 *       <div class="ep-busy"></div>
		 *     </body>
		 * 
		 * Hide a busy layer on body.
		 * 
		 * JavaScript:
		 * 
		 *     ep('div').busy('hide');
		 * 
		 * HTML:
		 * 
		 *     <body>
		 *       <h1>Example</h1>
		 *       <div>My test case ...</div>
		 *       <div>A footer.</div>
		 *       <div class="ep-busy"></div>
		 *     </body>
		 * 
		 * Results:
		 * 
		 *     <body>
		 *       <h1>Example</h1>
		 *       <div>My test case ...</div>
		 *       <div>A footer.</div>
		 *     </body>
		 * 
		 * 
		 * @param {String} action An action for busy layer, 'show' or 'hide'.
		 * 
		 * @method busy
		 * @member jQuery
		 * 
		 * @since 6.11.0
		 */
		busy: function( action ){
			return this.each(function(){
				var elem = $(this),
					layer = elem.find('> .ep-busy');

				if( action==='hide' ){
					var pos = $.data( this, 'epBusyOldposition');

					if( pos === 'static' ){
						$.removeData( this, 'epBusyOldposition' );
						elem.css('position','relative');
					}

					layer.remove();
				}
				else if( !layer.length ){
					var pos = elem.css('position');

					if( pos === 'static' ){
						$.data( this, 'ep-busy-oldposition', pos );
						elem.css('position','relative');
					}

					stack.push( $('<div>')
						.attr('class','ep-busy')
						.css( 'border-radius', elem.css('border-radius') )
						.appendTo( elem )[0] );
				}
			});
		}
	});

	return ep;

});

/* ---- Module:ep.fn.contextorientation ---- */

/*
 * @copyright		© Copyright 2006-2010, epages GmbH, All Rights Reserved.
 *
 * @module			ep.fn.contextOrientation
 *
 * @revision		$Revision: 1.6.2.1 $
 */

define("ep/fn/contextorientation", [
	"jquery",
	"ep"
], function ($, ep) {

	var xExpr = /(left|center|right)/,
		yExpr = /(top|middle|bottom)/;

	ep.fn.extend({
		/**
		 * Set position to each of the set of matched elements related to an event or other element.
		 * 
		 * The `.contextOrientation()` method adds/removes a busy layer to/from each of the set of matched elements.
		 * 
		 * ### Examples
		 * Show a tooltip on click the image and position it right of the click position.
		 * 
		 * JavaScript:
		 * 
		 *     $('#context')
		 *         .on( 'click', function( event ){
		 *             ep(this)
		 *                 .show()
		 *                 .contextOrientation( event, 'right' );
		 *         });
		 * 
		 * HTML:
		 * 
		 *     <body>
		 *       <img id="context" src="example.jpg" alt="example picture"/>
		 *       <div id="tooltip">
		 *         <h1>Example</h1>
		 *         <span>Tooltip informations ...</span>
		 *       </div>
		 *     </body>
		 * 
		 * CSS:
		 * 
		 *     #tooltip {
		 *         position: absolute;
		 *         width: 100px;
		 *     }
		 * 
		 * 
		 * @param {String,Object} action A selector, element or event as context to orient.
		 * @param {String} orient A vertical and/or horizontal position: middle, bottom, right, center or left.
		 * @param {Array} [adjust] An array of numbers to adjust the positioning [0: adjust x, 1: adjust y].
		 * 
		 * @method contextOrientation
		 * @member jQuery
		 * 
		 * @since 6.11.0
		 */
		contextOrientation: function( context, orient, adjust ){
			adjust = adjust || [0,0];

			var orientX = xExpr.exec(orient),
				orientY = yExpr.exec(orient);

			orientX = orientX ? orientX[1] : '';
			orientY = orientY ? orientY[1] : '';

			if( context instanceof $.Event ){
				var contextO = { left:context.pageX, top:context.pageY },
					contextW = 0,
					contextH = 0;
			}
			else{
				context = $(context);
				var contextO = context.offset(),
					contextW = context.outerWidth(),
					contextH = context.outerHeight();
			}

			return this.each(function(){
					var elem = $(this),
						elemW = elem.outerWidth(),
						elemH = elem.outerHeight(),
						pos = contextO;

					switch( orientX ){
						case 'right':
							pos.left += contextW + adjust[0];
						break;
						case 'left':
							pos.left -= elemW + adjust[0];
						break;
						case 'center':
							pos.left += (contextW/2) - (elemW/2) + adjust[0];
						break;
						default:
							pos.left += adjust[0];
						break;
					}
					switch( orientY ){
						case 'bottom':
							pos.top += contextH + adjust[1];
						break;
						case 'top':
							pos.top -= elemH + adjust[1];
						break;
						case 'middle':
							pos.top += (contextH/2) - (elemH/2) + adjust[1];
						break;
						default:
							pos.top += adjust[1];
						break;
					}
					elem.css({
						'position':	'absolute',
						'top':		pos.top,
						'left':		pos.left
					});
				});
		}
	});

	return ep;

});

/* ---- Module:ep.sprite ---- */

/**
 * @class ep
 * 
 */

/*
 * @copyright		© Copyright 2006-2010, epages GmbH, All Rights Reserved.
 *
 * @module			ep.sprite
 *
 * @revision		$Revision: 1.5.2.1 $
 */

define("ep/sprite", [
	"ep",

	"ep/fn/sprite"
], function (ep) {

	ep.extend({
		/**
		 * Create a sprite icon.
		 * 
		 * The `ep.sprite()` method creates a span element an add css classes to style the icon.
		 * 
		 * ### Examples
		 * Create a arrow top-bottom icon is 16px size.
		 * 
		 * JavaScript:
		 * 
		 *     ep.sprite( 'arrow-tb', 's' );
		 * 
		 * Results:
		 * 
		 *     <span class="ep-sprite ep-sprite-s ep-sprite-arrow-tb"></span>
		 * 
		 * 
		 * ### Dependencies
		 * 
		 *  + `ep`
		 *  + `ep.fn.sprite`
		 * 
		 * @param {String} name A sprite icon name.
		 * @param {String} [size] Size of the icon (xs, s, l, m, l, xl, 64, 128), Default: m.
		 * 
		 * @method sprite
		 * @static 
		 * @member ep
		 * 
		 * @since 6.11.0
		 */
		sprite: function( name, size ){
			return ep('<span>').addSprite( name, size );
		}
	});

	return ep;

});

/* ---- Module:ep.ui.form ---- */

/**
 * Advanced form handling.
 *
 * The `.uiForm()` method add advanced form handling, like ajax or validate, to a form.
 *
 * Default handling:
 *
 *  + prevent submit if no action attribute givn
 *  + prevent submit if an element of the form invalid
 *
 * ### Examples
 * Apply .uiForm() to all forms and set an ajax handle for submit.
 *
 * JavaScript:
 *
 *     ep('form')
 *         .uiForm({
 *             ajax: {
 *                 success: function( successText ){
 *                     alert( successText );
 *                 },
 *                 error: function( errorText ){
 *                     alert( errorText );
 *                 }
 *             }
 *         });
 *
 *
 * @class jQuery.ui.uiForm
 *
 * @uses ep
 * @uses ep.ajax
 * @uses jQuery.fn.form
 * @uses jQuery.ui.widget
 * @since 6.11.0
 */

/**
 * Set the validity state of the form to `true` (valid) or `false` (invalid).
 *
 * @param {Boolean} [valid] A boolean indication whether to set the valid state of the form.
 *
 * @method setValid
 * @member jQuery.ui.uiForm
 *
 * @since 6.11.0
 */

/**
 * @cfg {Boolean} compareDiff A boolean indication wether to submit changed form only.
 */

/**
 * @cfg {Boolean} showSaveWarn A boolean indication wether to show a warning when leaving a page without saving.
 */

/**
 * @cfg {Object} ajax A map of ajax options to send form via ajax. If no url givn the action attribute will be used as url, same works for type/method.
 */

/**
 * See `jQuery.ui.uiForm` for details.
 *
 * @param {Object} [options] A map of additional options pass to the method.
 * @param {Boolean} compareDiff A boolean indication wether to submit changed form only.
 * @param {Boolean} showSaveWarn A boolean indication wether to show a warning when leaving a page without saving.
 * @param {Object} ajax A map of ajax options to send form via ajax. If no url givn the action attribute will be used as url, same works for type/method.
 *
 * @method uiForm
 * @member jQuery
 *
 * @since 6.11.0
 */

/*
 * @copyright       © Copyright 2006-2012, epages GmbH, All Rights Reserved.
 *
 * @module          ep.ui.form
 *
 * @revision        $Revision: 1.15.2.4.10.1 $
 */

define("ep/ui/form", [
    "jquery",
    "ep",
    "$dict!ep/dict",

    "jquery/ui/widget",
    "jquery/cookie",
    "jquery/fn/form",
    "ep/ajax"
], function ($, ep, epDict) {

    /*
     *
     * @dictionary      ep/dict
     *
     * @translation     {LoseChanges}
     *
     */

    var
    // jQuery window object
        win = $(window),

        tLoseChanges = epDict.translate("LoseChanges"),

        // Hash serializer
        serializeArray = function (hash) {
            var arr = [];

            $.each(hash, function (name, value) {
                arr.push({
                    name: name,
                    value: value
                });
            });

            return arr;
        };

    $.widget('ui.uiForm', {

        options: {
            showSaveWarn: false,
            tokenName: "SecToken"
        },

        _create: function () {
            var self = this,
                o = self.options,
                cookie = $.cookie(o.tokenName);

            self.elem = ep(self.element)
                .on('change.uiForm', $.proxy(self, '_change'))
                .on('submit.uiForm', $.proxy(self, '_submit'))
                .on('validate.uiForm', $.proxy(self, '_validate'))
                .on('reset.uiForm', $.proxy(self, '_reset'))
                .on('mousedown', ':submit', $.proxy(self, '_submitButtonFix'));

            // Add security token
            if (cookie && cookie !== null && self.elem.find("input[name='" + o.tokenName + "']").length === 0) {
                self.elem.append('<input type="hidden" name="' + o.tokenName + '" value="' + cookie + '" />');
            }

            self.timeStamp = $.now();

            //find all saveButtons and change label and class if page was reloaded after save
            self.setSaveButtonSaved();
        },

        // Validate all input elemenst of form
        _validate: function (event) {
            var self = this;

            if (!self.elem.attr('formnovalidate') && event.target === self.elem[0]) {
                var elems = self.elem
                    .formInput();

                elems.trigger('validate')
                    .filter(':invalid:first')
                    .focus()
                    .trigger('validate');

                self._change();
            }
        },

        // Public get valid state
        /**
         * Get a boolean indication wether the elements of the form are valid.
         *
         * @method isValid
         * @member jQuery.ui.uiForm
         *
         * @since 6.11.0
         */
        isValid: function () {
            return this.elem.attr('formnovalidate') ? true : !this.elem[0].formInvalid;
        },

        // Public set valid state by boolean value
        setValid: function (stat) {
            this.elem[0].formInvalid = !stat;
        },

        // Set valid state by checking input elements
        _setValid: function (elems) {
            this.setValid(!elems.filter(':invalid').length);
        },

        // Check changed state by input elements
        _isChanged: function (elems) {
            return !!elems
                .filter(':changed')
                .length;
        },

        _submitButtonFix: function (event) {
            var self = this,
                context = self._submitButtonFix;

            clearTimeout(context.timeout);

            // Reset
            if (event === true && context.input) {
                context.input.remove();
            }
            // Set to remember
            else if (event) {
                context.button = $(event.target);
            }
            // Fix button context by hidden input
            else if (!event && context.button) {
                context.input = $("<input type=\"hidden\">")
                    .attr({
                        name: context.button.attr("name"),
                        value: context.button.attr("value")
                    })
                    .appendTo(self.elem);

                // Remove the hidden button fix element with a short delay
                context.timeout = setTimeout(function () {
                    self._submitButtonFix(true);
                }, 300);
            }
        },

        // Handle submit check and AJAX submits
        _submitCheck: function (event) {
            var self = this,
                o = self.options,
                valid = self.isValid(),
                action = self.elem.attr('action'),
                ajax = self.options.ajax,
                isPrevented;

            // Prevent default if invalid, double submit or form without action
            if ((!action && !ajax) || !valid || (event.timeStamp - self.timeStamp) < 300) {
                event.preventDefault();
            }

            // Reset reference time for double call prevention
            self.timeStamp = event.timeStamp;

            // Detect prevented state to handle submit done / fail
            isPrevented = event.isDefaultPrevented();

            if (!isPrevented) {

                // Remove warning before page leave
                if (o.showSaveWarn) {
                    win.off('beforeunload.uiForm', self._beforeunload);
                }

                // Submit form via AJAX
                if (ajax) {
                    // Prevent default without handle submitFail
                    event.preventDefault();

                    // AJAX send handler
                    var send = function (settings) {
                        var
                        // Local for data
                            data = settings.data || [],

                            // AJAX default settings
                            defaults = {
                                // Use action attrigute as url
                                url: action || '',
                                // Use method attribute as type
                                type: self.elem.attr('method') || 'post',
                                // Add form input data
                                data: self.elem.serializeArray() || []
                            };

                        // Remove original data (use serialized)
                        if (settings.data) {
                            delete settings.data;
                        }

                        // Serialize for mergable data array
                        if (!$.isArray(data)) {
                            data = serializeArray(data);
                        }

                        // Build AJAX settings
                        $.extend(true, defaults, settings);

                        // Merge data arrays
                        $.merge(defaults.data, data);

                        // Return jqXHR promise
                        return ep.ajax(defaults)
                            .done(function () {
                                self.elem.trigger('submitDone');
                            })
                            .fail(function () {
                                self.elem.trigger('submitFail');
                            });
                    };

                    if ($.isFunction(ajax)) {
                        ajax(send);
                    } else {
                        send(ajax);
                    }
                }
            }

            // Fix submit buttons values
            self._submitButtonFix();

            // Trigger done / fail (if not AJAX)
            if (!ajax) {
                self.elem.trigger(isPrevented ? 'submitFail' : 'submitDone');
            }

            // Remove check handler
            self.elem.off('submit.uiForm', $.proxy(self, '_submitCheck'));
        },

        // Submit event pre controller
        _submit: function (event) {
            var self = this,
                o = self.options;

            // Control last event handle of submit call
            if (!event.uiFormTriggert) {

                // This way other *submit* event handlers can expect the validation to be done.
                self.elem.trigger('validate');

                // Actually set *formInvalid* attribute on *element*.
                self._setValid(self.elem.formInput());

                // Stop event
                event.stopImmediatePropagation();
                event.preventDefault();

                // Save autocomplete for IE
                if (window.external && typeof window.external.AutoCompleteSaveForm === 'function') {
                    window.external.AutoCompleteSaveForm(self.elem[0]);
                }

                // Add sumbit check as last event handle and trigger submit again
                self.elem
                    .on('submit.uiForm', $.proxy(self, '_submitCheck'))
                    .trigger({
                        type: 'submit',
                        uiFormTriggert: true
                    });
            }
        },

        // Reset form inputs
        _reset: function (event) {
            this.elem
                .formInput()
                .each(function () {
                    $(this).triggerHandler('reset');
                });
        },

        // Handle leave warning before leaving the page
        _change: function () {
            var self = this;

            //reset button state and text if form was changed
            var buttons = self.elem.
            formInput()
                .filter('.Saved');
            if (ep.config.saved) {
                buttons.each(function (i) {
                    var node = $(this),
                        originalText = node.data('originalText');
                    if (node.hasClass('Saved') && originalText) {
                        node
                            .addClass('SaveButton')
                            .removeClass('Saved')
                            .text(node.data('originalText'));
                    }
                });
            }

            if (self.options.showSaveWarn) {
                if (self._isChanged(self.elem.formInput())) {
                    win.on('beforeunload.uiForm', $.proxy(self._beforeunload, self));
                } else {
                    win.off('beforeunload.uiForm', $.proxy(self._beforeunload, self));
                }
            }
        },

        // Just the before page leave event callback
        _beforeunload: function () {
            return this.options.showSaveWarn ? tLoseChanges : undefined;
        },

        // Public set SaveButton class to Saved
        setSaveButtonSaved: function () {
            var self = this,
                buttons = self.elem.
            formInput()
                .filter('.SaveButton');

            if (ep.config.saved) {
                buttons.each(function (i) {
                    var node = $(this),
                        originalText = node.text();

                    node
                        .addClass('Saved')
                        .removeClass('SaveButton')
                        .data('originalText', originalText);

                    if (ep.config.saveButtonChangeMap && ep.config.saveButtonChangeMap[originalText]) {
                        node.text(ep.config.saveButtonChangeMap[originalText]);
                    }
                });
            }
        }

    });

    return ep;

});


/* ---- Module:ep.ui.tooltip ---- */

/**
 * Create a tooltip.
 * 
 * The `.uiTooltip()` method create a tooltip from each element in the set of matched elements.
 * 
 * ### Examples
 * In this example a tooltip is created for the text above. The data-js attribute within a span tag is used to execute the tooltip. By hovering over the text the tooltip text appears and gets not hidden by click, because the interactive option is set to true. The parent div tag is the context element for the show/hide handling.
 * 
 * JavaScript:
 * 
 *     
 *     <div>
 *      some text
 *      <span class="Tooltip ep-js"  data-js="ep.uiTooltip({'interactive' : true, 'context':'parent'});">
 *       tooltip text
 *      </span>
 *     </div>
 * 
 * 
 * @class jQuery.ui.uiTooltip
 * @extends jQuery.widget
 * 
 * @uses ep
 * @uses jQuery.ui.widget
 * @uses ep.fn.sprite
 * @uses ep.fn.contextOrientation
 * @since 6.11.0
 */

/**
 * @event show This event is triggered when the tooltip was displayed.
 * @member jQuery.ui.uiTooltip
 * @since 6.11.0
 */

/**
 * @event hide This event is triggered when the tooltip was hidden.
 * @member jQuery.ui.uiTooltip
 * @since 6.11.2
 */

/**
 * Call up a previously attached tooltip.
 * 
 * @param {Function} [callback] A method to execute after the tooltip was displayed (after animated show).
 * 
 * @method show
 * @member jQuery.ui.uiTooltip
 * 
 * @since 6.11.0
 */

/**
 * Hide a previously displayed tooltip.
 * 
 * @param {Function} [callback] A method to execute after the tooltip was hidden (after animated hide).
 * 
 * @method hide
 * @member jQuery.ui.uiTooltip
 * 
 * @since 6.11.0
 */

/**
 * @cfg {String} event A event handle when show/hide the tooltip. Supported handles: 'click' or 'hover'
 */

/**
 * @cfg {Object,String} context A DOM element, jQuery object or selector to specify a context element for the show/hide handling.
 */

/**
 * @cfg {Boolean} interactive A boolean indication whether to prevent hide when clicked in the tooltip.
 */

/**
 * @cfg {String} orientation Specify the position of the tooltip to the context element. Supported orientations: 'top', 'left', 'right', 'bottom', 'center', 'middle'. If orientation empty the context will be the cursor.
 */

/**
 * @cfg {Array} offsetAdjust An array of numbers for x and y position adjust. The numbers will be intepreted as pixel.
 */

/**
 * @cfg {String} addClass The tooltip wraps an element around the givn element, the addClass option specifies classes to add to the wrap element.
 */

/**
 * @cfg {Number} showDelay A delay duration to show the tooltip.
 */

/**
 * @cfg {Number} hideDelay A delay duration to hide the tooltip.
 */

/**
 * @cfg {Boolean} closeButton A boolean indication whether to add a close button to the tooltip.
 */

/**
 * See `jQuery.ui.uiTooltip` for details.
 * 
 * @param {Object} [options] A map of additional options pass to the method.
 * @param {String} event A event handle when show/hide the tooltip. Supported handles: 'click' or 'hover'
 * @param {Object,String} context A DOM element, jQuery object or selector to specify a context element for the show/hide handling.
 * @param {Boolean} interactive A boolean indication whether to prevent hide when clicked in the tooltip.
 * @param {String} orientation Specify the position of the tooltip to the context element. Supported orientations: 'top', 'left', 'right', 'bottom', 'center', 'middle'. If orientation empty the context will be the cursor.
 * @param {Array} offsetAdjust An array of numbers for x and y position adjust. The numbers will be intepreted as pixel.
 * @param {String} addClass The tooltip wraps an element around the givn element, the addClass option specifies classes to add to the wrap element.
 * @param {Number} showDelay A delay duration to show the tooltip.
 * @param {Number} hideDelay A delay duration to hide the tooltip.
 * @param {Boolean} closeButton A boolean indication whether to add a close button to the tooltip.
 * 
 * @fires show
 * @fires hide
 * 
 * @method uiTooltip
 * @member jQuery
 * 
 * @since 6.11.0
 */

/*
 * @copyright		© Copyright 2006-2010, epages GmbH, All Rights Reserved.
 *
 * @module			ep.ui.tooltip
 *
 * @revision		$Revision: 1.10.2.4.10.1 $
 */
/*jslint nomen: true*/
/*global define*/
define("ep/ui/tooltip", [
    "jquery",
    "ep",

    "jquery/ui/widget",
    "ep/ui/core",
    "ep/fn/sprite",
    "ep/fn/contextorientation"
], function ($, ep) {
	'use strict';

    var EVENTS = {
        'focus': ['focus.uiTooltip', 'blur.uiTooltip'],
        'click': ['click.uiTooltip'],
        'hover': ['mouseenter.uiTooltip', 'mouseleave.uiTooltip']
    };

    $.widget("ui.uiTooltip", /* my.parent.widget,*/ {

        options: {
            event: 'hover',
            context: 'prev',
            interactive: false,
            orientation: 'bottom',
            // can be top,left,right,bottom,center,middle,cursor
            offsetAdjust: [0, 0],
            addClass: '',
            showDelay: 200,
            hideDelay: 400,
            closeButton: false
        },

        _create: function () {
            var o = this.options,
                href = '';

            href += 'javascript';
            href += ':void(0)';

            this.elem = this.element
				.removeClass('HideElement ToolTip Tooltip') //both classes define display:none
				.removeAttr('style');

            // add context + bind events
            if (typeof o.context === 'string' && o.context.toLowerCase() === 'prev') {
                this.context = this.element.prev();
            } else if (typeof o.context === 'string' && o.context.toLowerCase() === 'next') {
                this.context = this.element.next();
            } else if (typeof o.context === 'string' && o.context.toLowerCase() === 'parent') {
                this.context = this.element.parent();
            } else {
                this.context = $(o.context);
            }

            // add wrapper around tooltip content
            this.wrap = ep('<div>').addClass('ep-uiTooltip ui-front' + (o.addClass ? ' ' + o.addClass : '')).attr('style', this.elem.attr('style') || '').appendTo('body').append(this.elem).hide();

            if (o.closeButton) {
                /*jslint sloppy: true, browser: true*/
                this.closeButton = ep('<a>').attr({
                    'href': href,
                    'class': 'ep-uiTooltip-closeButton'
                }).text('x').on('click', {}, $.proxy(this, '_hide')).appendTo(this.wrap);
            }
        },

        _init: function () {
            this.wrap.off('.uiTooltip');
            this.context.off('.uiTooltip');

            this.wrap.on('mouseenter.uiTooltip', $.proxy(this, '_enter')).on('mouseleave.uiTooltip', $.proxy(this, '_leave'));

            var e = EVENTS[this.options.event];
            if (e[0]) {
                this.context.on(e[0], $.proxy(this, '_show'));
            }
            if (e[1]) {
                this.context.on(e[1], $.proxy(this, '_hide'));
            }
        },

        _moveToTop: ep.ui.createMoveToTop('wrap'),

        _enter: function () {
            if (this.options.interactive) {
                this.cursorInside = true;
                this.wrap.stop(true, true);
            }
        },

        _leave: function () {
            this.cursorInside = false;
            this.hide();
        },

        _show: function (event, callback) {
            var o = this.options,
				context,
				orient,
                add,

                eventTrigger;

            if (!o.disabled) {
                context = this.context;
                orient = o.orientation;
                add = o.offsetAdjust;

                //Move to top, but keep silent
                this._moveToTop({}, true);

                if (orient === 'cursor') {
                    orient = undefined;
                }
                if (event instanceof $.Event && !orient && o.event !== 'focus') {
                    context = event;
                } else if ($.isArray(event)) {
                    context = new $.Event({
                        pageX: event[0],
                        pageY: event[1]
                    });
                }

                // Set position
                this.wrap.contextOrientation(context, orient, add);

                // Hide all tooltips
                $('.ep-uiTooltip').stop(true, true).hide();

                // Start show current tooltip
                this.wrap.delay(o.showDelay).fadeIn('normal', callback);

                this.elem.triggerHandler('show');

                // If tooltip context inside wrapped by a 'ui-front' element trigger focus on context without event bubbling
                if (this.context.parents('.ui-front').length) {
                    eventTrigger = $.Event({
                        type: 'focus'
                    });
                    eventTrigger.stopPropagation();

                    this.context.trigger(eventTrigger);
                }
            }
        },

        show: function (callback) {
            this._show({}, callback);
        },

        _hide: function (event) {
            if (!this.cursorInside || event.data) {
                this.hide();
            }
        },

        hide: function (callback) {
            var o = this.options;
            if (!o.disabled) {
                this.wrap.stop(true, true).delay(o.interactive ? o.hideDelay + 400 : o.hideDelay).fadeOut('normal', callback);

                this.elem.triggerHandler('hide');

                $('html').off('mouseup', $.proxy(this, '_hide'));
            }
        },

        _setOption: function (key, value) {
            if (key === 'context') {
                this.context.off('.uiTooltip');
                this.context = $(value);
            }
            return this._superApply(arguments);
        },

        destroy: function () {
            this.wrap.off('.uiTooltip');
            this.elem.unwrap();
            this.context.off('.uiTooltip');

            $('html').off('mouseup', $.proxy(this, '_hide'));

            this._superApply(arguments);
        }

    });

    return ep;

});


/* ---- Module:ep.ui.input ---- */

/**
 * Advanced handling for input elements.
 * 
 * The `.uiInput()` method add advanced handling to a input elements.
 * 
 * ### Examples
 * Apply .uiInput() to all input element and set autofocus to the first matched element.
 * 
 * JavaScript:
 * 
 *     ep(':input')
 *         .first()
 *             .uiInput({autofocus: true})
 *         .end()
 *         .not(':first')
 *             .uiInput()
 *         .end();
 * 
 * 
 * @class jQuery.ui.uiInput
 * @extends jQuery.widget
 * 
 * @uses ep
 * @uses ep.dict
 * @uses jQuery.support.placeholder
 * @uses jQuery.support.multipleUpload
 * @uses jQuery.fn.form
 * @uses jQuery.fn.class
 * @uses ep.ui.tooltip
 * @since 6.11.0
 */

/**
 * @event changeValue This event is triggered when the value is changed.
 * @member jQuery.ui.uiInput
 * @since 6.11.0
 */

/**
 * @cfg {String} placeholder A text as placeholder.
 */

/**
 * @cfg {String} info A info text show as tooltip if the element has focus.
 */

/**
 * @cfg {Boolean} autofocus A boolean indication wether the element gets focus on page load.
 */

/**
 * @cfg {Boolean} big A boolean indication wether the element display bigger than the normal one.
 */

/**
 * @cfg {String} orientation A string ('right', 'left', 'top' or 'bottom') to decide in which direction tooltipps will be shown.
 */

/**
 * See `jQuery.ui.uiInput` for details.
 * 
 * @param {Object} [options] A map of additional options pass to the method.
 * @param {String} placeholder A text as placeholder.
 * @param {String} info A info text show as tooltip if the element has focus.
 * @param {Boolean} autofocus A boolean indication wether the element gets focus on page load.
 * @param {Boolean} big A boolean indication wether the element display bigger than the normal one.
 * @param {String} orientation A string ('right', 'left', 'top' or 'bottom') to decide in which direction tooltipps will be shown.
 * 
 * @fires changeValue
 * 
 * @method uiInput
 * @member jQuery
 * 
 * @since 6.11.0
 */

/*
 * @copyright		© Copyright 2006-2010, epages GmbH, All Rights Reserved.
 *
 * @module			ep.ui.input
 *
 * @revision		$Revision: 1.10.2.2 $
 */

define("ep/ui/input", [
	"jquery",
	"ep",
	"util/support",
	"$dict!ep/dict",

	"jquery/fn/form",
	"jquery/fn/class",
	"ep/ui/tooltip"
], function ($, ep, support, epDict) {

/*
 * @dictionary		ep.dict
 *
 * @translation		{SelectFile}
 */

	// Trigger click from custom ui element on original one
 	$(document)
 		.on("click", "input + .ep-uiInput-custom:not(label *, input:disabled + *)", function(event){
 			$(this.previousSibling)
 				.trigger({
	 				type: "click",
	 				data: event.data,
	 				originalTarget: this.previousSibling
 				});
 		});

	$.widget('ui.uiInput',{

		options: {
		//	placeholder:		'text',
		//	info:				'text',
			autofocus:			false,
			big:				false
		},

		_create: function(){
			var self = this,
				o = self.options,

				elem = self.elem = self.element
					.data( 'uiUiInput', self ),

				// stack of additional elements
				stack = self.stack = $([]),

				// get type
				type = self.type = elem[0].tagName.toLowerCase()+':',

				// classes
				elemClasses = '';

			// detailed type
			self.type = type = (type==='input:' || type==='button:') ? type+elem[0].type : type;

			// get instance of dict
			self.dict = epDict;

			// set placeholder
			if( o.placeholder ){
				elem.attr( 'placeholder', o.placeholder );
			}

			elem.on( 'changeAttr.uiInput', $.proxy(self, '_changeAttr') )
				.on( 'reset.uiInput', $.proxy(self, '_change') )
				.on( 'focusin.uiInput', function(){
					if( self.tooltip ){
						self.tooltip[ self.tooltip.is(':empty') ? 'hide' : 'show' ]();
					}
				})
				.on( 'focusout.uiInput',  function(){
					self._leave();
					if( self.tooltip ){
						self.tooltip.hide();
					}
				});

			if( (/file$/i).test(type) ){
				elemClasses += ' ep-uiInput-file';
				// create a button
				stack.push(
					(
						self.custom = $('<span class="ep-uiInput-custom"><span class="ep-uiInput ep-uiInput-button">' + self.dict.translate('SelectFile')+'...</span></span>')
							.insertAfter(elem)
					)[0]
				);
				// create a input to display selected file name
				stack.push(
					(
						self.fileText = $('<span class="ep-uiInput ep-uiInput-text">' + (elem.val() || '&nbsp;')  + '</span>')
							.prependTo(self.custom)
					)[0]
				);
			}

			if( self.options.big ){
				elemClasses += ' ep-uiInput-big';
			}
			if( (/(^(textarea:|select:)|(text|password|email|url|tel|date|datetime|time|number)$)/).test(type) ){
				elemClasses += ' ep-uiInput';
			}

			if( (/checkbox$/).test(type) ){
				elemClasses += ' ep-uiInput-checkbox';
				stack.push(
					(
						self.custom = $('<span class="ep-uiInput-custom ep-uiInput ep-uiInput-base ep-uiInput-field"></span>')
							.insertAfter(elem)
					)[0]
				);
			}
			else if( (/radio$/).test(type) ){
				elemClasses += ' ep-uiInput-radio';
				stack.push(
					(
						self.custom = $('<span class="ep-uiInput-custom"></span>')
							.insertAfter(elem)
					)[0]
				);
			}
			else if( (/^select:/).test(type) ){
				elemClasses += ' ep-uiInput-select';
			}
			else if( (/(^(button:|a:)|(submit|reset|button|image)$)/).test(type) ){
				elemClasses +=		(/image$/).test(type) ? ' ep-uiInput ep-uiInput-image' : ' ep-uiInput ep-uiInput-button';
				// handle reset on form
				if( (/reset$/).test(type) ){
					elem.on('click.uiInput',function(event){
							event.preventDefault();
							$(this.form).formReset();
						});
				}
				// handle submit on buttons having the form attribute
				if( (/submit$/).test(type) ){
					if( this.elem.attr('form') ){
						if( !support.inputFormAttr ){
							this.elem.on('click', function(){
								event.preventDefault ? event.preventDefault() : event.returnValue = false;
								$('form#'+$(this).attr('form')).submit();
							});
						}
					}
				}
			}
			else if( (/^textarea:$/).test(type) ){
				elemClasses += ' ep-uiInput-textarea2';
			}
			else if( (/(text|password|email|url|tel|date|datetime|time|number)$/i).test(type) ){
				elemClasses += ' ep-uiInput-text';
			}
			// change event
			if( (/(^(select:)|(file|checkbox|radio)$)/).test(type) ){
				elem.on( 'change.uiInput', $.proxy(self, '_change') );
			}
			// key event
			if( (/(^(textarea:)|(text|password|checkbox|radio|email|url|tel|date|datetime|time|number)$)/).test(type) ){
				elem.on( 'keyup.uiInput', $.proxy(self, '_change') );
			}

			// add classes for styling
			elem.addClass( elemClasses );

			// save value state
			self.lastState = [ elem[0].value, elem[0].checked, elem[0].selectedIndex ];
		},
		// init binds
		_init: function(){

			// init tooltip
			this._tooltipInit();

			// handle autofocus for this elem
			if( this.elem.attr('autofocus') || this.options.autofocus ){
				this.elem[0].focus();
			}
		},
		// handle addClass to the wrap
		/**
		 * The `.uiInput()` method wraps an element around the input, the addClass add classes to the wrap element.
		 * 
		 * @param {String} className One or more class names to be added to the class attribute of each matched element.
		 * 
		 * @method addClass
		 * @member jQuery.ui.uiInput
		 * 
		 * @since 6.11.0
		 */
		addClass: function( name ){
			if( !(/(hover|active|focused)/).test(name) || !this.elem.is(':disabled,:readonly') ){
				this.elem.addClass(name);
			}
		},
		// handle removeClass to the wrap
		/**
		 * The `.uiInput()` method wraps an element around the input, the removeClass removes classes from the wrap element.
		 * 
		 * @param {String} className A class name to be removed from the class attribute of each matched element.
		 * 
		 * @method removeClass
		 * @member jQuery.ui.uiInput
		 * 
		 * @since 6.11.0
		 */
		removeClass: function( name ){
			this.elem.removeClass(name);
		},

		_tooltipInit: function( buildManual ){
			if( !this.tooltip && (this.options.info || buildManual) ){
				this.tooltip = ep('<div>')
					.addClass('ep-uiInput-info')
					.uiTooltip({
						interactive:	true,
						event:			'focus',
						context:		this.elem,
						orientation:	'right',
						offsetAdjust:	[0,0]
					});
				if( this.options.info ){
					this.tooltip.html(this.options.info);
				}
				// add to stack
				this.stack.push(this.tooltip[0]);
			}
		},

		_setOption: function( key, value ) {
			if( key === 'placeholder' ){
				this.elem.attr( 'placeholder', value );
			}

			return this._superApply(arguments);
		},

		// actions if change attr by javascript
		_changeAttr: function( event, attr ){
			if( attr.hasOwnProperty('value') ){
				this._change({});
			}
		},

		_stateChanged: function(){
			var oldState = this.lastState,
				newState = [ this.elem[0].value ,this.elem[0].checked, this.elem[0].selectedIndex ],
				ret = !( oldState[0] === newState[0] && oldState[1] === newState[1] && oldState[2] === newState[2] );

			this.lastState = newState;

			return ret;
		},

		_change: function( event ){
			if( event.keyCode!==9 ){
				// special for checkbox
				if( (/checkbox$/i).test(this.type) ){
					this.elem
						.trigger( 'changeAttr', {'checked':this.elem.is(':checked')} );
				}
				// special for radios
				else if( (/radio$/i).test(this.type) ){
					this.elem
						.formGroup(':radio')
							.filter(':checked')
								.trigger( 'changeAttr', {'checked':false} )
							.end()
							.filter(':not(:checked)')
								.trigger( 'changeAttr', {'checked':true} );
				}
				// display selected file
				else if( (/file$/i).test(this.type) ){
					if(this.elem.val()!=""){
						this.fileText.text( this.elem.val().replace(/^.*?fakepath[\/\\]?/,'') );
					}else{
						this.fileText.html('&nbsp;');
					}
				}
			}

			this._leave();
		},

		_leave: function(){
			this.elem.toggleClass('ui-changed', this.elem.is(':changed'));

			if( this._stateChanged() ){
				this.elem.trigger('changeValue');
				// trigger changed to form
				$(this.elem[0].form).trigger('change');
			}
		},

		destroy: function(){
			this.elem
				.removeClass(/(ep-uiInput[\w\d-]*|epWidth-\d+)/g);
			this.stack.remove();

			return this._superApply(arguments);
		}
	});

	return ep;

});

/* ---- Module:ep.ui.dialog ---- */

/**
 * Create a dialog.
 *
 * The `.uiDialog()` method creates a dialog for each element in the set of matched elements.
 *
 * ### Examples
 * Apply .uiDialog() with an Ok and Cancel Button to all divs with class dialog.
 *
 * JavaScript:
 *
 *     ep('div.dialog')
 *         .uiDialog({
 *             buttons: [
 *              {text: 'Ok', click: function(){ alert('OK'); }},
 *              {text: 'Cancel', click: function(){ alert('Cancel'); }}
 *             ]
 *         });
 *
 *     // use identifier as button text
 *
 *     ep('div.dialog')
 *         .uiDialog({
 *             buttons: {
 *              Ok:     {click: function(){ alert('OK'); }},
 *              Cancel: {click: function(){ alert('Cancel'); }}
 *             }
 *         });
 *
 * Apply .uiDialog() with an Ok and Cancel Button including a form handling.
 *
 * JavaScript:
 *
 *     ep('div.dialog')
 *         .uiDialog({
 *             form: {
 *                 action: '?ViewAction=MyExample',
 *                 method: 'post'
 *             },
 *             buttons:{
 *              Ok:     {type: 'submit'},
 *              Cancel: {click: function(){ ep(this).uiDialog('close'); }}
 *             }
 *         });
 *
 *
 * @class jQuery.ui.uiDialog
 * @extends jQuery.dialog
 *
 * @uses ep
 * @uses ep.ui.form
 * @uses ep.ui.input
 * @uses jQuery.ui.dialog
 * @since 6.11.0
 */

/**
 * See `jQuery.ui.uiDialog` for details.
 *
 * @method uiDialog
 * @member jQuery
 *
 * @since 6.11.0
 */

/*
 * @copyright       © Copyright 2006-2010, epages GmbH, All Rights Reserved.
 *
 * @module          ep.ui.dialog
 *
 * @revision        $Revision: 1.16.2.9 $
 */

/*jslint nomen:true*/
/*globals define*/

define("ep/ui/dialog", [
    "jquery",
    "ep",

    "jquery/ui/dialog",
    "ep/ui/form",
    "ep/ui/input"
], function ($, ep) {
    'use strict';

    $.widget("ui.uiDialog", $.ui.dialog, {

        /**
         * @cfg {Object} [options] A map of additional options pass to the method.
         * @cfg {Object} [options.form] A map of attributes passed to a form around the dialog.
         * @cfg {Boolean} [options.closeText] A boolean indication whether to display the close button, with the default close text.
         */
        options: {
            //  closeOnClickOut: false,
            draggable: false,
            resizable: "se",
            preventScroll: false
        },

        _create: function () {
            var self = this,
                o = self.options;

            self._superApply(arguments);

            // #BUG http://bugs.jqueryui.com/ticket/9097
            self.element.data("ui-dialog", self);

            if (o.form) {
                self._createForm(o.form);
            }

            self.uiDialog
                .removeClass("ui-corner-all")
                .addClass("epDialog");
            self.uiDialogTitlebar
                .removeClass("ui-corner-all");

            self._setOption("closeText", "");
            self.uiDialogTitlebar
                .find(".ui-dialog-titlebar-close")
                .insertBefore(self.uiDialogTitlebar.find(".ui-dialog-title"));
        },

        _createForm: function (form) {
            var opt = form.options;

            if (opt) {
                delete form.options;
            }

            this.uiForm = this.options.form = ep("<form>")
                .attr(this.options.form)
                .attr({
                    // Setting tabIndex makes the form focusable
                    tabIndex: -1,
                    role: "dialog"
                })
                .addClass(this.uiDialog.attr("class"))
                .toggle(this._isOpen)
                .insertBefore(this.uiDialog)
                .append(this.uiDialog.children())
                .uiForm(opt || {});

            // Remove previous used dialog element
            this.uiDialog.remove();

            // Set form as dialog container
            this.uiDialog = this.uiForm;

            // Initialize wrapper again
            this._initWrapper();
        },

        // Copy of original _createWrapper, but splitted into _createWrapper and _initWrapper
        _createWrapper: function () {
            this.uiDialog = $("<div>")
                .addClass("ui-dialog ui-widget ui-widget-content ui-corner-all ui-front " +
                    this.options.dialogClass)
                .hide()
                .attr({
                    // Setting tabIndex makes the div focusable
                    tabIndex: -1,
                    role: "dialog"
                })
                .appendTo(this._appendTo());

            this._initWrapper();
        },

        _initWrapper: function () {

            this._on(this.uiDialog, {
                keydown: function (event) {
                    if (this.options.closeOnEscape && !event.isDefaultPrevented() && event.keyCode && event.keyCode === $.ui.keyCode.ESCAPE) {
                        event.preventDefault();
                        this.close(event);
                        return;
                    }

                    // prevent tabbing out of dialogs
                    if (event.keyCode !== $.ui.keyCode.TAB) {
                        return;
                    }
                    var tabbables = this.uiDialog.find(":tabbable"),
                        first = tabbables.filter(":first"),
                        last = tabbables.filter(":last");

                    if ((event.target === last[0] || event.target === this.uiDialog[0]) && !event.shiftKey) {
                        first.focus(1);
                        event.preventDefault();
                    } else if ((event.target === first[0] || event.target === this.uiDialog[0]) && event.shiftKey) {
                        last.focus(1);
                        event.preventDefault();
                    }
                },
                mousedown: function (event) {
                    if (this._moveToTop(event) && !this.uiDialog.find('select').length) {
                        this._focusTabbable();
                    }
                }
            });

            // We assume that any existing aria-describedby attribute means
            // that the dialog content is marked up properly
            // otherwise we brute force the content as the description
            if (!this.element.find("[aria-describedby]").length) {
                this.uiDialog.attr({
                    "aria-describedby": this.element.uniqueId().attr("id")
                });
            }
        },

        _moveToTop: function (event, silent) {
            var moved = Boolean(this.uiDialog.nextAll(":visible").not('.ep-cke-full').insertBefore(this.uiDialog).length);
            if (moved && !silent) {
                this._trigger("focus", event);
            }

            return (moved && !silent);
        },

        _setOption: function (key, value) {
            var self = this;

            switch (key) {
            case "form":
                if (!self.uiForm) {
                    self._createForm(value);
                } else {
                    self.uiForm.uiForm(value);
                }
                break;
            case "title":
                $(".ui-dialog-title", self.uiDialogTitlebar)
                    .empty()
                    .append(self.options.title = (value || "&#160;"));
                break;
            case "closeText":
                self.uiDialogTitlebar.find(".ui-dialog-titlebar-close").toggle(value !== false);
                value = value === true ? "close" : (value || "");
                break;
            default:
                self._superApply(arguments);
            }
        },

        _keepFocus: function () {
            if (this.options.closeOnClickOut) {
                this.close();
            } else {
                this._superApply(arguments);
            }
        },

        // Add classes to button area elements
        _createButtonPane: function () {
            var sup = this._superApply(arguments);

            this.uiDialogButtonPane.addClass("epDialogButtonBar");
            this.uiButtonSet.addClass("uiDialogButtonPane");

            return sup;
        },

        // Custom createButtons method (add button object to options, no click required, no jQuery UI Button)
        _createButtons: function () {
            var that = this,
                buttons = this.options.buttons;

            // if we already have a button pane, remove it
            this.uiDialogButtonPane.remove();
            this.uiButtonSet.empty();

            if ($.isEmptyObject(buttons)) {
                this.uiDialog.removeClass("ui-dialog-buttons");
                return;
            }

            $.each(buttons, function (name, props) {
                var click,
                    buttonOptions;

                if ($.isFunction(props)) {
                    props = {
                        click: props,
                        text: name
                    };
                }

                // Default to a non-submitting button
                props = $.extend({
                    type: "button",
                    text: name
                }, props);
                // Change the context for the click callback to be the main element
                click = props.click || function () {};
                props.click = function () {
                    click.apply(that.element[0], arguments);
                };

                delete props.icons;
                delete props.showText;
                buttons[name] = $("<button></button>", props).appendTo(that.uiButtonSet);
            });
            this.uiDialog.addClass("ui-dialog-buttons");
            this.uiDialogButtonPane.appendTo(this.uiDialog);
        },

        open: function () {
            if (this.options.preventScroll) {
                $("body").css("overflow", "hidden");
            }
            return this._superApply(arguments);
        },

        close: function () {
            if (this.options.preventScroll) {
                $("body").css("overflow", "auto");
            }
            return this._superApply(arguments);
        }

    });

    return ep;

});

/* ---- Module:ep.ui.magnifier ---- */

/**
 * Adding magnifier function to an image
 *
 * The `.uiMagnifier()` widget adds a magnifier to an preview image. The magnified image is passed as
 * additional option and will be shown in a magnified area.
 *
 * The dimensions of the magnifier mover depends on the dimensions of the magnified image,
 * the magnified area and the preview image.
 *
 * ### Examples
 * Add a magnifier on the right side of an image.
 *
 * JavaScript:
 *
 *     ep('#image').uiMagnifier({
 *       'magnifiedPicture':'magnifiedImage.jpg',
 *       'magWidth': 200,
 *       'magHeight': 200,
 *       'dir': 'right'
 *     });
 *
 * HTML:
 *
 *     <img src="Image.jpg" name="Bild" alt="Bild" id="image" />
 *
 *
 * @class jQuery.ui.uiMagnifier
 * @extends jQuery.widget
 *
 * @uses ep
 * @uses jQuery.ui.widget
 * @uses jQuery.event.special.load
 * @uses ep.fn.contextOrientation
 * @since 6.12.0
 */

/**
 * Setting a new preview and magnified image.
 *
 * @param {String} newPreviewImage Specifies path and name of the file containing the new preview image.
 * @param {String} newMagnifiedImage Specifies path and name of the file containing the new magnified image.
 *
 * @method setImage
 * @member jQuery.ui.uiMagnifier
 *
 * @since 6.12.0
 */

/**
 * @cfg {String} magnifiedPicture Specifies path and name of the file containing the magnified image.
 */

/**
 * @cfg {integer} magWidth Width of the magnified area.
 */

/**
 * @cfg {integer} magHeight Height of the magnified area.
 */

/**
 * @cfg {String} magBorder CSS string defining the border of the magnifier mover.
 */

/**
 * @cfg {string} magBG CSS string defining the background of the magnifier mover.
 */

/**
 * @cfg {float} magOpac Number from 0 to 1 defining the opacity of the magnifier mover.
 */

/**
 * @cfg {string} dir Direction where the magnified area is shown relative to the preview image. (posible values 'left', 'right', 'center')
 */

/**
 * @cfg {integer} zIndex Number defining the layer position of the magnified area.
 */

/**
 * @cfg {object} slideshow An object representing a ep.uiSlideshow.
 */

/**
 * See `jQuery.ui.uiMagnifier` for details.
 *
 * @param {Object} [options] A map of additional options pass to the method.
 * @param {String} magnifiedPicture Specifies path and name of the file containing the magnified image.
 * @param {integer} magWidth Width of the magnified area.
 * @param {integer} magHeight Height of the magnified area.
 * @param {String} magBorder CSS string defining the border of the magnifier mover.
 * @param {string} magBG CSS string defining the background of the magnifier mover.
 * @param {float} magOpac Number from 0 to 1 defining the opacity of the magnifier mover.
 * @param {string} dir Direction where the magnified area is shown relative to the preview image. (posible values 'left', 'right', 'center')
 * @param {integer} zIndex Number defining the layer position of the magnified area.
 * @param {object} slideshow An object representing a ep.uiSlideshow.
 *
 * @method uiMagnifier
 * @member jQuery
 *
 * @since 6.12.0
 */

/*jslint browser: true, plusplus: true, nomen: true, ass: true*/
/*global define*/

define("ep/ui/magnifier", [
    "jquery",
    "ep",
    "$dict!ep/dict",
    "$tmpl!ep/ui/magnifier",

    "jquery/ui/widget",
    "ep/ui/core",
    "ep/fn/contextorientation"
], function ($, ep, epDict, tmplMagnifier) {

    'use strict';

    var tExpand = epDict.translate("Expand");

    $.widget("ui.uiMagnifier", {
        options: {
            //    action            : "lightbox",        //
            images: "img", // selector / array of data / data / image node / array of image nodes / jQuery object
            orientation: "right",
            width: 250,
            height: 250
        },

        _create: function () {
            var self = this,
                o = self.options,
                imgs = self.images = ep.ui.imgData(o.images)
                    .on("change.uiMagnifier", $.proxy(self, "_change"))
                    .on("resizestop.uiMagnifier", $.proxy(self, "_resizeZoom"));

            self.animating = false;
            self.refresh = false;
            self.noZoom = false;

            // load template and add element names to instance
            $.extend(self, tmplMagnifier([{
                expand: tExpand
            }])
                .appendTo(self.element)
                .tmplItem("elements"));

            self.cache = {
                box: {
                    width: self.box.innerWidth(),
                    height: self.box.innerHeight()
                },
                boxMag: {},
                ratio: 1
            };

            self.zoom.appendTo("body");

            self.container.on("click.uiMagnifier", function () {
                if (o.action) {
                    imgs.trigger(o.action);
                }
            });

            self._setOptions(o);
        },

        _init: function () {
            this._change();
        },

        destroy: function () {
            var self = this;

            self.images.off(".uiMagnifier");
            self.zoom.remove();
            self.container.remove();
            self._superApply(arguments);
        },

        _setOption: function (key, value) {
            var self = this;

            if (key === "action") {
                self.container.css("cursor", value ? "pointer" : "");
            } else if (key === "width") {
                self.zoom.width(value);
            } else if (key === "height") {
                self.zoom.height(value);
            }

            return this._superApply(arguments);
        },

        _change: function () {
            var self = this,
                curr,
                imgSrc;

            if (self.animating) {
                self.refresh = true;
            } else {
                curr = self.images.current();

                // Get optimal image size for box and check image by src large
                imgSrc = curr._checkSrcName(curr.srcM, curr.getSrcFor(self.box));

                self.refresh = false;
                self.animating = true;

                self.zoom.hide();
                self.container.off("mouseenter.uiMagnifier mousemove.uiMagnifier mouseleave.uiMagnifier");

                self.boxImg = $('<img alt="" src="' + imgSrc + '"/>')
                    .appendTo(self.boxWrap.empty().hide())
                    .on("load", function () {
                        var imgSrcLarge;

                        self.boxWrap.show();

                        if (self.refresh) {
                            self.animating = false;
                            self._change();
                        } else {
                            curr = self.images.current();
                            imgSrcLarge = curr._checkSrcName(curr.srcM, curr.srcL);

                            self.zoomImg = $('<img alt="" src="' + imgSrcLarge + '"/>')
                                .appendTo(self.zoomWrap.empty())
                                .on("load", function () {
                                    self.animating = false;

                                    if (self.refresh) {
                                        self._change();
                                    } else {
                                        self._resizeZoom();
                                        self.container.on("mouseenter.uiMagnifier", $.proxy(self, "_enterMag"))
                                            .on("mousemove.uiMagnifier", $.proxy(self, "_moveMag"))
                                            .on("mouseleave.uiMagnifier", $.proxy(self, "_leaveMag"));
                                    }
                                });
                        }
                    });

            }
        },

        _resizeZoom: function () {
            var self = this,

                o = self.options,
                cache = self.cache;

            if (!self.zoomImg || !self.boxImg) {
                return;
            }

            cache.ratio = Math.max(self.zoomImg[0].width / self.boxImg[0].width, self.zoomImg[0].height / self.boxImg[0].height);
            self.noZoom = cache.ratio <= 1;

            // Skip resize dom elements if zoom disabled
            if (self.noZoom) {
                return;
            }

            cache.box.width = self.box.innerWidth();
            cache.box.height = self.box.innerHeight();

            self.boxMag
                .outerWidth(o.width / cache.ratio)
                .outerHeight(o.height / cache.ratio);

            cache.boxMag.width = self.boxMag.outerWidth();
            cache.boxMag.height = self.boxMag.outerHeight();

            self.zoom
                .width(o.width)
                .height(o.height);

            self.zoomWrap
                .width(cache.box.width * cache.ratio)
                .height(cache.box.height * cache.ratio);
        },

        _enterMag: function () {
            var self = this;

            // Don't show zoom box if zomm disabled
            if (self.noZoom) {
                return;
            }

            self.boxMag.show();

            self.zoom.contextOrientation(self.box, self.options.orientation, [10, 0])
                .show();
        },

        _moveMag: function (event) {
            var self = this,
                cache = self.cache,
                offset = self.box.offset(),
                top = Math.ceil(Math.min(Math.max(0, (event.pageY - offset.top) - cache.boxMag.height / 2), cache.box.height - cache.boxMag.height)),
                left = Math.ceil(Math.min(Math.max(0, (event.pageX - offset.left) - cache.boxMag.width / 2), cache.box.width - cache.boxMag.width));

            self.boxMag.css({
                top: top + "px",
                left: left + "px"
            });

            self.zoomWrap.css({
                top: -(top * cache.ratio) + "px",
                left: -(left * cache.ratio) + "px"
            });
        },

        _leaveMag: function () {
            var self = this;
            self.boxMag.hide();
            self.zoom.hide();
        }

    });

    return ep;

});

/* ---- Module:ep.ui.slides ---- */

/**
 * Create a slideshow for a given set of images.
 *
 * The `ep.uiSlides()` method creates a slideshow for a given set of images.
 *
 * ### Examples
 * Create a simple slideshow.
 *
 * JavaScript:
 *
 *     ep('#slides01')
 *       .uiSlides({
 *         images  : '#images img',
 *         action  : "lightbox",
 *         caption : true,
 *         count   : true,
 *         delay   : 500,
 *         autoplay: true
 *     });
 *
 * HTML:
 *
 *     <ul id="images" style="display:none;">
 *       <li>
 *         <img
 *           alt="Bild 1"
 *           src="ep/ui/slidesTest_Image1.jpg"
 *           data-src-m="ep/ui/slidesTest_Image1.jpg"
 *           data-src-l="ep/ui/slidesTest_Image1.jpg"
 *         />
 *       </li>
 *       <li>
 *         <img
 *           alt="Bild 2"
 *           src="ep/ui/slidesTest_Image2.jpg"
 *           data-src-m="ep/ui/slidesTest_Image2.jpg"
 *           data-src-l="ep/ui/slidesTest_Image2.jpg"
 *         />
 *       </li>
 *       <li>
 *         <img
 *           alt="Bild 3"
 *           src="ep/ui/slidesTest_Image1.jpg"
 *           data-src-m="ep/ui/slidesTest_Image1.jpg"
 *           data-src-l="ep/ui/slidesTest_Image1.jpg"
 *         />
 *       </li>
 *     </ul>
 *     <div id="slides01" style="width:400px;height:400px;"></div>
 *
 *
 * @class jQuery.ui.uiSlides
 * @extends jQuery.widget
 *
 * @uses ep.ui.core
 * @uses jQuery.event.special.load
 * @uses jQuery.event.special.touch
 * @uses jQuery.fn.class
 * @uses jQuery.tmpl
 * @uses jQuery.ui.widget
 * @since 6.14.0
 */

/**
 * @cfg {String} images A set of images which will be displayed.
 */

/**
 * @cfg {String} effect The change over effect.
 */

/**
 * @cfg {Number} delay The time images will be visible in the play mode.
 */

/**
 * @cfg {Boolean} autoplay A boolean indication wether to change images automatically by delay.
 */

/**
 * @cfg {String} controls The way the controls will be displayed (auto / visible / hidden).
 */

/**
 * @cfg {Boolean} caption A boolean indication wether to show the caption of the images.
 */

/**
 * @cfg {Boolean} count A boolean indication wether to show the count of the images like (i of n).
 */

/**
 * @cfg {String} defaultSize which image size should be used as default ( 'XS' / 'S' / 'M' / 'L' ).
 */

/**
 * See `jQuery.ui.uiSlides` for details.
 *
 * @param {Object} options A map of additional options pass to the method.
 * @param {String} images A set of images which will be displayed.
 * @param {String} effect The change over effect.
 * @param {Number} delay The time images will be visible in the play mode.
 * @param {Boolean} autoplay A boolean indication wether to change images automatically by delay.
 * @param {String} controls The way the controls will be displayed (auto / visible / hidden).
 * @param {Boolean} caption A boolean indication wether to show the caption of the images.
 * @param {Boolean} count A boolean indication wether to show the count of the images like (i of n).
 * @param {String} defaultSize which image size should be used as default ( 'XS' / 'S' / 'M' / 'L' ).
 *
 * @method uiSlides
 * @member jQuery
 *
 * @since 6.14.0
 */

/*
 * @copyright        © Copyright 2006-2012, epages GmbH, All Rights Reserved.
 *
 * @module            ep.ui.slides
 *
 * @revision        $Revision: 1.9.2.4.4.1 $
 */

/*jslint browser: true, plusplus: true, nomen: true, ass: true*/
/*global define*/

define("ep/ui/slides", [
    "jquery",
    "ep",
    "$dict!ep/dict",
    "$tmpl!ep/ui/slides",

    "jquery/ui/widget",
    "jquery/fn/class",
    "jquery/event/special/load",
    "jquery/event/special/touch",
    "ep/ui/core"
], function ($, ep, epDict, tmplSlides) {

    'use strict';

    var fx = ep.ui.changeOverFx,
        tExpand = epDict.translate("Expand");

    $.widget("ui.uiSlides", {
        options: {
            //    action            : "lightbox",        //
            images: "img", // selector / array of data / data / image node / array of image nodes / jQuery object
            effect: "standard", // change-over effect
            delay: 3000, // how long are the images visible in play mode
            autoplay: false, // flag whether to change images automatically by delay
            controls: 'auto', // show controls or not ('auto' / 'visible' / 'hidden')
            caption: false, // show caption of images
            count: false, // show count of images like (i of n)
            defaultSize: 'M' // which image size should be used as default ( 'XS' / 'S' / 'M' / 'L' )
        },

        _create: function () {
            var self = this,
                o = self.options,
                imgs = self.images = ep.ui.imgData(o.images).on("change.uiSlides", $.proxy(self, "_change"));

            self.animating = false;
            self.refresh = false;

            // load template and add element names to instance
            $.extend(self, tmplSlides([{
                expand: tExpand
            }])
                .appendTo(self.element)
                .tmplItem('elements'));

            self.ctrlPrevHandle.on("click.uiSlides", function () {
                imgs.current("prev");
            });

            self.ctrlNextHandle.on("click.uiSlides", function () {
                imgs.current("next");
            });

            self.container.on("click.uiSlides", function (event) {
                if (!$(event.originalTarget).is('.ep-uiSlides-ctrl a') && o.action) {
                    self._external(true);
                    imgs.trigger(o.action);
                }
            })
                .on("touchdrag.uiSlides", function (event) {
                    event.preventDefault();
                })
                .on("touchswiperight.uiSlides", function () {
                    imgs.current("prev");
                })
                .on("touchswipeleft.uiSlides", function () {
                    imgs.current("next");
                });

            self._setOptions(o);
        },

        _init: function () {
            var self = this;

            self._internal(true);
            self._change();
        },

        destroy: function () {
            var self = this;

            self.images.off(".uiSlides");
            self.container.remove();
            self._superApply(arguments);
        },

        _internal: function (set) {
            return arguments.length ? (this.eventInernal = set) : this.eventInernal;
        },

        _external: function (set) {
            var self = this;

            if (set) {
                self.eventExternal = true;
                self._autoplay();
            }

            return self.eventExternal;
        },

        _autoplay: function () {
            var self = this,
                o = self.options;

            clearInterval(self.playTimeout);

            if (o.autoplay && !self._external()) {
                // auto play with delay interval
                self.playTimeout = setTimeout(function () {
                    self._internal(true);
                    self.images.current(self.images.currentItem === self.images.length - 1 ? 0 : "next");
                }, o.delay);
            }
        },

        _setOption: function (key, value) {
            var self = this;

            if (key === "action") {
                self.container.css("cursor", value ? "pointer" : "");
            } else if (key === "controls") {
                self.container.removeClass(/ep-uiSlides-ctrl-[\w]+/)
                    .addClass("ep-uiSlides-ctrl-" + value);
            }

            return this._superApply(arguments);
        },

        _change: function () {
            var self = this,
                o = self.options,

                imgs,
                imgsNumber,
                imgsLength,
                prev,
                curr,
                next,

                imgSrc,

                boxNext,
                img;

            self._external(!self._internal());
            self._internal(true);

            if (self.animating) {
                self.refresh = true;
            } else {
                self.refresh = false;
                self.animating = true;

                imgs = self.images;
                imgsNumber = imgs.currentItem + 1;
                imgsLength = imgs.length;
                prev = imgs.prev();
                curr = imgs.current() || {};
                next = imgs.next();
                
                // Get optimal image size for box and check image by default src
                imgSrc = curr._checkSrcName(curr['src' + o.defaultSize], curr.getSrcFor(self.box));

                self.ctrlPrev.addClass('ui-hidden');
                self.ctrlNext.addClass('ui-hidden');

                // change curr <> next
                boxNext = self.boxNext;
                self.boxNext = self.boxCurr;
                self.boxCurr = boxNext;

                self.desc.stop(true, true)
                    .slideUp();

                img = $('<img alt="" src="' + imgSrc + '"/>')
                    .on("load", function () {
                        var slideshow = $('#ProductSlideshow'),
                            currentHeight = slideshow.height();

                        if (this.height > currentHeight) {
                            slideshow.height(this.height);
                        }

                        // call chang-over effect
                        (fx(o.effect))(
                            self.box,
                            self.boxNext.stop(true, true),
                            self.boxCurr.stop(true, true).hide().empty().append(img),
                            o.delay,
                            function () {
                                self.ctrlPrev.toggleClass('ui-hidden', !prev);

                                self.ctrlNext.toggleClass('ui-hidden', !next);

                                self.descCount.html(imgsNumber + "/" + imgsLength)
                                    .toggle(!!o.count);

                                self.descCaption.html(curr.desc.replace(/\n/g, "<br />"))
                                    .toggle(!!(o.caption && curr.desc));

                                if (o.count || (o.caption && curr.desc)) {
                                    self.desc.stop(true, true)
                                        .slideDown();
                                }

                                self.animating = false;

                                if (self.refresh) {
                                    self._change();
                                } else {
                                    self._autoplay();
                                }
                            }
                        );
                    })
                    .appendTo('head');
            }
        }
    });

    return ep;

});

/* ---- Module:ep.ui.coverflow ---- */

/**
 * Create a flash coverflow effect to display images.
 *
 * The `.uiCoverflow()` method creates a flash object to display the given images.
 *
 * The classes BorderColor0x000000,MainColorAlt0x000000 and
 * MainColor0x000000 define how the created coverflow will look like.
 * title and title2 define how the to action links of the coverflow are named.
 * The first action link takes the src from the a tag of every image in the collection as target.
 * The second link only workes inside ePages and uses the addToBasket method of this widget.
 *
 * You can create a coverflow with the optional parameter imagesData and pass the images data in an array to
 * the widget like:
 *
 * ### Examples
 * Apply .uiCoverflow() to collection of images.
 *
 * JavaScript:
 *
 *     ep('.CoverFlow')
 *         .uiCoverflow({});
 *
 * HTML:
 *
 *     <div class="CoverFlow BorderColor0x333333 MainColorAlt0x000000 MainColor0x000000 HideElement" title="Coverflow" title2="title2">
 *       <a href="http://www.epages.de">
 *         <img src="ep/ui/CoverflowTest_image.jpg"
 *              longdesc="longDescription"
 *         />
 *       </a>
 *       <a href="http://www.epages.de">
 *        <img src="ep/ui/CoverflowTest_image.jpg"
 *             longdesc="longDescription"
 *        />
 *       </a>
 *     </div>
 *
 * Apply .uiCoverflow() to a domnode and add images directly via parameter.
 *
 * JavaScript:
 *
 *     ep('.CoverFlow')
 *         .uiCoverflow({
 *           imagesData: [
 *           {
 *             medium: 'imageA.png',
 *             desciption:'a beautiful image'
 *           },
 *           {
 *             medium: 'imageB.png',
 *             desciption:'a beautiful image'
 *           }
 *           ]
 *         });
 *
 * HTML:
 *
 *     <div class="CoverFlow BorderColor0x333333 MainColorAlt0x000000 MainColor0x000000 HideElement" title="Coverflow" title2="title2">
 *     </div>
 *
 *
 * @class jQuery.ui.uiCoverflow
 * @extends jQuery.widget
 *
 * @uses ep
 * @uses jQuery.ui.widget
 * @uses jQuery.support.flash
 * @uses jQuery.compareVersion
 * @since 6.11.1
 */

/**
 * @cfg {Array} [imagesData] an array of hashes with the data of the images to display
 */

/**
 * See `jQuery.ui.uiCoverflow` for details.
 *
 * @param {Object} [options] A map of additional options pass to the method.
 * @param {Array} [imagesData] an array of hashes with the data of the images to display
 *
 * @method uiCoverflow
 * @member jQuery
 *
 * @since 6.11.1
 */

/*
 * @copyright       © Copyright 2006-2010, epages GmbH, All Rights Reserved.
 *
 * @module          ep.ui.coverflow
 *
 * @revision        $Revision: 1.10.2.2.10.1 $
 */

define("ep/ui/coverflow", [
    "jquery",
    "ep",
    "util/string",
    "util/support",
    "util/version",

    "jquery/cookie",
    "jquery/ui/widget",
    "ep/ui/core",
    "ep/ui/slides"
], function ($, ep, str, support, version) {

	var shift = Array.prototype.shift,

		swf = location.protocol + '//' + location.host + ep.config.javascriptRoot + '/ep/ui/coverflow.swf',

		uid = 0,

		bridge = function (self) {
			return (bridge[self.id] = {
				// get flash optimized data of images
				/**
				 * returns the data of the images which will be displayed inside the coverflow. This method is called by
				 * the flash object.
				 *
				 * @method getData
				 * @member jQuery.ui.uiCoverflow
				 *
				 * @since 6.11.1
				 */
				getData: function () {
					var result = [],
						caption = self.options.caption;

					self.images.each(function (i, item) {
						result.push([
                            item.srcM, // medium image source
                            caption && item.desc ? str.shrink(item.desc.replace(/\n/g, " "), {
								length: 40,
								ratio: 0.5
							}) : "", // image description
                            "showProduct", // click display action
                            "addToBasket", // click add to basket action
                            false, // is map
                            i // stack index number
                        ]);
					});

					return result;
				},
				// handle change event trigegr by flash
				change: function (i) {
					self.images.current(i);
				},
				// trigger show product action
				showProduct: function (i) {
					if (self.options.action) {
						self.images.trigger(self.options.action);
					}
				},
				//#JSCOVERAGE_IF false
				// trigger add to basket action
				/**
				 * this method is a connector method for the flash object and adds the current selected product to the basket.
				 * method only works inside epages and with valid product data.
				 *
				 * @method addToBasket
				 * @member jQuery.ui.uiCoverflow
				 *
				 * @since 6.11.1
				 */
				addToBasket: function (i) {
					var node = self.images.current().node,
						addToBasketLink,
						tokenName = "SecToken",
						cookie = $.cookie(tokenName);

					if (node) {
						addToBasketLink = $(node).closest("a").data("addToBasket");
						if (addToBasketLink) {
							// check if security token exists and add security cookie information
							if (cookie && cookie !== null) {
								addToBasketLink += "&" + tokenName + "=" + cookie;
							}

							$.ajax({
								type: 'POST',
								url: addToBasketLink,
								async: false
							})
								.done(function () {
									window.location.href = location.protocol.toLowerCase() == "https:" ?
										ep.config.webUrlSsl :
										ep.config.webUrl;
								});
						}
					}
				}
				//#JSCOVERAGE_ENDIF
			});
		};

	$.widget('ui.uiCoverflow', {

		options: {
			//  action      : "slideshow",  // example: 'slideshow' / 'location'
			title: "",
			images: "img",
			caption: false,

			count: false, // only for alternative/fallback html version
			autoplay: true, // only for alternative/fallback html version
			controls: true, // only for alternative/fallback html version
			delay: 3000 // only for alternative/fallback html version
		},

		_create: function () {
			var self = this,
				o = self.options,
				imgs = self.images = ep.ui.imgData(o.images)
				.on("change.uiCoverflow", $.proxy(self, "_change"));

			// provide swf connection
			self.id = "cwf" + $.now() + "" + (++uid);
			bridge(self);

			// set title
			o.title = o.title || self.element.attr("title") || "";

			// check flash vs. alternative
			if (version.compare(support.flash, '9') >= 0 && imgs.length > 2) {
				self.flash = $();
				self._buildFlash();
				self.element.addClass('Flashed')
					.removeClass('HideElement');
				$(window)
					.on('resize', $.proxy(self, '_buildFlash'));
			} else {
				self._buildHTML();
			}
		},

		_change: function () {
			var self = this;

			if (self.flash && self.flash[0] && self.flash[0].setCurrent) {
				self.flash[0].setCurrent(self.images.currentItem);
			}
		},

		_buildHTML: function () {
			var self = this,
				o = self.options;

			self.element
				.removeClass('HideElement')
				.uiSlides(o)
				.children('a')
				.hide();
		},

		_buildFlash: function () {
			var self = this,
				//random string is necessary to avoid that the IE thinks he had not to render the flash again
				movie = $.browser.msie && parseInt($.browser.version) <= 8 ?
				swf + "?" + $.now() + (++uid) :
				swf;
			// flash object html string
			flash = '<object ' +
				'name="' + self.id + '" ' +
				'id="' + self.id + '" ' +
				'type="application/x-shockwave-flash" ' +
				'data="' + movie + '" ' +
				'data-jsapi="jQuery.ui.uiCoverflow.flash" ' +
				'data-jscallback="getData" ' +
				'data-jschange="change" ' +
				'><param ' +
				'name="movie" ' +
				'value="' + movie + '" ' +
				'/><param ' +
				'name="allowscriptaccess" ' +
				'value="always"' +
				'/><param ' +
				'name="wmode" ' +
				'value="transparent" ' +
				'/><param ' +
				'name="swliveconnect" ' +
				'value="true" ' +
				'/></object>';

			// clear existing in DOM
			if (self.flash) {
				self.flash.remove();
			}
			// add to DOM
			self.flash = self.element
				.attr('title', self.options.title)
				.append(flash)
				.find('object');
		},

		destroy: function () {
			this._superApply(arguments);
		}

	});

	// external public connetion for swf/flash actions
	$.extend($.ui.uiCoverflow, {
		flash: function () {
			return bridge[shift.call(arguments)][shift.call(arguments)].apply(bridge, arguments);
		}
	});

	return ep;

});


/* ---- Module:ep.ui.thumbbox ---- */

/**
 * Create a thumbnail box for a given set of images.
 * 
 * The `ep.uiThumbbox()` method creates a thumbnail box for a given set of images. A thumbnail is a small preview of an image.
 * 
 * The thumbbox can be part of the `ep.uiLightbox()` and can also be used with `ep.uiSlides()`.
 * 
 * ### Examples
 * Create a thumbbox (list style).
 * 
 * JavaScript:
 * 
 *     ep('#thumbbox01')
 *       .uiThumbbox({
 *         images  : '#images img',
 *         width : 200,
 *         height  : 200,
 *         action  : "slides",
 *         view  : "list"
 *      });
 * 
 * HTML:
 * 
 *     <ul id="images" style="display:none;">
 *       <li>
 *         <img
 *           alt="Bild 1"
 *           src="ep/ui/thumbboxTest_Image1.jpg"
 *           data-src-m="ep/ui/thumbboxTest_Image1.jpg"
 *           data-src-l="ep/ui/thumbboxTest_Image1.jpg"
 *         />
 *       </li>
 *       <li>
 *         <img
 *           alt="Bild 2"
 *           src="ep/ui/thumbboxTest_Image2.jpg"
 *           data-src-m="ep/ui/thumbboxTest_Image2.jpg"
 *           data-src-l="ep/ui/thumbboxTest_Image2.jpg"
 *         />
 *       </li>
 *       <li>
 *         <img
 *           alt="Bild 3"
 *           src="ep/ui/thumbboxTest_Image1.jpg"
 *           data-src-m="ep/ui/thumbboxTest_Image1.jpg"
 *           data-src-l="ep/ui/thumbboxTest_Image1.jpg"
 *         />
 *       </li>
 *     </ul>
 *     <div id="thumbbox01" style="width:650px;"></div>
 * 
 * 
 * @class jQuery.ui.uiThumbbox
 * @extends jQuery.widget
 * 
 * @uses ep.ui.core
 * @uses jQuery.fn.class
 * @uses jQuery.tmpl
 * @uses jQuery.ui.widget
 * @since 6.14.0
 */

/**
 * @cfg {String} event The event that changes the current image.
 */

/**
 * @cfg {String} images A set of images which will be displayed.
 */

/**
 * @cfg {Number} width The width of the thumbnail.
 */

/**
 * @cfg {Number} height The height of the thumbnail.
 */

/**
 * @cfg {String} view The style of the thumbbox (list / slide / fisheye).
 */

/**
 * See `jQuery.ui.uiThumbbox` for details.
 * 
 * @param {Object} options A map of additional options pass to the method.
 * @param {String} event The event that changes the current image.
 * @param {String} images A set of images which will be displayed.
 * @param {Number} width The width of the thumbnail.
 * @param {Number} height The height of the thumbnail.
 * @param {String} view The style of the thumbbox (list / slide / fisheye).
 * 
 * @method uiThumbbox
 * @member jQuery
 * 
 * @since 6.14.0
 */

/*
 * @copyright		© Copyright 2006-2012, epages GmbH, All Rights Reserved.
 *
 * @module			ep.ui.thumbbox
 *
 * @revision		$Revision: 1.6.2.2 $
 */

define("ep/ui/thumbbox", [
	"jquery",
	"ep",
	"$tmpl!ep/ui/thumbbox",

	"jquery/fn/class",
	"jquery/ui/widget",
	"ep/ui/core"
], function ($, ep, tmplThumbbox){

	$.widget( "ui.uiThumbbox", {
		options: {
		//	action			: "lightbox",
			event			: "click",
			images			: "img",			// selector / array of data / data / image node / array of image nodes / jQuery object		//
			width			: 100,				// width of thumbnail
			height			: 100,				// height of thumbnail
			view			: "list"			// style of thumbbox ("list" / "slide" / "fisheye")
		},

		_create: function(){
			var self	= this,
				o		= self.options,
				imgs	= self.images = ep.ui.imgData(o.images),
				width	= o.width,
				height	= o.height,
				srcType	= 'srcXs';

			if( width > 190 || height > 190 ){
				srcType	= 'srcL';
			}
			else if( width > 140 || height > 140 ){
				srcType	= 'srcM';
			}
			else if( width > 90 || height > 90 ){
				srcType	= 'srcS';
			}

			$.extend( self, tmplThumbbox([{imgData:imgs.get(),srcType:srcType}] ).appendTo(self.element).tmplItem('elements') );

			self._setOptions(o);

			// set current the thumbnail of the current image active
			self.element.find('li:first').addClass('active');
			imgs.on('change', function(){
				var currentSrc = imgs.current()[srcType],
					thumbList = $('img[src="'+currentSrc+'"]').closest('ul'),
					thumbItem = $('img[src="'+currentSrc+'"]').closest('li'),
					thumbboxWidth = $('img[src="'+currentSrc+'"]').closest('.ep-uiThumbbox').width(),
					thumblistLeft = thumbList[0].offsetLeft,
					thumbLeft = thumbItem[0].offsetLeft;

				self.element.find('li.active').removeClass('active');
				thumbItem.addClass('active');

				if(self.options.view === "slide"){
					// scroll active thumb into view if necessary
					if(thumblistLeft + thumbLeft < 0){
						thumbList.stop(true, true).animate({
							'left': -thumbLeft + "px"
						});
					}else if(thumblistLeft + thumbLeft > thumbboxWidth){
						thumbList.stop(true, true).animate({
							'left': (thumbboxWidth-thumbLeft-thumbItem.outerWidth()) + "px"
						});
					}
				}
			});

		},

		_init: function(){

		},

		destroy: function(){
			var self = this;

			self.images.off(".uiThumbbox");
			self.container.remove();
			self._superApply(arguments);
		},

		_setOption: function( key, value ) {
			var self = this,
				o = self.options,
				imgs = self.images;

			if ( key === "view" ) {
				// reset slide
				self.container
					.off("mousemove.uiThumbbox")
					.css( "height", "" )
					.removeClass(/ep-uiThumbbox-[\w]+/)
					.addClass("ep-uiThumbbox-"+value);

				if( value == "slide" ){
					// init slide
					self.container
						.on("mousemove.uiThumbbox",$.proxy(self, "_slideMove"))
						.height( self.list.outerHeight(true) );
				}
			}
			else if( key === "width" ){
				self.list
					.children()
					.width(value);
			}
			else if( key === "height" ){
				self.list
					.children()
					.height(value)
					.css("line-height",value+"px");
				self._setOption("view",self.options.view);
			}
			else if( key === "event" ){
				self.element
					.off(".uiThumbbox", "img")
					.on(value + ".uiThumbbox", "li", function(event){
						var item = $(this).data("item");

						if( item !== undefined && item != imgs.currentItem ){

							imgs.current( item );

							if( o.action ){
								imgs.trigger(o.action);
							}
						}
					});
			}

			return this._superApply(arguments);
		},

		_slideMove: function( event ){
			var self			= this,
				containerLeft	= self.container.offset().left,
				containerWidth	= self.container.width(),
				listWidth		= self.list.width(),
				mouseLeft		= event.pageX - containerLeft,
				speed			= self.list.position().left

			self.list.stop(true);

			if(listWidth > containerWidth){
				if( mouseLeft < (containerWidth * 1/4) ){
					self.list.animate({left: "0px"}, Math.abs(speed*2), 'linear');
				}
				else if( mouseLeft > (containerWidth * 3/4) ){
					self.list.animate({left: (containerWidth-listWidth)+"px"}, Math.abs((listWidth-containerWidth+speed)*2), 'linear');
				}
			}
		}
	});

	return ep;

});

/* ---- Module:ep.ui.lightbox ---- */

/**
 * Create a lightbox for a given set of images.
 * 
 * The `ep.uiLightbox()` method creates a lightbox for a given set of images. The lightbox shows the images
 * in a seperate dialog.
 * 
 * ### Examples
 * Create a simple lightbox.
 * 
 * JavaScript:
 * 
 *     ep('#images')
 *       .uiLightbox({
 *         images          : '#images img',
 *         controls        : 'visible',
 *         caption         : true,
 *         count           : true,
 *         thumbs          : true,
 *         closeOnEscape   : true,
 *         closeOnClickOut : true
 *     });
 * 
 * HTML:
 * 
 *     <ul id="images">
 *       <li>
 *         <img
 *           alt="Bild 1"
 *           src="ep/ui/lightboxTest_Image1.jpg"
 *           data-src-m="ep/ui/lightboxTest_Image1.jpg"
 *           data-src-l="ep/ui/lightboxTest_Image1.jpg"
 *         />
 *       </li>
 *       <li>
 *         <img
 *           alt="Bild 2"
 *           src="ep/ui/lightboxTest_Image2.jpg"
 *           data-src-m="ep/ui/lightboxTest_Image2.jpg"
 *           data-src-l="ep/ui/lightboxTest_Image2.jpg"
 *         />
 *       </li>
 *       <li>
 *         <img
 *           alt="Bild 3"
 *           src="ep/ui/lightboxTest_Image1.jpg"
 *           data-src-m="ep/ui/lightboxTest_Image1.jpg"
 *           data-src-l="ep/ui/lightboxTest_Image1.jpg"
 *         />
 *       </li>
 *     </ul>
 * 
 * 
 * @class jQuery.ui.uiLightbox
 * @extends jQuery.widget
 * 
 * @uses ep.ui.core
 * @uses jQuery.fn.size
 * @uses jQuery.ui.widget
 * @uses ep.ui.dialog
 * @uses ep.ui.slides
 * @uses ep.ui.thumbbox
 * @since 6.14.0
 */

/**
 * @cfg {String} images A set of images which will be displayed.
 */

/**
 * @cfg {String} effect The change over effect.
 */

/**
 * @cfg {String} controls The way the controls will be displayed (auto / visible / hidden).
 */

/**
 * @cfg {Boolean} caption A boolean indication wether to show the caption of the images.
 */

/**
 * @cfg {Boolean} count A boolean indication wether to show the count of the images like (i of n).
 */

/**
 * @cfg {Boolean} thumbs A boolean indication wether to show thumbnails inside the lightbox.
 */

/**
 * @cfg {Boolean} closeOnEscape A boolean indication wether to close the lightbox by pressing the escape button.
 */

/**
 * @cfg {Boolean} closeOnClickOut A boolean indication wether to close the lightbox by clicking outside of the dialog.
 */

/**
 * @cfg {String} defaultSize The default size of images used for the slides widget.
 */

/**
 * See `jQuery.ui.uiLightbox` for details.
 * 
 * @param {Object} options A map of additional options pass to the method.
 * @param {String} images A set of images which will be displayed.
 * @param {String} effect The change over effect.
 * @param {String} controls The way the controls will be displayed (auto / visible / hidden).
 * @param {Boolean} caption A boolean indication wether to show the caption of the images.
 * @param {Boolean} count A boolean indication wether to show the count of the images like (i of n).
 * @param {Boolean} thumbs A boolean indication wether to show thumbnails inside the lightbox.
 * @param {Boolean} closeOnEscape A boolean indication wether to close the lightbox by pressing the escape button.
 * @param {Boolean} closeOnClickOut A boolean indication wether to close the lightbox by clicking outside of the dialog.
 * @param {String} defaultSize The default size of images used for the slides widget.
 * 
 * @method uiLightbox
 * @member jQuery
 * 
 * @since 6.14.0
 */

/*
 * @copyright		© Copyright 2006-2012, epages GmbH, All Rights Reserved.
 *
 * @module			ep.ui.lightbox
 *
 * @revision		$Revision: 1.8.2.4.10.1 $
 */

define("ep/ui/lightbox", [
	"jquery",
	"ep",

	"jquery/ui/dialog",
	"jquery/ui/widget",
	"ep/ui/core",
	"ep/ui/dialog",
	"ep/ui/slides",
	"ep/ui/thumbbox"
], function ($, ep) {

	var win = $(window),

		winWidth = win.width(),

		winHeight = win.height(),

		_superDialog = $.ui.uiDialog.prototype,

		body;

	$.widget( "ui.uiLightbox", {
		options: {
			images			: "img",			// selector / array of data / data / image node / array of image nodes / jQuery object
			effect			: "standard",		// change-over effect
			controls		: 'visible',		// show controls or not ('auto' / 'visible' / 'hidden')
			caption			: false,			// show caption of images
			count			: false,			// show count of images like (i of n)
			thumbs			: false,			// show thumbnails inside of lightbox
			closeOnEscape	: true,
			closeOnClickOut	: true,
			defaultSize     : 'M'
		},

		_create: function(){
			var self = this,
				imgs = self.images = ep.ui.imgData(this.options.images)
					.on("lightbox.uiLightbox", $.proxy(self, "open"))
					.on("resizestop.uiLightbox", $.proxy(self, "_resizestop"));

			self.options.modal = true;

			imgs.each(function(i, item){
				if( item.node ){
					$(item.node)
						.on("click.uiLightbox",function(event){
							event.preventDefault();
							imgs.current(i)
								.trigger("lightbox");
						});
				}
			});
		},

		_setOption: function( name, value ){
			var self = this;

			if( name == "thumbs" && self.uiDialog ){
				self.uiDialog.toggleClass("ep-uiLightbox-showThumbs", value && self.images.length > 1);
			}

			self._superApply(arguments);
		},

		destroy: function(){
			var self = this;

			self.images
				.off(".uiLightbox")
				.each(function(i, item){
					if( item.node ){
						$(item.node).off("click.uiLightbox");
					}
				});

			if( self.uiDialog ){
				self.uiDialog.remove();
			}

			self._superApply(arguments);
		},

		_build: function(){
			var self = this,
				o = self.options;

			if( !self.uiDialog ){
				self.uiDialog = ep('<div class="ep-uiLightbox"/>')
					.outerWidth(win.width()-100,true)
					.outerHeight(win.height()-100,true)
					.attr({
						// Setting tabIndex makes the div focusable
						tabIndex: -1,
						role: "dialog"
					})
					.on("keydown", function( event ) {
						if ( self.options.closeOnEscape && !event.isDefaultPrevented() && event.keyCode && event.keyCode === $.ui.keyCode.ESCAPE ) {
							event.preventDefault();
							self.close( event );
						}
					})
					.appendTo("body")
					.addClass("ui-dialog ui-hidden ui-front");

				// set visibility of thumbs area
				self._setOption( "thumbs", o.thumbs );

				self.slidesWrap = ep('<div class="ep-uiLightbox-slides"/>')
					.appendTo(self.uiDialog)
					.uiSlides({
						images	    : o.images,
						effect	    : o.effect,
						controls    : o.controls,
						caption	    : o.caption,
						count	    : o.count,
						autoplay    : false,
						defaultSize : 'L'
					});

				self.thumbsWrap = ep('<div class="ep-uiLightbox-thumbs"/>')
					.appendTo(self.uiDialog)
					.uiThumbbox({
						images	: o.images,
						width	: 100,
						height	: 100
					});

				self.ctrlClose = $('<a href="javascript:void(0);" class="ep-uiLightbox-ctrlClose"/>')
					.prependTo(self.uiDialog)
					.on("click.uiLightbox",$.proxy(self, "close"));

				self.ctrlCloseHandler = $('<span>x</span>')
					.appendTo(self.ctrlClose);
			}
		},

		_appendTo: _superDialog._appendTo,

		_allowInteraction: _superDialog._allowInteraction,

		moveToTop: _superDialog.moveToTop,

		_moveToTop: _superDialog._moveToTop,

		_keepFocus: _superDialog._keepFocus,

		_createOverlay: _superDialog._createOverlay,

		_destroyOverlay: _superDialog._destroyOverlay,

		_resizestop: function(){
			if( this.uiDialog ){
				this.uiDialog
					.outerWidth( win.width() - 100, true )
					.outerHeight( win.height() - 100, true );
			}
		},

		open: function(){
			this._build();

			var self = this;
			self._createOverlay();
			self._moveToTop();
			self.uiDialog
				.removeClass("ui-hidden")
				.trigger("focus");
			self._resizestop();
		},

		close: function(){
			var self = this;

			self._destroyOverlay();
			self.uiDialog
				.addClass("ui-hidden");
		}
	});

	return ep;

});

/* ---- Module:ep.ui.spinner ---- */

/**
 * Add spinner handling for input elements.
 *
 * The `.uiSpinner()` method add spinner handling to an input elements.
 *
 * The `.uiSpinner()` method is a validation input also and using the validation types ''date'' and ''number'' from
 * the ep.validate module. Have a look at the additional options, some options are only available for
 * a special validation types.
 *
 * ### Examples
 * Apply .uiSpinner() to input element named percent.
 *
 * JavaScript:
 *
 *     ep(':input[name=percent]')
 *         .uiSpinner({
 *             required:   true,
 *             type:       'number',
 *             format:     'p',
 *             min:        10,
 *             max:        50,
 *             step:       10
 *         });
 *
 * HTML:
 *
 *     <form>
 *       <input type="text" name="percent" />
 *     </form>
 *
 *
 * @class jQuery.ui.uiSpinner
 * @extends jQuery.ui.uiValidate
 *
 * @uses ep.ui.validate
 * @uses ep.date
 * @uses ep.sprite
 * @since 6.11.0
 */

/**
 * @cfg {String} type A value respectively validation type: 'number' or 'date'.
 */

/**
 * @cfg {String} unit A unit for example 'GByte', es this option only for type 'number' an format 'n*'
 */

/**
 * @cfg {Number} step A difference to next/previous step.
 */

/**
 * @cfg {Number} stepType One of the supported types: 'fullYear', 'month', 'date', 'hours', 'minutes' or 'seconds'. For spinner type date only.
 */

/**
 * See `jQuery.ui.uiSpinner` for details.
 *
 * @param {Object} [options] A map of additional options pass to the method.
 * @param {String} type A value respectively validation type: 'number' or 'date'.
 * @param {String} unit A unit for example 'GByte', es this option only for type 'number' an format 'n*'
 * @param {Number} step A difference to next/previous step.
 * @param {Number} stepType One of the supported types: 'fullYear', 'month', 'date', 'hours', 'minutes' or 'seconds'. For spinner type date only.
 *
 * @method uiSpinner
 * @member jQuery
 *
 * @since 6.11.0
 */

/*
 * @copyright		© Copyright 2006-2010, epages GmbH, All Rights Reserved.
 *
 * @module			ep.ui.spinner
 *
 * @revision		$Revision: 1.11.2.4.10.2 $
 */

define("ep/ui/spinner", [
	"jquery",
	"ep",

	"ep/i18n",
	"ep/date",
	"ep/sprite",
	"ep/ui/validate"
], function ($, ep) {

/*
 * @dictionary			ep.dict
 *
 * @translation			{INVALID_STEP}
 */

	var is = function( val ){
			return !!( val===0 || (!isNaN(val) && val) );
		},
		html = $('html');

	$.widget('ui.uiSpinner',$.ui.uiValidate,{

		options: {
	// ep.ui.Input
		//	big:				true,
		//	autofocus:			false,
		//	info:				'text',

	// ep.ui.Validate
		//	accept:				'',
		//	min:				1,
		//	max:				20,
		//	minlength:			1,
		//	maxlength:			4,
		//	pattern:			[\w]+,
		//	required:			true,
		//	tooltipOffset:		[0,-7],
		//	valid:				true,
		//	type:				'basic',
		//	format:				'',

	// ep.ui.Spinner
		//	unit:				'GByte',
			type:				'number',
			format:				'n0',
			step:				1,
			stepType:			'hours',
			validateStep: false
		},

		_create: function(){
			this._superApply(arguments);
			var self = this;

			this.options = $.extend({
					step:			parseInt( this.elem.attr('step'), 10 )
				},this.options);

			this.elem
				.addClass('ep-uiSpinner')
				.on( 'keydown', function(event){
					if( event.keyCode === 38 || event.keyCode === 40 ){
						event.preventDefault();
						if( !self._interval ){
							self._start( event.keyCode === 38 ? 1 : -1 );
						}
					}
				})
				.on( 'keyup', function(event){
					if( event.keyCode === 38 || event.keyCode === 40 ){
						event.preventDefault();
						self._stop();
					}
				});

			this.stepper = $('<span>')
				.addClass('ep-uiInput ep-uiInput-button ep-uiSpinner-stepper')
				.insertAfter(this.elem);
			this.stepUp = ep( this.dict.parse('<a href="javascript:;">+</a>') )
				.addClass('ep-uiSpinner-stepUp')
				.attr({
					'tabIndex': -1
				})
				.on( 'mousedown.uiSpinner', function(event){
					if(event.button === 0){
						self._start(1);
					}
				})
				.appendTo(this.stepper);
			this.stepDown = ep( this.dict.parse('<a href="javascript:;">&ndash;</a>') )
				.addClass('ep-uiSpinner-stepDown')
				.attr({
					'tabIndex': -1
				})
				.on( 'mousedown.uiSpinner', function(event){
					if(event.button === 0){
						self._start(-1);
					}
				})
				.appendTo(this.stepper);

			this.stack.push( this.stepper[0], this.stepUp[0], this.stepDown[0] );
		},

		_init: function(){
			this._superApply(arguments);
			this._unitInit();

			var o = this.options;

			// Detect format by format,step, min and max options
			if( o.type!=='date' ){
				var formatMatch = (/(c|n|p)(\d{0,})/).exec(o.format),
					formatDecimals = parseInt(formatMatch[2] || 0, 10),

					stepSplit = (o.step+'').split('.'),
					stepDecimals = stepSplit[1] ? stepSplit[1].length : 0,

					minSplit = (o.min+'').split('.'),
					minDecimals = minSplit[1] ? minSplit[1].length : 0,

					maxSplit = (o.max+'').split('.'),
					maxDecimals = maxSplit[1] ? maxSplit[1].length : 0,

					// Get highest value of decimals from format/step/min/max
					decimals = Math.max(Math.max(Math.max(formatDecimals, stepDecimals), minDecimals), maxDecimals);

				this.options.format = formatMatch[1] + decimals;
			}
		},

		_unitInit: function(){
			if( !this.unit && this.options.unit ){
				this.unit = $('<span>')
					.addClass('ep-uiSpinner-unit')
					.insertBefore(this.stepper);
				this.stack.push(this.unit[0]);
			}
			if( this.unit ){
				this.unit.text(this.options.unit);
				var padding = (this.unit.width()+4)+'px';
				this.elem.css( 'padding-right', padding );
				this.unit.css( 'margin-left', '-' + padding );
			}
		},

		_tooltipInit: function(){
			this._superApply(arguments);
			if( this.tooltip ){
				this.tooltip.uiTooltip( 'option', 'offsetAdjust', [30,-1] );
			}
		},

		_changeAttr: function( event, attr ){
			var self = this;
			$.each( attr, function( name, value ){
				if( (/^(accept|pattern|required)$/i).test(name) ){
					self.options[ name ] = value;
				}
				else if( (/^(min|max|minlength|maxlength|step)$/i).test(name) ){
					self.options[ name ] = parseInt( value, 10 );
				}
			});
		},

		_parseValue: function(){
			var val = this.elem.attr('value'),
				o = this.options,
				region = {region: o.region};

			if( o.type === 'date' ){
				if( !is(this._val) ){
					this._val = is(o.min) ? new ep.Date(o.min) : new ep.Date();
				}
				val = $.i18n.parseDate( val, o.format, region );
				this._val = is(val) ? new ep.Date(val) : this._val;
			}
			else{
				if( !is(this._val) ){
					this._val = is(o.min) ? o.min : 0;
				}
				region.currency = o.currency;

				val = $.i18n.parseNumber( val, 10, region );
				this._val = is(val) ? val : this._val;
			}
		},

		_start: function( inc ){
			this._parseValue();

			this._type = '_spin' + (this.options.type==='date' ? 'Date' : 'Number');
			this._step = this.options.step * inc;
			this._count = 0;
			this[this._type]();
			// set interval for auto count up/down
			this._interval = setInterval( $.proxy(this, '_spin'), 250 );

			html.on( 'mouseup.uiSpinner', $.proxy(this, '_stop') );
		},

		_spin: function(){
			this._count++;
			if( (/^(10|20|30)$/).test(this._count+'') ){
				clearInterval(this._interval);
				// update interval speed for auto count up/down
				this._interval = setInterval( $.proxy(this, '_spin'), 150/this._count );
			}
			this[this._type]();
		},

		_spinNumber: function(){
			var o = this.options;

			this._val += this._step;

			if( is(o.min) && o.min > this._val ){
				this._val = o.min;
				this._stop();
			}
			else if( is(o.max) && o.max < this._val ){
				this._val = o.max;
				this._stop();
			}

			this.elem.val( $.i18n.formatNumber( this._val , o.format, {region:o.region,currency:o.currency} ) );
		},

		_spinDate: function( add ){
			var o = this.options;

			this._val[ $.camelCase('add-'+o.stepType) ]( this._step );

			if( is(o.min) && o.min > this._val.getTime() ){
				this._val = new ep.Date(o.min);
				this._stop();
			}
			else if( is(o.max) && o.max < this._val.getTime() ){
				this._val = new ep.Date(o.max);
				this._stop();
			}

			this.elem.val( $.i18n.formatDate( this._val, o.format, {region:o.region} ) );
		},

		_stop: function(){
			html.off( 'mouseup.uiSpinner', $.proxy(this, '_stop') );

			this._interval = clearInterval(this._interval);


			this.elem
				.filter(':visible')
					.focus()
				.end()
				.trigger('changeValue');
		},

		_createErrorMsgOptions: function(){
			var exampleValue = '',
				self = this,
				o = self.options;
			var tmpOptions = this._superApply(arguments);
			if(this.valid == "INVALID_STEP"){
				exampleValue = o.min + ', ' + (o.min + o.step) + ', ' + (o.min + 2 * o.step);

				return {
					example: exampleValue
				};
			}
			else{
				return tmpOptions;
			}
		},

		_validate: function( event ){
			var self = this,
				o = self.options,
				val = $.i18n.parseNumber(this.elem.val());
			this._superApply(arguments);
			if(o.validateStep && this.valid == true){
				if( ((val - o.min).toFixed(3) * 1000 ).toFixed(3) % (o.step * 1000) ){
					this._setValidStatus("INVALID_STEP");
					if( event.type!=='changeAttr' ){
						$(this.elem[0].form).trigger('change');
					}
				}
			}
		},

		destroy: function(){
			this.elem
				.off('.uiSpinner')
				.removeClass('epWidth-29')
				.removeClass(/ep-uiSpinner[\w\d-]*/g);

			this._superApply(arguments);
		}
	});

	return ep;

});

/* ---- Module:ep.ui.datepicker ---- */

/**
 * Add date selection from calendar handling for input elements.
 * 
 * The `.uiDatepicker()` method add validate handling to a input elements.
 * 
 * The `.uiDatepicker()` method is a validation input also and using the validation type ''date'' from
 * the ep.validate module. Have a look at the additional options, some options are only available for
 * a special validation types.
 * 
 * ### Examples
 * Apply .uiDatepicker() to input element named date.
 * 
 * JavaScript:
 * 
 *     ep(':input[name=date]')
 *         .uiDatepicker({
 *             type:       'date',
 *             format:     'd',
 *             time:       false
 *         });
 * 
 * HTML:
 * 
 *     <form>
 *       <input type="text" name="date" />
 *     </form>
 * 
 * 
 * @class jQuery.ui.uiDatepicker
 * @extends jQuery.ui.uiValidate
 * 
 * @uses ep
 * @uses ep.date
 * @uses ep.sprite
 * @uses ep.fn.busy
 * @uses ep.ui.spinner
 * @uses jQuery.tmpl
 * @since 6.11.0
 */

/**
 * Call up a previously attached date picker.
 * 
 * @method show
 * @member jQuery.ui.uiDatepicker
 * 
 * @since 6.11.0
 */

/**
 * Close a previously opened date picker.
 * 
 * @method hide
 * @member jQuery.ui.uiDatepicker
 * 
 * @since 6.11.0
 */

/**
 * @cfg {String} type The value respectively validation type must be 'date'.
 */

/**
 * @cfg {String} format A date formatter [look at the jQuery.i18n plugin].
 */

/**
 * @cfg {Integer} min A local timestamp (not UTC) as minimum valid date.
 */

/**
 * @cfg {Integer} max A local timestamp (not UTC) as maximum valid date.
 */

/**
 * @cfg {String} showOn A handle indication, how to show the datepicker. Supported handles: 'focus', 'button', 'both' (button and focus) or 'inline'.
 */

/**
 * @cfg {Integer,String} showOn A duration for show and hide effect. [look at jQuery.show() or jQuery.hide() for supported durations].
 */

/**
 * @cfg {String} show One off the supported show effects: 'show', 'fadeIn' or 'slideIn'.
 */

/**
 * @cfg {String} hide One off the supported hide effects: 'hide', 'fadeOut' or 'slideOut'.
 */

/**
 * @cfg {Array} weekDaysAvailable An array of 7 weekdays with indications wether a day is available. Week starts on sunday.
 */

/**
 * @cfg {Integer} numberOfMonths Set how many months to show at once.
 */

/**
 * @cfg {Boolean} showOtherMonth Display dates in other months (non-selectable) at the start or end of the current month. To make these days selectable use selectOtherMonths.
 */

/**
 * @cfg {Boolean} selectOtherMonth When true days in other months shown before or after the current month are selectable. This only applies if showOtherMonths is also true.
 */

/**
 * @cfg {Boolean} changeMonth Allows you to change the month by selecting from a drop-down list. You can enable this feature by setting the attribute to true.
 */

/**
 * @cfg {Boolean} changeYear Allows you to change the year by selecting from a drop-down list. You can enable this feature by setting the attribute to true. Use the yearRange option to control which years are made available for selection.
 */

/**
 * @cfg {Boolean} time Allows you to select time also. Requires a format which support time.
 */

/**
 * @cfg {Boolean} timeStep A difference to next/previous step in minutes.
 */

/**
 * See `jQuery.ui.uiDatepicker` for details.
 * 
 * @param {Object} [options] A map of additional options pass to the method.
 * @param {String} type The value respectively validation type must be 'date'.
 * @param {String} format A date formatter [look at the jQuery.i18n plugin].
 * @param {Integer} min A local timestamp (not UTC) as minimum valid date.
 * @param {Integer} max A local timestamp (not UTC) as maximum valid date.
 * @param {String} showOn A handle indication, how to show the datepicker. Supported handles: 'focus', 'button', 'both' (button and focus) or 'inline'.
 * @param {Integer,String} showOn A duration for show and hide effect. [look at jQuery.show() or jQuery.hide() for supported durations].
 * @param {String} show One off the supported show effects: 'show', 'fadeIn' or 'slideIn'.
 * @param {String} hide One off the supported hide effects: 'hide', 'fadeOut' or 'slideOut'.
 * @param {Array} weekDaysAvailable An array of 7 weekdays with indications wether a day is available. Week starts on sunday.
 * @param {Integer} numberOfMonths Set how many months to show at once.
 * @param {Boolean} showOtherMonth Display dates in other months (non-selectable) at the start or end of the current month. To make these days selectable use selectOtherMonths.
 * @param {Boolean} selectOtherMonth When true days in other months shown before or after the current month are selectable. This only applies if showOtherMonths is also true.
 * @param {Boolean} changeMonth Allows you to change the month by selecting from a drop-down list. You can enable this feature by setting the attribute to true.
 * @param {Boolean} changeYear Allows you to change the year by selecting from a drop-down list. You can enable this feature by setting the attribute to true. Use the yearRange option to control which years are made available for selection.
 * @param {Boolean} time Allows you to select time also. Requires a format which support time.
 * @param {Boolean} timeStep A difference to next/previous step in minutes.
 * 
 * @method uiDatepicker
 * @member jQuery
 * 
 * @since 6.11.0
 */

/*
 * @copyright		© Copyright 2006-2010, epages GmbH, All Rights Reserved.
 *
 * @module			ep.ui.datepicker
 *
 * @revision		$Revision: 1.7.2.3 $
 */

define("ep/ui/datepicker", [
	"jquery",
	"ep",
	"$dict!ep/dict",
	"$tmpl!ep/ui/datepicker",

	"ep/date",
	"ep/sprite",
	"ep/fn/busy",
	"ep/ui/spinner"
], function ($, ep, epDict, tmplDatepicker) {

/*
 * @dictionary		ep.dict
 *
 * @translation		{Today}
 *					{Done}
 */

	$.widget('ui.uiDatepicker',$.ui.uiValidate,{

		options: {
	// ep.ui.Input
		//	big:				true,
		//	autofocus:			false,
		//	placeholder:		'text',
		//	info:				'text',

	// ep.ui.Validate
		//	accept:				'',
		//	min:				1,
		//	max:				20,
		//	minlength:			1,
		//	maxlength:			4,
		//	pattern:			[\w]+,
		//	required:			true,
		//	valid:				true,
		//	type:				'basic',
		//	format:				'',

	// ep.ui.Datepicker
		//	onAfterSetValue:	undefined					// callback called after value was set
			type:				'date',
			format:				'l',						// format for i18n
			showOn:				'button',					// show datepicker on 'focus' || 'button' || 'both' or 'inline'
			duration:			'normal',					// duration for show and hide effect
			show:				'fadeIn',					// show effect 'show' || 'fadeIn' || 'slideIn'
			hide:				'fadeOut',					// hide effect 'hide' || 'fadeOut' || 'slideOut'
			weekDaysAvailable:	[1,1,1,1,1,1,1],			// which days ar avaible boolean in array
			numberOfMonths:		1,							// display number of month
			showOtherMonth:		true,						// show days from other month
			selectOtherMonth:	false,						// days from other month ar clickable
			changeMonth:		true,						// enable select month
			changeYear:			true,						// enable select year
			region:				$.i18n.settings.region,		// region for i18n
			time:				true,						// use as date and time picker
			timeStep:			15,							// step for time spinner in minutes
			min:				undefined,					// min for range miliseconds || dateObj
			max:				undefined					// max for range miliseconds || dateObj
		},

		_create: function(){
			this._superApply(arguments);

			// get instance of dict
			this.dict = epDict;

			var currentDate = this.options.currentDate,
				date;

			date = currentDate ? new ep.Date(currentDate.year, currentDate.month, currentDate.day) : new ep.Date();
			date
				.setMinutes(30)
				.setSeconds(0)
				.setMilliseconds(0);

			this._date =			date.clone().setHours(0,0,0,0);
			this._dateNow =			this._date.clone();
			this._dateSelected =	this._date.clone();
			this._timeSelected =	date.clone().setFullYear(0,0,0);

			this.domCache = $('<div>');
			this.cal = $.i18n.regions[ this.options.region ].calendar;

			this.elem.on( 'changeValue.uiDatepicker', $.proxy(this, '_changeElemVal') );

			this.showButton = $('<span>')
				.attr({
					'class':	'ep-uiInput ep-uiInput-base ep-uiInput-button ep-uiDatepicker-showButton'
				})
				.html(
					ep.sprite('calendar','s').addClass('ep-uiInput-buttonSpriteOnly')
				)
				.on( 'click.uiDatepicker', $.proxy(this, 'show') )
				.appendTo( this.domCache );

			this.stack.push( this.domCache[0], this.showButton[0] );

			this._changeElemVal();
		},

		_init: function(){
			this._superApply(arguments);

			var o = this.options;

			if( (/^(focus|both)$/).test(o.showOn) ){
				this.elem
					.off('focus.uiDatepicker')
					.on( 'focus.uiDatepicker', $.proxy(this, 'show') );
			}
			if( (/^(button|both)$/).test(o.showOn) ){
				this.showButton
					.insertAfter( this.placeholder || this.elem );
			}
			else{
				this.showButton
					.appendTo( this.domCache );
			}

			if( this.container ){
				this._initCalCache();

				if( o.time && !this.timeBar ){
					this._createTimeBar();
				}
			}

			this._tooltipInit();

			if( o.showOn === 'inline' ){
				this.show();
			}
		},

		_initCalCache: function(){
			this._calCache = {
				weekDays: arrayRotate( $.merge([],this.cal.days.namesShort), this.cal.firstDay),
				months: $.merge([],this.cal.months.names)
			};
		},

		_tooltipInit: function(){
			this._superApply(arguments);
			if( this.tooltip && (/^(button|both)$/).test(this.options.showOn) ){
				this.tooltip.uiTooltip( 'option', 'offsetAdjust', [30,-1] );
			}
			else if( this.tooltip ){
				this.tooltip.uiTooltip( 'option', 'offsetAdjust', [3,-2] );
			}
		},

		_createBase: function(){
			var self = this;
			// the datepicker
			this.container = ep('<form>')
				.addClass('epDialog ep-uiDatepicker-container ui-dialog ui-front')
				.hide();
			// go to previous month
			this.prevButton = ep('<button type="button">')
				.append( ep.sprite('arrow-l','s').addClass('ep-uiInput-buttonSpriteOnly') )
				.addClass('ep-uiDatepicker-prev')
				.on( 'click.uiDatepicker', function(){
					self._changeMonth(-1);
				});
			// go to next month
			this.nextButton = ep('<button type="button">')
				.append( ep.sprite('arrow-r','s').addClass('ep-uiInput-buttonSpriteOnly') )
				.addClass('ep-uiDatepicker-next')
				.on( 'click.uiDatepicker', function(){
					self._changeMonth(1);
				});
			// bar on the bottom
			this.buttonBar = $('<div>')
				.addClass('ep-uiDatepicker-buttonBar')
				.appendTo( this.container );
			// select the current day
			this.todayButton = ep('<button type="button">')
				.text( this.dict.translate('Today') )
				.appendTo( this.buttonBar )
				.addClass('ep-uiDatepicker-today')
				.on( 'click.uiDatepicker', function(){
					self._date = self._dateNow.clone().setHours(0,0,0,0);
					self._changeDay( self._date.getTime() );
					self._createCalendars();
				});
			// close the datepicker
			this.doneButton = ep('<button type="button">')
				.text( this.dict.translate('Done') )
				.appendTo( this.buttonBar )
				.addClass('ep-uiDatepicker-done')
				.on( 'click.uiDatepicker', $.proxy(this, 'hide') );
			// live click handler to select a day on click
			this.container
				.on( 'click', 'a.ep-uiDatepicker-dayClick', $.proxy(this, '_selectDay') )
				.on( 'change', 'select.ep-uiDatepicker-monthSelect,select.ep-uiDatepicker-yearSelect', function(){
					self._changeMonth(parseInt(this.value,10));
				});
			// stack for calendars
			this.calendars = $();
			// reinit
			this._init();
			// add to DOM
			this.container.appendTo('body');
			// save in stack
			this.stack.push(
				this.container[0],
				this.prevButton[0],
				this.nextButton[0],
				this.doneButton[0],
				this.todayButton[0],
				this.buttonBar[0]
			);
		},

		_createTimeBar: function(){
			this.timeBar = $('<div>')
				.addClass('ep-uiDatepicker-timeBar')
				.insertBefore( this.buttonBar );

			this.stack.push( this.timeBar[0] );

			this._createTimeSelect();
		},

		_createTimeSelect: function(){
			this.timeSelect = ep('<input>')
				.attr({
					'class': 'epWidth100',
					'placeholder': '00:00'
				})
				.appendTo( this.timeBar )
				.uiSpinner({
					type:		'date',
					step:		15,
					stepType:	'minutes',
					format:		't',
					region:		this.options.region
				})
				.uiInput('addClass','ep-uiDatepicker-time')
				.on( 'changeValue.uiDatepicker', $.proxy(this, '_changeTimeVal') );

			this._setTimeVal();

			this.stack.push( this.timeSelect[0]	);
		},

		_createCalendars: function(){
			// set busy layer
			this.container.busy('show');
			// vars
			var o				= this.options,
				calendarsData	= this._calendarData(),
				calendars;
			// build weeks
			$.each( calendarsData, function( i, calendarData){
				while( calendarData.days.length >= 7 ){
					calendarData.weeks.push({days:calendarData.days.splice(0,7)});
				}
			});
			// build calendars
			calendars = tmplDatepicker(calendarsData);
			calendars
				.not(':first,:last')
				.addClass('ep-uiDatepicker-calendarMiddle');
			calendars
				.not(':last')
				.first()
				.addClass('ep-uiDatepicker-calendarFirst');
			calendars
				.not(':first')
				.last()
				.addClass('ep-uiDatepicker-calendarLast');
			// place prev button to new calendars and handle range
			this.prevButton
				.attr( 'disabled', !inRange( o.min, this._date.clone().setFirstMonthDay().setHours(0,0,0,-1).getTime() ) )
				.prependTo( calendars.filter(':first').find('.ep-uiDatepicker-titleBar') );
			// place next button to new calendars and handle range
			this.nextButton
				.attr( 'disabled', !inRange( undefined, this._date.clone().setLastMonthDay().setHours(0,0,0,0).addDate(1).getTime(), o.max ) )
				.appendTo( calendars.filter(':last').find('.ep-uiDatepicker-titleBar') );
			// remove old calendars
			this.calendars
				.html('')
				.remove();
			// show new calendars in datepicker
			this.container.prepend(calendars)
				.busy('hide');
			// set new calendars
			this.calendars = calendars;
		},

		_calendarData: function(){
			var o				= this.options,
				baseDate		= this._date.clone().addMonth( - Math.ceil(o.numberOfMonths/2) ),
				nowTime			= this._dateNow.getTime(),
				selectedTime	= this._dateSelected.getTime(),
				region			= {region: this.options.region},
				baseMonth		= this._date.getMonth(),
				changeMonth		= null,
				changeYear		= null,
				data			= [],
				i;

			if( o.changeMonth ){
				changeMonth = [];
				$.each( this._calCache.months, function( i, name ){
					if( name ){
						changeMonth.push({ value: (baseMonth-i)*-1, name: name, currentMonth: baseMonth===i });
					}
				});
			}

			if( o.changeYear ){
				var yDate = this._date.clone();

				changeYear = [{ value: 0, name: yDate.getFormat( "yyyy", region ), currentYear: true }];

				for( i=1 ; i<=10 ; i++ ){
					yDate.addFullYear(-1);
					changeYear.unshift({ value: i*-12, name: yDate.getFormat( "yyyy", region ), currentYear: false });
				}
				yDate.addFullYear(10);
				for( i=1 ; i<=10 ; i++ ){
					yDate.addFullYear(1);
					changeYear.push({ value: i*12, name: yDate.getFormat( "yyyy", region ), currentYear: false });
				}
			}

			for( i=0,iLength=o.numberOfMonths ; i<iLength ; i++ ){
				var date =			baseDate.addMonth(1),
					iDate =			date.clone().setDate(0),
					iFirstDate =	date.clone().setFirstMonthDay(),
					iFirstTime =	iFirstDate.getTime(),
					iLastTime =		date.clone().setLastMonthDay().getTime(),
					iDays =			iFirstDate.getMonthLength(),
					iWeekDay =		iFirstDate.getDay() - this.cal.firstDay,
					add =			{
										year:		iFirstDate.getFormat( "yyyy", region ),
										years:		changeYear,
										month:		iFirstDate.getFormat( "MMMM", region ),
										months:		changeMonth,
										weekDays:	this._calCache.weekDays,
										weeks:		[],
										days:		[]
									};

				if( iWeekDay<0 ){
					iWeekDay = iWeekDay+7;
				}

				iDate.addDate( - iWeekDay );

				for( var j=1,jLength=(Math.ceil( (iWeekDay+iDays) / 7) * 7 ) ; j<=jLength ; j++ ){
					var jDate =			iDate.addDate(1),
						jTime =			jDate.getTime(),
						currentMonth =	inRange( iFirstTime, jTime, iLastTime ),
						clickable =		inRange( o.min, jTime, o.max ) && o.weekDaysAvailable[ jDate.getDay() ];

					add.days.push({
						'date':				jDate.clone(),
						'tstamp':			jTime,
						'day':				jDate.getDate(),
						'currentMonth':		!!currentMonth,
						'clickable':		(currentMonth || o.selectOtherMonth) && clickable,
						'visible':			!!(currentMonth || o.selectOtherMonth || o.showOtherMonth),
						'selected':			jTime===selectedTime,
						'now':				jTime===nowTime
					});
				}

				data.push(add);
			}

			return data;
		},

		_setElemVal: function( noBubbling ){
			var val = new ep.Date(
							this._dateSelected.getFullYear(),
							this._dateSelected.getMonth(),
							this._dateSelected.getDate(),
							isNaN(this._timeSelected.getHours()) ? 0 : this._timeSelected.getHours(),
							isNaN(this._timeSelected.getMinutes()) ? 0 : this._timeSelected.getMinutes(),
							isNaN(this._timeSelected.getSeconds()) ? 0 : this._timeSelected.getSeconds()
						)
						.getFormat(
							this.options.format,
							{region:this.options.region}
						);

			if( noBubbling ){
				this.elem.val( val );
			}
			else{
				this.elem.attr( 'value', val );
			}

			// callback called after value was set
			if(this.options.onAfterSetValue !== undefined){
				this.options.onAfterSetValue(this.elem);
			}
		},

		_getElemVal: function(){
			var date = $.i18n.parseDate( this.elem.val(), this.options.format, {region:this.options.region} );
			return date ? new ep.Date( date.getTime() ) : null;
		},

		_changeElemVal: function(){
			var o = this.options,
				date = this._getElemVal();

			if( date && inRange( o.min, date.clone().setLastMonthDay().getTime() ) && inRange( undefined, date.clone().setFirstMonthDay().getTime(), o.max ) ){
				if( this.elem.is(':focus') ){
					this._date = date.clone().setHours(0,0,0,0);
				}
				this._dateSelected = date.clone().setHours(0,0,0,0);
				this._timeSelected = date.clone().setFullYear(0,0,0);

				if( this.timeSelect ){
					this._setTimeVal();
				}
			}
			if( this.container && this.container.filter(':visible').length ){
				this._createCalendars();
			}
		},

		_setTimeVal: function(){
			if( !this.timeSelect.is(':focus') ){
				this.timeSelect.val( this._timeSelected.getFormat( 't', {region:this.options.region} ) );
			}
		},

		_getTimeVal: function(){
			var date = $.i18n.parseDate( this.timeSelect.val(), 't', {region:this.options.region} );
			return date ? new ep.Date( date.getTime() ) : null;
		},

		_changeTimeVal: function(event){
			var date = this._getTimeVal();

			if( date ){
				this._timeSelected = date.setFullYear(0,0,0);
				this._setElemVal();
			}
		},

		_changeMonth: function( inc ){
			this._date.addMonth(inc);
			this._createCalendars();
		},

		_changeDay: function( tstamp ){
			this._dateSelected = new ep.Date(tstamp);
			this._setElemVal();
		},

		_selectDay: function( event ){
			this._changeDay( parseInt( $(event.target).attr('data-tstamp'), 10 ) );
		},

		_show: function(){
			var o = this.options;

			if( o.showOn !== 'inline' ){
				this.container.contextOrientation( this.elem, 'bottom', [-1,1] ).focus();
				this.container
					.stop(true,true)
					[ $.fn[o.show] ? o.show : 'show' ](o.duration);

				$('html').on( 'keyup', $.proxy(this,'_hide') );
			}
			else{
				this.buttonBar
					.hide();
				this.container
					.insertAfter(this.elem)
					.css('position','relative')
					.show();
			}
			this.elem.blur();
		},

		show: function(){
			var self = this;

			if( this.elem.is(":disabled") ){
				return;
			}
			if( !this.container ){
				this._createBase();
			}

			this._show();
			this._changeElemVal();
			this._setValidStatus(true);
		},

		_hide: function( event ){
			if( event.keyCode===27 ){
				this.hide();
				this._validate(event);
			}
		},

		hide: function(){
			var o = this.options;

			if( o.showOn !== 'inline' ){
				this.container
					.stop(true,true)
					[ $.fn[o.hide] ? o.hide : 'hide' ](o.duration);

				$('html').off( 'keyup', $.proxy(this,'_hide') );
			}
		},

		/**
		 * Returns the current date for the datepicker as `ep.Date()` object.
		 * 
		 * @method getDate
		 * @member jQuery.ui.uiDatepicker
		 * 
		 * @since 6.11.0
		 */
		getDate: function(){
			return new ep.Date(
							this._dateSelected.getFullYear(),
							this._dateSelected.getMonth(),
							this._dateSelected.getDate(),
							this._timeSelected.getHours(),
							this._timeSelected.getMinutes(),
							this._timeSelected.getSeconds()
						);
		}
	});

	var arrayRotate = function( array, size ){
			var tmp = array.splice( 0, size );

			return array.concat( tmp );
		},

		inRange = function( min, val, max ){
			min = new ep.Date(typeof min === 'object' && min.getTime ? min.getTime() : min).setHours(0,0,0,0).getTime();
			max = new ep.Date(typeof max === 'object' && max.getTime ? max.getTime() : max).setHours(0,0,0,0).getTime();
			return !min || val >= min ? !max || val <= max ? true : false : false;
		};

	return ep;

});

/* ---- Module:ep.canvas ---- */

/**
 * Create a HTML5 canvas element.
 * 
 * The `ep.canvas()` function creates canvas elements which also work in older browsers without
 * native canvas support (like the Internet Explorer 7 and 8). Therefor the excanvas and canvastext
 * plugins are used.
 * 
 * The plugin offers the default methods and attributes from the canvas api and a multiline text drawing
 * method.
 * 
 * ### Examples
 * Create a canvas and draw on it
 * 
 * JavaScript:
 * 
 *     $('<canvas />')
 *       .appendTo('body')
 *       .canvas()
 *         .fillStyle('#4E8DA6')
 *         .fillRect(10, 10, 200, 100)
 *         .strokeStyle('#F2EA79')
 *         .lineWidth(5)
 *         .lineJoin('round')
 *         .strokeRect(10, 10, 200, 100)
 *         .fillStyle('#011C40')
 *         .multiline({
 *            x: 40,
 *            y: 40,
 *            phi: 15,
 *            text: "Hello World",
 *            fontSize: 22,
 *            fontFamily: "Arial",
 *            align: 'center',
 *            delimiter: "\n",
 *            rp: 'c',
 *            style: 'fillText'
 *         });
 * 
 * 
 * @class jQuery.canvas
 * 
 * @uses jQuery.canvas.excanvas
 * @uses jQuery.canvas.canvastext
 * @since 6.14.0
 */

/**
 * Setter and getter method to define the fill color or style of a shape or text.
 * 
 * Possible color formats:
 * - color name as string
 * - rgb(a)
 * - hex
 * 
 * @param {Color, Style} [value] A value to define the color or style.
 * 
 * @method fillStyle
 * @member jQuery.canvas
 * 
 * @since 6.14.0
 */

/**
 * Setter and getter method to define the stroke color or style of a shape or text.
 * 
 * Possible color formats:
 * - color name as string
 * - rgb(a)
 * - hex
 * 
 * @param {Color, Style} [value] A value to define the color or style.
 * 
 * @method strokeStyle
 * @member jQuery.canvas
 * 
 * @since 6.14.0
 */

/**
 * Setter and getter method to define the width of a stroke.
 * 
 * @param {Float} [value] The width of the stroke being drawed.
 * 
 * @method lineWidth
 * @member jQuery.canvas
 * 
 * @since 6.14.0
 */

/**
 * Setter and getter method to define the style of the ending of a line.
 * 
 * @param {String} [value] The style of the ending of the line (possible values: butt, round, square).
 * 
 * @method lineCap
 * @member jQuery.canvas
 * 
 * @since 6.14.0
 */

/**
 * Setter and getter method to define the style of the corners of a line.
 * 
 * @param {String} [value] The style of the corners of the line (possible values: bevel, round,  miter).
 * 
 * @method lineJoin
 * @member jQuery.canvas
 * 
 * @since 6.14.0
 */

/**
 * Setter and getter method to define the transparency of a drawing.
 * 
 * @param {Integer} [value] The value of the transparency.
 * 
 * @method globalAlpha
 * @member jQuery.canvas
 * 
 * @since 6.14.0
 */

/**
 * Setter and getter method to define how shapes and drawings are positioned onto the canvas.
 * 
 * @param {String} [value] The position on the canvas (possible values: source-atop, source-in, source-out,source-over, destination-atop, destination-in, destination-out, destination-over, lighter, copy, xor,vendorName-operationName) .
 * 
 * @method globalCompositeOperation
 * @member jQuery.canvas
 * 
 * @since 6.14.0
 */

/**
 * Setter and getter method to define the horizontal distance of a shadow.
 * 
 * @param {Integer} [value] The horizontal distance of the shadow.
 * 
 * @method shadowOffsetX
 * @member jQuery.canvas
 * 
 * @since 6.14.0
 */

/**
 * Setter and getter method to define the vertical distance of a shadow.
 * 
 * @param {Integer} [value] The vertical distance of the shadow.
 * 
 * @method shadowOffsetY
 * @member jQuery.canvas
 * 
 * @since 6.14.0
 */

/**
 * Setter and getter method to define the size of the blurring effect.
 * 
 * @param {Integer} [value] The size of the blurring effect.
 * 
 * @method shadowBlur
 * @member jQuery.canvas
 * 
 * @since 6.14.0
 */

/**
 * Setter and getter method to define the color of a shadow.
 * 
 * @param {Color} [value] The color of the shadow.
 * 
 * @method shadowColor
 * @member jQuery.canvas
 * 
 * @since 6.14.0
 */

/**
 * Setter and getter method to define the limit size of the corners in a line.
 * 
 * @param {Integer} [value] The limit size of the corners in a line.
 * 
 * @method miterLimit
 * @member jQuery.canvas
 * 
 * @since 6.14.0
 */

/**
 * Setter and getter method to define the font properties used for writing on the canvas.
 * 
 * @param {String} [value] The font properties used for writing on the canvas.
 * 
 * @method font
 * @member jQuery.canvas
 * 
 * @since 6.14.0
 */

/**
 * Draws a filled rectangle using the color/style of the fillStyle attribute.
 * 
 * @param {Float} x The x-coordinate of where to place the upperleft corner of the rectangle.
 * @param {Float} y The y-coordinate of where to place the upperleft corner of the rectangle.
 * @param {Float} width The width of the rectangle, in pixels.
 * @param {Float} height The height of the rectangle, in pixels.
 * 
 * @method fillRect
 * @member jQuery.canvas
 * 
 * @since 6.14.0
 */

/**
 * Draws the lines of a rectangle using the color/style of the strokeStyle attribute.
 * 
 * @param {Float} x The x-coordinate of where to place the upperleft corner of the rectangle.
 * @param {Float} y The y-coordinate of where to place the upperleft corner of the rectangle.
 * @param {Float} width The width of the rectangle, in pixels.
 * @param {Float} height The height of the rectangle, in pixels.
 * 
 * @method strokeRect
 * @member jQuery.canvas
 * 
 * @since 6.14.0
 */

/**
 * Clears a rectangle area. All pixels inside this area will be erased.
 * 
 * @param {Float} x The x-coordinate of where to place the upperleft corner of the rectangle.
 * @param {Float} y The y-coordinate of where to place the upperleft corner of the rectangle.
 * @param {Float} width The width of the rectangle, in pixels.
 * @param {Float} height The height of the rectangle, in pixels.
 * 
 * @method clearRect
 * @member jQuery.canvas
 * 
 * @since 6.14.0
 */

/**
 * Draws an image onto the canvas.
 * 
 * @param {Image, Video, Canvas} img The image object to use in the drawing.
 * @param {Float} x The x coordinate of where to position the top-left corner of the image.
 * @param {Float} y The y coordinate of where to position the top-left corner of the image.
 * @param {Float} [width] The width of the drawing (image), in pixels.
 * @param {Float} [height] The height of the drawing (image), in pixels.
 * @param {Float} [dx] The x coordinate of where to position the clipped part of the image.
 * @param {Float} [dy] The y coordinate of where to position the clipped part of the image.
 * @param {Float} [dwidth] The width of the clipped part of the image, in pixels.
 * @param {Float} [dheight] The height of the clipped part of the image, in pixels.
 * 
 * @method drawImage
 * @member jQuery.canvas
 * 
 * @since 6.14.0
 */

/**
 * Draws text on the canvas and fills it with the color set by the fillStyle attribute.
 * 
 * @param {String} text The text that will be written on the canvas.
 * @param {Float} x The canvas' x-coordinate of where to place the text.
 * @param {Float} y The canvas' y-coordinate of where to place the text.
 * @param {Float} [maxWidth] The maximum allowed width of the text, in pixels.
 * 
 * @method fillText
 * @member jQuery.canvas
 * 
 * @since 6.14.0
 */

/**
 * Draws text on the canvas, without filling, using the color set by the strokeStyle attribute.
 * 
 * @param {String} text The text that will be written on the canvas.
 * @param {Float} x The canvas' x-coordinate of where to place the text.
 * @param {Float} y The canvas' y-coordinate of where to place the text.
 * @param {Float} [maxWidth] The maximum allowed width of the text, in pixels.
 * 
 * @method strokeText
 * @member jQuery.canvas
 * 
 * @since 6.14.0
 */

/**
 * Measures the given text string, returns the result in pixels.
 * 
 * @param {String} text The text that will be measured.
 * 
 * @method measureText
 * @member jQuery.canvas
 * 
 * @since 6.14.0
 */

/**
 * Rotates the drawings based on the given angle.
 * 
 * @param {Float} angle The value of the angle in degree.
 * 
 * @method rotate
 * @member jQuery.canvas
 * 
 * @since 6.14.0
 */

/**
 * Scales the drawings based on the x and y parameters.
 * 
 * @param {Float} x The scaling factor of the the width.
 * @param {Float} y The scaling factor of the the height.
 * 
 * @method scale
 * @member jQuery.canvas
 * 
 * @since 6.14.0
 */

/**
 * Moves the drawings horizontally and vertically.
 * 
 * @param {Float} x Moves the canvas horizontally to the given coordinate.
 * @param {Float} y Moves the canvas vertically to the given coordinate.
 * 
 * @method translate
 * @member jQuery.canvas
 * 
 * @since 6.14.0
 */

/**
 * Pushes the current state onto the stack.
 * 
 * @method save
 * @member jQuery.canvas
 * 
 * @since 6.14.0
 */

/**
 * Pops the top state on the stack, restoring the context to that state.
 * 
 * @method restore
 * @member jQuery.canvas
 * 
 * @since 6.14.0
 */

/**
 * Creates a gradient object. Use this object as a value to the strokeStyle or fillStyle attributes.
 * 
 * @param {Float} x0 The x-coordinate of the start of the gradient.
 * @param {Float} y0 The y-coordinate of the start of the gradient.
 * @param {Float} x1 The x-coordinate of the end of the gradient.
 * @param {Float} y1 The y-coordinate of the end of the gradient.
 * 
 * @method createLinearGradient
 * @member jQuery.canvas
 * 
 * @since 6.14.0
 */

/**
 * Creates a gradient object as a circle. Use this object as a value to the strokeStyle or fillStyle attributes.
 * 
 * @param {Float} x0 The x-coordinate of the start of the gradient.
 * @param {Float} y0 The y-coordinate of the start of the gradient.
 * @param {Float} r0 The radius of the start-circle of the gradient.
 * @param {Float} x1 The x-coordinate of the end of the gradient.
 * @param {Float} y1 The y-coordinate of the end of the gradient.
 * @param {Float} r1 The radius of the start-circle of the gradient.
 * 
 * @method createRadialGradient
 * @member jQuery.canvas
 * 
 * @since 6.14.0
 */

/**
 * Creates a pattern from an image to be used by the fillStyle or strokeStyle attributes.
 * 
 * @param {Image} img The image object to use when creating the pattern.
 * @param {String} repeat Describes how the pattern will be repeated (possible values: repeat, repeat-x, repeat-y, no-repeat).
 * 
 * @method createPattern
 * @member jQuery.canvas
 * 
 * @since 6.14.0
 */

/**
 * Creates a new imagedata object, containing data from the canvas.
 * 
 * @param {Float} x The x coordinate, in the canvas, of the rectangle-area you will get.
 * @param {Float} y The y coordinate, in the canvas, of the rectangle-area you will get.
 * @param {Float} width The width of the rectangle-area you will get.
 * @param {Float} height The height of the rectangle-area you will get.
 * 
 * @method getImageData
 * @member jQuery.canvas
 * 
 * @since 6.14.0
 */

/**
 * Draws imagedata onto the canvas.
 * 
 * @param {Image} imgData The imagedata object to put on the canvas.
 * @param {Float} x The x coordinate, in the canvas, of where to put the drawings.
 * @param {Float} y The y coordinate, in the canvas, of where to put the drawings.
 * @param {Float} dirtyX The x coordinate, of the drawings you want to put onto the canvas.
 * @param {Float} dirtyY The y coordinate, of the drawings you want to put onto the canvas.
 * @param {Float} dirtyWidth The width of the drawings you want to put onto the canvas.
 * @param {Float} dirtyHeight The height of the drawings you want to put onto the canvas.
 * 
 * @method putImageData
 * @member jQuery.canvas
 * 
 * @since 6.14.0
 */

/**
 * Creates a circle, or parts of a circle.
 * 
 * @param {Float} x The x-coordinate of the center of the circle.
 * @param {Float} y The y-coordinate of the center of the circle.
 * @param {Image} r The radius of the circle.
 * @param {Float} sAngle Specifies where in the circle's angle the drawing should start.
 * @param {Float} eAngle Specifies where in the circle's angle the drawing should end.
 * @param {Boolean} [clockwise] Specifies whether the drawing should be clockwise or not.
 * 
 * @method arc
 * @member jQuery.canvas
 * 
 * @since 6.14.0
 */

/**
 * Creates an arc between two points.
 * 
 * @param {Float} x1 The x-coordinate of the beginning of the arc.
 * @param {Float} y1 The y-coordinate of the beginning of the arc.
 * @param {Float} x2 The x-coordinate of the end of the arc.
 * @param {Float} y2 The y-coordinate of the end of the arc.
 * @param {Float} r The radius of the arc.
 * 
 * @method arcTo
 * @member jQuery.canvas
 * 
 * @since 6.14.0
 */

/**
 * Starts a new path, or clears the current path.
 * 
 * @method beginPath
 * @member jQuery.canvas
 * 
 * @since 6.14.0
 */

/**
 * Creates a cubic Bezier curve from the current point in the path to the specified path.
 * 
 * @param {Float} x1 The x-coordinate of the first controlpoint.
 * @param {Float} y1 The y-coordinate of the first controlpoint.
 * @param {Float} x2 The x-coordinate of the second controlpoint.
 * @param {Float} y2 The y-coordinate of the second controlpoint.
 * @param {Float} x The x-coordinate of where to create the line to.
 * @param {Float} y The y-coordinate of where to create the line to.
 * 
 * @method bezierCurveTo
 * @member jQuery.canvas
 * 
 * @since 6.14.0
 */

/**
 * Creates an area in the canvas, and this area is the only visible area in the canvas.
 * 
 * @method clip
 * @member jQuery.canvas
 * 
 * @since 6.14.0
 */

/**
 * Creates a line (path) from the last point in the path, to the first point. Completes the path.
 * 
 * @method closePath
 * @member jQuery.canvas
 * 
 * @since 6.14.0
 */

/**
 * Fills the current path with the selected colorh.
 * 
 * @method fill
 * @member jQuery.canvas
 * 
 * @since 6.14.0
 */

/**
 * Returns a Boolean value, `true` if the specified point is in the path, otherwise `false`.
 * 
 * @param {Float} x The x-coordinate of the point.
 * @param {Float} y The y-coordinate of the point.
 * 
 * @method isPointInPath
 * @member jQuery.canvas
 * 
 * @since 6.14.0
 */

/**
 * Creates a line from the last point in the path to the given point.
 * 
 * @param {Float} x The x-coordinate of where to create the line to.
 * @param {Float} y The y-coordinate of where to create the line to.
 * 
 * @method lineTo
 * @member jQuery.canvas
 * 
 * @since 6.14.0
 */

/**
 * Moves the path to the specified point, without creating a line.
 * 
 * @param {Float} x The x-coordinate of where to move the path to.
 * @param {Float} y The y-coordinate of where to move the path to.
 * 
 * @method moveTo
 * @member jQuery.canvas
 * 
 * @since 6.14.0
 */

/**
 * Creates a quadratic Bezier curve from the current point in the path to the specified path.
 * 
 * @param {Float} cpx The x-coordinate of the controlpoint.
 * @param {Float} cpy The y-coordinate of the controlpoint.
 * @param {Float} x The x-coordinate of where to create the line to.
 * @param {Float} y The y-coordinate of where to create the line to.
 * 
 * @method quadraticCurveTo
 * @member jQuery.canvas
 * 
 * @since 6.14.0
 */

/**
 * Creates a rectangle.
 * 
 * @param {Float} x The canvas' x-coordinate of where to place the upperleft corner of the rectangle.
 * @param {Float} y The canvas' y-coordinate of where to place the upperleft corner of the rectangle.
 * @param {Float} width The width of the rectangle, in pixels.
 * @param {Float} height The height of the rectangle, in pixels.
 * 
 * @method rect
 * @member jQuery.canvas
 * 
 * @since 6.14.0
 */

/**
 * Creates a stroke/path described with the specified path methodse.
 * 
 * @method stroke
 * @member jQuery.canvas
 * 
 * @since 6.14.0
 */

/*
 * @copyright   © Copyright 2006-2012, epages GmbH, All Rights Reserved.
 *
 * @module      ep.canvas
 *
 * @base      http://canvas.quaese.de/
 *
 * @revision    $Revision: 1.6.2.2 $
 */

define("ep/canvas", ["jquery", "ep"].concat(this.HTMLCanvasElement ? [] : ["jquery/canvas/excanvas", "jquery/canvas/canvastext"]), function ($, ep) {

	var init = function(canvas){
			//if the context feature don't exist and the IE CanvasManager-Object is available
			if((!canvas.getContext) && (G_vmlCanvasManager !== undefined)){
				canvas = G_vmlCanvasManager.initElement(canvas);
			}

			// if the context feature exists
			if(canvas.getContext){
				canvas.ctx = canvas.getContext('2d');
				return canvas;
			}

			return null;
		},

		degToRad = function(angle){
			return angle * Math.PI/180;
		},

		calcDimensions = function(lineHeight, defaults, ctx){
			var multiLines = defaults.text.split(defaults.delimiter),
					multiObj = {},
					measureWidth = 0,
					newWidth, newHeight;

			// determine the max line width
			for(var i=0, iLen=multiLines.length; i<iLen; i++){
				multiObj[i] = {};
				multiObj[i].width = ctx.measureText(multiLines[i]).width;
				measureWidth = (multiObj[i].width > measureWidth)? multiObj[i].width : measureWidth;
			}

			var arcTan = Math.atan(measureWidth/(lineHeight*multiLines.length)),
					diagonal = Math.sqrt(measureWidth*measureWidth + lineHeight*multiLines.length*lineHeight*multiLines.length),
					newAngle = defaults.phi,
					argument = {};

			if(newAngle > 90 && newAngle < 180 || newAngle > 270 && newAngle < 360){
				argument.x = degToRad(newAngle) - arcTan - degToRad(90);
				argument.y = degToRad(180) - degToRad(newAngle) - arcTan ;
			}else{
				argument.x = degToRad(90) - degToRad(newAngle) - arcTan;
				argument.y = arcTan - degToRad(newAngle);
			}

			newWidth = Math.abs(Math.cos(argument.x) * diagonal);
			newHeight = Math.abs(Math.cos(argument.y) * diagonal);

			return {w: newWidth, h: newHeight, measureWidth: measureWidth, multiLines: multiLines, lineHeight: lineHeight};
		},

		qpCanvas = function(){

		},

		// extend qpCanvas-prototype with own attributes and methods
		// @ this   = canvas-element (collection)
		// @ this.ctx = context (getContext('2d') (collection)
		// @ this[0]  = first canvas-element
		// @ this[0]  = first context (getContext('2d'))
		fn = $.extend(qpCanvas.prototype, {
			length: 0,                      // length property
			push: Array.prototype.push,     // inherit push-method from Array-Object
			each: jQuery.fn.each,           // inherit each-method from JQuery-Object

			end: function(){                // simulate jQuery end-method
				return this.prevObject || $();
			},

			// calculates the dimensions of an multiline text
			// returns an object, containing some useful sizes/dimensions as
			// - w: (float) new width of surrounding canvas,
			// - h: (float) new height of surrounding canvas,
			// - innerW: (float) new width of text element,
			// - innerH: (float) new height of text element,
			// - measureWidth: (float) new width of text element,
			// - multiLines: (array) splitted text,
			// - lineHeight: (float) height of a single line,
			// - scale: (float) scale factor (can be set to a differ value from 1 when resizableCanvas is set to false),
			// - text: (string) text that fits into the maxHeight and maxWidth dimensions,
			// - x: (float) horizontal offset of multiline text in canvas element,
			// - y: (float) vertical offset of multiline text in canvas element
			rescaleDimensions: function(options){
				var defaults = $.extend({
					x: 0,                   // horizontal coordinate
					y: 0,                   // vertical coordinate
					style: 'fillText',      // text method (fillText or strokeText)
					fontSize: 12,           // font size
					fontFamily: 'Arial',    // font family
					fontUnit: 'pt',         // font unit
					phi: 0,                 // rotate angle (in degree)
					delimiter: "\n",        // delimter t o detect new lines
					align: "left",          // text align (left, right, center)
					rp: 'c',                // rotation coordinates: nw, n, ne, w, c (default), e, sw, s, se
					correctLineHeight: 0,   // useful to adjust the lineheight
					minSize: 10,            // minimal size a text can be scaled
					maxWidth: undefined,    // if set to an number, the multitext dimensions will be calculated depending to its borders
					maxHeight: undefined,   // if set to an number, the multitext dimensions will be calculated depending to its borders
					resizeCanvas: false,    // if set to true, the multiline will be trimmed so that it fits into the borders (maxWidth and/or maxHeight)
					resizable: true,        // if set to true font size will be scaled when size of multiline is greater than maxWidth and/or maxHeight and fit into the borders
					text: 'dummy\ndummy'
				}, options);

				// test text method
				defaults.style = (defaults.style.match(/fillText|strokeText/))? defaults.style : 'fillText';

				// set font
				this[0].ctx.save();
				this[0].ctx.font = defaults.fontSize + defaults.fontUnit + " " + defaults.fontFamily;

				// insert temp. div which contains the text
				var isOldIE = ($.browser.msie && parseInt($.browser.version, 10) < 9)? true : false,
						$textElem = $("<div />").html("QjÖ").css({
							'font-size': defaults.fontSize + defaults.fontUnit,
							'line-height': (isOldIE ? '150%' : ''),
							'font-family': defaults.fontFamily,
							'position': 'absolute',
							'left': '-9999px',
							'padding': 0
						});

				$((isOldIE ? 'body' : 'html')).append($textElem);

				var lineHeight = $textElem.height() + defaults.correctLineHeight, // get line-height for one text line
						scale = 1,
						newDimensions = calcDimensions(lineHeight, defaults, this[0].ctx),
						newWidth = newDimensions.w,
						newHeight = newDimensions.h,
						measureWidth = newDimensions.measureWidth,
						multiLines = newDimensions.multiLines,
						newInnerWidth = measureWidth,
						newInnerHeight = lineHeight * multiLines.length;

				// remove temp. text element again
				$textElem.remove();
				this[0].ctx.restore();

				return {
					lineHeight: lineHeight,
					scale: scale,
					newDimensions: newDimensions,
					newWidth: newWidth,
					newHeight: newHeight,
					measureWidth: measureWidth,
					multiLines: multiLines,
					newInnerWidth: newInnerWidth,
					newInnerHeight: newInnerHeight,
					defaults: defaults
				};
			},

			/**
			 * Calculates the size of a text.
			 * 
			 * @param {Float} [x] The canvas' x-coordinate of where to place the text.
			 * @param {Float} [y] The canvas' y-coordinate of where to place the text.
			 * @param {String} text The text that will be written on the canvas.
			 * @param {String} [style] The style of the text that will be written on the canvas (possible values: fillText, strokeText).
			 * @param {Float} [fontSize] The font size the text that will be written on the canvas.
			 * @param {String} [fontFamily] The font family of the text that will be written on the canvas.
			 * @param {String} [fontUnit] The font unit of the text that will be written on the canvas.
			 * @param {Float} [phi] The rotation angle (in degree) of the text that will be written on the canvas.
			 * @param {String} [rp] The point around the text will be rotated (possible values: nw, n, ne, w, c (default), e, sw, s, se).
			 * @param {String} [delimiter] The delimiter used to detect a new line.
			 * @param {String} [align] The text align of the text that will be written on the canvas.
			 * @param {Float} [maxWidth] The maximal width of the text drawing.
			 * @param {Float} [maxHeight] The maximal height of the text drawing.
			 * @param {Boolean} [resizeCanvas] A boolean that defines whether a text will be scaled if the maximum size is reached.
			 * @param {Boolean} [resizable] A boolean that defines whether a text will be trimmed if the maximum size is reached .
			 * @param {Float} [correctLineHeight] An offset to correct the line height.
			 * 
			 * @method calcTextDimensions
			 * @member jQuery.canvas
			 * 
			 * @since 6.14.0
			 */
			calcTextDimensions: function(options){
				this[0].ctx.save();

				var rescaledDimensions = this.rescaleDimensions(options),
						lineHeight = rescaledDimensions.lineHeight,
						scale = rescaledDimensions.scale,
						newDimensions = rescaledDimensions.newDimensions,
						newWidth = newDimensions.w,
						newHeight = newDimensions.h,
						measureWidth = newDimensions.measureWidth,
						multiLines = newDimensions.multiLines,
						newInnerWidth = measureWidth,
						newInnerHeight = lineHeight * multiLines.length,
						defaults = rescaledDimensions.defaults;

				// if multiline text should fit into borders
				if(defaults.maxWidth || defaults.maxHeight){

					if(defaults.resizable){
						var scaleWidth = defaults.maxWidth/newWidth,
							scaleHeight = defaults.maxHeight/newHeight,
							testScale = 1,
							rescaled = false;

						if(defaults.maxWidth && newWidth>defaults.maxWidth){
							testScale = scaleWidth;
						}
						if(defaults.maxHeight && newHeight>defaults.maxHeight){
							testScale = (scaleHeight < scale)? scaleHeight : scale;
						}

						if(testScale*newHeight < defaults.minSize*multiLines.length){
							rescaled = true;
							$.extend(options, {
								fontSize: defaults.fontSize*testScale * (defaults.minSize*multiLines.length)/(testScale*newHeight)
							});

							rescaledDimensions = this.rescaleDimensions(options);
							lineHeight = rescaledDimensions.lineHeight;
							scale = rescaledDimensions.scale;
							newDimensions = rescaledDimensions.newDimensions;
							newWidth = newDimensions.w;
							newHeight = newDimensions.h;
							measureWidth = newDimensions.measureWidth;
							multiLines = newDimensions.multiLines;
							newInnerWidth = measureWidth;
							newInnerHeight = lineHeight * multiLines.length;
							defaults = rescaledDimensions.defaults;
						}
					}

					// if text should be scaled so that it fits into borders (maxWidth & maxHeight)
					if(defaults.resizable && newHeight > defaults.minSize*multiLines.length && !rescaled){
						if(defaults.maxWidth && newWidth>defaults.maxWidth){
							scale = defaults.maxWidth/newWidth;
						}
						if(defaults.maxHeight && newHeight>defaults.maxHeight){
							scale = (defaults.maxHeight/newHeight < scale)? defaults.maxHeight/newHeight : scale;
						}
						defaults.fontSize *= scale;
					// if text should be trimmed so that it fits into borders (maxWidth & maxHeight)
					}else{
						if(defaults.resizeCanvas){

							while(newWidth>=defaults.maxWidth || newHeight>=defaults.maxHeight){
								defaults.text = defaults.text.substr(0, defaults.text.length-1);

								newDimensions = calcDimensions(lineHeight, defaults, this[0].ctx);
								newWidth = newDimensions.w;
								newHeight = newDimensions.h;
							}

							measureWidth = newDimensions.measureWidth;
							multiLines = newDimensions.multiLines;
							newInnerWidth = measureWidth;
							newInnerHeight = lineHeight * multiLines.length;
						}
					}

					newHeight = Math.ceil(scale*newHeight);
					newWidth = Math.ceil(scale*newWidth);
					newInnerHeight = Math.ceil(scale*newInnerHeight);
					newInnerWidth = Math.ceil(scale*newInnerWidth);
				}

				if(defaults.resizeCanvas || defaults.phi !== 0){
					defaults.x = 0.5 * (newWidth - newInnerWidth);
					defaults.y = 0.5 * (newHeight - newInnerHeight);
				}

				this[0].ctx.restore();

				return {
					w: newWidth,
					h: newHeight,
					innerW: newInnerWidth,
					innerH: newInnerHeight,
					measureWidth: measureWidth,
					multiLines: multiLines,
					lineHeight: lineHeight,
					scale: scale,
					text: defaults.text,
					x: defaults.x,
					y: defaults.y,
					fontSize: defaults.fontSize
				};
			},

			// multiline for canvas
			/**
			 * Draws a multiline text onto the selected canvas elements.
			 * 
			 * @param {Float} [x] The canvas' x-coordinate of where to place the text.
			 * @param {Float} [y] The canvas' y-coordinate of where to place the text.
			 * @param {String} text The text that will be written on the canvas.
			 * @param {String} [style] The style of the text that will be written on the canvas (possible values: fillText, strokeText).
			 * @param {Float} [fontSize] The font size the text that will be written on the canvas.
			 * @param {String} [fontFamily] The font family of the text that will be written on the canvas.
			 * @param {String} [fontUnit] The font unit of the text that will be written on the canvas.
			 * @param {Float} [phi] The rotation angle (in degree) of the text that will be written on the canvas.
			 * @param {String} [rp] The point around the text will be rotated (possible values: nw, n, ne, w, c (default), e, sw, s, se).
			 * @param {String} [delimiter] The delimiter used to detect a new line.
			 * @param {String} [align] The text align of the text that will be written on the canvas.
			 * @param {Float} [correctLineHeight] An offset to correct the line height.
			 * 
			 * @method multiline
			 * @member jQuery.canvas
			 * 
			 * @since 6.14.0
			 */
			multiline: function(options){
				var defaults = $.extend({
				x: 0,                   // horizontal coordinate
				y: 0,                   // vertical coordinate
				style: 'fillText',      // text method (fillText or strokeText)
				fontSize: 12,
	//        resizable: true,
				fontFamily: 'Arial',
				fontUnit: 'pt',
				phi: 0,                 // rotate angle (in degree)
				delimiter: "\n",        // delimter to detect new lines
				align: "left",          // text align (left, right, center)
				rp: 'c',                // rotation coordinates: nw, n, ne, w, c (default), e, sw, s, se
	//        maxWidth: undefined,
	//        maxHeight: undefined,
	//        resizeCanvas: false,
				correctLineHeight: 0,
				text: 'default'
				}, options);

				// execute multiline for every element in the jQuery-query
				return this.each(function(){

					// test text method
					defaults.style = (defaults.style.match(/fillText|strokeText/))? defaults.style : 'fillText';

					// set font
					this.ctx.font = defaults.fontSize + defaults.fontUnit + " " + defaults.fontFamily;

					// insert temp. div which contains the text
					var isOldIE = ($.browser.msie && parseInt($.browser.version, 10) < 9)? true : false,
							$textElem = $("<div />").html("QjÖ").css({
								'font-size': defaults.fontSize + defaults.fontUnit,
								'line-height': (isOldIE ? '150%' : ''),
								'font-family': defaults.fontFamily,
								'position': 'absolute',
								'left': '-9999px',
								'padding': 0
							});

					// append text element to body or html element - depending on used user agent
					$((isOldIE ? 'body' : 'html')).append($textElem);

					// get line-height for one text line
					var lineHeight = $textElem.height() + defaults.correctLineHeight,
							newDimensions = calcDimensions(lineHeight, defaults, this.ctx),
							scale = newDimensions.scale,
							newWidth = newDimensions.w,
							newHeight = newDimensions.h,
							measureWidth = newDimensions.measureWidth,
							multiLines = newDimensions.multiLines,
							multiObj = {};

					// remove temp. text element again
					$textElem.remove();

					// save context
					this.ctx.save();

					// determine the max line width
					for(var i=0, iLen=multiLines.length; i<iLen; i++){
						multiObj[i] = {};
						multiObj[i].width = this.ctx.measureText(multiLines[i]).width;
					}

					// move origin to the start coordinate transfered by the parameters x and y
					this.ctx.translate(defaults.x, defaults.y);

					// set font attributes again
					this.ctx.font = defaults.fontSize + defaults.fontUnit + " " + defaults.fontFamily;
					this.ctx.fontSize = defaults.fontSize;
					this.ctx.fontFamily = defaults.fontFamily;
					this.ctx.fontUnit = defaults.fontUnit;
					this.ctx.textBaseline = 'middle'; // top, hanging, middle, alphabetic, ideographic, bottom

					// calculate rotation coorinates
					var rotPoint = {x: 0, y: 0};
					switch(defaults.rp){
						case 'nw':  // north-west
						rotPoint.x = 0;
						rotPoint.y = 0;
						break;
						case 'n':  // north
						rotPoint.x = measureWidth/2;
						rotPoint.y = 0;
						break;
						case 'ne': // north-east
						rotPoint.x = measureWidth;
						rotPoint.y = 0;
						break;
						case 'w':  // west
						rotPoint.x = 0;
						rotPoint.y = lineHeight*multiLines.length/2;
						break;
						case 'c':  // center
						rotPoint.x = measureWidth/2;
						rotPoint.y = lineHeight*multiLines.length/2;
						break;
						case 'e':  // east
						rotPoint.x = measureWidth;
						rotPoint.y = lineHeight*multiLines.length/2;
						break;
						case 'sw': // south-west
						rotPoint.x = 0;
						rotPoint.y = lineHeight*multiLines.length;
						break;
						case 's':  // south
						rotPoint.x = measureWidth/2;
						rotPoint.y = lineHeight*multiLines.length;
						break;
						case 'se': // south-east
						rotPoint.x = measureWidth;
						rotPoint.y = lineHeight*multiLines.length;
						break;
					}

					// move origin to rotation coordinates
					this.ctx.translate(rotPoint.x, rotPoint.y);

					// for debug only: show rotation coordinates
					//this.ctx.fillRect(0, 0, 3, 3);

					// rotate
					this.ctx.rotate(defaults.phi*Math.PI/180);


					// draw multilines
					for(var j=0, jLen=multiLines.length; j<jLen; j++){
						var leftIndent = (defaults.align==="left")
								? 0-rotPoint.x                                          // align left
								: ((defaults.align==="right")
									? (measureWidth-multiObj[j].width-rotPoint.x)         // align right
									: (measureWidth/2-multiObj[j].width/2-rotPoint.x));   // align center

						// draw line in context
						this.ctx[defaults.style](multiLines[j], leftIndent, (j+0.5)*lineHeight-rotPoint.y);
					}

					// restore context
					this.ctx.restore();

				});
			},

			/**
			 * Returns the content of the current canvas as an image. In browsers with no native canvas support it
			 * returns `undefined`.
			 * 
			 * @param {String} type The type of the image that will be generated.
			 * @param {Integer} index The index of the canvas from which the image that will be generated.
			 * 
			 * @method toDataURL
			 * @member jQuery.canvas
			 * 
			 * @since 6.14.0
			 */
			toDataURL: function(options){
				var defaults = $.extend({
					type: 'image/png',    // default MIME-Type
					index: 0        // index of the canvas-element
					}, options);

				return (this[defaults.index] && (this[defaults.index].toDataURL !== undefined))? this[defaults.index].toDataURL(defaults.type) : undefined;
			}

		});

	// default canvas attributes (getter and setter)
	$.each([
		'fillStyle',
		'strokeStyle',
		'lineWidth',
		'lineCap',
		'lineJoin',
		'globalAlpha',
		'globalCompositeOperation',
		'shadowOffsetX',
		'shadowOffsetY',
		'shadowBlur',
		'shadowColor',
		'miterLimit',
		'font'
	], function(i, method){
		fn[method] = function(){
			var args = arguments[0];

			// getter
			if(args === undefined){
				return this[0].ctx[method];
			// setter
			}else{
				return this.each(function(){
					this.ctx[method] = args;
				});
			}
		};
	});

	// default canvas methods
	$.each([
		'fillRect',
		'strokeRect',
		'clearRect',
		'drawImage',
		'fillText',
		'strokeText',
		'measureText',
		'rotate',
		'scale',
		'translate',
		'save',
		'restore',
		'createLinearGradient',
		'createRadialGradient',
		'createPattern',
		'getImageData',
		'putImageData',
		'arc',
		'arcTo',
		'beginPath',
		'bezierCurveTo',
		'clip',
		'closePath',
		'fill',
		'isPointInPath',
		'lineTo',
		'moveTo',
		'quadraticCurveTo',
		'rect',
		'stroke'
	], function(i, method){
		fn[method] = function(){
			var args = arguments;
			return this.each(function(){
				this.ctx[method].apply(this.ctx, args);
			});
		};
	});

	// write canvas plugin in jQuery Prototype
	/**
	 * See `jQuery.canvas` for details.
	 * 
	 * @method canvas
	 * @member jQuery
	 * 
	 * @since 6.14.0
	 */
	$.fn.canvas = function(options){
		var result = new qpCanvas();

		this.each(function(){
			result.push(init(this));
		});

		result.prevObject = this;

		return result;
	};

	return ep;

});

/* ---- Module:ep.fn.sendasform ---- */

/**
 * Send element as form.
 */

/*
 * @copyright       © Copyright 2006-2014, epages GmbH, All Rights Reserved.
 *
 * @module          ep.sendasform
 *
 * @revision        $Revision:
 */

/*jslint ass: false, unparam: true, nomen:true*/
/*globals define*/

define("ep/fn/sendasform", [
    "jquery",
    "ep",
    "util/storage",

    'jquery/cookie'
], function ($, ep, storage) {
    'use strict';

    var sendForm = function (elem, options) {
        var form = $('<form method="post" action="' + (options.additional.url ? options.additional.url : '?') + '" />'),
            cookie = $.cookie(options.additional.tokenName),
            formOptions = options.formOptions,
            _key;

        if (options.additional.target) {
            form.attr('target', options.additional.target);
        }

        for (_key in formOptions) {
            if (formOptions.hasOwnProperty(_key)) {
                form.append('<input type="hidden" name="' + _key + '" value="' + formOptions[_key] + '" />');
            }
        }

        // check if security token exists and add hidden input with security cookie information
        if (cookie && cookie !== null) {
            form.append('<input type="hidden" name="' + options.additional.tokenName + '" value="' + cookie + '" />');
        }

        // append form to document
        $(options.additional.body).append(form);

        // submit form
        if (options.additional.send) {
            form.trigger('submit');
        }
    };

    /**
     * Add a form to an element given by selector, inject a security token into and send it
     * @param  {Object}  options      Optional options
     * @param  {Object}  formOptions  key/value pairs representing name/value attributes for hidden inputs
     * @param  {Object}  additional   Additional options to control script
     * @param  {Object}  fn           Function that is executed when onclick-Event fires (before form is sent)
     * @param  {string}  body         Selector to identify the element into the form will be appended (default: 'body')
     * @param  {boolean} send         Indicator if the form is sent automatically (default: true)
     */
    ep.fn.sendAsForm = function (options) {
        var elem = this,
            additional = {
                target: false,
                tokenName: 'SecToken',
                body: 'body',
                send: true
            };

        options.additional = options.additional || {};

        // copy/overwrite additional
        $.extend(additional, options.additional);
        $.extend(options.additional, additional);

        elem.on('click', function (e) {
            e.preventDefault();

            if (typeof additional.fn === 'function') {
                additional.fn();
            }

            // delete product comparision from session storage on logout
            if (options.formOptions.ChangeAction && options.formOptions.ChangeAction === "Logout") {
                storage.sessionStorage('Product::ProductComparison', null);
            }

            sendForm(elem, options);
        });

        return this;
    };

    return ep;

});


/* ---- Module:de_epages.core ---- */

/*
 * @copyright		© Copyright 2006-2010, epages GmbH, All Rights Reserved.
 *
 * @module			de_epages/core
 *
 * @revision		$Revision: 1.4 $
 */

define("de_epages/core", ["de_epages"], function (de_epages) {
	return de_epages;
});;

/* ---- Module:de_epages.design.inc.sf-initialize ---- */

/*
 * @copyright		© Copyright 2006-2010, epages GmbH, All Rights Reserved.
 *
 * @module			de_epages/design/inc/sf-initialize
 *
 * @revision		$Revision: 1.4.4.1 $
 */

define("de_epages/design/inc/sf-initialize", [
	"jquery"
], function ($) {

	var win = $(window),
		// Regexp to find anchor jump mark
		anchorExp = /#([\w][\w\d\-]*)$/,
		// jump to position handle
		scrollFix = function( event, href ){
			var match = anchorExp.exec( href || $(this).attr('href') );
			if( match && !$(this).hasClass('ui-tabs-anchor') ){
				var refElem = $('#'+match[1]+', a[name="'+match[1]+'"]');
				if( refElem.length ){
					win.scrollTop( refElem.offset().top );
					event.preventDefault();
				}
			}
		};

	// handle jump to id on a site
	$(document).on( 'click', 'a', scrollFix );

	if( anchorExp.test(location.href) ){
			// fix anchor jump on page load
		var startUpFix = function(){
				clearInterval(intervalId);

				middle.scrollTop(0);

				scrollFix( $.Event(), location.href );
			},
			// check anchor jump on page load
			intervalCall = function(){
				intervalIndex++;
				if( intervalIndex >= 25 || middleChild.position().top < 0 ){
					startUpFix();
				}
			},
			// check count
			intervalIndex = 0,
			// check id
			intervalId,
			// container to fix
			middle,
			// first child of container
			middleChild;

		$.ready(function(){
			middle = $('.Middle').on('scroll',startUpFix);
			middleChild = middle.children(':first');
			// start check handle
			intervalId = setInterval(intervalCall,100);
		});
	}

	return {};

});

/* ---- Module:de_epages.catalog.ui.productlastviewed ---- */

/**
 * @cfg {Integer} maxItems A number between 1 and 10 to indicate the count of maximum displayed products.
 */

/**
 * Add a list of last viewed products.
 * 
 * The `.productLastViewed()` method append a list of last viewed products to each element in the set of matched elements.
 * 
 * This method depends on a storage controller in defined as ''Menu'' in the ''SF PageType'' named ''Script-ProductLastViewed''.
 * 
 * ### Examples
 * Perform an ajax request.
 * 
 * JavaScript:
 * 
 *     de_epages('#lastProducts')
 *         .productLastViewed({
 *             maxItems: 3
 *         });
 * 
 * HTML:
 * 
 *     <div id="lastProducts">
 *     </div>
 * 
 * Results:
 * 
 *     <div id="lastProducts">
 *       <ul class="de_epages-catalogUiProductLastViewed">
 *         <li>
 *           <a href="?ObjectPath=/Example1..."><img src="/Webroot...example1...image.jpg" />Example 1</a>
 *         </li>
 *         <li>
 *           <a href="?ObjectPath=/Example2..."><img src="/Webroot...example2...image.jpg" />Example 2</a>
 *         </li>
 *         <li>
 *           <a href="?ObjectPath=/Example3..."><img src="/Webroot...example3...image.jpg" />Example 3</a>
 *         </li>
 *       </ul>
 *     </div>
 * 
 * 
 * @param {Object} [options] A map of additional options pass to the method.
 * @param {Integer} maxItems A number between 1 and 10 to indicate the count of maximum displayed products.
 * 
 * @method productLastViewed
 * @member jQuery
 * 
 * @since 6.11.0
 */

/*
 * @copyright		© Copyright 2006-2010, epages GmbH, All Rights Reserved.
 *
 * @module			de_epages.catalog.ui.productLastViewed
 *
 * @revision		$Revision: 1.5.2.2 $
 */

define("de_epages/catalog/ui/productlastviewed", [
	"jquery",
	"de_epages",
	"util/storage",

	"jquery/ui/widget",
	"jquery/tmpl"
], function ($, de_epages, storage) {

	$.widget( 'ui.catalogUiProductLastViewed', {

		options: {
			maxItems: 5
		},

		_create: function(){
			this.listElem = $('<ul>').addClass('de_epages-catalogUiProductLastViewed');

			this.products = storage.localStorage('Catalog::ProductLastViewed.list');

			if( this.products ){

				var tstampMap = [],
					tstampData = [],
					tmplData = [],
					maxItems = this.options.maxItems-1;

				// create am map with tstamps to sort
				$.each( this.products, function( id, product ){
					tstampMap.push( product.tstamp );
					tstampData[ product.tstamp ] = product;
				});

				// sort
				tstampMap = tstampMap.sort().reverse();

				// push products in the right order
				$.each( tstampMap, function( i, tstamp ){
					tmplData.push( tstampData[ tstamp ] );

					if( i >= maxItems ){
						return false;
					}
				});

				// append elements via template
				this.element.append( this.listElem.append( $.tmpl( '<li><a href="?ObjectPath=${objectPath}"><img src="${image}" />${name}</a></li>', tmplData ) ) );
			}
		},

		destroy: function(){
			this.listElem.remove();

			this._superApply(arguments);
		}
	});

	return de_epages;

});

/* ---- Module:de_epages.productcomparison.ui.productcompare ---- */

/*
 * @copyright		© Copyright 2006-2010, epages GmbH, All Rights Reserved.
 *
 * @module			de_epages/productcomparison/ui/productcompare
 *
 * @revision		$Revision: 1.1.22.1 $
 */

define("de_epages/productcomparison/ui/productcompare", [
	"jquery",
	"de_epages",
	"util/storage",

	"jquery/ui/widget",
	"ep/ui/input",
	"ep/ui/tooltip"
], function ($, de_epages, storage) {

	$.widget('ui.productcomparisonUiProductcompare', {

		options: {
			maxItemNo:              8,
			minItemNo:              2,
			productID:              undefined,
			tooltipTooManyProducts: undefined,
			tooltipNoProducts:      undefined
		},

		_create: function(){
			var self = this.element,
				checkboxID = self.attr('id'),
				productID = this.options.productID,
				label = $('#'+checkboxID).nextAll('label'),
				link = label.children('a').first();

			/* check product id */
			if (!this._check(productID, link)){
				return;
			}

			this.options.label = label;
			this.options.checkboxID = checkboxID;

			/* add 'click' event handler on associated 'Compare' link */
			label.on('click', $.proxy(function(event) {
				this._handleClick(event, link, self);
			}, this));

			/* create checkbox, (un)tick checkbox, and add 'change' event handler */
			$(self).uiInput();
			this._tick(productID);
			self.on('change', $.proxy(function(event) {
				this._handleChange(event, self);
			}, this));
		},

		_check: function(productID, link) {
			if (productID === undefined || isNaN(parseInt(productID)) || link.length === 0){
				console.warn('ProductComparison: parameter \'productID\' and/or \'compare\' link missing; product comparison is removed from SF.');
				self.remove();
				if (label.length > 0){
					label.remove();
				}
				return false;
			}
			return true;
		},

		_tick: function(productID) {
			var productList = storage.sessionStorage('Product::ProductComparison') || [],
				isSelected = ($.inArray(productID, productList) > -1) ? true : false;
            this.element.prop('checked', isSelected);
		},

		_handleClick: function(event, target, parent) {
			event.preventDefault();
			var productIDs = storage.sessionStorage('Product::ProductComparison') || [],
				url = target.attr('href');

			this._addProductToComparisonList(this.options.productID, productIDs);
			storage.sessionStorage('Product::ProductComparison', productIDs);
			if (productIDs.length < this.options.minItemNo){
				parent.prop('checked', true);
				this._showTooltip('NoProductsInComparisonList', this.options.tooltipNoProducts, target);
				return;
			}

			$.each(productIDs, function(index, value){
				url += '&SelectedObjectID=' + value;
			});
			window.location = url;
		},

		_handleChange: function(event, target) {
			var productIDs = storage.sessionStorage('Product::ProductComparison') || [],
				productID = this.options.productID,
				isSelected = false;

			target = $('#'+target.attr('id'));
			if (target.is(':checked')){  // add product to comparison list
				if (productIDs.length >= this.options.maxItemNo){
					target.prop('checked', isSelected);
					this._showTooltip('TooManyComparisonProducts', this.options.tooltipTooManyProducts, target);
					return;
				}
				this._addProductToComparisonList(productID, productIDs);
				isSelected = true;
			} else {  // remove product from comparison list
				productIDs = $.grep(productIDs, function (value){
					return value != productID;
				});
			}
			target.prop('checked', isSelected);
			storage.sessionStorage('Product::ProductComparison', productIDs);
		},

		_addProductToComparisonList: function(productID, productIDs) {
			var index = $.inArray(productID, productIDs);
			if (index > -1){  // deletes former occurrence
				productIDs.splice(index, 1);
			}
			productIDs.push(productID);
			while (productIDs.length > this.options.maxItemNo){
				productIDs.shift();
			}
		},

		_showTooltip: function(id, message, element) {
			if (message === undefined){
				console.warn('ProductComparison: No tooltip message is defined.');
				return;
			}

			var template = $($('#'+id+'Tooltip'));
			if (!template[0]){
				template = $('<div id="'+id+'Tooltip" class="Message Medium Notification Wide"><div class="Headline"></div><div class="MessageDetails"><span class="ExtractedContentAreaElement">'+message+'</span></div></div>')
					.uiTooltip({ interactive: true, orientation: 'bottom center', event: 'click' });
			}
			template.uiTooltip({ context: element });
			template.uiTooltip('show');
		},

		destroy: function() {
			var options = this.options;
			$(this.element).uiInput('destroy');
			$('#'+options.checkboxID).off('change');
			options.label.off('click');

			return this._superApply(arguments);
		}

	});

	return de_epages;

});

/* ---- Module:de_epages.productcomparison.ui.comparelink ---- */

/*
 * @copyright		© Copyright 2006-2010, epages GmbH, All Rights Reserved.
 *
 * @module			de_epages/productcomparison/ui/comparelink
 *
 * @revision		$Revision: 1.2.22.1 $
 */

define("de_epages/productcomparison/ui/comparelink", [
	"jquery",
	"de_epages",
	"util/storage",

	"jquery/ui/widget"
], function ($, de_epages, storage) {

	$.widget('ui.productcomparisonUiComparelink', {

		options: {
			maxItemNo:              8,
			productID:              undefined
		},

		_create: function(){
			var self = this.element,
				productID = this.options.productID;

			/* check product id */
			if (!this._check(productID, self)){
				return;
			}

			/* add 'click' event handler on associated 'Compare' link */
			self.on('click', $.proxy(function(event) {
				this._handleClick(event, self);
			}, this));
		},

		_check: function(productID) {
			if (productID === undefined || isNaN(parseInt(productID))){
				console.warn('ProductComparison: parameter \'productID\' and/or \'compare\' link missing; product comparison is removed from SF.');
				self.remove();
				return false;
			}
			return true;
		},

		_handleClick: function(event, target) {
			var productIDs = storage.sessionStorage('Product::ProductComparison') || [],
				url = target.attr('href');

			event.preventDefault();

			this._addProductToComparisonList(this.options.productID, productIDs);

			storage.sessionStorage('Product::ProductComparison', productIDs);

			$.each(productIDs, function(index, value){
				url += '&SelectedObjectID=' + value;
			});

			window.location = url;
		},

		_addProductToComparisonList: function(productID, productIDs) {
			var index = $.inArray(productID, productIDs);

			if (index > -1){  // deletes former occurrence
				productIDs.splice(index, 1);
			}

			productIDs.push(productID);

			while (productIDs.length > this.options.maxItemNo){
				productIDs.shift();
			}
		},

		destroy: function() {
			this.off('click');

			return this.Inherited(arguments);
		}

	});

	return de_epages;

});

/* ---- Module:jquery.metaparse ---- */

/*
 * @author			Evan Vosberg
 * @copyright		© 2012 by Evan Vosberg
 * @info			http://github.com/evanvosberg
 *
 * @license			Licensed under the MIT (http://www.opensource.org/licenses/mit-license.php) license.
 *
 * @module			jquery/metaparse
 */


define("jquery/metaparse", ["jquery", "module"], function ($, mod, undefined) {

	var doc = document,

		metaExp = /(?:(?:^|\s+)((?:[\$\w]+)?)((?:\.(?:require|ready)\([^\)]*\))?)(\.[\$\w]+\(.*\)))/,

		requireExp = /^\.require/,

		/* >>>> DEPRECATED >>>> */
		readyExp = /^\.ready/,
		/* <<<< DEPRECATED <<<< */

		promiseDone = $.Deferred()
			.resolve()
			.promise(),

		promiseFail = $.Deferred()
			.reject()
			.promise(),

		metaparse = function (data) {
			var meta = {};

			meta.data = data.replace(metaExp, function (m, m1, m2, m3) {
				meta.depend = m2;
				meta.execute = (m1 || "jQuery") + "(elem)" + m3;

				return "";
			});

			return meta;
		},

		// Set internal already parsed status
		isMetaparsed = function (elem, set) {
			return set === undefined ? $._data(elem)
				.metaparsed : ($._data(elem)
				.metaparsed = set);
		},

		config = $.metaparseSettings = $.extend({
			type: "class",
			name: "metaparse"
		}, mod.config()),

		// Indicates automatically run on dom ready
		autoparse;

	/* >>>> DEPRECATED >>>> */
	if ($.config && $.config.metaparse) {
		/*global console*/
		if (typeof console !== "undefined" && console.warn) {
			console.warn("DEPRECATED: use 'module config of requirejs' instead of 'jQuery.config.metaparse'.");
		}

		$.extend(config, $.config.metaparse);
	}
	/* <<<< DEPRECATED <<<< */

	$.extend({
		metaparse: function (elem, settings /*internal*/ , isEach) {
			// Check whether elem is already parsed
			if (!isMetaparsed(elem)) {
				var s = isEach ? settings : $.extend({}, config, settings),
					type = s.type,
					name = s.name,
					meta = {},
					execute,
					depend,
					deferred,
					temp;

				if (type === "class") {
					meta = metaparse(elem.className);
					elem.className = meta.data;
				}
				else if (type === "elem") {
					if (!elem.getElementsByTagName) {
						return;
					}

					if ((temp = elem.getElementsByTagName(name)[0])) {
						meta = metaparse(temp.innerHTML);
						temp.innerHTML = meta.data;
					}
				}
				else if (elem.getAttribute !== undefined) {
					if (type === "html5" || type === "data") {
						name = "data-" + name;
					}

					if ((temp = elem.getAttribute(name))) {
						meta = metaparse(temp);
						elem.setAttribute(name, meta.data);
					}
				}

				// $.globalEval isn't faster then eval this short string
				if ((execute = meta.execute)) {
					temp = function () {
						isMetaparsed(elem, true);
						/*jshint evil:true */
						eval(execute);

						if (deferred) {
							deferred.resolve();
						}
					};

					depend = (depend = meta.depend);
					if ((depend = depend && requireExp.test(depend) && depend.replace(requireExp, ""))) {
						deferred = $.Deferred();
						/*jshint evil:true */
						require(eval(depend), temp);
						return deferred.promise();
					}
					/* >>>> DEPRECATED >>>> */
					if ((depend = depend && readyExp.test(depend) && depend.replace(readyExp, ""))) {
						/*jshint evil:true */
						return $.ready(eval(depend), temp);
					}
					/* <<<< DEPRECATED <<<< */
					else {
						temp();
						return promiseDone;
					}
				}
			}

			return promiseFail;
		}
	});

	$.fn.extend({
		metaparse: function (settings /*internal*/ , isAutoparse) {
			var s = $.extend({}, config, settings),
				self = this,
				stack = [],
				depend;

			self.each(function () {
				if ((depend = $.metaparse(this, s, true))
					.state() !== "rejected") {
					stack.push(depend);
				}
			});

			$.when.apply($, stack)
				.done(function () {
					self.each(function () {
						$.event.trigger("metaparse", null, this, true);
					});

					if (isAutoparse) {
						isMetaparsed(doc, true);
						$.event.trigger("metaparse", null, doc, true);
					}

				});

			return self;
		}
	});

	$.event.special.metaparse = {
		// Don't add real event
		setup: $.noop,

		// Add special handler
		add: function (bind) {
			// Execute handler immediately if elem is already parsed
			if (isMetaparsed(this)) {
				bind.handler.call(this, $.Event("metaparse"));
			}
		}
	};

	// Run metaparse automatically on dom ready if defined in config
	function runAutoparse() {
		$(function () {
			$(autoparse.selector || (typeof autoparse === "string" ? autoparse : ".metaparse"))
				.metaparse({}, true);
		});
	}

	if ((autoparse = config.autoparse)) {
		if (autoparse.require) {
			require(autoparse.require, runAutoparse);
		}
		/* >>>> DEPRECATED >>>> */
		else if (autoparse.ready) {
			$.ready(autoparse.ready, runAutoparse);
		}
		/* <<<< DEPRECATED <<<< */
		else {
			runAutoparse();
		}

		delete $.metaparseSettings.autoparse;
	}

	return $;

});